(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    737446,      20888]
NotebookOptionsPosition[    726776,      20588]
NotebookOutlinePosition[    727151,      20604]
CellTagsIndexPosition[    727108,      20601]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Friedmann equations in kinetic gravity braiding", "Section",
 CellChangeTimes->{{3.7776839679253263`*^9, 3.777683978264307*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7776845095196247`*^9, 3.77768451030444*^9}}],

Cell["\<\
Author: Reggie Bernardo (rbernardo@nip.upd.edu.ph)

In this notebook, we derive the Friedmann equations in kinetic gravity \
braiding. In doing so, we mostly use xAct\[CloseCurlyQuote]s derivative xCoba \
for component calculations. We also borrow Cyril Pitrou\[CloseCurlyQuote]s \
(CP) code for variational differentiation to derive the covariant field \
equations.\
\>", "Text",
 CellChangeTimes->{{3.7776839874671593`*^9, 3.7776840999033537`*^9}, {
  3.777684175044571*^9, 3.777684176293292*^9}, {3.777684376105797*^9, 
  3.777684427833199*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0.1 Setup",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777684103615888*^9, 3.777684108386374*^9}, 
   3.7776846492181263`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xCoba"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"<<", "xAct`xCoba`"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "    ", "\[IndentingNewLine]", 
   RowBox[{"DefManifold", "[", 
    RowBox[{"M", ",", "dim", ",", 
     RowBox[{"{", 
      RowBox[{
      "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", "j", ",", 
       "k", ",", "l", ",", "p", ",", "q", ",", "r", ",", "s"}], "}"}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"DefMetric", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"g", "[", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "]"}], ",", "CD", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
     RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Detg", "]"}], "^=", "\"\<g\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "define", " ", "scalar", " ", "field", " ", "and", " ", "potentials"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], ",", "M"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "K", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "G", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.7776842285875587`*^9, {3.777684343005937*^9, 3.77768437303294*^9}, {
   3.777684449042101*^9, 3.777684630351591*^9}, {3.777685859005588*^9, 
   3.777685859671356*^9}, {3.777686291180215*^9, 3.777686292009376*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.77777883227142*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.77777883227142*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832318284*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832440668*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832440668*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832440668*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788324561214`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326188803`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326253867`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326253867`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326253867`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832641023*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832641023*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832641023*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326566358`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326566358`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326566358`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326722565`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326722565`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326722565`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326878777`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326878777`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788326878777`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788327034993`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788328258705`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832841499*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832841499*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788328571177`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788328571177`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788328727393`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788328727393`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832888362*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832888362*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832903983*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832903983*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832903983*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832926113*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832926113*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832941743*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778833019861*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788331201077`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778833142245*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788331578665`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788332893505`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788333271103`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788333271103`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788333427477`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "K", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", "scalar function ", K,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788333427477`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "G", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`G, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.7777788333427477`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778833358366*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0.2 CP code",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.77768465587844*^9, 3.777684673012726*^9}}],

Cell["\<\
Here is the code by CP that we use for deriving the covariant field equations.\
\>", "Text",
 CellChangeTimes->{{3.777684697448556*^9, 3.777684715449011*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "UpIndexQ"}], ",", 
       RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "DownIndexQ"}], ",", 
       RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
      RowBox[{"(*", 
       RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}], 
      ",", " ", 
      RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dgloc", "=", 
      RowBox[{"SymbolJoin", "[", 
       RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"hp", "=", 
      RowBox[{"Head", "@", 
       RowBox[{"Perturbation", "[", 
        RowBox[{"g", "[", 
         RowBox[{
          RowBox[{"DownIndex", "@", "a"}], ",", 
          RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"hp", "===", "Perturbation"}], ",", 
       RowBox[{"DefMetricPerturbation", "[", 
        RowBox[{"g", ",", "dgloc", ",", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
       RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
         "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
         " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", " ", 
         "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pertexpr", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
              RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
           RowBox[{"ToCanonical", "@", 
            RowBox[{"ContractMetric", "@", 
             RowBox[{"ExpandPerturbation", "@", 
              RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
          RowBox[{
           RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
           "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"We", " ", "then", " ", "use", " ", 
          RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", " ", 
          "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ", 
          "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
          "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dgloc", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], "]"}],
                  ",", 
                 RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
               "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
          " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
          "tensor"}], ",", " ", 
         RowBox[{
         "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", "the", 
          " ", "formal", " ", "first", " ", "order", " ", "perturbation", " ",
           "the", " ", "tensor"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
         "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"inds", "=", 
         RowBox[{"DummyIn", "/@", 
          RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "@@", "inds"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
          "and", " ", "replace", " ", 
          RowBox[{"Perturbation", "[", 
           RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", "this", 
          " ", "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", " ", 
          RowBox[{"VarD", " ", "works", " ", 
           RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need", 
           " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
           "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
               "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "@", 
     RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
    "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "VarD", " ", "and", " ", "removal", " ", "of", " ", 
          "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], "]"}],
                "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"g_", "?", "MetricQ"}], "[", 
     RowBox[{"as__", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
          RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
     "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sqrtg", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
        RowBox[{
         RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ToCanonical", "[", 
      RowBox[{
       RowBox[{"PerturbAction", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"sqrtg", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
         RowBox[{"Not", "[", 
          RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", "tensor", ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}]}], "]"}], ":=", 
    RowBox[{"VarAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
          RowBox[{"Not", "[", 
           RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}],
      "[", "inds___", "]"}], ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VarAction", "[", 
    RowBox[{"expr_", ",", 
     RowBox[{
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
   RowBox[{"VarAction", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"tensor", "[", "inds", "]"}], ",", 
     RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["I. Kinetic gravity braiding",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777684771051243*^9, 3.777684777686041*^9}}],

Cell["\<\
Kinetic gravity braiding is defined by the following Lagrangian.\
\>", "Text",
 CellChangeTimes->{{3.777685051160142*^9, 3.777685071298682*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "b", "]"}], "[", 
     RowBox[{"\[Phi]", "[", "]"}], "]"}], 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "b"}], "]"}], "[", 
     RowBox[{"\[Phi]", "[", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LK", "=", 
   RowBox[{"K", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", "]"}], ",", "X"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{"quadratic", " ", "sector"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LG", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"G", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "]"}], ",", "X"}], "]"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "i", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "i"}], "]"}], "[", 
      RowBox[{"\[Phi]", "[", "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LEH", "=", 
    RowBox[{"\[Kappa]", " ", 
     RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", 
  RowBox[{"LK", "+", "LG", "+", "LEH"}]}]}], "Input",
 CellChangeTimes->{{3.7776850890641727`*^9, 3.777685188201232*^9}, {
  3.777685232922462*^9, 3.777685328684702*^9}, {3.777685885612694*^9, 
  3.777685891586584*^9}}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     K,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False]}]}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "-", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}]}], "]"}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "i"], 
       SubscriptBox["\[Del]", "i"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`i][
      $CellContext`CD[-$CellContext`i][
       $CellContext`\[Phi][]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{3.7776858921055403`*^9, 3.777686312077167*^9, 
  3.777686750087504*^9, 3.777686833416018*^9, 3.7776876921697273`*^9, 
  3.7776879990617847`*^9, 3.777688061840715*^9, 3.777774900298315*^9, 
  3.7777788451422434`*^9}]
}, Open  ]],

Cell["\<\
For the rest of this section, we derive the covariant field equations from \
this Lagrangian. Finally, we bring it down to component form by using the \
spatially flat FRW metric.\
\>", "Text",
 CellChangeTimes->{{3.777685375452651*^9, 3.777685460201378*^9}}],

Cell[CellGroupData[{

Cell["Background field equations", "Subsubsection",
 CellChangeTimes->{{3.777685478944446*^9, 3.777685481993011*^9}}],

Cell[TextData[{
 "For clarity, we separate the analysis into the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence (defined by ",
 StyleBox["K",
  FontSlant->"Italic"],
 "), braiding (defined by ",
 StyleBox["G",
  FontSlant->"Italic"],
 ") and Einstein-Hilbert sectors (tracked by \[Kappa]). \n\nThe contributions \
to the metric field equation (modified Einstein equation) are as follows."
}], "Text",
 CellChangeTimes->{{3.777685562579516*^9, 3.777685695300316*^9}, {
  3.777686048518564*^9, 3.777686054051899*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MFEbgK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"VarAction", "[", 
       RowBox[{"LK", ",", 
        RowBox[{"g", "[", 
         RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
      "ToCanonical"}], "//", "NoScalar"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MFEbgG", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"VarAction", "[", 
       RowBox[{"LG", ",", 
        RowBox[{"g", "[", 
         RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
      "ToCanonical"}], "//", "NoScalar"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MFEbgEH", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"LEH", ",", 
         RowBox[{"g", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "RicciToEinstein"}], "//", "ToCanonical"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MFEbgEH", "+", "MFEbgK", "+", "MFEbgG"}], "\[Equal]", 
  "\"\<8 \[Pi] \!\(\*SubscriptBox[SuperscriptBox[\(T\), \((M)\)], \(bc\)]\)\>\
\""}]}], "Input",
 CellChangeTimes->{{3.7776857000160217`*^9, 3.777685820606783*^9}, {
  3.77768590902424*^9, 3.7776859472749968`*^9}, {3.7776859825127287`*^9, 
  3.777685995319107*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686315060945*^9, 3.7776867501475697`*^9, 
  3.777686833529635*^9, 3.777687692229*^9, 3.777687999115205*^9, 
  3.777688061895612*^9, 3.7777749003673067`*^9, 3.7777788451735253`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686315060945*^9, 3.7776867501475697`*^9, 
  3.777686833529635*^9, 3.777687692229*^9, 3.777687999115205*^9, 
  3.777688061895612*^9, 3.7777749003673067`*^9, 3.7777788451891136`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "e"], 
       SubscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \
\\((M)\\)], \\(bc\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{
  3.7776858223690443`*^9, 3.77768590307835*^9, 3.777685950506002*^9, {
   3.77768598845282*^9, 3.7776859964171047`*^9}, 3.7776863155900593`*^9, 
   3.777686750738288*^9, 3.777686834121142*^9, 3.777687692803525*^9, 
   3.7776879997021103`*^9, 3.7776880624830637`*^9, 3.7777749011159267`*^9, 
   3.7777788459597993`*^9}]
}, Open  ]],

Cell["\<\
The contributions to the scalar field equation are as follows.\
\>", "Text",
 CellChangeTimes->{{3.7776860372102003`*^9, 3.7776860454678583`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BSEbgK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"VarAction", "[", 
       RowBox[{"LK", ",", 
        RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
      "ToCanonical"}], "//", "NoScalar"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BSEbgG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"LG", ",", 
         RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "ToCanonical"}], "//", "NoScalar"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BSEbgK", "+", "BSEbgG"}], "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7776860788488817`*^9, 3.777686143256228*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SubscriptBox["\[Del]", "c"], 
        SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[-$CellContext`c][
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.777686144760418*^9, 3.777686320706005*^9, 
  3.777686751287487*^9, 3.777686834684125*^9, 3.777687693385708*^9, 
  3.777688000265327*^9, 3.777688063051939*^9, 3.777774901848841*^9, 
  3.7777788466927967`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["II. Friedmann equations",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777686179101707*^9, 3.777686184072307*^9}}],

Cell["\<\
In this section, we use xCoba to reduce the covariant expressions derived \
previously into their component forms in FRW spacetime. We start, of course, \
by defining the chart and the FRW metric.\
\>", "Text",
 CellChangeTimes->{{3.7776861974948483`*^9, 3.7776862533410788`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "define", " ", "chart", " ", "B", " ", "in", " ", "manifold", " ", "M"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefChart", "[", 
     RowBox[{"B", ",", "M", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"t", "[", "]"}], ",", 
        RowBox[{"x", "[", "]"}], ",", 
        RowBox[{"y", "[", "]"}], ",", 
        RowBox[{"z", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "scale", " ", "factor", " ", "a", 
     StyleBox[
      RowBox[{"(", "t", ")"}],
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], "and", " ", "FRW", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "a", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FRW", "=", 
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"]}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "tell", " ", "xCoba", " ", "FRW", " ", "is", " ", "the", " ", "metric", 
     " ", "and", " ", "compute", " ", "curvature", " ", "quantities"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricInBasis", "[", 
     RowBox[{"g", ",", 
      RowBox[{"-", "B"}], ",", "FRW"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricCompute", "[", 
     RowBox[{"g", ",", "B", ",", "All", ",", 
      RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.777686278318387*^9, 3.777686283132815*^9}, {
  3.777686345022435*^9, 3.777686431063656*^9}, {3.7776866634874153`*^9, 
  3.7776867062141743`*^9}, {3.777686803669854*^9, 3.777686804238579*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefChart", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"chart \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefChart, ": Defining ", "chart ", $CellContext`B, ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"t", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`t[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"x", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`x[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852500879*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"y", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`y[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852500879*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"z", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`z[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852516493*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", "mapping ", $CellContext`B, 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852516493*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse mapping \"\>", "\[InvisibleSpace]", "iB",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", 
   "inverse mapping ", $CellContext`iB, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852516493*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"diB", "[", 
    RowBox[{
     RowBox[{"-", "\[FormalA]"}], ",", "iBb"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`diB[-\[FormalA], $CellContext`iBb], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852532113*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"dB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", "B\[FormalA]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`dB[-$CellContext`b, $CellContext`B\[FormalA]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852532113*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefBasis", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"basis \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Coordinated basis.\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefBasis, ": Defining ", "basis ", $CellContext`B, ". ", 
   "Coordinated basis."],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852532113*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parallel derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"PDB", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "parallel derivative ", 
   $CellContext`PDB[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852547733*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionPDB[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852554242*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelPDB[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852554242*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Riemann tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RiemannPDB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", "e"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Riemann tensor ", 
   $CellContext`RiemannPDB[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852554242*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciPDB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Ricci tensor ", 
   $CellContext`RicciPDB[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852569868*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric +1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaUpB", "[", 
    RowBox[{"b", ",", "c", ",", "d", ",", "e"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric +1 density ", 
   $CellContext`etaUpB[$CellContext`b, $CellContext`c, $CellContext`d, \
$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852569868*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric -1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaDownB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric -1 density ", 
   $CellContext`etaDownB[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852569868*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "a", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`a, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788525854893`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", "1"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> -1, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788525854893`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852601123*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852601123*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788526167336`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852632356*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852654487*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852654487*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788526701155`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788526857347`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788526857347`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852701366*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.77777885271698*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.77777885271698*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788527326045`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788527547293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788527547293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetgB", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetgB[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.777778852770358*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelCDPDB[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788528016014`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We now define the matter SET and also assume that the scalar field respects \
the isotropy and homogeneity of the spacetime, i.e, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "(", "t", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.777687075777155*^9, 3.7776871480056753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PF", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"\[Rho]", "[", 
        RowBox[{"t", "[", "]"}], "]"}]}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComponentValue", "[", 
    RowBox[{
     RowBox[{"ComponentArray", "[", 
      RowBox[{"T", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"b", ",", "B"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"c", ",", "B"}], "}"}]}], "]"}], "]"}], ",", "PF"}], "]"}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"compute", " ", "down"}], "-", 
    RowBox[{
    "down", " ", "components", " ", "of", " ", "matter", " ", "SET"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ChangeComponents", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", "B"}], "}"}]}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"matter", " ", "SET"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(T\), \(a\)], \(b\)]\)\>\"", 
   "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{
           RowBox[{"-", "b"}], ",", 
           RowBox[{"-", "c"}]}], "]"}], "//", 
         RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
        "ToValues"}], "//", "ToValues"}], "//", "MatrixForm"}], ")"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "in", " ", "FRW"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"\[Phi]0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(0\)]\)\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComponentValue", "[", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "]"}], ",", " ", 
    RowBox[{"\[Phi]0", "[", 
     RowBox[{"t", "[", "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.777687168943804*^9, 3.77768729132369*^9}, 
   3.777687329868163*^9, {3.777687380512602*^9, 3.777687380956182*^9}, {
   3.777687591270731*^9, 3.7776876239071608`*^9}, {3.7776876647361097`*^9, 
   3.777687665072289*^9}, {3.777687809350095*^9, 3.777687809842127*^9}, {
   3.7776879675610027`*^9, 3.777687974209988*^9}, {3.7776880433914824`*^9, 
   3.777688044880334*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`T[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{0, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530177174`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"\[Rho]", "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     0, -$CellContext`B}] -> -$CellContext`\[Rho][
      $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530177174`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853033333*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853033333*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530554633`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530711036`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530711036`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853086712*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788531023436`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.77777885311796*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.77777885311796*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853133579*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853133579*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788531557107`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788531557107`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`T[{2, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853171338*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.77777885318696*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.77777885318696*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788532025795`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788532182026`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853233823*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853233823*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`T[{2, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788532559843`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788532559843`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`T[{3, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788532716427`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{3, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788532716427`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788533028536`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853349719*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788533874784`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788534343863`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788534499645`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788535033464`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788535345902`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788535879984`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788536192584`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853634867*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788536882467`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788537038617`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], 
   " by ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788537572465`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778853788495*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788538353653`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788538509865`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788538887453`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788539043665`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], 
   " by ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788539577665`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788539733953`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], 
   " by ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778854020258*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.777778854058017*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["b",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["c",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{-$CellContext`b, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["d",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["c",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{-$CellContext`d, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"T", 
          StyleBox[GridBox[{
             {" ", 
              StyleBox["d",
               FontColor->RGBColor[1., 0., 0.]]},
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`T[{-$CellContext`b, -$CellContext`B}, {$CellContext`d, \
$CellContext`B}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.7863743`7.347174305097051", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`T[{-$CellContext`b, -$CellContext`B}, \
{-$CellContext`c, -$CellContext`B}] -> $CellContext`g[{-$CellContext`d, \
-$CellContext`B}, {-$CellContext`c, -$CellContext`B}] \
$CellContext`T[{-$CellContext`b, -$CellContext`B}, {$CellContext`d, \
$CellContext`B}], " in ", 0.7863743`7.347174305097051, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788540736465`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \\(a\\)], \
\\(b\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"\[Rho]", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "0", "0", "0"},
      {"0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "0", "0"},
      {"0", "0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "0"},
      {"0", "0", "0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.777687354562492*^9, 3.77768771134719*^9, 
  3.777688017053129*^9, 3.77768807695894*^9, 3.777774913194344*^9, 
  3.7777788540892677`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Phi]0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Phi]0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788541048865`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Phi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Phi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[Phi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Phi][] -> $CellContext`\[Phi]0[
     $CellContext`t[]], " for tensor ", $CellContext`\[Phi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788541048865`*^9}]
}, Open  ]]
}, Open  ]],

Cell["The scalar field\[CloseCurlyQuote]s kinetic density becomes...", "Text",
 CellChangeTimes->{{3.777688706101716*^9, 3.7776887133805523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Xcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"X", "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<X\>\"", "\[Equal]", "Xcomp"}]}], "Input"],

Cell[BoxData[
 RowBox[{"\<\"X\"\>", "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.777688756737903*^9, 3.7777749132633443`*^9, 
  3.7777788541582656`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence sector"
}], "Subsubsection",
 CellChangeTimes->{{3.777688122624342*^9, 3.777688129588325*^9}}],

Cell[TextData[{
 "The following rule simplifies the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potentials explicitly appearing in the field equations."
}], "Text",
 CellChangeTimes->{{3.777689243948004*^9, 3.777689262601183*^9}, {
  3.777689578804942*^9, 3.777689584271594*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplifyK", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{"K", "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "The ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence sector of the metric field equation becomes..."
}], "Text",
 CellChangeTimes->{{3.777688102903036*^9, 3.777688103802415*^9}, {
   3.777688140918531*^9, 3.7776881801810207`*^9}, {3.7776892885004587`*^9, 
   3.777689289129653*^9}, 3.777689431347332*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcompK", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MFEbgK", "/.", "simplifyK"}], "//", 
       RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
     "ToValues"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcompK", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7776882968747187`*^9, 3.777688298546734*^9}, {
  3.777688362302208*^9, 3.7776884232164297`*^9}, {3.777689307076829*^9, 
  3.777689399529705*^9}, {3.7776895627183857`*^9, 3.777689566872184*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["K",
           ShowAutoStyles->False,
           AutoSpacing->False],
          K,
          Editable->False], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["K",
            ShowAutoStyles->False,
            AutoSpacing->False],
           K,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}]}], "]"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}]}], "]"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}]}], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.777688299113648*^9, {3.777688365726948*^9, 3.777688423760202*^9}, {
   3.777689370900238*^9, 3.777689400361327*^9}, 3.777689567350685*^9, 
   3.7777749133323374`*^9, 3.7777788542207603`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["k-",
  FontSlant->"Italic"],
 "essence sector of the scalar field equation becomes..."
}], "Text",
 CellChangeTimes->{{3.7776894086870604`*^9, 3.777689427441592*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSEcompK", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"BSEbgK", "/.", "simplifyK"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "BSEcompK"}], "Input",
 CellChangeTimes->{{3.777689506690275*^9, 3.777689523879896*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     K,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], ",", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"]}]}], "]"}], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.777689524632443*^9, 3.7777749134325795`*^9, 
  3.7777788543053923`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["braiding sector", "Subsubsection",
 CellChangeTimes->{{3.777688184006239*^9, 3.777688185896373*^9}}],

Cell["\<\
The following rule simplifies the braiding potentials explicitly appearing in \
the field equations.\
\>", "Text",
 CellChangeTimes->{{3.777689591562269*^9, 3.777689596602059*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplifyG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi][],
         Editable->False], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            StyleBox["(",
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             InterpretationBox[
              StyleBox[
               RowBox[{
                SubscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[-$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`CD[$CellContext`b][
               $CellContext`\[Phi][]],
              Editable->False]}], 
            StyleBox[")",
             FontColor->RGBColor[1, 0, 0]]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]]],
          Editable->False]}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}]}], "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.777689693212407*^9, 3.777689698564372*^9}, 
   3.7776898972258472`*^9}],

Cell["The braiding sector of the metric field equation becomes...", "Text",
 CellChangeTimes->{{3.777688191499263*^9, 3.777688196325246*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcompG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MFEbgG", "/.", "simplifyG"}], "//", 
            RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
           "TraceBasisDummy"}], "//", "ToValues"}], "//", "ToValues"}], "//", 
       RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//", 
     "ToValues"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcompG", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.777689907911278*^9, 3.7776899274376907`*^9}, {
  3.777690075127079*^9, 3.7776900758801317`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False], "]"}], "2"]}]}], "]"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776899188625603`*^9, 3.777689928107102*^9}, 
   3.7776900796798573`*^9, 3.777774914699628*^9, 3.7777788554549522`*^9}]
}, Open  ]],

Cell["The braiding sector of the scalar field equation becomes...", "Text",
 CellChangeTimes->{{3.7776909751880207`*^9, 3.777690982623814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSEcompG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"BSEbgG", "/.", "simplifyG"}], "//", 
             RowBox[{"SeparateMetric", "[", "g", "]"}]}], "//", 
            RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
           "ToValues"}], "//", "ToValues"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "BSEcompG"}], "Input",
 CellChangeTimes->{{3.7776909883971148`*^9, 3.7776910016389427`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}]}], "]"}]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "3"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "3"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.777691106014162*^9, 3.777775054405594*^9, 
  3.7777789804754457`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Einstein-Hilbert sector", "Subsubsection",
 CellChangeTimes->{{3.777688201163343*^9, 3.777688207778205*^9}}],

Cell["\<\
The Einstein-Hilbert part of the metric field equation leads to the \
well-known expression...\
\>", "Text",
 CellChangeTimes->{{3.777688213392612*^9, 3.777688254005632*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcompEH", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MFEbgEH", "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
      "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcompEH", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7776882690362864`*^9, 3.77768827442028*^9}, {
  3.777688304780467*^9, 3.777688307637043*^9}, {3.777689533780676*^9, 
  3.777689554857657*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]], "0", "0", "0"},
     {"0", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`a,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]}], ")"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`a,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]}], ")"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`a,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776882700069513`*^9, 3.777688274856617*^9}, 
   3.77768830809842*^9, {3.777689543457099*^9, 3.777689555592108*^9}, 
   3.7777750544961696`*^9, 3.777778980542407*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matter sector", "Subsubsection",
 CellChangeTimes->{{3.7776918567665777`*^9, 3.7776918584310303`*^9}}],

Cell["\<\
The matter sector is defined by the perfect fluid in the usual way, i.e.,...\
\>", "Text",
 CellChangeTimes->{{3.777691860535028*^9, 3.777691879356771*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Tcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          RowBox[{"-", "b"}], ",", 
          RowBox[{"-", "c"}]}], "]"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
      "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Tcomp", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.777691882286499*^9, 3.777691908500108*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Rho]", "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "0", "0", "0"},
     {"0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776918927994843`*^9, 3.7776919090199127`*^9}, 
   3.7777750545163126`*^9, 3.777778980573655*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Friedmann equations", "Subsubsection",
 CellChangeTimes->{{3.777691578623334*^9, 3.777691581852126*^9}}],

Cell["\<\
The Friedmann equations follow by equating the gravitational sector with the \
matter sector. The spatial isotropy and homogeneity, of course, imply that \
there are only two independent components for background tensors. We, thus, \
equate only the time-time part and the space-space part of the gravitational \
and matter sectors.

This leads us to...\
\>", "Text",
 CellChangeTimes->{{3.777691583933619*^9, 3.777691615951915*^9}, {
  3.7776916581539373`*^9, 3.777691737928487*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEgrav", "=", 
    RowBox[{"MFEcompK", "+", "MFEcompG", "+", "MFEcompEH"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"MFEgrav", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "\[Kappa]"}], "]"}], 
      "\[Equal]", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"Tcomp", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ")"}], "/.", 
    RowBox[{
     RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{"MFEgrav", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", "\[Kappa]"}], "]"}], 
       "\[Equal]", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"Tcomp", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1", \
"\[IndentingNewLine]", "FE2"}], "Input",
 CellChangeTimes->{{3.7776916276755943`*^9, 3.7776916525962667`*^9}, {
  3.777691742666757*^9, 3.7776917856871977`*^9}, {3.777691925270817*^9, 
  3.77769195636649*^9}, {3.7776921465647984`*^9, 3.777692164420169*^9}, {
  3.777692242891243*^9, 3.777692257048708*^9}, {3.7777788092476945`*^9, 
  3.777778817884759*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  FractionBox[
   RowBox[{"\[Rho]", "[", "t", "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.7776917728469143`*^9, 3.7776919572971992`*^9, {3.777692153934587*^9, 
   3.777692172752434*^9}, 3.777692257530259*^9, 3.7777750545565844`*^9, 
   3.7777789805957794`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}], "2"], " ", 
   RowBox[{"P", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7776917728469143`*^9, 3.7776919572971992`*^9, {3.777692153934587*^9, 
   3.777692172752434*^9}, 3.777692257530259*^9, 3.7777750545565844`*^9, 
   3.7777789806114073`*^9}]
}, Open  ]],

Cell["\<\
In this case, the scalar field equation also follows from the Friedmann \
equations. The resulting expression is given by...\
\>", "Text",
 CellChangeTimes->{{3.77769204849536*^9, 3.7776920855198097`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFE", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"BSEcompK", "+", "BSEcompG"}], "\[Equal]", "0"}], ")"}], "/.", 
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "SFE"}], "Input",
 CellChangeTimes->{{3.7776920886511297`*^9, 3.777692119722003*^9}, {
  3.7776921676273823`*^9, 3.7776921698194113`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "[", "t", "]"}], "2"]]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7776921202754517`*^9, 3.777692170398808*^9, 
  3.777775054698418*^9, 3.777778980689516*^9}]
}, Open  ]],

Cell[TextData[{
 "We can also express these in terms of the Hubble parameter, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "=", 
    RowBox[{
     RowBox[{"a", "'"}], "/", "a"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The following rule does exactly this."
}], "Text",
 CellChangeTimes->{{3.777775493657487*^9, 3.7777755429139214`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleatoH", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "t", "]"}], 
          RowBox[{"a", "[", "t", "]"}]], "\[Equal]", 
         RowBox[{"H", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "t", "]"}], 
            RowBox[{"a", "[", "t", "]"}]], ",", "t"}], "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"a", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "ruleatoH"}], "Input",
 CellChangeTimes->{{3.7777755456033773`*^9, 3.7777756362451468`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], "+", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7777756367768545`*^9, 3.7777789807585144`*^9}]
}, Open  ]],

Cell["\<\
The Friedmann equations and the scalar field equation then become...\
\>", "Text",
 CellChangeTimes->{{3.7777756500826187`*^9, 3.7777756611479483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FE1H", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"FE1", "/.", "ruleatoH"}], "/.", 
     RowBox[{"\[Kappa]", "\[Rule]", 
      FractionBox["1", "2"]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE2H", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"FE2", "/.", "ruleatoH"}], "/.", 
     RowBox[{"\[Kappa]", "\[Rule]", 
      FractionBox["1", "2"]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFEH", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SFE", "/.", "ruleatoH"}], "/.", 
      RowBox[{"\[Kappa]", "\[Rule]", 
       FractionBox["1", "2"]}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1H", \
"\[IndentingNewLine]", "FE2H", "\[IndentingNewLine]", "SFEH"}], "Input",
 CellChangeTimes->{{3.777775662568621*^9, 3.7777757131341105`*^9}, {
  3.7777759224295654`*^9, 3.7777759337843575`*^9}, {3.777779779801956*^9, 
  3.7777797926685333`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
     ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     K,
     Editable->False], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
     RowBox[{"P", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
    ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.777779794372369*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "[", "t", "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "[", "t", "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
           "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943884068`*^9}]
}, Open  ]],

Cell["\<\
We can compare SFEH with the expression (Eq. (2.5)) presented in \
[Albuquerque, I. S., Frusciante, N., Nunes, N. J., & Tsujikawa, S. (2018). \
New scaling solutions in cubic Horndeski theories. Physical Review D, 98(6), \
064038.]...\
\>", "Text",
 CellChangeTimes->{{3.7777806392759233`*^9, 3.777780649019097*^9}, {
  3.7777807474150515`*^9, 3.7777808107705307`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
    RowBox[{"6", 
     RowBox[{"H", "[", "t", "]"}], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox[
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"]}], ")"}], 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
    RowBox[{"2", 
     RowBox[{
      RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", "t", "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SFEcheck", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "3"]], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "3"], 
           RowBox[{"J", "[", "t", "]"}]}], ",", "t"}], "]"}]}], "\[Equal]", 
       RowBox[{"P", "[", "t", "]"}]}], ")"}], "/.", "ruleatoH"}], "//", 
    "Simplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.777781002746241*^9, 3.7777810970928707`*^9}, {
  3.777781130372286*^9, 3.7777812971149993`*^9}, {3.7777815779024687`*^9, 
  3.777781581625745*^9}, {3.7777816153396316`*^9, 3.7777816182259693`*^9}}],

Cell["\<\
It can easily be shown that SFEcheck is equivalent to SFEH...\
\>", "Text",
 CellChangeTimes->{{3.777781624657537*^9, 3.777781677380106*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"SFEH", ",", 
        RowBox[{
         RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"SFEcheck", ",", 
        RowBox[{
         RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.777781682149948*^9, 3.777781712863505*^9}, {
  3.777781799217659*^9, 3.7777817993695564`*^9}, {3.7777820998144083`*^9, 
  3.7777821274107647`*^9}, {3.777782536866577*^9, 3.7777825430379353`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.77778212806709*^9, {3.7777825382098856`*^9, 3.777782543446007*^9}}]
}, Open  ]],

Cell["\<\
To end this notebook, we simply save the Friedmann equations and the scalar \
field equation for future purposes.\
\>", "Text",
 CellChangeTimes->{{3.777782838515044*^9, 3.7777828634869347`*^9}, {
  3.7777829587549086`*^9, 3.777782971258998*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<friedmann_kgb.m\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"FE1H", ",", "FE2H", ",", "SFEH"}], "}"}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.777782868698241*^9, 3.777782869553407*^9}, {
  3.7777829003649545`*^9, 3.7777829500263066`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{690, 782},
WindowMargins->{{278, Automatic}, {Automatic, 192}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 134, 1, 70, "Section"],
Cell[717, 25, 119, 2, 30, "Input"],
Cell[839, 29, 558, 11, 125, "Text"],
Cell[CellGroupData[{
Cell[1422, 44, 178, 3, 49, "Subsection"],
Cell[CellGroupData[{
Cell[1625, 51, 2923, 81, 1154, "Input"],
Cell[CellGroupData[{
Cell[4573, 136, 374, 5, 55, "Print"],
Cell[4950, 143, 642, 12, 55, "Print"],
Cell[5595, 157, 394, 5, 55, "Print"],
Cell[5992, 164, 354, 4, 55, "Print"],
Cell[6349, 170, 335, 4, 55, "Print"],
Cell[6687, 176, 374, 5, 55, "Print"],
Cell[7064, 183, 650, 13, 55, "Print"],
Cell[7717, 198, 397, 5, 55, "Print"],
Cell[8117, 205, 376, 5, 55, "Print"],
Cell[8496, 212, 645, 12, 55, "Print"],
Cell[9144, 226, 445, 6, 101, "Print"],
Cell[9592, 234, 376, 5, 55, "Print"],
Cell[9971, 241, 529, 7, 146, "Print"],
Cell[10503, 250, 374, 5, 55, "Print"],
Cell[10880, 257, 616, 12, 55, "Print"],
Cell[11499, 271, 702, 13, 55, "Print"],
Cell[12204, 286, 803, 13, 55, "Print"],
Cell[13010, 301, 761, 13, 55, "Print"],
Cell[13774, 316, 779, 13, 55, "Print"],
Cell[14556, 331, 376, 5, 55, "Print"],
Cell[14935, 338, 645, 12, 55, "Print"],
Cell[15583, 352, 415, 5, 101, "Print"],
Cell[16001, 359, 376, 5, 55, "Print"],
Cell[16380, 366, 531, 7, 146, "Print"],
Cell[16914, 375, 376, 5, 55, "Print"],
Cell[17293, 382, 708, 13, 55, "Print"],
Cell[18004, 397, 716, 13, 55, "Print"],
Cell[18723, 412, 866, 18, 55, "Print"],
Cell[19592, 432, 970, 20, 55, "Print"],
Cell[20565, 454, 945, 19, 55, "Print"],
Cell[21513, 475, 963, 19, 55, "Print"],
Cell[22479, 496, 792, 15, 55, "Print"],
Cell[23274, 513, 914, 19, 55, "Print"],
Cell[24191, 534, 932, 20, 55, "Print"],
Cell[25126, 556, 958, 20, 55, "Print"],
Cell[26087, 578, 876, 18, 55, "Print"],
Cell[26966, 598, 383, 5, 55, "Print"],
Cell[27352, 605, 757, 13, 55, "Print"],
Cell[28112, 620, 387, 5, 55, "Print"],
Cell[28502, 627, 888, 18, 55, "Print"],
Cell[29393, 647, 943, 19, 55, "Print"],
Cell[30339, 668, 886, 18, 55, "Print"],
Cell[31228, 688, 772, 14, 55, "Print"],
Cell[32003, 704, 520, 9, 55, "Print"],
Cell[32526, 715, 512, 9, 55, "Print"],
Cell[33041, 726, 524, 9, 55, "Print"],
Cell[33568, 737, 778, 14, 55, "Print"],
Cell[34349, 753, 733, 13, 55, "Print"],
Cell[35085, 768, 721, 13, 55, "Print"],
Cell[35809, 783, 734, 13, 55, "Print"],
Cell[36546, 798, 750, 14, 55, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[37357, 819, 151, 2, 41, "Subsection"],
Cell[37511, 823, 168, 3, 77, "Text"],
Cell[37682, 828, 16940, 426, 4702, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[54659, 1259, 168, 2, 41, "Subsection"],
Cell[54830, 1263, 154, 3, 75, "Text"],
Cell[CellGroupData[{
Cell[55009, 1270, 1426, 45, 353, "Input"],
Cell[56438, 1317, 2950, 101, 134, "Output"]
}, Open  ]],
Cell[59403, 1421, 269, 5, 124, "Text"],
Cell[CellGroupData[{
Cell[59697, 1430, 117, 1, 96, "Subsubsection"],
Cell[59817, 1433, 521, 14, 221, "Text"],
Cell[CellGroupData[{
Cell[60363, 1451, 1373, 39, 304, "Input"],
Cell[CellGroupData[{
Cell[61761, 1494, 661, 13, 55, "Print"],
Cell[62425, 1509, 853, 17, 55, "Print"]
}, Open  ]],
Cell[63293, 1529, 23468, 748, 368, "Output"]
}, Open  ]],
Cell[86776, 2280, 156, 3, 75, "Text"],
Cell[CellGroupData[{
Cell[86957, 2287, 786, 23, 255, "Input"],
Cell[87746, 2312, 33533, 1103, 603, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[121340, 3422, 164, 2, 41, "Subsection"],
Cell[121507, 3426, 290, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[121822, 3435, 2263, 62, 207, "Input"],
Cell[CellGroupData[{
Cell[124110, 3501, 624, 12, 22, "Print"],
Cell[124737, 3515, 678, 13, 22, "Print"],
Cell[125418, 3530, 676, 13, 22, "Print"],
Cell[126097, 3545, 676, 13, 22, "Print"],
Cell[126776, 3560, 676, 13, 22, "Print"],
Cell[127455, 3575, 632, 12, 22, "Print"],
Cell[128090, 3589, 650, 12, 22, "Print"],
Cell[128743, 3603, 799, 17, 26, "Print"],
Cell[129545, 3622, 808, 17, 26, "Print"],
Cell[130356, 3641, 662, 13, 24, "Print"],
Cell[131021, 3656, 720, 14, 24, "Print"],
Cell[131744, 3672, 846, 18, 24, "Print"],
Cell[132593, 3692, 864, 19, 24, "Print"],
Cell[133460, 3713, 892, 19, 24, "Print"],
Cell[134355, 3734, 808, 17, 24, "Print"],
Cell[135166, 3753, 818, 16, 24, "Print"],
Cell[135987, 3771, 910, 20, 24, "Print"],
Cell[136900, 3793, 664, 12, 24, "Print"],
Cell[137567, 3807, 1787, 44, 30, "Print"],
Cell[139357, 3853, 1764, 43, 30, "Print"],
Cell[141124, 3898, 1764, 43, 30, "Print"],
Cell[142891, 3943, 1766, 43, 30, "Print"],
Cell[144660, 3988, 2989, 76, 30, "Print"],
Cell[147652, 4066, 2163, 58, 30, "Print"],
Cell[149818, 4126, 1764, 43, 30, "Print"],
Cell[151585, 4171, 1766, 43, 30, "Print"],
Cell[153354, 4216, 2991, 76, 30, "Print"],
Cell[156348, 4294, 2991, 76, 30, "Print"],
Cell[159342, 4372, 2163, 58, 30, "Print"],
Cell[161508, 4432, 1763, 43, 30, "Print"],
Cell[163274, 4477, 2988, 76, 30, "Print"],
Cell[166265, 4555, 2991, 76, 30, "Print"],
Cell[169259, 4633, 2991, 76, 30, "Print"],
Cell[172253, 4711, 2165, 58, 30, "Print"],
Cell[174421, 4771, 708, 13, 24, "Print"],
Cell[175132, 4786, 815, 16, 24, "Print"]
}, Open  ]]
}, Open  ]],
Cell[175974, 4806, 407, 11, 54, "Text"],
Cell[CellGroupData[{
Cell[176406, 4821, 3525, 108, 327, "Input"],
Cell[CellGroupData[{
Cell[179956, 4933, 707, 15, 24, "Print"],
Cell[180666, 4950, 2937, 76, 32, "Print"],
Cell[183606, 5028, 1966, 52, 32, "Print"],
Cell[185575, 5082, 1712, 43, 32, "Print"],
Cell[187290, 5127, 1712, 43, 32, "Print"],
Cell[189005, 5172, 1714, 43, 32, "Print"],
Cell[190722, 5217, 2937, 76, 32, "Print"],
Cell[193662, 5295, 1714, 43, 32, "Print"],
Cell[195379, 5340, 2935, 76, 32, "Print"],
Cell[198317, 5418, 1927, 51, 32, "Print"],
Cell[200247, 5471, 1711, 43, 32, "Print"],
Cell[201961, 5516, 1711, 43, 32, "Print"],
Cell[203675, 5561, 2935, 76, 32, "Print"],
Cell[206613, 5639, 1712, 43, 32, "Print"],
Cell[208328, 5684, 2937, 76, 32, "Print"],
Cell[211268, 5762, 1714, 43, 32, "Print"],
Cell[212985, 5807, 2935, 76, 32, "Print"],
Cell[215923, 5885, 1924, 51, 32, "Print"],
Cell[217850, 5938, 1711, 43, 32, "Print"],
Cell[219564, 5983, 2937, 76, 32, "Print"],
Cell[222504, 6061, 1714, 43, 32, "Print"],
Cell[224221, 6106, 2935, 76, 32, "Print"],
Cell[227159, 6184, 1712, 43, 32, "Print"],
Cell[228874, 6229, 2937, 76, 32, "Print"],
Cell[231814, 6307, 1714, 43, 32, "Print"],
Cell[233531, 6352, 2937, 76, 32, "Print"],
Cell[236471, 6430, 1927, 51, 32, "Print"],
Cell[238401, 6483, 12237, 312, 32, "Print"],
Cell[250641, 6797, 12235, 312, 32, "Print"],
Cell[262879, 7111, 12237, 312, 32, "Print"],
Cell[275119, 7425, 12237, 312, 32, "Print"],
Cell[287359, 7739, 2941, 76, 30, "Print"],
Cell[290303, 7817, 24110, 617, 59, "Print"],
Cell[314416, 8436, 12237, 312, 32, "Print"],
Cell[326656, 8750, 12237, 312, 32, "Print"],
Cell[338896, 9064, 12237, 312, 32, "Print"],
Cell[351136, 9378, 2939, 76, 30, "Print"],
Cell[354078, 9456, 24110, 617, 59, "Print"],
Cell[378191, 10075, 2941, 76, 30, "Print"],
Cell[381135, 10153, 24110, 617, 59, "Print"],
Cell[405248, 10772, 12235, 312, 32, "Print"],
Cell[417486, 11086, 12237, 312, 32, "Print"],
Cell[429726, 11400, 2941, 76, 30, "Print"],
Cell[432670, 11478, 24110, 617, 59, "Print"],
Cell[456783, 12097, 2941, 76, 30, "Print"],
Cell[459727, 12175, 24110, 617, 59, "Print"],
Cell[483840, 12794, 2941, 76, 30, "Print"],
Cell[486784, 12872, 24108, 617, 59, "Print"],
Cell[510895, 13491, 12235, 312, 32, "Print"],
Cell[523133, 13805, 4477, 115, 32, "Print"]
}, Open  ]],
Cell[527625, 13923, 3084, 97, 91, "Output"],
Cell[CellGroupData[{
Cell[530734, 14024, 630, 13, 24, "Print"],
Cell[531367, 14039, 1068, 31, 24, "Print"]
}, Open  ]]
}, Open  ]],
Cell[532462, 14074, 146, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[532633, 14079, 367, 11, 75, "Input"],
Cell[533003, 14092, 658, 22, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533698, 14119, 160, 5, 35, "Subsubsection"],
Cell[533861, 14126, 288, 7, 51, "Text"],
Cell[534152, 14135, 14060, 442, 205, "Input"],
Cell[548215, 14579, 326, 8, 31, "Text"],
Cell[CellGroupData[{
Cell[548566, 14591, 584, 13, 75, "Input"],
Cell[549153, 14606, 9646, 307, 113, "Output"]
}, Open  ]],
Cell[558814, 14916, 202, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[559041, 14926, 445, 12, 117, "Input"],
Cell[559489, 14940, 9595, 354, 133, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[569133, 15300, 106, 1, 35, "Subsubsection"],
Cell[569242, 15303, 190, 4, 51, "Text"],
Cell[569435, 15309, 14761, 462, 205, "Input"],
Cell[584199, 15773, 141, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[584365, 15778, 744, 19, 117, "Input"],
Cell[585112, 15799, 22947, 715, 125, "Output"]
}, Open  ]],
Cell[608074, 16517, 143, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[608242, 16522, 749, 20, 138, "Input"],
Cell[608994, 16544, 22189, 810, 343, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[631232, 17360, 114, 1, 35, "Subsubsection"],
Cell[631349, 17363, 184, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[631558, 17371, 540, 14, 96, "Input"],
Cell[632101, 17387, 7186, 225, 115, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[639336, 17618, 108, 1, 35, "Subsubsection"],
Cell[639447, 17621, 166, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[639638, 17628, 543, 16, 75, "Input"],
Cell[640184, 17646, 2849, 94, 91, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[643082, 17746, 110, 1, 35, "Subsubsection"],
Cell[643195, 17749, 494, 10, 131, "Text"],
Cell[CellGroupData[{
Cell[643714, 17763, 1680, 50, 194, "Input"],
Cell[645397, 17815, 6544, 227, 136, "Output"],
Cell[651944, 18044, 6226, 217, 124, "Output"]
}, Open  ]],
Cell[658185, 18264, 215, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[658425, 18272, 449, 12, 75, "Input"],
Cell[658877, 18286, 23386, 808, 468, "Output"]
}, Open  ]],
Cell[682278, 19097, 362, 10, 52, "Text"],
Cell[CellGroupData[{
Cell[682665, 19111, 1023, 31, 95, "Input"],
Cell[683691, 19144, 1365, 48, 35, "Output"]
}, Open  ]],
Cell[685071, 19195, 162, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[685258, 19202, 1006, 29, 212, "Input"],
Cell[686267, 19233, 5446, 185, 108, "Output"],
Cell[691716, 19420, 4755, 156, 86, "Output"],
Cell[696474, 19578, 20003, 669, 352, "Output"]
}, Open  ]],
Cell[716492, 20250, 379, 7, 71, "Text"],
Cell[716874, 20259, 7936, 264, 249, "Input"],
Cell[724813, 20525, 151, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[724989, 20532, 904, 25, 54, "Input"],
Cell[725896, 20559, 120, 2, 32, "Output"]
}, Open  ]],
Cell[726031, 20564, 256, 5, 51, "Text"],
Cell[726290, 20571, 446, 12, 54, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

