(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    666368,      17425]
NotebookOptionsPosition[    655167,      17120]
NotebookOutlinePosition[    655737,      17140]
CellTagsIndexPosition[    655694,      17137]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Linear perturbations of a stealth black hole in ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence"
}], "Section",
 CellChangeTimes->{3.7733152431446114`*^9}],

Cell[TextData[{
 "\tIn this notebook, we use xPert and xCoba to efficiently study the linear \
gravitational perturbations on top of the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence stealth black hole presented in Ref. [1].\n\n[1] Tattersall, O.J., \
Ferreira, P.G. and Lagos, M., 2018. Speed of gravitational waves and black \
hole hair. Physical Review D, 97(8), p.084005."
}], "Text",
 CellChangeTimes->{{3.7640401685563574`*^9, 3.7640402108201447`*^9}, {
  3.76404058914036*^9, 3.7640406142743535`*^9}, {3.7640428695021496`*^9, 
  3.764042897760912*^9}, {3.7651097554604225`*^9, 3.7651097558496704`*^9}, {
  3.773313214957367*^9, 3.7733133067994843`*^9}, {3.773313341145874*^9, 
  3.773313363781763*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["I. Setup", "Subsection",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsubsection",
 CellChangeTimes->{{3.7640406370673976`*^9, 3.764040642088087*^9}, {
   3.765596066088698*^9, 3.765596070115701*^9}, 3.7786606170508285`*^9}],

Cell[TextData[{
 "\tFirst of all, we setup xPert to obtain covariant expressions for the \
linearized field equations of ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence theory. We thus define a manifold, metric, scalar field, and ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potential."
}], "Text",
 CellChangeTimes->{{3.764040645949489*^9, 3.764040666638496*^9}, {
   3.7733134095019865`*^9, 3.7733134955101404`*^9}, 3.773315216673257*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xPert"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Options", "[", "MakeRule", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Options", "[", "ContractMetric", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"org", "[", "expr_", "]"}], ":=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
      "$PerturbationParameter", ",", "ToCanonical"}], "]"}]}], 
   RowBox[{"(*", 
    RowBox[{
    "organizes", " ", "expression", " ", "perturbation", " ", "order"}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "                                  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefManifold", "[", 
     RowBox[{"Md", ",", "dim", ",", 
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "i", ",", "j", ",", 
        "k", ",", "l", ",", "u", ",", "v"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefMetric", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
      RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"define", " ", "scalar", " ", "field", " ", "and", " ", "k"}], 
     "-", 
     RowBox[{"essence", " ", "potential"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], ",", "Md"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "Q", "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{
    "bookkeeping", " ", "parameter", " ", "for", " ", "GR", " ", "pieces"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7640407744771357`*^9, 3.764040797237398*^9}, {
   3.7733133906815205`*^9, 3.7733134013437567`*^9}, {3.7733135036479645`*^9, 
   3.7733136461538267`*^9}, {3.7733140765215254`*^9, 3.773314095415901*^9}, 
   3.7733145823247566`*^9, {3.77331980106966*^9, 3.77331980129852*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930168682*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930174102*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759302151103`*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759303293257`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759303344803`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759303395224`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930345769*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305023456`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305086565`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930513671*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305172195`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930521296*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305262566`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930530075*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305342455`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305399156`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305446587`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305484056`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "Md", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", 
   "manifold ", $CellContext`Md, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.77337593055227*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentMd", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentMd, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305565977`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305615873`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930565658*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930569686*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`a, -$CellContext`b, \
-$CellContext`c, -$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930573752*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930578042*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305818925`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759305867257`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930591907*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930596631*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759306005173`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759306052017`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930609609*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.77337593061414*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759306473055`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759307417545`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930763834*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930768152*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930923611*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930948301*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930963337*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759309675336`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "Q", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`Q, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.7733759309710774`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930974568*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["II. ", "Subsection",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["k", "Subsection",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["-essence theory", "Subsection",
  FontColor->RGBColor[1, 0.5, 0.5]]
}], "Subsubsection",
 CellChangeTimes->{{3.7640413518512836`*^9, 3.7640413557921743`*^9}, {
  3.7640429160967827`*^9, 3.764042919302894*^9}, {3.7655960768978186`*^9, 
  3.76559607693461*^9}, {3.7655990411378393`*^9, 3.765599043246704*^9}, {
  3.773314628546077*^9, 3.773314640009923*^9}}],

Cell[TextData[{
 "The ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence Lagrangian is defined as follows."
}], "Text",
 CellChangeTimes->{{3.764041358186518*^9, 3.7640414664704266`*^9}, {
  3.764042924090413*^9, 3.7640429583561006`*^9}, {3.765595260060114*^9, 
  3.7655952959116096`*^9}, {3.7733146521368427`*^9, 3.7733146720959005`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"L\[Phi]", "=", 
   RowBox[{"Q", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "b"}], "]"}], "@", 
       RowBox[{"\[Phi]", "[", "]"}]}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", "b", "]"}], "@", 
       RowBox[{"\[Phi]", "[", "]"}]}], "/", "2"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LEH", "=", 
   RowBox[{"\[Kappa]", " ", 
    RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"L", "=", 
    RowBox[{"L\[Phi]", "+", "LEH"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", "L"}]}], "Input",
 CellChangeTimes->{{3.764041478859988*^9, 3.7640415539969983`*^9}, {
   3.7640415842731957`*^9, 3.7640417843906937`*^9}, {3.7640427554528036`*^9, 
   3.7640428100625052`*^9}, 3.764043060768496*^9, {3.7655953123826694`*^9, 
   3.7655953879317756`*^9}, {3.773314677019885*^9, 3.7733147460971975`*^9}, {
   3.7733149732657604`*^9, 3.773314975852343*^9}, 3.7733706529299126`*^9}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["Q",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q,
     Editable->False], "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]],
      Editable->False]}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{
  3.7640418396225977`*^9, {3.764042794843155*^9, 3.764042811797239*^9}, {
   3.764043051746503*^9, 3.764043061728173*^9}, 3.764044185235381*^9, 
   3.7640455464407964`*^9, 3.764049981723111*^9, 3.7640632732449245`*^9, 
   3.7655834157309246`*^9, 3.7655953047870593`*^9, {3.7655953429483757`*^9, 
   3.7655953646717396`*^9}, 3.765597814901467*^9, 3.7655990105198784`*^9, 
   3.765604209211776*^9, 3.765629941346422*^9, 3.765678974457131*^9, 
   3.773314747745637*^9, 3.773314976352801*^9, 3.7733152657586355`*^9, 
   3.7733172859559355`*^9, 3.773317678010567*^9, 3.773319618267468*^9, 
   3.7733198211415477`*^9, 3.773320018495205*^9, 3.773366040494365*^9, 
   3.7733681329240913`*^9, 3.7733683154527473`*^9, 3.7733706673847766`*^9, 
   3.773371136266919*^9, 3.7733712824655123`*^9, 3.7733759310905533`*^9}]
}, Open  ]],

Cell["\<\
We derive the field equations by using Cyril Pitrou\[CloseCurlyQuote]s \
algorithm for computing variational derivatives. This is publicly available \
as \[OpenCurlyDoubleQuote]https://github.com/xAct-contrib/examples\
\[CloseCurlyDoubleQuote] in https://github.com/xAct-contrib/examples.\
\>", "Text",
 CellChangeTimes->{{3.764041909583539*^9, 3.7640419728046494`*^9}, {
  3.7640420347769413`*^9, 3.764042050481558*^9}, {3.764042093427538*^9, 
  3.7640421814934196`*^9}, {3.764042969090994*^9, 3.764042975414912*^9}, {
  3.765595399677781*^9, 3.765595418887517*^9}, {3.7733147719216022`*^9, 
  3.773314809439645*^9}, {3.773314854654686*^9, 3.773314871619092*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Cyril", " ", 
    RowBox[{"Pitrou", "'"}], "s", " ", "code"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "UpIndexQ"}], ",", 
         RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "DownIndexQ"}], ",", 
         RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
        RowBox[{"(*", 
         RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}],
         ",", " ", 
        RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dgloc", "=", 
        RowBox[{"SymbolJoin", "[", 
         RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"hp", "=", 
        RowBox[{"Head", "@", 
         RowBox[{"Perturbation", "[", 
          RowBox[{"g", "[", 
           RowBox[{
            RowBox[{"DownIndex", "@", "a"}], ",", 
            RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"hp", "===", "Perturbation"}], ",", 
         RowBox[{"DefMetricPerturbation", "[", 
          RowBox[{"g", ",", "dgloc", ",", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
         RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
           "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
           " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", 
           " ", "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pertexpr", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
                RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
             RowBox[{"ToCanonical", "@", 
              RowBox[{"ContractMetric", "@", 
               RowBox[{"ExpandPerturbation", "@", 
                RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
            RowBox[{
             RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
             "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"We", " ", "then", " ", "use", " ", 
            RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", 
            " ", "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ",
             "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
            "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dgloc", "[", 
                    RowBox[{
                    RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], 
                    "]"}], ",", 
                   RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
                 "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
           "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
            " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
            "tensor"}], ",", " ", 
           RowBox[{
           "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", 
            "the", " ", "formal", " ", "first", " ", "order", " ", 
            "perturbation", " ", "the", " ", "tensor"}]}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
           "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"inds", "=", 
           RowBox[{"DummyIn", "/@", 
            RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "@@", "inds"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
            "and", " ", "replace", " ", 
            RowBox[{"Perturbation", "[", 
             RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", 
            "this", " ", "dummy", " ", "tensor"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", 
            " ", 
            RowBox[{"VarD", " ", "works", " ", 
             RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need",
              " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
             "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
                 "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "@", 
       RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
      "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "VarD", " ", "and", " ", "removal", " ", "of", " ", 
            "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], 
                  "]"}], "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"g_", "?", "MetricQ"}], "[", 
       RowBox[{"as__", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
            RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
       "]"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sqrtg", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
          RowBox[{
           RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"ToCanonical", "[", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"expr", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
          RowBox[{
           RowBox[{"PerturbAction", "[", 
            RowBox[{"sqrtg", ",", 
             RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", "tensor", ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}], "[", "inds___", "]"}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{
        RowBox[{"tensor_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
             RowBox[{"Not", "[", 
              RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
          ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", 
       RowBox[{"tensor", "[", "inds", "]"}], ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7733148779743304`*^9, 3.7733148851860466`*^9}}],

Cell["The Einstein equation is then given by...", "Text",
 CellChangeTimes->{{3.7640422043450317`*^9, 3.7640422292151117`*^9}, {
  3.773314905890073*^9, 3.7733149485996275`*^9}, {3.773315040552918*^9, 
  3.7733150408164835`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BME", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{"L", ",", 
          RowBox[{"g", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}], "]"}], "//", "ContractMetric"}], 
       "//", "RicciToEinstein"}], "//", "ToCanonical"}], "//", "NoScalar"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", "BME"}], "Input",
 CellChangeTimes->{{3.7640422984553337`*^9, 3.764042307144582*^9}, {
  3.7733149248273196`*^9, 3.773314958494128*^9}, {3.7733150071107416`*^9, 
  3.7733150112680798`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773315274844597*^9, 3.773317286371027*^9, 
  3.773317678233873*^9, 3.77331961863072*^9, 3.7733198213770494`*^9, 
  3.773320018806266*^9, 3.773366040759925*^9, 3.7733681330924206`*^9, 
  3.773368315549214*^9, 3.7733706774803314`*^9, 3.773371136438784*^9, 
  3.773371282527999*^9, 3.773375931135731*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773315274844597*^9, 3.773317286371027*^9, 
  3.773317678233873*^9, 3.77331961863072*^9, 3.7733198213770494`*^9, 
  3.773320018806266*^9, 3.773366040759925*^9, 3.7733681330924206`*^9, 
  3.773368315549214*^9, 3.7733706774803314`*^9, 3.773371136438784*^9, 
  3.773371282527999*^9, 3.773375931141677*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"G", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox["Q",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q,
     Editable->False], "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False]}], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]]],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "a"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Phi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Phi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False]}], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]]],
      Editable->False]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.764042236088004*^9, 3.764042991629761*^9, 3.7640430844720263`*^9, 
   3.76404419606584*^9, 3.7640455555868216`*^9, 3.764049990540106*^9, 
   3.7640632905220957`*^9, 3.765583429404025*^9, 3.765595444828689*^9, 
   3.76559782711736*^9, 3.7655990214548197`*^9, 3.765604217166937*^9, 
   3.765629950183978*^9, 3.7656789815492196`*^9, {3.773314959226824*^9, 
   3.773315012372303*^9}, 3.773315275033079*^9, 3.7733172866201105`*^9, 
   3.7733176784256454`*^9, 3.773319618902492*^9, 3.773319821581339*^9, 
   3.773320019088368*^9, 3.7733660409942455`*^9, 3.7733681332856693`*^9, 
   3.77336831572307*^9, 3.773370677683202*^9, 3.77337113662621*^9, 
   3.7733712826842127`*^9, 3.7733759313096695`*^9}]
}, Open  ]],

Cell["while the scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.764043210934701*^9, 3.7640432161342635`*^9}, {
  3.7733150444994307`*^9, 3.7733150524362125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"L", ",", 
         RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "ToCanonical"}], "//", "NoScalar"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "BSE"}], "Input",
 CellChangeTimes->{{3.764043265681262*^9, 3.764043269068035*^9}, {
  3.7733150551918793`*^9, 3.7733150656298685`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "a"], 
      SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False]}], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]]],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`a][
     $CellContext`\[Phi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SubscriptBox["\[Del]", "a"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Phi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]],
          Editable->False]}], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]]],
      Editable->False]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7640432264535275`*^9, 3.7640442044431486`*^9, 
  3.76404556367175*^9, 3.764050000139815*^9, 3.764063301003994*^9, 
  3.765583452161162*^9, 3.765595482871152*^9, 3.765597836099633*^9, 
  3.765599028484426*^9, 3.7656042298358493`*^9, 3.7656299580921326`*^9, 
  3.765678990816456*^9, 3.7733150667102423`*^9, 3.7733152779684443`*^9, 
  3.7733172868631477`*^9, 3.77331767861984*^9, 3.773319619182754*^9, 
  3.7733198218009186`*^9, 3.7733200193838615`*^9, 3.773366041181732*^9, 
  3.773368133478488*^9, 3.773368315909585*^9, 3.7733706813542156`*^9, 
  3.773371136782423*^9, 3.7733712828248034`*^9, 3.7733759314510326`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["III. Linearized gravity", "Subsection",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsubsection",
 CellChangeTimes->{{3.764043122978939*^9, 3.7640431482697897`*^9}, {
  3.7733153635935807`*^9, 3.773315372172624*^9}}],

Cell["\<\
\tWe now linearize the field equations presented in the previous section. In \
the next section, we shall write down the linearized field equations in \
static and spherically-symmetric background.\
\>", "Text",
 CellChangeTimes->{{3.7640431506860847`*^9, 3.7640431793601103`*^9}, {
   3.764043418865844*^9, 3.764043467137682*^9}, {3.7733153067632055`*^9, 
   3.7733153387457576`*^9}, 3.7733162963879757`*^9, {3.7786611011722956`*^9, 
   3.778661101618695*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefMetricPerturbation", "[", 
   RowBox[{"g", ",", "h", ",", "\[Epsilon]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Unprotect", "[", "IndexForm", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndexForm", "[", 
    RowBox[{"LI", "[", "x_", "]"}], "]"}], ":=", 
   RowBox[{"ColorString", "[", 
    RowBox[{
     RowBox[{"ToString", "[", "x", "]"}], ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "IndexForm", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndexForm", "[", 
   RowBox[{"LI", "[", "n", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensorPerturbation", "[", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order", "]"}], "]"}], ",", 
    RowBox[{"\[Phi]", "[", "]"}], ",", "Md"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7640441579067197`*^9, 3.7640441600154533`*^9}, {
  3.7733153830674543`*^9, 3.7733153905617623`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.764043484379655*^9, 3.76404421110468*^9, 3.76404556981987*^9, 
   3.7640500143554773`*^9, 3.7640633075337334`*^9, 3.7655834618976045`*^9, 
   3.76559557043641*^9, 3.765597857329047*^9, 3.765599051650891*^9, 
   3.7656042583291893`*^9, 3.765629976702411*^9, 3.76567900631513*^9, {
   3.7733153855022125`*^9, 3.7733153916288347`*^9}, 3.7733172923614388`*^9, 
   3.7733177153291883`*^9, 3.773319627517304*^9, 3.7733198272637396`*^9, 
   3.7733200235034723`*^9, 3.7733660483946514`*^9, 3.7733681558150535`*^9, 
   3.7733683159156704`*^9, 3.773370686931037*^9, 3.7733711425310755`*^9, 
   3.773371282856045*^9, 3.7733759314643564`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.764043484379655*^9, 3.76404421110468*^9, 3.76404556981987*^9, 
   3.7640500143554773`*^9, 3.7640633075337334`*^9, 3.7655834618976045`*^9, 
   3.76559557043641*^9, 3.765597857329047*^9, 3.765599051650891*^9, 
   3.7656042583291893`*^9, 3.765629976702411*^9, 3.76567900631513*^9, {
   3.7733153855022125`*^9, 3.7733153916288347`*^9}, 3.7733172923614388`*^9, 
   3.7733177153291883`*^9, 3.773319627517304*^9, 3.7733198272637396`*^9, 
   3.7733200235034723`*^9, 3.7733660483946514`*^9, 3.7733681558150535`*^9, 
   3.7733683159156704`*^9, 3.773370686931037*^9, 3.7733711425310755`*^9, 
   3.773371282856045*^9, 3.7733759314759235`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Psi]", "[", 
    RowBox[{"LI", "[", "\<\"order\"\>", "]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Psi][
    xAct`xTensor`LI["order"]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.764043484379655*^9, 3.76404421110468*^9, 3.76404556981987*^9, 
   3.7640500143554773`*^9, 3.7640633075337334`*^9, 3.7655834618976045`*^9, 
   3.76559557043641*^9, 3.765597857329047*^9, 3.765599051650891*^9, 
   3.7656042583291893`*^9, 3.765629976702411*^9, 3.76567900631513*^9, {
   3.7733153855022125`*^9, 3.7733153916288347`*^9}, 3.7733172923614388`*^9, 
   3.7733177153291883`*^9, 3.773319627517304*^9, 3.7733198272637396`*^9, 
   3.7733200235034723`*^9, 3.7733660483946514`*^9, 3.7733681558150535`*^9, 
   3.7733683159156704`*^9, 3.773370686931037*^9, 3.7733711425310755`*^9, 
   3.773371282856045*^9, 3.7733759314808254`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Here are some rules for breaking down the perturbations into metric and \
scalar modes.\
\>", "Text",
 CellChangeTimes->{
  3.76404350134409*^9, {3.7640633190467243`*^9, 3.7640633260450687`*^9}, {
   3.773315438597988*^9, 3.773315470134034*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pertscalar", "=", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"LI", "[", "order_", "]"}], ",", "__"}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "0"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pertmetric", "=", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "0"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.764043509529133*^9, 3.7640435459581585`*^9}, 
   3.7640436636855836`*^9, {3.7733154825855346`*^9, 3.773315488194816*^9}, {
   3.7733157970023813`*^9, 3.773315801557928*^9}}],

Cell[TextData[{
 "The following rules impose that the perturbations be defined as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "ab"], "=", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "_"], "ab"], "+", 
     SubscriptBox["h", "ab"]}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     OverscriptBox["\[Phi]", "_"], "+", "\[Psi]"}]}], TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "ab"], TraditionalForm]]],
 " and \[Psi] also contain nonlinear orders. The results for this are \
indistinguishable at linear order."
}], "Text",
 CellChangeTimes->{{3.764043590548537*^9, 3.7640436361429834`*^9}, {
  3.773315544624812*^9, 3.7733155993700027`*^9}, {3.7733156307781816`*^9, 
  3.773315770633793*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rule1", "=", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"LI", "[", "order_", "]"}], ",", "__"}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "1"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rule2", "=", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "1"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.76404364537481*^9, 3.7640436572972965`*^9}, {
  3.7733157879181166`*^9, 3.7733157932947187`*^9}}],

Cell["The following is for aesthetics.", "Text",
 CellChangeTimes->{
  3.764043725840581*^9, {3.7733158953413057`*^9, 3.7733159130123706`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[Delta]\[Psi]", "[", "]"}], ",", "Md"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleScalarPert", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"LI", "[", "1", "]"}], "]"}], ",", 
     RowBox[{"\[Delta]\[Psi]", "[", "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.773315821220405*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]\[Psi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]\[Psi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404373501898*^9, 3.764044219508417*^9, 
  3.7640455784869595`*^9, 3.764050025538237*^9, 3.7640633452435474`*^9, 
  3.7655834698502455`*^9, 3.7655956091188407`*^9, 3.7655978653896604`*^9, 
  3.7655990578681803`*^9, 3.7656042651869574`*^9, 3.7656299830708013`*^9, 
  3.765679018940076*^9, 3.77331591720389*^9, 3.7733172989530983`*^9, 
  3.77331772229006*^9, 3.7733196277544966`*^9, 3.7733198362135525`*^9, 
  3.773320029292633*^9, 3.773366054283887*^9, 3.7733681631409636`*^9, 
  3.7733683159723597`*^9, 3.7733706977878647`*^9, 3.7733711481547575`*^9, 
  3.7733712829029517`*^9, 3.773375931520975*^9}]
}, Open  ]],

Cell["\<\
Finally, we define the tensor \[ScriptH] to replace the metric perturbations \
in preparation for xCoba/component analysis.\
\>", "Text",
 CellChangeTimes->{{3.7640469742448945`*^9, 3.764047001025877*^9}, {
  3.773315923606468*^9, 3.773315954129094*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[ScriptH]", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "Md", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<\[ScriptH]\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert1", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", 
       RowBox[{"-", "a_"}], ",", 
       RowBox[{"-", "b_"}]}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert2", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", 
       RowBox[{"-", "a_"}], ",", "b_"}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", "b"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert3", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", 
       RowBox[{"-", "b_"}]}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{"a", ",", 
       RowBox[{"-", "b"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert4", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", "b_"}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert", "=", 
   RowBox[{"{", 
    RowBox[{
    "ruleMetricPert1", ",", "ruleMetricPert2", ",", "ruleMetricPert3", ",", 
     "ruleMetricPert4"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.773315958302376*^9, 3.7733159771299067`*^9}, 
   3.773316138167801*^9, 3.773317306390889*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptH]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773317306867585*^9, 3.773317724978654*^9, 
  3.7733196278154373`*^9, 3.773319837771775*^9, 3.7733200309592037`*^9, 
  3.7733660564240084`*^9, 3.7733681659336557`*^9, 3.773368315993075*^9, 
  3.7733706994593487`*^9, 3.7733711499355907`*^9, 3.773371282934191*^9, 
  3.773375931535898*^9}]
}, Open  ]],

Cell["We delay no further and linearize the field equations.", "Text",
 CellChangeTimes->{{3.773316255878912*^9, 3.7733162697764835`*^9}}],

Cell[TextData[StyleBox["I. Linearized field equations: covariant calculations",
 FontSize->18,
 FontColor->RGBColor[1, 0.5, 0]]], "Text",
 CellChangeTimes->{{3.7733163876626787`*^9, 3.773316400403436*^9}}],

Cell[TextData[{
 "The following set of rules aesthetically simplify the background limits of \
the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potential and its derivatives."
}], "Text",
 CellChangeTimes->{{3.7733173700122843`*^9, 3.7733174111204863`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"Q0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*OverscriptBox[\(K\), \(_\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"QX0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(_\)], \(X\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"QXX0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(_\)], \(XX\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"QXXX0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(_\)], \(XXX\)]\)\>\""}]}],
    "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SimplifyQ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["Q",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Q,
        Editable->False], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", "Q0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "'"}], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", "QX0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "''"}], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", "QXX0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "'''"}], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", "QXXX0"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7733174060240355`*^9, 3.773317406491267*^9}, {
  3.7733174823022842`*^9, 3.7733175345679464`*^9}, {3.7733176028537254`*^9, 
  3.773317635056509*^9}, {3.773370710925413*^9, 3.7733707331077175`*^9}, {
  3.7733707650289774`*^9, 3.7733707992010517`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "Q0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`Q0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773317417289153*^9, 3.7733177298717995`*^9, 
  3.773319627892497*^9, 3.773319839954559*^9, 3.773320033532157*^9, 
  3.773366060719879*^9, 3.773368168103772*^9, 3.773368316018008*^9, 
  3.773370805137158*^9, 3.773371151763286*^9, 3.7733712829497747`*^9, 
  3.7733759315535665`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "QX0", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`QX0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773317417289153*^9, 3.7733177298717995`*^9, 
  3.773319627892497*^9, 3.773319839954559*^9, 3.773320033532157*^9, 
  3.773366060719879*^9, 3.773368168103772*^9, 3.773368316018008*^9, 
  3.773370805137158*^9, 3.773371151763286*^9, 3.7733712829497747`*^9, 
  3.773375931559024*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "QXX0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`QXX0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773317417289153*^9, 3.7733177298717995`*^9, 
  3.773319627892497*^9, 3.773319839954559*^9, 3.773320033532157*^9, 
  3.773366060719879*^9, 3.773368168103772*^9, 3.773368316018008*^9, 
  3.773370805137158*^9, 3.773371151763286*^9, 3.7733712829497747`*^9, 
  3.7733759315634427`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "QXXX0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`QXXX0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773317417289153*^9, 3.7733177298717995`*^9, 
  3.773319627892497*^9, 3.773319839954559*^9, 3.773320033532157*^9, 
  3.773366060719879*^9, 3.773368168103772*^9, 3.773368316018008*^9, 
  3.773370805137158*^9, 3.773371151763286*^9, 3.7733712829497747`*^9, 
  3.7733759315678825`*^9}]
}, Open  ]]
}, Open  ]],

Cell["The linearized Einstein equation is given by...", "Text",
 CellChangeTimes->{{3.7733164372611885`*^9, 3.7733164506169176`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EElinear", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Perturbed", "[", 
            RowBox[{"BME", ",", "1"}], "]"}], "//", "ExpandPerturbation"}], "//",
           "ContractMetric"}], "//", "NoScalar"}], "//", "ToCanonical"}], "//",
        "org"}], ")"}], "/.", "SimplifyQ"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", "EElinear", ")"}], "\[Equal]", 
  "\"\<8 \[Pi] \[Epsilon] \!\(\*SubscriptBox[\(T\), \(ab\)]\)\>\""}]}], \
"Input",
 CellChangeTimes->{{3.773316452150737*^9, 3.7733165335172906`*^9}, {
   3.7733166061901207`*^9, 3.773316964773902*^9}, {3.773317054300076*^9, 
   3.7733170838813686`*^9}, {3.7733171265462976`*^9, 3.773317241125397*^9}, {
   3.7733173322616644`*^9, 3.7733173660413322`*^9}, 3.773317429345099*^9, {
   3.7733178620369453`*^9, 3.773317863903512*^9}, {3.7733180755838027`*^9, 
   3.7733181012362003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox["K", "_"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "X"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QX0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox["K", "_"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Q0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], "c", "d"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], $CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"R", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["R",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciScalarCD[],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "c", " "},
                {" ", " ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`h[
           xAct`xTensor`LI[1], $CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", "c"},
                {" ", "b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`h[
           xAct`xTensor`LI[1], -$CellContext`b, $CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", "c"},
                {" ", "a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`h[
           xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", " "},
                {" ", "a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`h[
           xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "c", "d"},
                {" ", " ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`h[
           xAct`xTensor`LI[1], $CellContext`c, $CellContext`d]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "c", " "},
                {" ", " ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`h[
           xAct`xTensor`LI[1], $CellContext`c, -$CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False]}]}], ")"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \[Epsilon] \\!\\(\\*SubscriptBox[\\(T\\), \
\\(ab\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{{3.7733164961696005`*^9, 3.7733165342083693`*^9}, {
   3.773316608812399*^9, 3.773316634867557*^9}, 3.7733166738131676`*^9, 
   3.773316852585021*^9, 3.773317430087282*^9, 3.77331774391146*^9, 
   3.7733178648307*^9, {3.7733180927482595`*^9, 3.7733181025945024`*^9}, 
   3.7733196284008207`*^9, 3.7733198445977187`*^9, 3.7733200407988944`*^9, 
   3.773366065781175*^9, 3.7733681709320574`*^9, 3.7733683164124837`*^9, 
   3.7733708124791875`*^9, 3.7733711540752473`*^9, 3.7733712832934437`*^9, 
   3.7733759319066267`*^9}]
}, Open  ]],

Cell["\<\
On the other hand, the linearized scalar field equation is... \
\>", "Text",
 CellChangeTimes->{{3.7733177581221867`*^9, 3.7733177748562236`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFElinear", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Perturbed", "[", 
            RowBox[{"BSE", ",", "1"}], "]"}], "//", "ExpandPerturbation"}], "//",
           "ContractMetric"}], "//", "NoScalar"}], "//", "ToCanonical"}], "//",
        "org"}], ")"}], "/.", "SimplifyQ"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", "SFElinear", ")"}], "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.773316554181466*^9, 3.7733165551340275`*^9}, {
  3.7733165895907974`*^9, 3.7733165921820974`*^9}, {3.773316978861601*^9, 
  3.7733170127883263`*^9}, {3.7733177814809113`*^9, 3.773317852391872*^9}, {
  3.7733180517413683`*^9, 3.773318055320876*^9}, {3.773318088784252*^9, 
  3.773318109531026*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "X"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QX0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "XX"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QXX0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Psi][
           xAct`xTensor`LI[1]]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "b", " "},
                {" ", " ", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`h[
          xAct`xTensor`LI[1], $CellContext`b, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", "b"},
                {" ", "a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`h[
          xAct`xTensor`LI[1], -$CellContext`a, $CellContext`b]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], "a", "b"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], $CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Psi][
           xAct`xTensor`LI[1]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", "c"},
               {" ", "a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", " "},
                {" ", "a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`h[
          xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XXX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XXX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.77331659273783*^9, {3.773316995265541*^9, 3.773317013791396*^9}, {
   3.7733178060967736`*^9, 3.7733178533586245`*^9}, 3.773318110978798*^9, 
   3.7733196290244527`*^9, 3.7733198486561003`*^9, 3.773320043949954*^9, 
   3.773366069858305*^9, 3.7733681740225625`*^9, 3.7733683170065084`*^9, 
   3.7733708268039556`*^9, 3.773371170212697*^9, 3.7733712837152195`*^9, 
   3.7733759322719574`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["II. Linearized field equations: component \
calculations",
 FontSize->18,
 FontColor->RGBColor[1, 0.5, 0]]], "Text",
 CellChangeTimes->{{3.7733178872275934`*^9, 3.7733179063033886`*^9}}],

Cell[TextData[{
 "Finally, we present the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence stealth black hole of Ref. [1]. We then reduce EElinear and SFE \
linear in component forms.\n\nWe start by defining the shift symmetric ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potential [1]:"
}], "Text",
 CellChangeTimes->{{3.773317922565898*^9, 3.773317975146597*^9}, {
  3.773318022970854*^9, 3.773318030578541*^9}, {3.7733755333526373`*^9, 
  3.773375534778934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Beta]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ktfl", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"b", "+", 
   RowBox[{"2", "\[Beta]", 
    SqrtBox[
     RowBox[{"-", "b"}]]}]}]}]}], "Input",
 CellChangeTimes->{{3.773317976118695*^9, 3.773318019320345*^9}, {
  3.773371062306238*^9, 3.773371063363315*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Beta]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Beta], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733711748054123`*^9, 3.7733712837620883`*^9, 
  3.773375932345396*^9}]
}, Open  ]],

Cell[TextData[{
 "In the background, the scalar field\[CloseCurlyQuote]s kinetic density \
becomes constant, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "=", 
    RowBox[{"-", 
     SuperscriptBox["\[Beta]", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The background potentials in the linearized equations then become..."
}], "Text",
 CellChangeTimes->{{3.773318147792363*^9, 3.773318164584118*^9}, {
  3.7733185413235674`*^9, 3.7733185697644353`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"\[Beta]", ">", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X0", "=", 
   RowBox[{"-", 
    SuperscriptBox["\[Beta]", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TFLpotentials", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q0", "\[Rule]", 
       RowBox[{"Ktfl", "[", 
        RowBox[{"0", ",", "b"}], "]"}]}], ",", 
      RowBox[{"QX0", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Ktfl", "[", 
          RowBox[{"0", ",", "b"}], "]"}], ",", "b"}], "]"}]}], ",", 
      RowBox[{"QXX0", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Ktfl", "[", 
          RowBox[{"0", ",", "b"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"b", ",", "2"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"QXXX0", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Ktfl", "[", 
          RowBox[{"0", ",", "b"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"b", ",", "3"}], "}"}]}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"b", "\[Rule]", "X0"}]}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7733181776401653`*^9, 3.7733185143265195`*^9}, {
  3.7733710683066726`*^9, 3.7733710906142445`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox["K", "_"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q0,
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Beta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Beta],
      Editable->False], "2"]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "X"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QX0,
     Editable->False], "\[Rule]", "0"}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "XX"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QXX0,
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"]}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "XXX"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QXXX0,
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["3", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "4"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7733183281893315`*^9, 3.7733183488233476`*^9}, {
   3.773318398741041*^9, 3.7733184430906334`*^9}, 3.77331851678135*^9, 
   3.7733196291312313`*^9, 3.773319856470482*^9, 3.773320062454842*^9, 
   3.773366084604828*^9, 3.7733681796167307`*^9, 3.7733683170694284`*^9, 
   3.773370837082799*^9, 3.7733711006583433`*^9, 3.7733711768673887`*^9, 
   3.7733712837933264`*^9, 3.773375932395916*^9}]
}, Open  ]],

Cell["\<\
The Einstein equation and the scalar field equation then become...\
\>", "Text",
 CellChangeTimes->{{3.773318590815277*^9, 3.773318611519104*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EEtfl", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"EElinear", "/.", "TFLpotentials"}], "/.", "ruleMetricPert"}], "/.",
     "ruleScalarPert"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFEtfl", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SFElinear", "/.", "TFLpotentials"}], "/.", "ruleMetricPert"}], 
     "/.", "ruleScalarPert"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EEtfl", "==", 
  "\"\<8 \[Pi] \[Epsilon] \!\(\*SubscriptBox[\(T\), \(ab\)]\)\>\""}], "\
\[IndentingNewLine]", 
 RowBox[{"SFEtfl", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7733186137424917`*^9, 3.7733186713160934`*^9}, {
  3.773318736557102*^9, 3.7733187513217587`*^9}, {3.7733192792053895`*^9, 
  3.77331930810187*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Beta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Beta],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["R",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciScalarCD[],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"R", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`c, $CellContext`d],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
        Editable->False]}], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][$CellContext`c, $CellContext`d]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]]}], ")"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \[Epsilon] \\!\\(\\*SubscriptBox[\\(T\\), \
\\(ab\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{
  3.7733186743016424`*^9, {3.7733187426127815`*^9, 3.7733187518577604`*^9}, 
   3.773319308770158*^9, 3.773319629212333*^9, 3.7733198584991565`*^9, 
   3.77332006617548*^9, 3.773366095961528*^9, 3.7733681818405085`*^9, 
   3.773368317129166*^9, 3.773370849673602*^9, 3.7733711821474023`*^9, 
   3.7733712838714657`*^9, 3.7733759324784703`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SubscriptBox["\[Del]", "a"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]],
      Editable->False]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "2"]}]], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], 
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
         Editable->False]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], 
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"]], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], 
           SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Delta]\[Psi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], 
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]],
         Editable->False]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"]], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], 
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[$CellContext`c][
           $CellContext`\[Phi][]]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], GridBox[{
             {"\[ScriptH]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"a", "b"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], 
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "4"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "d"], 
           SubscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`d][
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Phi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "4"]}]]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.7733186743016424`*^9, {3.7733187426127815`*^9, 3.7733187518577604`*^9}, 
   3.773319308770158*^9, 3.773319629212333*^9, 3.7733198584991565`*^9, 
   3.77332006617548*^9, 3.773366095961528*^9, 3.7733681818405085`*^9, 
   3.773368317129166*^9, 3.773370849673602*^9, 3.7733711821474023`*^9, 
   3.7733712838714657`*^9, 3.7733759325114765`*^9}]
}, Open  ]],

Cell["\<\
At this point, we must use xCoba. The main idea is to put the above \
expressions in component form.\
\>", "Text",
 CellChangeTimes->{{3.7733187684378643`*^9, 3.773318803053726*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "xAct`xCoba`"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932550037*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.77337593255361*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932557232*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.7733759325616493`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.7733759325675635`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Proceeding in the usual way, we define a chart B, with coordinates (t, r, \
\[Theta], \[CurlyPhi]), in manifold Md.\
\>", "Text",
 CellChangeTimes->{{3.7733188632772217`*^9, 3.773318900765401*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefChart", "[", 
    RowBox[{"B", ",", "Md", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "[", "]"}], ",", 
       RowBox[{"r", "[", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "]"}], ",", 
       RowBox[{"\[CurlyPhi]", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"define", " ", "metric", " ", "components"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "M", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", "f0", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f0", "[", "r_", "]"}], "=", 
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{"2", "M"}], "r"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], 
      SuperscriptBox["r", "2"]}], 
     RowBox[{"6", "\[Kappa]"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bg", "=", 
   RowBox[{"f", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      RowBox[{"f0", "[", "r", "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TFLbh", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"f", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0", ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        FractionBox["1", 
         RowBox[{"f", "[", 
          RowBox[{"r", "[", "]"}], "]"}]], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        SuperscriptBox[
         RowBox[{"r", "[", "]"}], "2"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"xCoba", " ", "computes", " ", "curvature", " ", "quantities"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricInBasis", "[", 
   RowBox[{"g", ",", 
    RowBox[{"-", "B"}], ",", "TFLbh"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MetricCompute", "[", 
    RowBox[{"g", ",", "B", ",", "All", ",", 
     RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "component"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"\[Phi]0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(0\)]\)\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComponentValue", "[", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "]"}], ",", 
    RowBox[{"\[Phi]0", "[", 
     RowBox[{"r", "[", "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7733189181761007`*^9, 3.7733190818323417`*^9}, {
  3.773319233577424*^9, 3.773319248858676*^9}, {3.773319340721227*^9, 
  3.773319341136634*^9}, {3.773319419160674*^9, 3.7733194394219985`*^9}, {
  3.773319542175627*^9, 3.7733195800751348`*^9}, {3.773319867127632*^9, 
  3.773319893193243*^9}, {3.7733199245887737`*^9, 3.7733199351291447`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefChart", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"chart \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefChart, ": Defining ", "chart ", $CellContext`B, ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"t", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`t[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327420487`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"r", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`r[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932747657*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Theta]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`\[Theta][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327529535`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[CurlyPhi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`\[CurlyPhi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932758016*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", "mapping ", $CellContext`B, 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932763595*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse mapping \"\>", "\[InvisibleSpace]", "iB",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", 
   "inverse mapping ", $CellContext`iB, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932767891*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"diB", "[", 
    RowBox[{
     RowBox[{"-", "\[FormalA]"}], ",", "iBa"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`diB[-\[FormalA], $CellContext`iBa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327725143`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"dB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", "B\[FormalA]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`dB[-$CellContext`a, $CellContext`B\[FormalA]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932777422*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefBasis", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"basis \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Coordinated basis.\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefBasis, ": Defining ", "basis ", $CellContext`B, ". ", 
   "Coordinated basis."],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327831936`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parallel derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"PDB", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "parallel derivative ", 
   $CellContext`PDB[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327887955`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionPDB", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionPDB[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932793869*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelPDB", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelPDB[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.77337593279847*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Riemann tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RiemannPDB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", "d"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Riemann tensor ", 
   $CellContext`RiemannPDB[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328032293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciPDB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Ricci tensor ", 
   $CellContext`RicciPDB[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328083153`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric +1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaUpB", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric +1 density ", 
   $CellContext`etaUpB[$CellContext`a, $CellContext`b, $CellContext`c, \
$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328132267`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric -1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaDownB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric -1 density ", 
   $CellContext`etaDownB[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932817381*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`M, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932822392*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "f", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`f, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932826376*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "f0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`f0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932830219*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> -$CellContext`f[
      $CellContext`r[]], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328366127`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328487587`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932856057*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328693237`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759328806567`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`f[
      $CellContext`r[]]^(-1), " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932894989*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329025745`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329136224`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329291725`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329424744`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "2"]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`r[]^2, 
   " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329491186`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375932962042*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329721627`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759329827023`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759330034895`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["Sin",
         ShowAutoStyles->False,
         AutoSpacing->False],
        Sin,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`r[]^2 Sin[
       $CellContext`\[Theta][]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759330167656`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetgB", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetgB[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.773375933021589*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDPDB", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelCDPDB[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759330603733`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Phi]0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Phi]0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759332709336`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Phi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Phi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[Phi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Phi][] -> $CellContext`\[Phi]0[
     $CellContext`r[]], " for tensor ", $CellContext`\[Phi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759332759285`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The components of the perturbations are then computed as follows.\
\>", "Text",
 CellChangeTimes->{{3.773366469600523*^9, 3.7733664720698996`*^9}, {
  3.7733665025152383`*^9, 3.7733665045538893`*^9}, {3.773368063749564*^9, 
  3.77336807844987*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"spherical", " ", "harmonics"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefConstantSymbol", "/@", 
     RowBox[{"{", 
      RowBox[{"\[Lambda]", ",", "m", ",", "\[Omega]"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"PL", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(P\), \(lm\)]\)\>\""}]}],
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"PL", "''"}], "[", "\[Theta]_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "-", 
          RowBox[{
           SuperscriptBox["m", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], " ", 
       RowBox[{"PL", "[", "\[Theta]", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], 
       RowBox[{
        RowBox[{"PL", "'"}], "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YLM", ":=", 
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "m", " ", 
        RowBox[{"\[CurlyPhi]", "[", "]"}]}]], 
      RowBox[{"PL", "[", 
       RowBox[{"\[Theta]", "[", "]"}], "]"}], 
      SuperscriptBox["E", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
        RowBox[{"t", "[", "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"even", " ", "parity", " ", "sector"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"H0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"H1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(1\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"H2", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"KK", ",", 
      RowBox[{"PrintAs", "\[Rule]", "\"\<K\>\""}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"even", "=", 
     RowBox[{"YLM", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           RowBox[{"H0", "[", 
            RowBox[{"r", "[", "]"}], "]"}]}], ",", 
          RowBox[{"H1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"H1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], ",", 
          FractionBox[
           RowBox[{"H2", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           RowBox[{"f", "[", 
            RowBox[{"r", "[", "]"}], "]"}]], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"KK", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"r", "[", "]"}], "2"]}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", 
          RowBox[{
           RowBox[{"KK", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"r", "[", "]"}], "2"], 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}]}], 
       "}"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"odd", " ", "parity", " ", "sector"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"h0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"h1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(1\)]\)\>\""}]}], 
     "]"}], ";", 
    RowBox[{"odd", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0"}], "}"}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Eta]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pert", "=", 
     RowBox[{"even", "+", 
      RowBox[{"\[Eta]", " ", "odd"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"perturbation", " ", "components"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"ComponentArray", "[", 
       RowBox[{"\[ScriptH]", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"{", 
           RowBox[{"b", ",", "B"}], "}"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"{", 
           RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], "]"}], ",", "pert"}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChangeComponents", "[", 
     RowBox[{
      RowBox[{"\[ScriptH]", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}], ",", 
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"\[ScriptH]", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"b", ",", "B"}], "}"}]}], ",", 
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "\[Xi]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"\[Delta]\[Psi]", "[", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Xi]", "[", 
        RowBox[{"r", "[", "]"}], "]"}], "YLM"}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.773366593064456*^9, 3.77336661663792*^9}, {
  3.7733667709425535`*^9, 3.773366779891224*^9}, {3.7733668347114286`*^9, 
  3.7733668348525324`*^9}, {3.773366980015911*^9, 3.7733670108045745`*^9}, {
  3.77336723589386*^9, 3.773367245981041*^9}, {3.7733674722818136`*^9, 
  3.773367561633624*^9}, {3.7733676041279316`*^9, 3.773367670392033*^9}, {
  3.77336771620301*^9, 3.773367803580041*^9}, {3.7733679450121737`*^9, 
  3.773367956001275*^9}, {3.77336800446821*^9, 3.773368013528138*^9}, {
  3.773368285811098*^9, 3.7733682952640667`*^9}, {3.7733712547553983`*^9, 
  3.7733712549899473`*^9}, {3.7733759053881483`*^9, 3.7733759087747154`*^9}, {
  3.7788263279015703`*^9, 3.778826339850498*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Lambda]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Lambda], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "m", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`m, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933302916*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Omega]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Omega], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933307104*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "PL",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`PL, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933312274*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "H0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`H0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333174567`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "H1",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`H1, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333227034`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "H2",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`H2, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333266134`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "KK",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`KK, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333302712`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "h0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`h0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333348503`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "h1",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`h1, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333382726`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Eta]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Eta], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333425226`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`f[
      $CellContext`r[]] $CellContext`H0[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333543463`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "1"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H1,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`H1[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933370451*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933382027*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["\[Eta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Eta],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Sin",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Sin,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["P", "lm"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`PL,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`\[Eta] $CellContext`h0[
      $CellContext`r[]] Sin[
      $CellContext`\[Theta][]] Derivative[1][$CellContext`PL][
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759333981533`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759334143333`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[CurlyPhi][],
            Editable->False]}]}], ")"}]}]], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["H", "2"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`H2,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], "]"}], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["P", "lm"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`PL,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}]}], 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`f[
       $CellContext`r[]]^(-1) $CellContext`H2[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759334291496`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759334363937`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["\[Eta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Eta],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "1"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h1,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Sin",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Sin,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["P", "lm"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`PL,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`\[Eta] $CellContext`h1[
      $CellContext`r[]] Sin[
      $CellContext`\[Theta][]] Derivative[1][$CellContext`PL][
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933452375*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759334673986`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759334771166`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`KK,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`KK[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]] $CellContext`r[]^2, 
   " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759334941893`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759335009203`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759335155764`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.77337593352886*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759335422287`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`KK,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["Sin",
         ShowAutoStyles->False,
         AutoSpacing->False],
        Sin,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`KK[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]] $CellContext`r[]^2 Sin[
       $CellContext`\[Theta][]]^2, " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933554201*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759335861073`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933610528*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933637101*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933661867*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759336754475`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759336978407`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759337255106`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759337617626`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759338028564`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759338139906`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759338535137`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759338644657`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759339054613`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759339448614`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759339829473`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759339944367`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759340322747`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934043893*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759340832176`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934097031*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934137704*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759341710215`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     0, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759341867266`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759341979227`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`\[ScriptH][{1, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759342127886`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934229351*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`\[ScriptH][{1, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934245798*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`\[ScriptH][{2, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759342560177`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759342699833`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`\[ScriptH][{1, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934283785*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`\[ScriptH][{2, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759342961507`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`\[ScriptH][{3, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934311227*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["b",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["c",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{$CellContext`b, $CellContext`B}, \
{-$CellContext`c, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]]},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{$CellContext`b, $CellContext`B}, {$CellContext`a, \
$CellContext`B}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["c",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH][{-$CellContext`a, -$CellContext`B}, \
{-$CellContext`c, -$CellContext`B}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.7592157`7.3319101738857935", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`\[ScriptH][{$CellContext`b, $CellContext`B}, \
{-$CellContext`c, -$CellContext`B}] -> $CellContext`g[{$CellContext`b, \
$CellContext`B}, {$CellContext`a, $CellContext`B}] \
$CellContext`\[ScriptH][{-$CellContext`a, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}], " in ", 0.7592157`7.3319101738857935, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759343308287`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Xi]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Xi], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375934335678*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Delta]\[Psi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]\[Psi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Xi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Xi],
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[Delta]\[Psi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Delta]\[Psi][] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`PL[
      $CellContext`\[Theta][]] $CellContext`\[Xi][
      $CellContext`r[]], " for tensor ", $CellContext`\[Delta]\[Psi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.7733759343411508`*^9}]
}, Open  ]]
}, Open  ]],

Cell["Finally, the scalar field equation becomes...", "Text",
 CellChangeTimes->{{3.7733678423349247`*^9, 3.773367842953064*^9}, {
  3.7733680866464996`*^9, 3.7733680941529093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFEcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"SFEtfl", ",", "\[Epsilon]"}], "]"}], "//", 
         RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
        "ToValues"}], "//", "ToValues"}], "//", "Simplification"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"SFEcomp", "\[Equal]", "0"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "4"], " ", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[CurlyPhi][],
          Editable->False]}]}], ")"}]}]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Theta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Theta][],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Xi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Xi],
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["H", "2"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`H2,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], "2"], " ", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Xi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Xi],
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["H", "2"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`H2,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Xi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Xi],
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Beta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Beta],
               Editable->False], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["\[Phi]", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}], "-", 
            RowBox[{"3", " ", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], "3"]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Beta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Beta],
               Editable->False], "2"], " ", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["\[Phi]", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]0,
                Editable->False], "\[Prime]\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Beta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Beta],
               Editable->False], "2"], " ", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["H", "2"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`H2,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Phi]0,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["\[Xi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Xi],
                   Editable->False], "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["\[Beta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Beta],
                  Editable->False], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Phi]0,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}], "+", 
               RowBox[{"3", " ", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`f,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Phi]0,
                    Editable->False], "\[Prime]",
                   MultilineFunction->None], "[", 
                  InterpretationBox[
                   StyleBox["r",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`r[],
                   Editable->False], "]"}], "3"]}], "-", 
               RowBox[{"20", " ", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["\[Beta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Beta],
                  Editable->False], "2"], " ", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Phi]0,
                   Editable->False], "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.773367846720767*^9, 3.773368236425032*^9, 
  3.773368321664221*^9, 3.773370890131996*^9, 3.77337128790174*^9, 
  3.7733759360200152`*^9}]
}, Open  ]],

Cell["We simplify this as follows.", "Text",
 CellChangeTimes->{{3.7733683686658406`*^9, 3.773368374761974*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"removebrackets", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}], ",", 
     RowBox[{
      RowBox[{"r", "[", "]"}], "\[Rule]", "r"}], ",", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "]"}], "\[Rule]", "\[Theta]"}], ",", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "[", "]"}], "\[Rule]", "\[CurlyPhi]"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulef", "=", 
   RowBox[{"f", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["\[Beta]", "2"]}], 
       SuperscriptBox[
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "2"]]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFEcomp2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"SFEcomp", "/.", "removebrackets"}], ")"}], "/.", "rulef"}], 
      ")"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]pprule", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"SFEcomp2", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Xi]", "''"}], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Xi]pp", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "''"}], "[", "r", "]"}], "/.", "\[Xi]pprule"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"H2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"H2", "'"}], "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Xi]''(r)\>\"", "\[Equal]", "\[Xi]pp"}]}], "Input",
 CellChangeTimes->{{3.773368376546979*^9, 3.7733686388495235`*^9}, {
  3.7733687012114677`*^9, 3.773368784233404*^9}, {3.7733688411136017`*^9, 
  3.7733688511355023`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Xi]''(r)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "2"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H2,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "2"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H2,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "r"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Xi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Xi],
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "r"]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.7733686406693115`*^9, 3.7733687861726427`*^9, 
  3.7733688524941397`*^9, 3.773370893927984*^9, 3.7733712882766914`*^9, 
  3.773375936111142*^9}]
}, Open  ]],

Cell["\<\
To make this look like the expression in the companion article, we simply \
make the following transformation.\
\>", "Text",
 CellChangeTimes->{{3.773376733413616*^9, 3.773376768866003*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"hrr", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(rr\)]\)\>\""}]}],
      "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\"\<\[Xi]''(r)\>\"", "\[Equal]", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Xi]pp", "/.", 
        RowBox[{"H2", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"r", ",", 
           RowBox[{
            RowBox[{"hrr", "[", "r", "]"}], 
            RowBox[{"f", "[", "r", "]"}]}]}], "]"}]}]}], "/.", "rulef"}], 
      ")"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "'"}], "[", "r", "]"}], ",", 
       RowBox[{"hrr", "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"hrr", "'"}], "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773376797277991*^9, 3.77337692345638*^9}, {
  3.773377129217041*^9, 3.7733771864740677`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Xi]''(r)\"\>", "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["h", "rr"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hrr,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "2"], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "rr"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`hrr,
       Editable->False], "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "-", 
       RowBox[{"3", " ", "r", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}]], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Xi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Xi],
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "r"]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.7733769064507613`*^9, 3.773377155073775*^9, 
  3.773377187010594*^9}]
}, Open  ]],

Cell["\<\
This is the expression for the scalar field equation that is presented in the \
paper.\
\>", "Text",
 CellChangeTimes->{{3.7733772046812854`*^9, 3.773377216780513*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{825, 911},
WindowMargins->{{79, Automatic}, {Automatic, 55}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "ReverseColor.nb"]]}, Visible -> False, 
  FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (September 21, 2016)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 178, 6, 70, "Section"],
Cell[761, 30, 716, 13, 106, "Text"],
Cell[CellGroupData[{
Cell[1502, 47, 244, 3, 41, "Subsubsection"],
Cell[1749, 52, 453, 11, 358, "Text"],
Cell[CellGroupData[{
Cell[2227, 67, 3500, 95, 2854, "Input"],
Cell[CellGroupData[{
Cell[5752, 166, 772, 11, 216, "Print"],
Cell[6527, 179, 1041, 18, 117, "Print"],
Cell[7571, 199, 793, 11, 216, "Print"],
Cell[8367, 212, 754, 10, 117, "Print"],
Cell[9124, 224, 735, 10, 117, "Print"],
Cell[9862, 236, 774, 11, 216, "Print"],
Cell[10639, 249, 1050, 19, 117, "Print"],
Cell[11692, 270, 793, 11, 216, "Print"],
Cell[12488, 283, 774, 11, 216, "Print"],
Cell[13265, 296, 1043, 18, 117, "Print"],
Cell[14311, 316, 841, 12, 312, "Print"],
Cell[15155, 330, 774, 11, 216, "Print"],
Cell[15932, 343, 927, 13, 409, "Print"],
Cell[16862, 358, 774, 11, 216, "Print"],
Cell[17639, 371, 1014, 18, 117, "Print"],
Cell[18656, 391, 1100, 19, 117, "Print"],
Cell[19759, 412, 1201, 19, 216, "Print"],
Cell[20963, 433, 1159, 19, 117, "Print"],
Cell[22125, 454, 1177, 19, 117, "Print"],
Cell[23305, 475, 1105, 19, 117, "Print"],
Cell[24413, 496, 1118, 19, 117, "Print"],
Cell[25534, 517, 1266, 24, 117, "Print"],
Cell[26803, 543, 1366, 26, 216, "Print"],
Cell[28172, 571, 1341, 25, 117, "Print"],
Cell[29516, 598, 1359, 25, 117, "Print"],
Cell[30878, 625, 1188, 21, 117, "Print"],
Cell[32069, 648, 1314, 25, 216, "Print"],
Cell[33386, 675, 1332, 26, 216, "Print"],
Cell[34721, 703, 1356, 26, 216, "Print"],
Cell[36080, 731, 1274, 24, 117, "Print"],
Cell[37357, 757, 783, 11, 216, "Print"],
Cell[38143, 770, 1157, 19, 117, "Print"],
Cell[39303, 791, 785, 11, 216, "Print"],
Cell[40091, 804, 1285, 24, 216, "Print"],
Cell[41379, 830, 1343, 25, 117, "Print"],
Cell[42725, 857, 1284, 24, 216, "Print"],
Cell[44012, 883, 1170, 20, 117, "Print"],
Cell[45185, 905, 916, 15, 117, "Print"],
Cell[46104, 922, 908, 15, 117, "Print"],
Cell[47015, 939, 920, 15, 117, "Print"],
Cell[47938, 956, 1174, 20, 117, "Print"],
Cell[49115, 978, 1131, 19, 117, "Print"],
Cell[50249, 999, 1132, 19, 117, "Print"],
Cell[51384, 1020, 1148, 20, 117, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[52593, 1047, 541, 12, 35, "Subsubsection"],
Cell[53137, 1061, 341, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[53503, 1073, 1106, 29, 107, "Input"],
Cell[54612, 1104, 2000, 55, 45, "Output"]
}, Open  ]],
Cell[56627, 1162, 674, 10, 49, "Text"],
Cell[57304, 1174, 18041, 437, 1742, "Input"],
Cell[75348, 1613, 229, 3, 156, "Text"],
Cell[CellGroupData[{
Cell[75602, 1620, 616, 16, 577, "Input"],
Cell[CellGroupData[{
Cell[76243, 1640, 779, 15, 117, "Print"],
Cell[77025, 1657, 971, 19, 51, "Print"]
}, Open  ]],
Cell[78011, 1679, 6134, 183, 94, "Output"]
}, Open  ]],
Cell[84160, 1865, 183, 2, 68, "Text"],
Cell[CellGroupData[{
Cell[84368, 1871, 483, 13, 206, "Input"],
Cell[84854, 1886, 4547, 140, 94, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[89450, 2032, 236, 3, 91, "Subsubsection"],
Cell[89689, 2037, 471, 8, 197, "Text"],
Cell[CellGroupData[{
Cell[90185, 2049, 1060, 28, 341, "Input"],
Cell[CellGroupData[{
Cell[91270, 2081, 1109, 20, 51, "Print"],
Cell[92382, 2103, 1287, 24, 51, "Print"],
Cell[93672, 2129, 1185, 21, 51, "Print"]
}, Open  ]]
}, Open  ]],
Cell[94884, 2154, 255, 6, 111, "Text"],
Cell[95142, 2162, 709, 19, 115, "Input"],
Cell[95854, 2183, 815, 25, 203, "Text"],
Cell[96672, 2210, 623, 18, 266, "Input"],
Cell[97298, 2230, 143, 2, 156, "Text"],
Cell[CellGroupData[{
Cell[97466, 2236, 441, 13, 266, "Input"],
Cell[97910, 2251, 1092, 18, 117, "Print"]
}, Open  ]],
Cell[99017, 2272, 264, 5, 255, "Text"],
Cell[CellGroupData[{
Cell[99306, 2281, 2210, 67, 887, "Input"],
Cell[101519, 2350, 873, 17, 117, "Print"]
}, Open  ]],
Cell[102407, 2370, 138, 1, 156, "Text"],
Cell[102548, 2373, 205, 3, 181, "Text"],
Cell[102756, 2378, 265, 7, 257, "Text"],
Cell[CellGroupData[{
Cell[103046, 2389, 7144, 211, 931, "Input"],
Cell[CellGroupData[{
Cell[110215, 2604, 758, 14, 117, "Print"],
Cell[110976, 2620, 758, 14, 117, "Print"],
Cell[111737, 2636, 766, 15, 117, "Print"],
Cell[112506, 2653, 768, 15, 117, "Print"]
}, Open  ]]
}, Open  ]],
Cell[113301, 2672, 133, 1, 156, "Text"],
Cell[CellGroupData[{
Cell[113459, 2677, 1029, 25, 680, "Input"],
Cell[114491, 2704, 38405, 1065, 1044, "Output"]
}, Open  ]],
Cell[152911, 3772, 156, 3, 156, "Text"],
Cell[CellGroupData[{
Cell[153092, 3779, 883, 22, 296, "Input"],
Cell[153978, 3803, 29492, 857, 408, "Output"]
}, Open  ]],
Cell[183485, 4663, 210, 4, 79, "Text"],
Cell[183698, 4669, 478, 12, 199, "Text"],
Cell[CellGroupData[{
Cell[184201, 4685, 410, 12, 124, "Input"],
Cell[184614, 4699, 563, 12, 51, "Print"]
}, Open  ]],
Cell[185192, 4714, 482, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[185699, 4730, 1296, 37, 296, "Input"],
Cell[186998, 4769, 2110, 70, 100, "Output"]
}, Open  ]],
Cell[189123, 4842, 156, 3, 68, "Text"],
Cell[CellGroupData[{
Cell[189304, 4849, 801, 21, 341, "Input"],
Cell[190108, 4872, 25569, 698, 1046, "Output"],
Cell[215680, 5572, 17602, 519, 945, "Output"]
}, Open  ]],
Cell[233297, 6094, 192, 4, 255, "Text"],
Cell[CellGroupData[{
Cell[233514, 6102, 73, 2, 161, "Input"],
Cell[CellGroupData[{
Cell[233612, 6108, 356, 5, 216, "Print"],
Cell[233971, 6115, 625, 12, 117, "Print"],
Cell[234599, 6129, 394, 5, 216, "Print"],
Cell[234996, 6136, 356, 5, 216, "Print"],
Cell[235355, 6143, 513, 7, 409, "Print"],
Cell[235871, 6152, 358, 5, 216, "Print"]
}, Open  ]]
}, Open  ]],
Cell[236256, 6161, 207, 4, 255, "Text"],
Cell[CellGroupData[{
Cell[236488, 6169, 3642, 103, 2196, "Input"],
Cell[CellGroupData[{
Cell[240155, 6276, 695, 13, 117, "Print"],
Cell[240853, 6291, 749, 14, 117, "Print"],
Cell[241605, 6307, 747, 14, 117, "Print"],
Cell[242355, 6323, 763, 14, 117, "Print"],
Cell[243121, 6339, 767, 14, 117, "Print"],
Cell[243891, 6355, 703, 13, 117, "Print"],
Cell[244597, 6370, 721, 13, 117, "Print"],
Cell[245321, 6385, 872, 18, 225, "Print"],
Cell[246196, 6405, 879, 18, 128, "Print"],
Cell[247078, 6425, 735, 14, 117, "Print"],
Cell[247816, 6441, 793, 15, 117, "Print"],
Cell[248612, 6458, 917, 19, 216, "Print"],
Cell[249532, 6479, 934, 20, 216, "Print"],
Cell[250469, 6501, 965, 20, 216, "Print"],
Cell[251437, 6523, 881, 18, 117, "Print"],
Cell[252321, 6543, 891, 17, 94, "Print"],
Cell[253215, 6562, 981, 21, 94, "Print"],
Cell[254199, 6585, 733, 13, 51, "Print"],
Cell[254935, 6600, 733, 13, 51, "Print"],
Cell[255671, 6615, 735, 13, 51, "Print"],
Cell[256409, 6630, 2229, 59, 57, "Print"],
Cell[258641, 6691, 1837, 44, 57, "Print"],
Cell[260481, 6737, 1835, 44, 57, "Print"],
Cell[262319, 6783, 1837, 44, 57, "Print"],
Cell[264159, 6829, 3062, 77, 57, "Print"],
Cell[267224, 6908, 2234, 59, 81, "Print"],
Cell[269461, 6969, 1837, 44, 57, "Print"],
Cell[271301, 7015, 1837, 44, 57, "Print"],
Cell[273141, 7061, 3062, 77, 57, "Print"],
Cell[276206, 7140, 3062, 77, 57, "Print"],
Cell[279271, 7219, 2030, 52, 57, "Print"],
Cell[281304, 7273, 1835, 44, 57, "Print"],
Cell[283142, 7319, 3062, 77, 57, "Print"],
Cell[286207, 7398, 3062, 77, 57, "Print"],
Cell[289272, 7477, 3062, 77, 57, "Print"],
Cell[292337, 7556, 2475, 67, 57, "Print"],
Cell[294815, 7625, 779, 14, 51, "Print"],
Cell[295597, 7641, 886, 17, 51, "Print"],
Cell[296486, 7660, 751, 14, 51, "Print"],
Cell[297240, 7676, 1189, 32, 51, "Print"]
}, Open  ]]
}, Open  ]],
Cell[298456, 7712, 258, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[298739, 7721, 9850, 277, 1960, "Input"],
Cell[CellGroupData[{
Cell[308614, 8002, 658, 13, 51, "Print"],
Cell[309275, 8017, 638, 12, 51, "Print"],
Cell[309916, 8031, 656, 13, 51, "Print"],
Cell[310575, 8046, 640, 12, 51, "Print"],
Cell[311218, 8060, 642, 12, 51, "Print"],
Cell[311863, 8074, 642, 12, 51, "Print"],
Cell[312508, 8088, 642, 12, 51, "Print"],
Cell[313153, 8102, 642, 12, 51, "Print"],
Cell[313798, 8116, 642, 12, 51, "Print"],
Cell[314443, 8130, 642, 12, 51, "Print"],
Cell[315088, 8144, 654, 13, 51, "Print"],
Cell[315745, 8159, 4107, 123, 103, "Print"],
Cell[319855, 8284, 3722, 109, 61, "Print"],
Cell[323580, 8395, 1789, 44, 57, "Print"],
Cell[325372, 8441, 4381, 131, 103, "Print"],
Cell[329756, 8574, 3039, 76, 57, "Print"],
Cell[332798, 8652, 4186, 124, 90, "Print"],
Cell[336987, 8778, 1791, 44, 57, "Print"],
Cell[338781, 8824, 4379, 131, 103, "Print"],
Cell[343163, 8957, 3039, 76, 57, "Print"],
Cell[346205, 9035, 3039, 76, 57, "Print"],
Cell[349247, 9113, 3908, 116, 61, "Print"],
Cell[353158, 9231, 1791, 44, 57, "Print"],
Cell[354952, 9277, 3039, 76, 57, "Print"],
Cell[357994, 9355, 3036, 76, 57, "Print"],
Cell[361033, 9433, 3039, 76, 57, "Print"],
Cell[364075, 9511, 4329, 130, 103, "Print"],
Cell[368407, 9643, 12406, 312, 100, "Print"],
Cell[380816, 9957, 12404, 312, 100, "Print"],
Cell[393223, 10271, 12404, 312, 100, "Print"],
Cell[405630, 10585, 12404, 312, 100, "Print"],
Cell[418037, 10899, 3035, 76, 57, "Print"],
Cell[421075, 10977, 12406, 312, 100, "Print"],
Cell[433484, 11291, 12406, 312, 100, "Print"],
Cell[445893, 11605, 12406, 312, 100, "Print"],
Cell[458302, 11919, 12406, 312, 100, "Print"],
Cell[470711, 12233, 3035, 76, 57, "Print"],
Cell[473749, 12311, 12406, 312, 100, "Print"],
Cell[486158, 12625, 3035, 76, 57, "Print"],
Cell[489196, 12703, 12406, 312, 100, "Print"],
Cell[501605, 13017, 12406, 312, 100, "Print"],
Cell[514014, 13331, 12406, 312, 100, "Print"],
Cell[526423, 13645, 3035, 76, 57, "Print"],
Cell[529461, 13723, 12406, 312, 100, "Print"],
Cell[541870, 14037, 3033, 76, 57, "Print"],
Cell[544906, 14115, 12406, 312, 100, "Print"],
Cell[557315, 14429, 3033, 76, 57, "Print"],
Cell[560351, 14507, 12404, 312, 100, "Print"],
Cell[572758, 14821, 12406, 312, 100, "Print"],
Cell[585167, 15135, 3035, 76, 57, "Print"],
Cell[588205, 15213, 3035, 76, 57, "Print"],
Cell[591243, 15291, 3035, 76, 57, "Print"],
Cell[594281, 15369, 3033, 76, 57, "Print"],
Cell[597317, 15447, 3033, 76, 57, "Print"],
Cell[600353, 15525, 3035, 76, 57, "Print"],
Cell[603391, 15603, 3035, 76, 57, "Print"],
Cell[606429, 15681, 3033, 76, 57, "Print"],
Cell[609465, 15759, 3035, 76, 57, "Print"],
Cell[612503, 15837, 3033, 76, 57, "Print"],
Cell[615539, 15915, 4551, 115, 57, "Print"],
Cell[620093, 16032, 650, 13, 51, "Print"],
Cell[620746, 16047, 2652, 81, 54, "Print"]
}, Open  ]]
}, Open  ]],
Cell[623425, 16132, 182, 2, 68, "Text"],
Cell[CellGroupData[{
Cell[623632, 16138, 498, 14, 251, "Input"],
Cell[624133, 16154, 20639, 619, 408, "Output"]
}, Open  ]],
Cell[644787, 16776, 112, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[644924, 16781, 2126, 64, 535, "Input"],
Cell[647053, 16847, 2926, 96, 175, "Output"]
}, Open  ]],
Cell[649994, 16946, 200, 4, 111, "Text"],
Cell[CellGroupData[{
Cell[650219, 16954, 1056, 31, 206, "Input"],
Cell[651278, 16987, 3668, 122, 195, "Output"]
}, Open  ]],
Cell[654961, 17112, 178, 4, 111, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

