(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    805944,      23687]
NotebookOptionsPosition[    800102,      23508]
NotebookOutlinePosition[    800455,      23523]
CellTagsIndexPosition[    800412,      23520]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Linear perturbations on bald black holes in kinetic gravity braiding\
\>", "Section",
 CellChangeTimes->{{3.778659199617829*^9, 3.778659222382524*^9}, {
  3.7800893292160606`*^9, 3.780089329595014*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7786613730498304`*^9, 3.778661373819543*^9}}],

Cell[TextData[{
 "In this notebook, we show that ",
 StyleBox["gravitational perturbations on bald black holes in kinetic gravity \
braiding (KGB) can be described by simply by the GR (Regge-Wheeler and \
Zerilli equations) plus a minimally coupled scalar field perturbation",
  FontSlant->"Italic"],
 ".\n\nWe use xAct for efficient calculations."
}], "Text",
 CellChangeTimes->{{3.778659270347067*^9, 3.77865936597223*^9}, {
  3.77865941640126*^9, 3.778659470184176*^9}, {3.778660602363035*^9, 
  3.7786606123129444`*^9}, {3.780089339903452*^9, 3.780089344645772*^9}, {
  3.780089386467951*^9, 3.7800894310008793`*^9}, {3.780089472476635*^9, 
  3.7800894732565513`*^9}, {3.780089536382767*^9, 3.7800895650022435`*^9}, {
  3.7800960970092363`*^9, 3.7800960981342306`*^9}}],

Cell[CellGroupData[{

Cell["I. Setup", "Subsection",
 CellChangeTimes->{{3.7786606215709085`*^9, 3.778660629586882*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xPert"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Options", "[", "MakeRule", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Options", "[", "ContractMetric", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"org", "[", "expr_", "]"}], ":=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
      "$PerturbationParameter", ",", "ToCanonical"}], "]"}]}], 
   RowBox[{"(*", 
    RowBox[{
    "organizes", " ", "expression", " ", "perturbation", " ", "order"}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "                                  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefManifold", "[", 
     RowBox[{"Md", ",", "dim", ",", 
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "i", ",", "j", ",", 
        "k", ",", "l", ",", "u", ",", "v"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefMetric", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
      RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"define", " ", "scalar", " ", "field"}], ",", " ", 
     RowBox[{"k", "-", 
      RowBox[{"essence", " ", "and", " ", "braiding", " ", "potential"}]}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], ",", "Md"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "Q", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "G", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "bookkeeping", " ", "parameter", " ", "for", " ", "GR", " ", "pieces"}], 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.778660650520007*^9, 3.7786606877326956`*^9}, {
  3.778661381203393*^9, 3.778661381654518*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704350497*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704355486*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704360471*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704420311*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704553953*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897045579433`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897045629296`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897045669184`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704760402*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704765388*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897047693777`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897047743645`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897047783575`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704782346*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.78008970478734*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897047923174`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704797303*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048003273`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048052807`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "Md", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", 
   "manifold ", $CellContext`Md, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048092723`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentMd", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentMd, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048142586`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704819244*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048232374`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704829219*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`a, -$CellContext`b, \
-$CellContext`c, -$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048332076`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704838193*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704843181*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704847172*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048521566`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048561773`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897048721027`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704877091*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897049040174`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704909006*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089704951889*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897050765553`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089705101491*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897051064763`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897052540812`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897052830048`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897052989626`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897053039503`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "Q", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`Q, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897053069425`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "G", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`G, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.780089705311927*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786606934947042`*^9, 3.77866138669781*^9, 
  3.7786632247400103`*^9, 3.77882608745743*^9, 3.7800897053149214`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II. Kinetic gravity braiding", "Subsection",
 CellChangeTimes->{{3.7786607113008947`*^9, 3.7786607160768166`*^9}}],

Cell["Kinetic gravity braiding is defined via the Lagrangian...", "Text",
 CellChangeTimes->{{3.7786607198002896`*^9, 3.7786607392505865`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LK", "=", 
   RowBox[{"Q", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", "]"}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "b"}], "]"}], "[", 
        RowBox[{"\[Phi]", "[", "]"}], "]"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"CD", "[", "b", "]"}], "[", 
        RowBox[{"\[Phi]", "[", "]"}], "]"}], "/", "2"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LG", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"G", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"CD", "[", 
           RowBox[{"-", "b"}], "]"}], "[", 
          RowBox[{"\[Phi]", "[", "]"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"CD", "[", "b", "]"}], "[", 
          RowBox[{"\[Phi]", "[", "]"}], "]"}], "/", "2"}]}]}], "]"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "c", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "c"}], "]"}], "[", 
      RowBox[{"\[Phi]", "[", "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LEH", "=", 
   RowBox[{"\[Kappa]", " ", 
    RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"L", "=", 
    RowBox[{"LK", "+", "LG", "+", "LEH"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", "L"}]}], "Input",
 CellChangeTimes->{{3.7786607482817163`*^9, 3.7786608707105646`*^9}, {
  3.778661397090942*^9, 3.7786614062092333`*^9}, {3.780089720743701*^9, 
  3.780089731724307*^9}}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["Q",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False]}]}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "-", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}]}], "]"}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{
  3.7786608734443684`*^9, {3.7786614000258913`*^9, 3.7786614066745214`*^9}, 
   3.778663233121693*^9, 3.7788260964522047`*^9, 3.7800897424306803`*^9}]
}, Open  ]],

Cell["\<\
We derive the field equations by using Cyril Pitrou\[CloseCurlyQuote]s \
algorithm for computing variational derivatives. This is publicly available \
as \[OpenCurlyDoubleQuote]https://github.com/xAct-contrib/examples\
\[CloseCurlyDoubleQuote] in https://github.com/xAct-contrib/examples.\
\>", "Text",
 CellChangeTimes->{3.7786608859165816`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Cyril", " ", 
    RowBox[{"Pitrou", "'"}], "s", " ", "code"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "UpIndexQ"}], ",", 
         RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "DownIndexQ"}], ",", 
         RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
        RowBox[{"(*", 
         RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}],
         ",", " ", 
        RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dgloc", "=", 
        RowBox[{"SymbolJoin", "[", 
         RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"hp", "=", 
        RowBox[{"Head", "@", 
         RowBox[{"Perturbation", "[", 
          RowBox[{"g", "[", 
           RowBox[{
            RowBox[{"DownIndex", "@", "a"}], ",", 
            RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"hp", "===", "Perturbation"}], ",", 
         RowBox[{"DefMetricPerturbation", "[", 
          RowBox[{"g", ",", "dgloc", ",", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
         RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
           "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
           " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", 
           " ", "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pertexpr", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
                RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
             RowBox[{"ToCanonical", "@", 
              RowBox[{"ContractMetric", "@", 
               RowBox[{"ExpandPerturbation", "@", 
                RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
            RowBox[{
             RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
             "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"We", " ", "then", " ", "use", " ", 
            RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", 
            " ", "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ",
             "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
            "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dgloc", "[", 
                    RowBox[{
                    RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], 
                    "]"}], ",", 
                   RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
                 "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
           "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
            " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
            "tensor"}], ",", " ", 
           RowBox[{
           "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", 
            "the", " ", "formal", " ", "first", " ", "order", " ", 
            "perturbation", " ", "the", " ", "tensor"}]}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
           "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"inds", "=", 
           RowBox[{"DummyIn", "/@", 
            RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "@@", "inds"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
            "and", " ", "replace", " ", 
            RowBox[{"Perturbation", "[", 
             RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", 
            "this", " ", "dummy", " ", "tensor"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", 
            " ", 
            RowBox[{"VarD", " ", "works", " ", 
             RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need",
              " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
             "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
                 "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "@", 
       RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
      "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "VarD", " ", "and", " ", "removal", " ", "of", " ", 
            "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], 
                  "]"}], "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"g_", "?", "MetricQ"}], "[", 
       RowBox[{"as__", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
            RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
       "]"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sqrtg", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
          RowBox[{
           RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"ToCanonical", "[", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"expr", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
          RowBox[{
           RowBox[{"PerturbAction", "[", 
            RowBox[{"sqrtg", ",", 
             RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", "tensor", ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}], "[", "inds___", "]"}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{
        RowBox[{"tensor_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
             RowBox[{"Not", "[", 
              RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
          ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", 
       RowBox[{"tensor", "[", "inds", "]"}], ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}]}]], "Input"],

Cell["The vacuum Einstein equation is then given by...", "Text",
 CellChangeTimes->{{3.778660915703196*^9, 3.7786609457572126`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BME", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{"L", ",", 
          RowBox[{"g", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}], "]"}], "//", "ContractMetric"}], 
       "//", "RicciToEinstein"}], "//", "ToCanonical"}], "//", "NoScalar"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"BME", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.778660940781784*^9, 3.778660941116452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786614214752073`*^9, 3.778663233362013*^9, 
  3.7788260967224655`*^9, 3.780089760975097*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786614214752073`*^9, 3.778663233362013*^9, 
  3.7788260967224655`*^9, 3.7800897609810815`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7786609221843824`*^9, 3.77866094932699*^9}, 
   3.778661422158272*^9, 3.778663234002796*^9, 3.7788260975610447`*^9, 
   3.7800897618667126`*^9}]
}, Open  ]],

Cell["Also, the scalar field satisfies its field equation...", "Text",
 CellChangeTimes->{{3.7786609591369934`*^9, 3.7786609784580865`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"L", ",", 
         RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "ToCanonical"}], "//", "NoScalar"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"BSE", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7786609861603355`*^9, 3.7786609864616146`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "a"], 
        SubscriptBox["\[Del]", "b"], 
        SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`a][
       $CellContext`CD[-$CellContext`b][
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "a"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`a][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`a][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.778660987660149*^9, 3.7786614249511847`*^9, 
  3.778663234559531*^9, 3.778826098450502*^9, 3.78008979025082*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II. Linearized theory", "Subsection",
 CellChangeTimes->{{3.7786610166860437`*^9, 3.7786610196332793`*^9}}],

Cell["\<\
Using xAct, we can derive the linearized field equations very easily (and \
efficiently) using xPert\[CloseCurlyQuote]s master functions Perturbed[...] \
and ExpandPerturbation[...].\
\>", "Text",
 CellChangeTimes->{{3.778661104960035*^9, 3.7786611639337497`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefMetricPerturbation", "[", 
   RowBox[{"g", ",", "h", ",", "\[Epsilon]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Unprotect", "[", "IndexForm", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndexForm", "[", 
    RowBox[{"LI", "[", "x_", "]"}], "]"}], ":=", 
   RowBox[{"ColorString", "[", 
    RowBox[{
     RowBox[{"ToString", "[", "x", "]"}], ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "IndexForm", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndexForm", "[", 
   RowBox[{"LI", "[", "n", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensorPerturbation", "[", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order", "]"}], "]"}], ",", 
    RowBox[{"\[Phi]", "[", "]"}], ",", "Md"}], "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.778661182560832*^9, 3.778661444393752*^9, 
  3.7786632429478493`*^9, 3.7788261064263906`*^9, 3.7800898051220617`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.778661182560832*^9, 3.778661444393752*^9, 
  3.7786632429478493`*^9, 3.7788261064263906`*^9, 3.780089805127046*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Psi]", "[", 
    RowBox[{"LI", "[", "\<\"order\"\>", "]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Psi][
    xAct`xTensor`LI["order"]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.778661182560832*^9, 3.778661444393752*^9, 
  3.7786632429478493`*^9, 3.7788261064263906`*^9, 3.780089805131034*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. Rules", "Subsubsection",
 CellChangeTimes->{{3.7786612150052767`*^9, 3.7786612184832015`*^9}}],

Cell["\<\
We first write down some rules to simplify the analysis of the results.

Here is a rule for breaking down the analysis into metric and scalar modes.\
\>", "Text",
 CellChangeTimes->{{3.7786612224929132`*^9, 3.778661272277321*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pertscalar", "=", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"LI", "[", "order_", "]"}], ",", "__"}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "0"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pertmetric", "=", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "0"}]}]}]}], ";"}]}], "Input"],

Cell[TextData[{
 "The following rules impose that the perturbations be defined as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "ab"], "=", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "_"], "ab"], "+", 
     SubscriptBox["h", "ab"]}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     OverscriptBox["\[Phi]", "_"], "+", "\[Psi]"}]}], TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "ab"], TraditionalForm]]],
 " and \[Psi] also contain nonlinear orders. The results for this are \
indistinguishable at linear order."
}], "Text",
 CellChangeTimes->{3.7786612932339144`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rule1", "=", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"LI", "[", "order_", "]"}], ",", "__"}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "1"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rule2", "=", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"0", "/;", 
     RowBox[{"order", ">", "1"}]}]}]}], ";"}]}], "Input"],

Cell["The following is for aesthetics.", "Text",
 CellChangeTimes->{3.7786613077604604`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[Delta]\[Psi]", "[", "]"}], ",", "Md"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleScalarPert", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"LI", "[", "1", "]"}], "]"}], ",", 
     RowBox[{"\[Delta]\[Psi]", "[", "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]\[Psi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]\[Psi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.778661312481688*^9, 3.7786614537049227`*^9, 
  3.778663243147056*^9, 3.778826106713318*^9, 3.7800898189629083`*^9}]
}, Open  ]],

Cell["\<\
Finally, we define the tensor \[ScriptH] to replace the metric perturbations \
in preparation for xCoba/component analysis.\
\>", "Text",
 CellChangeTimes->{3.778661318279637*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[ScriptH]", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "Md", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<\[ScriptH]\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert1", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", 
       RowBox[{"-", "a_"}], ",", 
       RowBox[{"-", "b_"}]}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert2", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", 
       RowBox[{"-", "a_"}], ",", "b_"}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", "b"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert3", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", 
       RowBox[{"-", "b_"}]}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{"a", ",", 
       RowBox[{"-", "b"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert4", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", "b_"}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert", "=", 
   RowBox[{"{", 
    RowBox[{
    "ruleMetricPert1", ",", "ruleMetricPert2", ",", "ruleMetricPert3", ",", 
     "ruleMetricPert4"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptH]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7786613238952584`*^9, 3.778661455517621*^9, 
  3.7786632431941648`*^9, 3.778826106736227*^9, 3.7800898283188896`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B. Linearized field equations", "Subsubsection",
 CellChangeTimes->{{3.7786613356520057`*^9, 3.778661341357419*^9}, {
  3.778661873325976*^9, 3.7786618736387243`*^9}}],

Cell["\<\
Here, we use xPert\[CloseCurlyQuote]s master functions Perturbed[...] and \
ExpandPerturbation[...] to obtain covariant expressions for the linearized \
field equations.

The linearized Einstein equation is given by...\
\>", "Text",
 CellChangeTimes->{{3.7786617988529387`*^9, 3.77866180287134*^9}, {
  3.778661862649428*^9, 3.778661918892214*^9}, {3.7786620866599307`*^9, 
  3.7786621014598336`*^9}, {3.7786622735357075`*^9, 3.778662291854123*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EElinear", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Perturbed", "[", 
             RowBox[{"BME", ",", "1"}], "]"}], "//", "ExpandPerturbation"}], "//",
            "ContractMetric"}], "//", "NoScalar"}], "//", "ToCanonical"}], "//",
         "org"}], ")"}], "/.", "ruleScalarPert"}], "/.", "ruleMetricPert"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EElinear", "\[Equal]", 
  "\"\<8 \[Pi] \[Epsilon] \!\(\*SubscriptBox[\(T\), \(ab\)]\)\>\""}]}], \
"Input",
 CellChangeTimes->{{3.7786621930529113`*^9, 3.778662211552553*^9}, {
   3.778662251297984*^9, 3.7786622567248363`*^9}, 3.780089862728888*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["R",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciScalarCD[],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"R", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`c, $CellContext`d],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][$CellContext`c, $CellContext`d]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"d", " "},
                {" ", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][$CellContext`d, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"c", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[ScriptH][-$CellContext`c, $CellContext`d]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "d"},
               {"c", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "d"},
               {"c", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "e"},
               {"c", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, $CellContext`e],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[$CellContext`e][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "i"], 
          SubscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`i][
         $CellContext`CD[-$CellContext`e][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "i"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`i][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"d", "e"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`d, -$CellContext`e],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}]}], ")"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \[Epsilon] \\!\\(\\*SubscriptBox[\\(T\\), \
\\(ab\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{3.7786622137015414`*^9, 3.7786622592899036`*^9, 
  3.7786632453208227`*^9, 3.7788261087860165`*^9, 3.780089886914222*^9}]
}, Open  ]],

Cell["The linearized scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.7786622958964167`*^9, 3.7786623031618195`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFElinear", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Perturbed", "[", 
             RowBox[{"BSE", ",", "1"}], "]"}], "//", "ExpandPerturbation"}], "//",
            "ContractMetric"}], "//", "NoScalar"}], "//", "ToCanonical"}], "//",
         "org"}], ")"}], "/.", "ruleScalarPert"}], "/.", "ruleMetricPert"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"SFElinear", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7786623165559835`*^9, 3.778662337591106*^9}, 
   3.780089926564212*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "a"], 
        SubscriptBox["\[Del]", "b"], 
        SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`a][
       $CellContext`CD[-$CellContext`b][
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "a"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`a][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`a][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`a][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], 
           SubscriptBox["\[Del]", "b"], 
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`CD[-$CellContext`b][
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]]]],
         Editable->False]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[$CellContext`b][
           $CellContext`\[Delta]\[Psi][]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"b", "c"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`b, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Delta]\[Psi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "b"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[$CellContext`c][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"b", "c"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`b, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"a", "b"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "b"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"a", "b"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][-$CellContext`b, -$CellContext`c]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"b", " "},
                {" ", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][$CellContext`b, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "b"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[ScriptH][-$CellContext`a, $CellContext`b]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"a", "b"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[$CellContext`c][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"d", " "},
                {" ", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][$CellContext`d, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`d][
          $CellContext`CD[$CellContext`d][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"c", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[ScriptH][-$CellContext`c, $CellContext`d]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[ScriptH][-$CellContext`b, -$CellContext`c]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[$CellContext`e][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"b", " "},
                {" ", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][$CellContext`b, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "b"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[ScriptH][-$CellContext`a, $CellContext`b]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"a", "b"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"b", "c"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`b, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Delta]\[Psi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`a][
                $CellContext`\[Phi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`a][
              $CellContext`\[Phi][]] $CellContext`CD[$CellContext`a][
              $CellContext`\[Phi][]]],
           Editable->False]}]}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7786623439140825`*^9, 3.7786632476476603`*^9, 
  3.778826111872126*^9, 3.78008993579652*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["III. Perturbations on bald black holes", "Subsection",
 CellChangeTimes->{{3.7786624418140583`*^9, 3.7786624491366053`*^9}, {
  3.78008995079043*^9, 3.78008995111759*^9}}],

Cell["\<\
Finally, we study specifically the perturbations on bald black holes in KGB. \
The bald limit corresponds to...\
\>", "Text",
 CellChangeTimes->{{3.778662452932974*^9, 3.778662453223996*^9}, {
  3.7786624910245194`*^9, 3.7786625710947957`*^9}, {3.7800899961112566`*^9, 
  3.78009002083515*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"bald", " ", "scalar"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", 
     RowBox[{"\[Phi]0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", 
       "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(0\)]\)\>\""}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rulebaldscalar", "=", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], "\[Rule]", "\[Phi]0"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"bald", " ", "tensor"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[CapitalLambda]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rulemaxsym", "=", 
     RowBox[{
      RowBox[{"RiemannCD", "[", 
       RowBox[{"b_", ",", "c_", ",", "d_", ",", "e_"}], "]"}], 
      "\[RuleDelayed]", 
      RowBox[{
       FractionBox["\[CapitalLambda]", "3"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"b", ",", "d"}], "]"}], 
          RowBox[{"g", "[", 
           RowBox[{"c", ",", "e"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"b", ",", "e"}], "]"}], 
          RowBox[{"g", "[", 
           RowBox[{"c", ",", "d"}], "]"}]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rulericcibald", "=", 
     RowBox[{
      RowBox[{"RicciCD", "[", 
       RowBox[{"b_", ",", "d_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"\[CapitalLambda]", " ", 
       RowBox[{"g", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rulescalarbald", "=", 
     RowBox[{
      RowBox[{"RicciScalarCD", "[", "]"}], "\[RuleDelayed]", 
      RowBox[{"4", "\[CapitalLambda]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ruleeinsteinbald", "=", 
     RowBox[{
      RowBox[{"EinsteinCD", "[", 
       RowBox[{"b_", ",", "d_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"-", "\[CapitalLambda]"}], " ", 
       RowBox[{"g", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rulebaldtensor", "=", 
     RowBox[{"{", 
      RowBox[{
      "rulemaxsym", ",", "rulericcibald", ",", "rulescalarbald", ",", 
       "ruleeinsteinbald"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rulebald", "=", 
     RowBox[{"Union", "[", 
      RowBox[{
       RowBox[{"{", "rulebaldscalar", "}"}], ",", "rulebaldtensor"}], "]"}]}],
     ";"}]}]}]], "Input",
 CellChangeTimes->{{3.78009004447993*^9, 3.7800900598717833`*^9}, {
   3.7800907621507235`*^9, 3.780090836883888*^9}, {3.780091180860731*^9, 
   3.780091237592966*^9}, {3.7800913065293884`*^9, 3.780091324010646*^9}, {
   3.78009198324082*^9, 3.7800920033480587`*^9}, {3.78009209956597*^9, 
   3.7800921735052423`*^9}, {3.780092289669648*^9, 3.780092431753785*^9}, {
   3.780092476330594*^9, 3.7800924765609426`*^9}, 3.780092578590152*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Phi]0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Phi]0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.780091242556694*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[CapitalLambda]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[CapitalLambda], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7800912425606833`*^9}]
}, Open  ]]
}, Open  ]],

Cell["The metric and scalar field equations then become...", "Text",
 CellChangeTimes->{{3.7786626077881727`*^9, 3.778662617995245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EElinearbald", "=", 
   RowBox[{
    RowBox[{"EElinear", "/.", "rulebald"}], "//", "ToCanonical"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFElinearbald", "=", 
    RowBox[{
     RowBox[{"SFElinear", "/.", "rulebald"}], "//", "ToCanonical"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EElinearbald", "\[Equal]", "0"}], "\[IndentingNewLine]", 
 RowBox[{"SFElinearbald", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7786626659255867`*^9, 3.7786626896493244`*^9}, {
  3.78009132897738*^9, 3.7800913466271734`*^9}, {3.780091404151069*^9, 
  3.780091442049961*^9}, {3.7800926146068416`*^9, 3.7800926245552454`*^9}, {
  3.780092656211641*^9, 3.7800926617418485`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "d"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {"c", " "},
             {" ", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "a"], GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"b", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[ScriptH][$CellContext`c, $CellContext`d]]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {"c", " "},
             {" ", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Delta]\[Psi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]\[Psi][],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7800926250379868`*^9, 3.7800926622684083`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Delta]\[Psi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Delta]\[Psi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], ",", "0"}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Delta]\[Psi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]\[Psi][],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7800926250379868`*^9, 3.78009266228237*^9}]
}, Open  ]],

Cell["\<\
The metric field equation is that of GR with a fine-tuned cosmological \
constant. To see this, first let us look at the background term...\
\>", "Text",
 CellChangeTimes->{{3.780093568598254*^9, 3.780093622711564*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEbackground", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"EElinearbald", ",", "\[Epsilon]", ",", "0"}], "]"}], "//", 
      "Simplification"}], ")"}], "\[Equal]", "0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7800940415537386`*^9, 3.7800941343707886`*^9}, {
  3.7800942075082054`*^9, 3.7800942160852733`*^9}}],

Cell["From this, we then get...", "Text",
 CellChangeTimes->{{3.780094156937421*^9, 3.7800941609875927`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EEbgsol", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"EEbackground", ",", 
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], ",", "0"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*InterpretationBox[
StyleBox[\"Q\",
ShowAutoStyles->False,
AutoSpacing->False],
$CellContext`Q,
Editable->False]\)[\!\(\*InterpretationBox[
StyleBox[SubscriptBox[\"\[Phi]\", \"0\"],
ShowAutoStyles->False,
AutoSpacing->False],
$CellContext`\[Phi]0,
Editable->False]\),0]\>\"", "\[Equal]", 
   RowBox[{
    InterpretationBox[
     StyleBox["Q",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], ",", "0"}], "]"}]}], "/.", "EEbgsol"}]}], "Input",
 CellChangeTimes->{{3.780094162606262*^9, 3.780094163411109*^9}, {
  3.7800942226527176`*^9, 3.7800942745479565`*^9}, {3.7800958283356075`*^9, 
  3.7800958345659485`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*InterpretationBox[\\n \
StyleBox[\\\"Q\\\",\\nShowAutoStyles->False,\\nAutoSpacing->False],\\n \
$CellContext`Q,\\nEditable->False]\\)[\\!\\(\\*InterpretationBox[\\n \
StyleBox[SubscriptBox[\\\"\[Phi]\\\", \
\\\"0\\\"],\\nShowAutoStyles->False,\\nAutoSpacing->False],\\n $CellContext`\
\[Phi]0,\\nEditable->False]\\),0]\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox["\[CapitalLambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[CapitalLambda],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.7800942749520187`*^9, 3.7800958352949963`*^9}]
}, Open  ]],

Cell["\<\
Then, the Einstein equation reduces to the first order expression...\
\>", "Text",
 CellChangeTimes->{{3.780094283438224*^9, 3.780094297826718*^9}, {
  3.780094362168686*^9, 3.780094372487092*^9}, {3.780094639397262*^9, 
  3.7800946403237877`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EElinearonly", "=", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"EElinearbald", "/.", "EEbgsol"}], "//", "ToCanonical"}], ",", 
     "\[Kappa]"}], "]"}], "\[Equal]", 
   "\"\<8 \[Pi] \!\(\*SubscriptBox[SuperscriptBox[\(T\), \((M)\)], \
\(ab\)]\)\>\""}]}]], "Input",
 CellChangeTimes->{{3.780094302018508*^9, 3.78009434760861*^9}, {
   3.78009437916424*^9, 3.7800944118707914`*^9}, {3.7800944668697357`*^9, 
   3.7800944730492167`*^9}, {3.7800946539353933`*^9, 3.780094666163698*^9}, {
   3.7800948098824697`*^9, 3.7800948324181724`*^9}, 3.7800957697103605`*^9, {
   3.7800958426632957`*^9, 3.780095845901639*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False]}], " ", 
       InterpretationBox[
        StyleBox["\[CapitalLambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[CapitalLambda],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[CapitalLambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[CapitalLambda],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][$CellContext`c, $CellContext`d]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Delta]\[Psi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]\[Psi][],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], ",", "0"}], "]"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \
\\((M)\\)], \\(ab\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{
  3.780094349188388*^9, {3.780094386859664*^9, 3.7800944122846813`*^9}, 
   3.7800944736336513`*^9, {3.780094661480218*^9, 3.780094666615487*^9}, 
   3.7800948334085236`*^9, 3.7800957707027006`*^9, 3.7800958463634024`*^9}]
}, Open  ]],

Cell["On the other hand, the scalar field equation is simply...", "Text",
 CellChangeTimes->{{3.78009477707618*^9, 3.780094784480348*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SFElinearonly", "=", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"SFElinearbald", ",", "\[Epsilon]"}], "]"}], "\[Equal]", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.780094787172149*^9, 3.780094806222215*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], ",", "0"}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], ",", "0"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Delta]\[Psi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Delta]\[Psi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]\[Psi][],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], ",", "0"}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7800948036690407`*^9, 3.7800948066540585`*^9}}]
}, Open  ]],

Cell["The background limit of this imposes...", "Text",
 CellChangeTimes->{{3.780095874068329*^9, 3.780095880655753*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SFEbgsol", "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"SFElinearbald", ",", "\[Epsilon]", ",", "0"}], "]"}], "\[Rule]",
     "0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7800958822075634`*^9, 3.780095917753523*^9}}],

Cell["\<\
Finally, the Einstein equation and the scalar field equation become...\
\>", "Text",
 CellChangeTimes->{{3.7800959250729566`*^9, 3.7800959370329776`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"final", " ", "form", " ", "EE"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EEfinal", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"EElinearonly", "/.", "SFEbgsol"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Kappa]", ",", "\[Epsilon]"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"final", " ", "form", " ", "SFE"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"SFEfinal", "=", 
    RowBox[{"SFElinearonly", "/.", "SFEbgsol"}]}]}]}]], "Input",
 CellChangeTimes->{{3.780095939919256*^9, 3.780096012405448*^9}, {
  3.7800960457722635`*^9, 3.780096053806751*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox["\[Epsilon]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Epsilon],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["\[CapitalLambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[CapitalLambda],
        Editable->False]}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox["\[CapitalLambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[CapitalLambda],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {"c", "d"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[$CellContext`c, $CellContext`d],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"c", "d"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], 
         SubscriptBox["\[Del]", "a"], GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", " "},
               {" ", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "c"], 
         SubscriptBox["\[Del]", "a"], GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"b", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`c][
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "c"], 
         SubscriptBox["\[Del]", "b"], GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`c][
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "c"], 
         SuperscriptBox["\[Del]", "c"], GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`c][
        $CellContext`CD[$CellContext`c][
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "d"], 
         SubscriptBox["\[Del]", "c"], GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`d][
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[ScriptH][$CellContext`c, $CellContext`d]]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "d"], 
         SuperscriptBox["\[Del]", "d"], GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", " "},
               {" ", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`d][
        $CellContext`CD[$CellContext`d][
         $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
       Editable->False]}]}], ")"}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \
\\((M)\\)], \\(ab\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{{3.7800959665450654`*^9, 3.780095995998315*^9}, 
   3.780096054323368*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox["\[Epsilon]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Epsilon],
    Editable->False], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "a"], 
         SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Delta]\[Psi][]]],
       Editable->False], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], ",", "0"}], "]"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "a"], 
         SuperscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Delta]\[Psi][]]],
       Editable->False], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], ",", "0"}], "]"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Delta]\[Psi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Delta]\[Psi][],
       Editable->False], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], ",", "0"}], "]"}]}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7800959665450654`*^9, 3.780095995998315*^9}, 
   3.7800960543343716`*^9}]
}, Open  ]],

Cell[TextData[{
 "This proves our assertion that ",
 StyleBox["for bald black holes in KGB, the problem reduces to that of tensor \
modes described by GR plus minimally coupled scalar modes.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.780096114453597*^9, 3.780096120663995*^9}, {
  3.780096177946837*^9, 3.7800962216998453`*^9}, {3.780096387692415*^9, 
  3.780096387831044*^9}, {3.7800983589456882`*^9, 3.7800983603349724`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{964, 836},
WindowMargins->{{Automatic, 487}, {Automatic, 68}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 212, 4, 70, "Section"],
Cell[795, 28, 120, 2, 30, "Input"],
Cell[918, 32, 773, 13, 87, "Text"],
Cell[CellGroupData[{
Cell[1716, 49, 98, 1, 49, "Subsection"],
Cell[CellGroupData[{
Cell[1839, 54, 3456, 97, 1286, "Input"],
Cell[CellGroupData[{
Cell[5320, 155, 231, 3, 94, "Print"],
Cell[5554, 160, 500, 10, 51, "Print"],
Cell[6057, 172, 252, 3, 94, "Print"],
Cell[6312, 177, 211, 2, 51, "Print"],
Cell[6526, 181, 192, 2, 51, "Print"],
Cell[6721, 185, 233, 3, 94, "Print"],
Cell[6957, 190, 509, 11, 51, "Print"],
Cell[7469, 203, 254, 3, 94, "Print"],
Cell[7726, 208, 231, 3, 94, "Print"],
Cell[7960, 213, 500, 10, 51, "Print"],
Cell[8463, 225, 302, 4, 136, "Print"],
Cell[8768, 231, 233, 3, 94, "Print"],
Cell[9004, 236, 388, 5, 178, "Print"],
Cell[9395, 243, 231, 3, 94, "Print"],
Cell[9629, 248, 472, 10, 51, "Print"],
Cell[10104, 260, 559, 11, 51, "Print"],
Cell[10666, 273, 658, 11, 94, "Print"],
Cell[11327, 286, 618, 11, 51, "Print"],
Cell[11948, 299, 636, 11, 51, "Print"],
Cell[12587, 312, 567, 11, 51, "Print"],
Cell[13157, 325, 577, 11, 51, "Print"],
Cell[13737, 338, 723, 16, 51, "Print"],
Cell[14463, 356, 827, 18, 94, "Print"],
Cell[15293, 376, 800, 17, 51, "Print"],
Cell[16096, 395, 820, 17, 51, "Print"],
Cell[16919, 414, 647, 13, 51, "Print"],
Cell[17569, 429, 771, 17, 94, "Print"],
Cell[18343, 448, 789, 18, 94, "Print"],
Cell[19135, 468, 817, 18, 94, "Print"],
Cell[19955, 488, 735, 16, 51, "Print"],
Cell[20693, 506, 242, 3, 94, "Print"],
Cell[20938, 511, 614, 11, 51, "Print"],
Cell[21555, 524, 246, 3, 94, "Print"],
Cell[21804, 529, 745, 16, 94, "Print"],
Cell[22552, 547, 800, 17, 51, "Print"],
Cell[23355, 566, 743, 16, 94, "Print"],
Cell[24101, 584, 629, 12, 51, "Print"],
Cell[24733, 598, 377, 7, 51, "Print"],
Cell[25113, 607, 369, 7, 51, "Print"],
Cell[25485, 616, 381, 7, 51, "Print"],
Cell[25869, 625, 635, 12, 51, "Print"],
Cell[26507, 639, 590, 11, 51, "Print"],
Cell[27100, 652, 591, 11, 51, "Print"],
Cell[27694, 665, 589, 11, 51, "Print"],
Cell[28286, 678, 609, 12, 51, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[28956, 697, 120, 1, 41, "Subsection"],
Cell[29079, 700, 143, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[29247, 705, 1679, 53, 370, "Input"],
Cell[30929, 760, 2899, 100, 123, "Output"]
}, Open  ]],
Cell[33843, 863, 356, 6, 197, "Text"],
Cell[34202, 871, 17971, 436, 5819, "Input"],
Cell[52176, 1309, 132, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[52333, 1314, 539, 15, 280, "Input"],
Cell[CellGroupData[{
Cell[52897, 1333, 571, 12, 51, "Print"],
Cell[53471, 1347, 765, 16, 51, "Print"]
}, Open  ]],
Cell[54251, 1366, 23232, 743, 627, "Output"]
}, Open  ]],
Cell[77498, 2112, 140, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[77663, 2117, 463, 13, 235, "Input"],
Cell[78129, 2132, 33490, 1101, 987, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[111668, 3239, 113, 1, 41, "Subsection"],
Cell[111784, 3242, 274, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[112083, 3251, 937, 26, 126, "Input"],
Cell[CellGroupData[{
Cell[113045, 3281, 593, 12, 22, "Print"],
Cell[113641, 3295, 769, 16, 22, "Print"],
Cell[114413, 3313, 667, 13, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[115129, 3332, 103, 1, 39, "Subsubsection"],
Cell[115235, 3335, 240, 5, 68, "Text"],
Cell[115478, 3342, 513, 16, 50, "Input"],
Cell[115994, 3360, 689, 23, 55, "Text"],
Cell[116686, 3385, 503, 16, 50, "Input"],
Cell[117192, 3403, 92, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[117309, 3408, 399, 12, 50, "Input"],
Cell[117711, 3422, 606, 11, 22, "Print"]
}, Open  ]],
Cell[118332, 3436, 189, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[118546, 3444, 2094, 65, 126, "Input"],
Cell[120643, 3511, 704, 14, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[121396, 3531, 173, 2, 39, "Subsubsection"],
Cell[121572, 3535, 459, 9, 68, "Text"],
Cell[CellGroupData[{
Cell[122056, 3548, 802, 21, 69, "Input"],
Cell[122861, 3571, 233447, 6840, 762, "Output"]
}, Open  ]],
Cell[356323, 10414, 137, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[356485, 10419, 690, 19, 325, "Input"],
Cell[357178, 10440, 361180, 10685, 7755, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[718419, 21132, 177, 2, 110, "Subsection"],
Cell[718599, 21136, 304, 6, 111, "Text"],
Cell[CellGroupData[{
Cell[718928, 21146, 3064, 82, 694, "Input"],
Cell[CellGroupData[{
Cell[722017, 21232, 512, 11, 51, "Print"],
Cell[722532, 21245, 532, 11, 51, "Print"]
}, Open  ]]
}, Open  ]],
Cell[723091, 21260, 136, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[723252, 21265, 763, 17, 280, "Input"],
Cell[724018, 21284, 23558, 693, 339, "Output"],
Cell[747579, 21979, 3748, 136, 145, "Output"]
}, Open  ]],
Cell[751342, 22118, 229, 4, 111, "Text"],
Cell[751574, 22124, 404, 10, 145, "Input"],
Cell[751981, 22136, 109, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[752115, 22141, 1592, 53, 190, "Input"],
Cell[753710, 22196, 820, 21, 99, "Output"]
}, Open  ]],
Cell[754545, 22220, 258, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[754828, 22229, 674, 14, 190, "Input"],
Cell[755505, 22245, 19696, 534, 267, "Output"]
}, Open  ]],
Cell[775216, 22782, 138, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[775379, 22787, 242, 6, 99, "Input"],
Cell[775624, 22795, 3761, 128, 157, "Output"]
}, Open  ]],
Cell[779400, 22926, 121, 1, 68, "Text"],
Cell[779524, 22929, 274, 7, 99, "Input"],
Cell[779801, 22938, 164, 3, 68, "Text"],
Cell[CellGroupData[{
Cell[779990, 22945, 702, 17, 280, "Input"],
Cell[780695, 22964, 15780, 420, 241, "Output"],
Cell[796478, 23386, 3138, 107, 157, "Output"]
}, Open  ]],
Cell[799631, 23496, 443, 8, 157, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

