(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1174511,      35345]
NotebookOptionsPosition[   1156628,      34827]
NotebookOutlinePosition[   1156978,      34842]
CellTagsIndexPosition[   1156935,      34839]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Monopole and dipole perturbations of stealth solutions in KGB\
\>", "Section",
 CellChangeTimes->{{3.7825481045306864`*^9, 3.7825481114549637`*^9}, {
  3.7846168105618505`*^9, 3.7846168200139856`*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.782548238926917*^9, 3.7825482398662033`*^9}}],

Cell[TextData[{
 "Author: Reggie Bernardo\n\nIn this notebook, we explore the monopole and \
dipole modes of stealth solutions in ",
 StyleBox["kinetic gravity braiding",
  FontSlant->"Italic"],
 ".\n\n*Sections III, IV, and V are to be run in separate/independent \
sessions."
}], "Text",
 CellChangeTimes->{{3.7825481400567455`*^9, 3.7825481906863403`*^9}, {
  3.784606740404924*^9, 3.784606768821248*^9}, {3.784615735480358*^9, 
  3.784615758702602*^9}}],

Cell[CellGroupData[{

Cell["0. xCoba", "Subsection",
 CellChangeTimes->{{3.782548210818509*^9, 3.782548212866645*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xCoba"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xCoba`"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$DefInfoQ", "=", "False"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"$CVVerbose", "=", "False"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$epsilonSign", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"$RicciSign", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"$RiemannSign", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"typical", " ", "xAct", " ", "starting", " ", 
     RowBox[{"point", ":", " ", 
      RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}]}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefManifold", "[", 
     RowBox[{"Md", ",", "dim", ",", 
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
        "u", ",", "v", ",", "w", ",", "x", ",", "y", ",", "z"}], "}"}]}], 
     "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DefMetric", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<;\>\"", ",", "\"\<\[EmptyDownTriangle]\>\""}], "}"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "chart"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefChart", "[", 
     RowBox[{"Schw", ",", "Md", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"t", "[", "]"}], ",", 
        RowBox[{"r", "[", "]"}], ",", 
        RowBox[{"\[Theta]", "[", "]"}], ",", 
        RowBox[{"\[Phi]", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"organization", " ", "tool"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Epsilon]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"linearize", "[", "expr_", "]"}], ":=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
       "Normal"}], ",", "\[Epsilon]", ",", "Together"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"spherical", " ", "harmonics"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "/@", 
     RowBox[{"{", 
      RowBox[{"l", ",", "m", ",", "\[Omega]"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"PL", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(P\), \(lm\)]\)\>\""}]}],
      "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"associated", " ", "Legendre", " ", "polynomials"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"PL", "''"}], "[", "\[Theta]_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l", 
           RowBox[{"(", 
            RowBox[{"l", "+", "1"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["m", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], " ", 
       RowBox[{"PL", "[", "\[Theta]", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], 
       RowBox[{
        RowBox[{"PL", "'"}], "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"spherical", " ", "harmonics"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YLM", ":=", 
     RowBox[{
      SqrtBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", "l"}], "+", "1"}], 
         RowBox[{"4", "\[Pi]"}]], 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l", "-", "m"}], ")"}], "!"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l", "+", "m"}], ")"}], "!"}]]}]], 
      SuperscriptBox["E", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "m", " ", 
        RowBox[{"\[Phi]", "[", "]"}]}]], 
      RowBox[{"PL", "[", 
       RowBox[{"\[Theta]", "[", "]"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.782548248182811*^9, 3.782548277682908*^9}, {
  3.7825483395899878`*^9, 3.7825483518981867`*^9}, {3.7825486008025846`*^9, 
  3.7825486030688877`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077380915883*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.8000773809208713`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.8000773809355297`*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.80007738098071*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.8000773810864315`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381092411*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381098398*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381105377*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.8000773812918777`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.8000773812988935`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381303846*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381308983*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381317813*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7825482158968515`*^9, 3.782548366731496*^9, 
  3.7825486138226185`*^9, 3.782554791602458*^9, 3.7825548873293724`*^9, 
  3.7826935012536297`*^9, 3.7826942514735217`*^9, 3.7826948574540625`*^9, 
  3.782695397088003*^9, 3.782698728648598*^9, 3.782700602809495*^9, 
  3.7827021986979923`*^9, 3.784469351160383*^9, 3.784472162424506*^9, 
  3.7844725721194277`*^9, 3.7844726573852005`*^9, 3.7845026101758213`*^9, 
  3.784507215284424*^9, 3.7846055550469713`*^9, 3.7846067186464367`*^9, 
  3.784843088756173*^9, 3.7848494032214746`*^9, 3.785043928599925*^9, 
  3.785988622617092*^9, 3.7859940556085596`*^9, 3.785994590362257*^9, 
  3.800064207991172*^9, 3.8000665934099245`*^9, 3.800077381322796*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["I. background", "Subsection",
 CellChangeTimes->{{3.7825491570491695`*^9, 3.782549159726302*^9}}],

Cell["\<\
We write down the background metric for the general static and spherically \
symmetric geometry...\
\>", "Text",
 CellChangeTimes->{{3.782549165243548*^9, 3.7825492233664465`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefScalarFunction", "/@", 
   RowBox[{"{", 
    RowBox[{"h", ",", "f"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DefConstantSymbol", "/@", 
    RowBox[{"{", 
     RowBox[{"M", ",", "\[CapitalLambda]"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Schwarzschild", "-", 
    RowBox[{"de", " ", "Sitter", " ", "limit"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SdS", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"h", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", "M"}], "r"], "-", 
          FractionBox[
           RowBox[{"\[CapitalLambda]", " ", 
            SuperscriptBox["r", "2"]}], "3"]}]}], "]"}]}], ",", 
      RowBox[{"f", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", "M"}], "r"], "-", 
          FractionBox[
           RowBox[{"\[CapitalLambda]", " ", 
            SuperscriptBox["r", "2"]}], "3"]}]}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "generic", " ", "static", " ", "and", " ", "spherically", " ", "symmetric",
     " ", "background"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"background", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"h", "[", 
        RowBox[{"r", "[", "]"}], "]"}]}], ",", 
      FractionBox["1", 
       RowBox[{"f", "[", 
        RowBox[{"r", "[", "]"}], "]"}]], ",", 
      SuperscriptBox[
       RowBox[{"r", "[", "]"}], "2"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"r", "[", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"background", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7825492324768147`*^9, 3.7825492905129604`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       RowBox[{
        InterpretationBox[
         StyleBox["h",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}], "0", "0", "0"},
     {"0", 
      FractionBox["1", 
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]], "0", "0"},
     {"0", "0", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], "2"], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.782549240511241*^9, 3.7825492989319057`*^9, 
  3.7825548036103883`*^9, 3.782554905906492*^9, 3.7826935088737555`*^9, 
  3.782694259253785*^9, 3.7826948647129283`*^9, 3.7826954051545315`*^9, 
  3.7826987376023755`*^9, 3.782700611409812*^9, 3.7827022140722504`*^9, 
  3.784469359158404*^9, 3.7844721724337554`*^9, 3.7844725799463787`*^9, 
  3.7844726657839184`*^9, 3.784502620508515*^9, 3.7845072243291454`*^9, 
  3.7846055629713907`*^9, 3.7846067267478733`*^9, 3.7848430995909653`*^9, 
  3.7848494177002892`*^9, 3.785043936224016*^9, 3.785988630381358*^9, 
  3.785994065501503*^9, 3.785994598121522*^9, 3.800064215223846*^9, 
  3.800066601673604*^9, 3.800077388730625*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II. metric and matter perturbations", "Subsection",
 CellChangeTimes->{{3.7825494672141047`*^9, 3.782549488492745*^9}, {
  3.782552024669238*^9, 3.7825520284370666`*^9}}],

Cell["\<\
We write down the general metric perturbations in Regge-Wheeler gauge.

For the even parity sector, we have...\
\>", "Text",
 CellChangeTimes->{{3.782549491054763*^9, 3.782549545650787*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"H0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"H1", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(1\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"H2", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"KK", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<K\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"even", "=", 
   RowBox[{"YLM", " ", 
    SuperscriptBox["E", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
      RowBox[{"t", "[", "]"}]}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"H0", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", 
        RowBox[{"H1", "[", 
         RowBox[{"r", "[", "]"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"H1", "[", 
         RowBox[{"r", "[", "]"}], "]"}], ",", 
        FractionBox[
         RowBox[{"H2", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"f", "[", 
          RowBox[{"r", "[", "]"}], "]"}]], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         RowBox[{"KK", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"]}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{
         RowBox[{"KK", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"even", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7825495788290377`*^9, 3.7825495900413847`*^9}, {
  3.784472534978112*^9, 3.784472535466649*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["h",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H1,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], "0", "0"},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H1,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H2,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}]}]], "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["K",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`KK,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "2"]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["K",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`KK,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], "2"]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7825496097040863`*^9, 3.7825548110592594`*^9, 
  3.782554911341111*^9, 3.782693515761056*^9, 3.782694266201824*^9, 
  3.78269487089219*^9, 3.7826954195498605`*^9, 3.782698744299641*^9, 
  3.782700620658309*^9, 3.782702221241762*^9, 3.784469377509203*^9, 
  3.784472177226035*^9, 3.784472585628091*^9, 3.784472669713954*^9, 
  3.784502624724883*^9, 3.784507232639722*^9, 3.784605567422536*^9, 
  3.7846067310010314`*^9, 3.7848431146256604`*^9, 3.784849424912608*^9, 
  3.785043945490464*^9, 3.7859886489944377`*^9, 3.7859940864637995`*^9, 
  3.785994602729781*^9, 3.800064237607789*^9, 3.8000666065943556`*^9, 
  3.8000773979258804`*^9}]
}, Open  ]],

Cell["For the odd parity sector, we have...", "Text",
 CellChangeTimes->{{3.7825495408135223`*^9, 3.782549551588876*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"h0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(0\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"h1", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(1\)]\)\>\""}]}], 
   "]"}], ";", 
  RowBox[{"odd", "=", 
   RowBox[{
    SuperscriptBox["E", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
      RowBox[{"t", "[", "]"}]}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"D", "[", 
            RowBox[{"YLM", ",", 
             RowBox[{"\[Phi]", "[", "]"}]}], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"D", "[", 
            RowBox[{"YLM", ",", 
             RowBox[{"\[Phi]", "[", "]"}]}], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"D", "[", 
            RowBox[{"YLM", ",", 
             RowBox[{"\[Phi]", "[", "]"}]}], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"D", "[", 
            RowBox[{"YLM", ",", 
             RowBox[{"\[Phi]", "[", "]"}]}], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0"}], "}"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"odd", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{
  3.7825495993619566`*^9, {3.7844725412112303`*^9, 3.784472542019953*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]},
     {"0", "0", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]},
     {
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], "0", "0"},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi][],
            Editable->False]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.782549616271041*^9, 3.782554811196448*^9, 
  3.7825549114682107`*^9, 3.7826935158980246`*^9, 3.782694266307869*^9, 
  3.782694871041442*^9, 3.782695419655098*^9, 3.7826987444131365`*^9, 
  3.782700620738038*^9, 3.7827022213686066`*^9, 3.7844693777395496`*^9, 
  3.784472177326605*^9, 3.784472586063978*^9, 3.7844726699286385`*^9, 
  3.7845026248593855`*^9, 3.7845072327178245`*^9, 3.784605567552684*^9, 
  3.7846067311679173`*^9, 3.7848431147405796`*^9, 3.7848494250079875`*^9, 
  3.7850439457204237`*^9, 3.7859886491169066`*^9, 3.7859940867134404`*^9, 
  3.7859946028787656`*^9, 3.8000642377236495`*^9, 3.8000666066880813`*^9, 
  3.800077398062518*^9}]
}, Open  ]],

Cell["\<\
For the matter perturbations, we first introduce the potentials...\
\>", "Text",
 CellChangeTimes->{{3.7825520373646183`*^9, 3.7825520479419017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"odd", " ", "sector"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"tt0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(t\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"tt1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(t\), \(1\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"tt2", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(t\), \(2\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"even", " ", "sector"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"T0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(T\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"T1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(T\), \(1\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"T2", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(T\), \(2\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"TK", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(T\), \(K\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"t0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", 
       "\"\<\!\(\*SubscriptBox[\(\[ScriptT]\), \(0\)]\)\>\""}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"t1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", 
       "\"\<\!\(\*SubscriptBox[\(\[ScriptT]\), \(1\)]\)\>\""}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"TG", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(T\), \(G\)]\)\>\""}]}], 
     "]"}], ";"}]}]}]], "Input"],

Cell["The even parity matter SET is given by...", "Text",
 CellChangeTimes->{{3.7825520675361414`*^9, 3.7825520801922855`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"removebrackets", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"t", "[", "]"}], "\[Rule]", "t"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "]"}], "\[Rule]", "r"}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "]"}], "\[Rule]", "\[Theta]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "]"}], "\[Rule]", "\[Phi]"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SETeven", "=", 
   RowBox[{"\[Epsilon]", " ", 
    SuperscriptBox["E", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
      RowBox[{"t", "[", "]"}]}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"T0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
        RowBox[{
         RowBox[{"T1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
        RowBox[{
         RowBox[{"t0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"t0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"T1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"T2", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"f", "[", 
           RowBox[{"r", "[", "]"}], "]"}]], "YLM"}], ",", 
        RowBox[{
         RowBox[{"t1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"t1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"t0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"t1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"TK", "[", 
             RowBox[{"r", "[", "]"}], "]"}], "YLM"}], "+", 
           RowBox[{
            RowBox[{"TG", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Theta]", "[", "]"}], ",", "2"}], "}"}]}], 
             "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"TG", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
             RowBox[{"\[Theta]", "[", "]"}]}], "]"}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"t0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"t1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"TG", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
             RowBox[{"\[Theta]", "[", "]"}]}], "]"}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"TK", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"], " ", "YLM"}], "+", 
           RowBox[{
            RowBox[{"TG", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"YLM", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Phi]", "[", "]"}], ",", "2"}], "}"}]}], "]"}], 
              "+", 
              RowBox[{
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "]"}], "]"}], 
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "]"}], "]"}], 
               RowBox[{"D", "[", 
                RowBox[{"YLM", ",", 
                 RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}]}], "}"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PFevenRW", "=", 
   RowBox[{
    RowBox[{"SETeven", "/.", "removebrackets"}], "//", "linearize"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PFevenRW", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7825521041390686`*^9, 3.782552123701701*^9}, {
  3.7825523308777494`*^9, 3.782552331118602*^9}, {3.782553566739602*^9, 
  3.7825535801296897`*^9}, {3.784472551494689*^9, 3.7844725523973384`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["h",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T0,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T1,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[ScriptT]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t0,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[ScriptT]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t0,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}]},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T1,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T2,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", "r", "]"}]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[ScriptT]", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t1,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[ScriptT]", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t1,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}]},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[ScriptT]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t0,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[ScriptT]", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t1,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         SuperscriptBox["r", "2"], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["l",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`l,
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "G"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TG,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "G"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TG,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              InterpretationBox[
               StyleBox["Csc",
                ShowAutoStyles->False,
                AutoSpacing->False],
               Csc,
               Editable->False], "[", "\[Theta]", "]"}], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "G"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TG,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "K"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TK,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["Cot",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Cot,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "G"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TG,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["P", "lm"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`PL,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        SuperscriptBox["r", "2"], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "G"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`TG,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["Cot",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Cot,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "\[Theta]", "]"}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[ScriptT]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t0,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[ScriptT]", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t1,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        SuperscriptBox["r", "2"], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "G"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`TG,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["Cot",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Cot,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "\[Theta]", "]"}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         SuperscriptBox["r", "2"], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "G"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TG,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              InterpretationBox[
               StyleBox["Sin",
                ShowAutoStyles->False,
                AutoSpacing->False],
               Sin,
               Editable->False], "[", "\[Theta]", "]"}], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "K"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TK,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["Cos",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Cos,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "G"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`TG,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["P", "lm"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`PL,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.782552139613265*^9, 3.782552333322833*^9, 
  3.782553597186365*^9, 3.7825548115090313`*^9, 3.782554911795807*^9, 
  3.782693516128809*^9, 3.782694266519212*^9, 3.7826948712505784`*^9, 
  3.7826954198787565`*^9, 3.7826987446406083`*^9, 3.7827006209444523`*^9, 
  3.782702221700502*^9, 3.784469378268703*^9, 3.7844721775281296`*^9, 
  3.7844725864822083`*^9, 3.784472670186205*^9, 3.784502625223647*^9, 
  3.784507232920871*^9, 3.784605567941805*^9, 3.784606731370761*^9, 
  3.7848431150515137`*^9, 3.784849425290208*^9, 3.785043946281232*^9, 
  3.7859886494805937`*^9, 3.7859940870461407`*^9, 3.7859946031999063`*^9, 
  3.8000642380712423`*^9, 3.8000666068911257`*^9, 3.800077398475371*^9}]
}, Open  ]],

Cell["The odd parity matter SET is given by...", "Text",
 CellChangeTimes->{{3.782552150126636*^9, 3.782552163088541*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"PFodd", "=", 
   RowBox[{"\[Epsilon]", " ", 
    SuperscriptBox["E", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
      RowBox[{"t", "[", "]"}]}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         FractionBox[
          RowBox[{"-", 
           RowBox[{"tt0", "[", 
            RowBox[{"r", "[", "]"}], "]"}]}], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}]], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"tt0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         FractionBox[
          RowBox[{"-", 
           RowBox[{"tt1", "[", 
            RowBox[{"r", "[", "]"}], "]"}]}], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}]], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"tt1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"-", 
           RowBox[{"tt0", "[", 
            RowBox[{"r", "[", "]"}], "]"}]}], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}]], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"-", 
           RowBox[{"tt1", "[", 
            RowBox[{"r", "[", "]"}], "]"}]}], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}]], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"tt2", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"YLM", ",", 
                RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
              RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"tt2", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Phi]", "[", "]"}], ",", "2"}], "}"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Theta]", "[", "]"}], ",", "2"}], "}"}]}], 
             "]"}]}]}], ")"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"tt0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"tt1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"tt2", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Phi]", "[", "]"}], ",", "2"}], "}"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Theta]", "[", "]"}], ",", "2"}], "}"}]}], 
             "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"tt2", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"YLM", ",", 
                RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
              RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], "}"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PFoddRW", "=", 
   RowBox[{
    RowBox[{"PFodd", "/.", "removebrackets"}], "//", "linearize"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PFoddRW", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.782553588029426*^9, 3.782553592471518*^9}, {
  3.784472557351532*^9, 3.7844725579530497`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt0,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt0,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]},
     {"0", "0", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt1,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt1,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]},
     {
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt0,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt1,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["m",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`m,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt2,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["Cot",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Cot,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "\[Theta]", "]"}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt2,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], "2"], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", "\[Theta]", "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["l",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`l,
             Editable->False], "2"], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", "\[Theta]", "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["Cos",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Cos,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["Sin",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Sin,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ")"}]}], 
       RowBox[{"4", " ", 
        SqrtBox["\[Pi]"]}]]},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt0,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt1,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", "\[Phi]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]}]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Csc",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Csc,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox["l",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`l,
              Editable->False], "+", 
             InterpretationBox[
              StyleBox["m",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`m,
              Editable->False]}], ")"}], "!"}]]], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["t", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`tt2,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], "2"], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", "\[Theta]", "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["l",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`l,
             Editable->False], "2"], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["P", "lm"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`PL,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", "\[Theta]", "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["Cos",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Cos,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["Sin",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Sin,
             Editable->False], "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ")"}]}], 
       RowBox[{"4", " ", 
        SqrtBox["\[Pi]"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "2"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt2,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["Cos",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Cos,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", "\[Theta]", "]"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", "\[Theta]", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["P", "lm"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`PL,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7825521770084496`*^9, 3.782552335762944*^9, 
  3.7825536042364287`*^9, 3.7825548116600914`*^9, 3.782554911947669*^9, 
  3.7826935162600317`*^9, 3.7826942666590605`*^9, 3.7826948713913507`*^9, 
  3.78269542001655*^9, 3.7826987447988443`*^9, 3.7827006210871844`*^9, 
  3.78270222185795*^9, 3.7844693784049883`*^9, 3.7844721776653786`*^9, 
  3.784472586663225*^9, 3.78447267036376*^9, 3.7845026254487867`*^9, 
  3.7845072330615025`*^9, 3.784605568077556*^9, 3.7846067315428467`*^9, 
  3.7848431152456226`*^9, 3.7848494254292307`*^9, 3.785043946423255*^9, 
  3.7859886496906395`*^9, 3.785994087190453*^9, 3.7859946034272304`*^9, 
  3.800064238209233*^9, 3.800066607031721*^9, 3.8000773986199827`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III. monopole term", "Subsection",
 CellChangeTimes->{{3.7825483827114244`*^9, 3.7825483885193596`*^9}, 
   3.782549152929364*^9, 3.7825494749681463`*^9, {3.784843053647494*^9, 
   3.7848430562279778`*^9}}],

Cell[TextData[{
 "For this section, we restrict our attention to the monopole term (",
 StyleBox["l",
  FontSlant->"Italic"],
 " = 0). In this case, ",
 StyleBox["m",
  FontSlant->"Italic"],
 " is also restricted to ",
 StyleBox["m",
  FontSlant->"Italic"],
 " = 0 and the only relevant spherical harmonic is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Y", "00"], "=", "constant"}], TraditionalForm]]],
 ", i.e., "
}], "Text",
 CellChangeTimes->{{3.7825483932605896`*^9, 3.78254845492563*^9}, {
  3.7825485241740255`*^9, 3.782548530099823*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mon", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[Rule]", "0"}], ",", 
     RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(P\), \(lm\)]\)''(\[Theta])\>\"", 
  "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"PL", "''"}], "[", "\[Theta]", "]"}], "/.", "mon"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(Y\), \(lm\)]\)(\[Theta],\[Phi])\>\"", 
  "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"YLM", "/.", "mon"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.782548489430272*^9, 3.7825484990713863`*^9}, {
  3.782548534781552*^9, 3.7825485516863036`*^9}, {3.7825486243708096`*^9, 
  3.782548669149875*^9}, {3.782549016558074*^9, 3.782549035538625*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(P\\), \\(lm\\)]\\)''(\[Theta])\"\>", 
  "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     InterpretationBox[
      StyleBox["Cot",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Cot,
      Editable->False], "[", "\[Theta]", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "\[Prime]",
     MultilineFunction->None], "[", "\[Theta]", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7825484994621067`*^9, {3.782548652337557*^9, 3.7825486698150053`*^9}, 
   3.782549036389887*^9, 3.7825548171715174`*^9, 3.7825549177335253`*^9, 
   3.7826935870944967`*^9, 3.782694269886936*^9, 3.7826948817639894`*^9, 
   3.7826954280875187`*^9, 3.7826987479562263`*^9, 3.7827006246768866`*^9, 
   3.782702227633009*^9, 3.7844725945561056`*^9, 3.7848431412690506`*^9, 
   3.7850439516993895`*^9, 3.7859886680502048`*^9, 3.8000642424689984`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(Y\\), \
\\(lm\\)]\\)(\[Theta],\[Phi])\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "lm"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`PL,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["\[Theta]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Theta][],
     Editable->False], "]"}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"]}]]}]], "Output",
 CellChangeTimes->{
  3.7825484994621067`*^9, {3.782548652337557*^9, 3.7825486698150053`*^9}, 
   3.782549036389887*^9, 3.7825548171715174`*^9, 3.7825549177335253`*^9, 
   3.7826935870944967`*^9, 3.782694269886936*^9, 3.7826948817639894`*^9, 
   3.7826954280875187`*^9, 3.7826987479562263`*^9, 3.7827006246768866`*^9, 
   3.782702227633009*^9, 3.7844725945561056`*^9, 3.7848431412690506`*^9, 
   3.7850439516993895`*^9, 3.7859886680502048`*^9, 3.8000642424689984`*^9}]
}, Open  ]],

Cell[TextData[{
 "The unique solution (which does not blow up at the poles) of the above \
differential equation is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["P", "lm"], "=", "constant"}], TraditionalForm]]],
 " and consequently the spherical harmonic ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Y", "lm"], TraditionalForm]]],
 " also becomes constant for ",
 StyleBox["l",
  FontSlant->"Italic"],
 " = 0.\n\nDue to this, there are no odd parity spherical harmonics and, \
thus, metric and matter perturbations with ",
 StyleBox["l",
  FontSlant->"Italic"],
 " = 0. We can see what happens to the odd parity perturbations..."
}], "Text",
 CellChangeTimes->{{3.7825490504575377`*^9, 3.782549128872158*^9}, {
  3.7825493185897436`*^9, 3.7825494038607974`*^9}, {3.782549664627701*^9, 
  3.78254968337481*^9}, {3.7825522100188932`*^9, 3.782552211230626*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"P00", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(P\), \(00\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"odd", "/.", "mon"}], "/.", 
      RowBox[{"PL", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}], "//", "MatrixForm"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PFoddRW", "/.", "mon"}], "/.", 
      RowBox[{"PL", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}], "//", "MatrixForm"}], 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.782549684170229*^9, 3.782549850977448*^9}, {
  3.7825522189902725`*^9, 3.782552251230735*^9}, {3.782554872901519*^9, 
  3.782554875098114*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.7825496847907248`*^9, 3.782549692284005*^9}, {
   3.7825498280473657`*^9, 3.782549851501408*^9}, {3.7825522303147483`*^9, 
   3.7825522516175394`*^9}, 3.78255234359756*^9, 3.7825548192983932`*^9, 
   3.782554917867776*^9, 3.7826935904694247`*^9, 3.782694272902113*^9, 
   3.7826948839195433`*^9, 3.7826954318283353`*^9, 3.7826987509583344`*^9, 
   3.78270062695887*^9, 3.782702230297146*^9, 3.7844725946372967`*^9, 
   3.7848431438904448`*^9, 3.785043954076888*^9, 3.7859886704060307`*^9, 
   3.8000642453277006`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.7825496847907248`*^9, 3.782549692284005*^9}, {
   3.7825498280473657`*^9, 3.782549851501408*^9}, {3.7825522303147483`*^9, 
   3.7825522516175394`*^9}, 3.78255234359756*^9, 3.7825548192983932`*^9, 
   3.782554917867776*^9, 3.7826935904694247`*^9, 3.782694272902113*^9, 
   3.7826948839195433`*^9, 3.7826954318283353`*^9, 3.7826987509583344`*^9, 
   3.78270062695887*^9, 3.782702230297146*^9, 3.7844725946372967`*^9, 
   3.7848431438904448`*^9, 3.785043954076888*^9, 3.7859886704060307`*^9, 
   3.8000642453433533`*^9}]
}, Open  ]],

Cell["\<\
We can then jump to the even parity sector. For this case, the metric and \
matter perturbations become...\
\>", "Text",
 CellChangeTimes->{{3.7825498616197157`*^9, 3.7825498807957067`*^9}, {
  3.782552269371332*^9, 3.782552270638029*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"evenmon", "=", 
   RowBox[{
    RowBox[{"even", "/.", "mon"}], "/.", 
    RowBox[{"PL", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", "P00"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
   RowBox[{"(", 
    RowBox[{"evenmon", "//", "MatrixForm"}], ")"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SETevenmon", "=", 
   RowBox[{
    RowBox[{"PFevenRW", "/.", "mon"}], "/.", 
    RowBox[{"PL", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", "P00"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SETevenmon", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7825498912626505`*^9, 3.782549918429562*^9}, {
  3.7825499786006393`*^9, 3.7825499938896465`*^9}, {3.7825522788817444`*^9, 
  3.7825522909772253`*^9}, {3.78255236042673*^9, 3.7825524326410847`*^9}, {
  3.782552567949788*^9, 3.7825525811156178`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "2"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H2,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], "0", "0"},
      {"0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["K",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`KK,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0"},
      {"0", "0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["K",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`KK,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}], "2"]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.7825498920833273`*^9, 3.7825499192745686`*^9}, 
   3.7825499944951334`*^9, 3.782552292345745*^9, 3.782552346623523*^9, 
   3.7825524331609554`*^9, 3.782552585064477*^9, 3.782554821130782*^9, 
   3.78255491794475*^9, 3.7826936049696507`*^9, 3.782694276842766*^9, 
   3.7826948857864466`*^9, 3.782695434838913*^9, 3.782698754371369*^9, 
   3.7827006291124*^9, 3.7827022323410597`*^9, 3.7844725946719255`*^9, 
   3.7848431459540606`*^9, 3.7850439715944004`*^9, 3.785988673439714*^9, 
   3.8000642480458097`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["T", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`T0,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["T", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`T1,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["T", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`T1,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["T", "2"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`T2,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}]}]], "0", "0"},
      {"0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         SuperscriptBox["r", "2"], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["T", "K"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`TK,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0"},
      {"0", "0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         SuperscriptBox["r", "2"], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["T", "K"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`TK,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.7825498920833273`*^9, 3.7825499192745686`*^9}, 
   3.7825499944951334`*^9, 3.782552292345745*^9, 3.782552346623523*^9, 
   3.7825524331609554`*^9, 3.782552585064477*^9, 3.782554821130782*^9, 
   3.78255491794475*^9, 3.7826936049696507`*^9, 3.782694276842766*^9, 
   3.7826948857864466`*^9, 3.782695434838913*^9, 3.782698754371369*^9, 
   3.7827006291124*^9, 3.7827022323410597`*^9, 3.7844725946719255`*^9, 
   3.7848431459540606`*^9, 3.7850439715944004`*^9, 3.785988673439714*^9, 
   3.8000642480770855`*^9}]
}, Open  ]],

Cell["Full metric for monopole.", "Text",
 CellChangeTimes->{{3.7826946051061172`*^9, 3.7826946113033047`*^9}, {
  3.782694898844886*^9, 3.7826949092897367`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"metricmon", "=", 
    RowBox[{"background", "+", 
     RowBox[{"\[Epsilon]", " ", "evenmon"}]}]}], ";"}], "\[IndentingNewLine]",
   "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "tell", " ", "xCoba", " ", "to", " ", "compute", " ", "curvature", " ", 
    "components"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricInBasis", "[", 
   RowBox[{"g", ",", 
    RowBox[{"-", "Schw"}], ",", "metricmon"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricCompute", "[", 
   RowBox[{"g", ",", "Schw", ",", "All", ",", 
    RowBox[{"CVSimplify", "\[Rule]", "linearize"}]}], "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell["Gauge fixing", "Subsubsection",
 CellChangeTimes->{{3.782693629016646*^9, 3.7826936306476088`*^9}}],

Cell[TextData[{
 "Before all else, let us discuss how gauge transformations can simplify the \
analysis of the monopole term.\n\nThe nongauge fixed symmetric tensor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "ab"], TraditionalForm]]],
 " can be written as..."
}], "Text",
 CellChangeTimes->{{3.7826936396998625`*^9, 3.7826936835776916`*^9}, {
  3.782693714594385*^9, 3.7826937343803315`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"GG", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<G\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"evenfull", "=", 
   RowBox[{"\[Epsilon]", " ", 
    SuperscriptBox["E", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
      RowBox[{"t", "[", "]"}]}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"H0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
        RowBox[{
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"H2", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"f", "[", 
           RowBox[{"r", "[", "]"}], "]"}]], "YLM"}], ",", 
        RowBox[{
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"KK", "[", 
             RowBox[{"r", "[", "]"}], "]"}], "YLM"}], "+", 
           RowBox[{
            RowBox[{"GG", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Theta]", "[", "]"}], ",", "2"}], "}"}]}], 
             "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], " ", 
         RowBox[{"GG", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
             RowBox[{"\[Theta]", "[", "]"}]}], "]"}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"h0", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"h1", "[", 
          RowBox[{"r", "[", "]"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"YLM", ",", 
           RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"GG", "[", 
          RowBox[{"r", "[", "]"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
             RowBox[{"\[Theta]", "[", "]"}]}], "]"}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"KK", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"], " ", "YLM"}], "+", 
           RowBox[{
            RowBox[{"GG", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"YLM", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Phi]", "[", "]"}], ",", "2"}], "}"}]}], "]"}], 
              "+", 
              RowBox[{
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "]"}], "]"}], 
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "]"}], "]"}], 
               RowBox[{"D", "[", 
                RowBox[{"YLM", ",", 
                 RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}]}], "}"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"evenfullmon", "=", 
   RowBox[{
    RowBox[{"evenfull", "/.", "mon"}], "/.", 
    RowBox[{"PL", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", "P00"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"evenfullmon", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7826937491328163`*^9, 3.7826937786203403`*^9}, {
  3.7826938172553587`*^9, 3.782693836544322*^9}, {3.782694280566024*^9, 
  3.7826942833879604`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "2"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H2,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], "0", "0"},
      {"0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["K",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`KK,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0"},
      {"0", "0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["K",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`KK,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}], "2"]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.7826937881333294`*^9, 3.7826938398521557`*^9, 
  3.782694284040713*^9, 3.7826949591325903`*^9, 3.7826954524597406`*^9, 
  3.7844726012987394`*^9, 3.7848431614831066`*^9, 3.800064279508502*^9}]
}, Open  ]],

Cell["We define the even parity gauge vector \[Xi]...", "Text",
 CellChangeTimes->{{3.782693949869294*^9, 3.782693962995511*^9}, {
  3.7826949943152456`*^9, 3.782694994548418*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"even", " ", "parity", " ", "gauge", " ", "vector"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Xi]mon", "[", 
       RowBox[{"-", "a"}], "]"}], ",", "Md", ",", 
      RowBox[{"PrintAs", "\[Rule]", "\"\<\[Xi]\>\""}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"M0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(M\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"M1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(M\), \(1\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"M2", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(M\), \(2\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"ComponentArray", "[", 
       RowBox[{"\[Xi]mon", "[", 
        RowBox[{"{", 
         RowBox[{"a", ",", "Schw"}], "}"}], "]"}], "]"}], ",", 
      RowBox[{"\[Epsilon]", " ", 
       SuperscriptBox["E", 
        RowBox[{
         RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
         RowBox[{"t", "[", "]"}]}]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"M0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"YLM", "/.", "mon"}], "/.", 
            RowBox[{"PL", "\[Rule]", 
             RowBox[{"Function", "[", 
              RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"M1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"YLM", "/.", "mon"}], "/.", 
            RowBox[{"PL", "\[Rule]", 
             RowBox[{"Function", "[", 
              RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"M2", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"YLM", "/.", "mon"}], "/.", 
              RowBox[{"PL", "\[Rule]", 
               RowBox[{"Function", "[", 
                RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}], ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"M2", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]], 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"YLM", "/.", "mon"}], "/.", 
              RowBox[{"PL", "\[Rule]", 
               RowBox[{"Function", "[", 
                RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}], ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChangeComponents", "[", 
     RowBox[{
      RowBox[{"\[Xi]mon", "[", 
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"a", ",", "Schw"}], "}"}]}], "]"}], ",", 
      RowBox[{"\[Xi]mon", "[", 
       RowBox[{"{", 
        RowBox[{"a", ",", "Schw"}], "}"}], "]"}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.782693980541681*^9, 3.782693984950502*^9}, {
  3.7826940284772644`*^9, 3.7826940512655616`*^9}, {3.7826940863610225`*^9, 
  3.782694088911776*^9}, {3.7826942261769314`*^9, 3.7826942320862284`*^9}, {
  3.782695373453128*^9, 3.7826953867862177`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {" "},
            {
             StyleBox["a",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Xi]mon[{-$CellContext`a, -$CellContext`Schw}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{-$CellContext`b, -$CellContext`Schw}, {-$CellContext`a, \
-$CellContext`Schw}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[Xi]", 
          StyleBox[GridBox[{
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Xi]mon[{$CellContext`b, $CellContext`Schw}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.015623`5.645309426260358", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`\[Xi]mon[{-$CellContext`a, -$CellContext`Schw}] -> \
$CellContext`g[{-$CellContext`b, -$CellContext`Schw}, {-$CellContext`a, \
-$CellContext`Schw}] $CellContext`\[Xi]mon[{$CellContext`b, \
$CellContext`Schw}], " in ", 0.015623`5.645309426260358, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.782694111609273*^9, 3.7826943464892397`*^9, 
  3.7826950108159113`*^9, 3.7826954599175363`*^9, 3.7844726013736296`*^9, 
  3.784843161599739*^9, 3.80006427958661*^9}]
}, Open  ]],

Cell["The gauge transformation is computed in the next line.", "Text",
 CellChangeTimes->{{3.7826941240936775`*^9, 3.782694140004059*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]hevenmon", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "a"}], "]"}], "[", 
      RowBox[{"\[Xi]mon", "[", 
       RowBox[{"-", "b"}], "]"}], "]"}], "+", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "b"}], "]"}], "[", 
      RowBox[{"\[Xi]mon", "[", 
       RowBox[{"-", "a"}], "]"}], "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(bc\)]\)\>\"", "==", 
   "\[Delta]hevenmon"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "components", " ", "of", " ", "the", " ", "gauge", " ", "transformation"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]hevencompmon", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]hevenmon", "//", 
           RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", 
          RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", "TraceBasisDummy"}], 
        "//", "TraceBasisDummy"}], "//", "ComponentArray"}], "//", 
      "ToValues"}], "//", "ToValues"}], "//", "linearize"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7826941480785365`*^9, 3.78269419114968*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(bc\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[EmptyDownTriangle]", "a"], GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {" "},
            {"b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi]mon[-$CellContext`b]],
    Editable->False], "+", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[EmptyDownTriangle]", "b"], GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {" "},
            {"a"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi]mon[-$CellContext`a]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.782694206166621*^9, 3.7826943496288867`*^9, 
  3.782694657592038*^9, 3.7826950185948143`*^9, 3.7826954629850807`*^9, 
  3.7844726014166965`*^9, 3.784843161647289*^9, 3.8000642796491327`*^9}]
}, Open  ]],

Cell[TextData[{
 "After a gauge transformation, the perturbation tensor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "ab"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " becomes..."
}], "Text",
 CellChangeTimes->{{3.7826950244615955`*^9, 3.7826950439508715`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hnewevenmon", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"evenfullmon", "+", "\[Delta]hevencompmon"}], "//", 
     "Simplification"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)'\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"hnewevenmon", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7826944199845147`*^9, 3.7826944278198786`*^9}, {
  3.782694459707941*^9, 3.7826944661465373`*^9}, {3.7826946865832205`*^9, 
  3.782694695688484*^9}, {3.7826948307932267`*^9, 3.7826948451975455`*^9}, {
  3.7826950563991585`*^9, 3.7826950611747656`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)'\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["h",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["M", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M0,
                 Editable->False], "[", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["h",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "1"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H1,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], "-", 
              RowBox[{
               RowBox[{
                InterpretationBox[
                 StyleBox["h",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`h,
                 Editable->False], "[", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["M", "0"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`M0,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "1"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H1,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], "-", 
              RowBox[{
               RowBox[{
                InterpretationBox[
                 StyleBox["h",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`h,
                 Editable->False], "[", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["M", "0"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`M0,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "2"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H2,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["M", "1"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`M1,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], "2"]}]], "0", "0"},
      {"0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["K",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`KK,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            InterpretationBox[
             StyleBox["r",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`r[],
             Editable->False]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0"},
      {"0", "0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["K",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`KK,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            InterpretationBox[
             StyleBox["r",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`r[],
             Editable->False]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}], "2"]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.7826944671374793`*^9, {3.782694653998949*^9, 3.7826946592152147`*^9}, {
   3.782695047060774*^9, 3.782695061840268*^9}, 3.7826954666156473`*^9, 
   3.784472601817849*^9, 3.78484316200666*^9, 3.800064279945898*^9}]
}, Open  ]],

Cell[TextData[{
 "It can be seen that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "1"], TraditionalForm]]],
 " can be chosen to make ",
 StyleBox["K",
  FontSlant->"Italic"],
 " vanish. Similarly, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "0"], TraditionalForm]]],
 " can be chosen to make ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "1"], TraditionalForm]]],
 " vanish. This leaves behind only the two perturbations ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "2"], TraditionalForm]]],
 ".\n\nTo see this..."
}], "Text",
 CellChangeTimes->{{3.7826951081871643`*^9, 3.7826951994351826`*^9}, {
  3.7826954789505224`*^9, 3.7826954906930094`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M1mon", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hnewevenmon", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"M1", "[", 
       RowBox[{"r", "[", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(M\), \(1\)]\)(r)\>\"", "\[Equal]", 
   RowBox[{"M1", "[", 
    RowBox[{"r", "[", "]"}], "]"}]}], "/.", "M1mon"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M0mon", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hnewevenmon", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], "/.", "M1mon"}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"M0", "'"}], "[", 
       RowBox[{"r", "[", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(M\), \(0\)]\)'(r)\>\"", "\[Equal]", 
   RowBox[{
    RowBox[{"M0", "'"}], "[", 
    RowBox[{"r", "[", "]"}], "]"}]}], "/.", "M0mon"}]}], "Input",
 CellChangeTimes->{{3.782695491643649*^9, 3.7826955596544914`*^9}, {
  3.782695596716654*^9, 3.782695677980404*^9}, {3.7826957386708994`*^9, 
  3.7826957624780717`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(M\\), \\(1\\)]\\)(r)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`KK,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["r",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`r[],
     Editable->False], "]"}], " ", 
   InterpretationBox[
    StyleBox["r",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`r[],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{{3.782695515064782*^9, 3.7826955599794035`*^9}, {
   3.78269563555756*^9, 3.7826956787637587`*^9}, {3.7826957458663063`*^9, 
   3.782695763065195*^9}, 3.784472601905352*^9, 3.78484316208928*^9, 
   3.800064280039626*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(M\\), \\(0\\)]\\)'(r)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "1"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H1,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`KK,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False]}]}], 
   RowBox[{"2", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["h",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}]}]]}]], "Output",
 CellChangeTimes->{{3.782695515064782*^9, 3.7826955599794035`*^9}, {
   3.78269563555756*^9, 3.7826956787637587`*^9}, {3.7826957458663063`*^9, 
   3.782695763065195*^9}, 3.784472601905352*^9, 3.78484316208928*^9, 
   3.800064280039626*^9}]
}, Open  ]],

Cell["With this, the gauge fixed metric perturbation becomes...", "Text",
 CellChangeTimes->{{3.7826957684887567`*^9, 3.782695785203225*^9}, {
  3.782695948334406*^9, 3.782695949994625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"redefining", " ", "the", " ", "components"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"newcompmon", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{
               InterpretationBox[
                StyleBox["h",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`h,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["H", "0"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`H0,
                  Editable->False], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}], "+", 
                RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                 InterpretationBox[
                  StyleBox["\[Omega]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Omega],
                  Editable->False], " ", 
                 RowBox[{
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["M", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`M0,
                   Editable->False], "[", 
                  InterpretationBox[
                   StyleBox["r",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`r[],
                   Editable->False], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["K",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`KK,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], " ", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], " ", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["h",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`h,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}]}]}], ")"}], "\[Equal]", 
           RowBox[{"2", 
            RowBox[{"\[Alpha]", "[", 
             RowBox[{"r", "[", "]"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["K",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`KK,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], " ", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], " ", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["H", "2"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`H2,
                  Editable->False], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["M", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M1,
                    Editable->False], "\[Prime]",
                   MultilineFunction->None], "[", 
                  InterpretationBox[
                   StyleBox["r",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`r[],
                   Editable->False], "]"}]}]}], ")"}]}]}], ")"}], "\[Equal]", 
           RowBox[{"2", 
            RowBox[{"\[Beta]", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            RowBox[{"f", "[", 
             RowBox[{"r", "[", "]"}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"H0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], ",", 
          RowBox[{"H2", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hevenmonGF", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"hnewevenmon", "/.", "M1mon"}], "/.", "M0mon"}], "/.", 
        "newcompmon"}], "//", "Simplify"}], "//", "MatrixForm"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", "hevenmonGF"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "redefinition", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"newcompmon", "//", "Simplification"}]}]}]], "Input",
 CellChangeTimes->{{3.782695696917699*^9, 3.7826957133057275`*^9}, {
  3.7826959202423925`*^9, 3.7826959843741264`*^9}, {3.782696030669093*^9, 
  3.7826962474686327`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"\[Alpha]", "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0", "0"},
      {"0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"\[Beta]", "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.78269570309456*^9, 3.7826957142805243`*^9}, 
   3.782695787029649*^9, 3.7826959673905125`*^9, {3.7826961768667836`*^9, 
   3.7826962382022963`*^9}, 3.784472601962136*^9, 3.7848431621445317`*^9, 
   3.8000642800864906`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        InterpretationBox[
         StyleBox["\[Omega]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Omega],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["h",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["M", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"\[Alpha]", "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["K",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`KK,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], " ", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}]}]}], 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["h",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "2"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H2,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"\[Beta]", "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`KK,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}]], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["M", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M1,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.78269570309456*^9, 3.7826957142805243`*^9}, 
   3.782695787029649*^9, 3.7826959673905125`*^9, {3.7826961768667836`*^9, 
   3.7826962382022963`*^9}, 3.784472601962136*^9, 3.7848431621445317`*^9, 
   3.8000642801021147`*^9}]
}, Open  ]],

Cell["\<\
This means that there are only two gauge independent even parity components.\
\>", "Text",
 CellChangeTimes->{{3.7826962758725014`*^9, 3.7826963096940064`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Einstein equation", "Subsubsection",
 CellChangeTimes->{{3.7826936353337154`*^9, 3.782693637237402*^9}}],

Cell["\<\
We now setup the Einstein equation (plus cosmological constant)...\
\>", "Text",
 CellChangeTimes->{{3.7825524678170404`*^9, 3.782552491288957*^9}, {
  3.782552595014284*^9, 3.7825526073179502`*^9}, {3.782552643432801*^9, 
  3.7825526578898478`*^9}, {3.7826963494593053`*^9, 3.782696370224003*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"RicciCD", "[", 
       RowBox[{
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"g", "[", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], 
       RowBox[{"RicciScalarCD", "[", "]"}]}]}], ")"}], "+", 
    RowBox[{"\[CapitalLambda]", " ", 
     RowBox[{"g", "[", 
      RowBox[{
       RowBox[{"-", "c"}], ",", 
       RowBox[{"-", "b"}]}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EE", "\[Equal]", 
  "\"\<8 \[Pi] \!\(\*SubscriptBox[\(T\), \(cb\)]\)\>\""}]}], "Input",
 CellChangeTimes->{3.784844241247851*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`c, -$CellContext`b],
     Editable->False]}], "+", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}], 
        StyleBox[GridBox[{
           {" ", " "},
           {"c", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`c, -$CellContext`b],
    Editable->False], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`c, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[\\(T\\), \
\\(cb\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{3.782552749595109*^9, 3.782554835937764*^9, 
  3.782554925156435*^9, 3.78269637682493*^9, 3.78269882502929*^9, 
  3.782700648490595*^9, 3.782702247467019*^9, 3.7844726020019836`*^9, 
  3.784844284069627*^9, 3.785044012671941*^9, 3.7859887213896933`*^9, 
  3.8000643081736374`*^9}]
}, Open  ]],

Cell["The linearized expression is given by...", "Text",
 CellChangeTimes->{{3.78255281135928*^9, 3.782552836407895*^9}, {
  3.782696382594907*^9, 3.782696392481763*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EERW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"EE", "//", 
          RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", "ComponentArray"}], "//",
         "ToValues"}], "//", "ToValues"}], ")"}], "/.", "removebrackets"}], "//",
     "linearize"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EERWGF", "=", 
   RowBox[{
    RowBox[{"EERW", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"KK", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", "0"}], "]"}]}], ",", 
       RowBox[{"H1", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", "0"}], "]"}]}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.782696399311391*^9, 3.7826965378081784`*^9}, {
   3.7826966498841567`*^9, 3.782696654883511*^9}, 3.7826967732137623`*^9}],

Cell[TextData[{
 "In this part, we manually include the ",
 StyleBox["hairy",
  FontSlant->"Italic"],
 " correction to the ",
 StyleBox["rr",
  FontSlant->"Italic"],
 "-component..."
}], "Text",
 CellChangeTimes->{{3.784844449376404*^9, 3.7848444797087917`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Lambda]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DefScalarFunction", "[", 
    RowBox[{"qt", ",", 
     RowBox[{
     "PrintAs", "\[Rule]", "\"\<\!\(\*OverscriptBox[\(q\), \(~\)]\)\>\""}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "hair"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]", "=", 
   RowBox[{"-", 
    FractionBox["\[Lambda]", 
     RowBox[{"2", "\[Kappa]"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hair", "=", 
   RowBox[{"\[Epsilon]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"qt", "[", "\[Omega]", "]"}], 
          RowBox[{"\[Kappa]", " ", 
           SuperscriptBox["r", "2"], 
           SuperscriptBox[
            RowBox[{"f", "[", "r", "]"}], 
            RowBox[{"3", "/", "2"}]]}]]}], 
        RowBox[{"(", 
         RowBox[{"YLM", "/.", "removebrackets"}], ")"}], " ", 
        SuperscriptBox["E", 
         RowBox[{
          RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}]]}], "/.", "mon"}], "/.", 
      RowBox[{"PL", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", "P00"}], "]"}]}]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.784844613178566*^9, 3.784844666516409*^9}, {
   3.784844796150288*^9, 3.7848448060547833`*^9}, {3.784844896440488*^9, 
   3.7848449472004557`*^9}, {3.7848451365664177`*^9, 
   3.7848451940226264`*^9}, {3.784845709288127*^9, 3.784845731737558*^9}, {
   3.7848457723111167`*^9, 3.7848457763609962`*^9}, {3.784845859237057*^9, 
   3.7848458599577045`*^9}, 3.7848458937543306`*^9, {3.784845925078485*^9, 
   3.784845925895585*^9}, {3.7848465681825657`*^9, 3.7848465864954553`*^9}, {
   3.785042604675642*^9, 3.785042606885743*^9}}],

Cell[TextData[{
 "We thus obtain the following ",
 StyleBox["nontrivial",
  FontSlant->"Italic"],
 " Einstein equation components..."
}], "Text",
 CellChangeTimes->{{3.782553390540433*^9, 3.7825534069906607`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tt", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"EERWGF", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"8", "\[Pi]", " ", 
        RowBox[{"SETevenmon", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tr", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"EERWGF", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}], "\[Equal]", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"8", "\[Pi]", " ", 
        RowBox[{"SETevenmon", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rr", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"EERWGF", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], "/.", "SdS"}], "//", 
       "Simplify"}], ")"}], "+", "hair"}], "\[Equal]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"8", "\[Pi]", " ", 
        RowBox[{"SETevenmon", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Theta]\[Theta]", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"EERWGF", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}], "/.", "SdS"}], "//", 
       "Simplify"}], ")"}], "\[Equal]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"8", "\[Pi]", " ", 
         RowBox[{"SETevenmon", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
       "Simplify"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ttsim", "=", 
  RowBox[{"tt", "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"trsim", "=", 
  RowBox[{"tr", "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"rrsim", "=", 
  RowBox[{"rr", "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Theta]\[Theta]sim", "=", 
  RowBox[{"\[Theta]\[Theta]", "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7825528502295656`*^9, 3.782552912822243*^9}, {
   3.7825534525865602`*^9, 3.7825535360694447`*^9}, {3.7825536293315206`*^9, 
   3.7825537583961773`*^9}, {3.782553889647703*^9, 3.78255391150762*^9}, {
   3.782554365858182*^9, 3.782554422749521*^9}, {3.7826965527355986`*^9, 
   3.782696579097909*^9}, {3.7848457440510817`*^9, 3.7848457442861075`*^9}, 
   3.7848459040017395`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "00"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`P00,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"6", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}], "-", 
      RowBox[{"48", " ", "\[Pi]", " ", 
       SuperscriptBox["r", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["T", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`T0,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H2,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{{3.7825537461779323`*^9, 3.7825537592964745`*^9}, {
   3.7825538915556555`*^9, 3.78255391190132*^9}, 3.782554424664989*^9, 
   3.7825548497120376`*^9, 3.782554925989896*^9, 3.782696607052631*^9, 
   3.782696788486364*^9, 3.782698849357856*^9, 3.782702253379169*^9, 
   3.7844726033220086`*^9, 3.784845481749939*^9, 3.7848457449029245`*^9, 
   3.7848457810419273`*^9, 3.784845876060665*^9, {3.784845911051614*^9, 
   3.7848459285403934`*^9}, {3.784846572864131*^9, 3.7848465889411616`*^9}, 
   3.7850440643854136`*^9, 3.7859887228198385`*^9, 3.800064309673279*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "00"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`P00,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"8", " ", "\[Pi]", " ", "r", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["T", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`T1,
         Editable->False], "[", "r", "]"}]}]}], ")"}]}], "r"], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7825537461779323`*^9, 3.7825537592964745`*^9}, {
   3.7825538915556555`*^9, 3.78255391190132*^9}, 3.782554424664989*^9, 
   3.7825548497120376`*^9, 3.782554925989896*^9, 3.782696607052631*^9, 
   3.782696788486364*^9, 3.782698849357856*^9, 3.782702253379169*^9, 
   3.7844726033220086`*^9, 3.784845481749939*^9, 3.7848457449029245`*^9, 
   3.7848457810419273`*^9, 3.784845876060665*^9, {3.784845911051614*^9, 
   3.7848459285403934`*^9}, {3.784846572864131*^9, 3.7848465889411616`*^9}, 
   3.7850440643854136`*^9, 3.7859887228198385`*^9, 3.800064309673279*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "00"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`P00,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}]}], "+", 
       RowBox[{"r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"48", " ", "\[Pi]", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "12"}], " ", 
              InterpretationBox[
               StyleBox["M",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{"6", " ", "r", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7825537461779323`*^9, 3.7825537592964745`*^9}, {
   3.7825538915556555`*^9, 3.78255391190132*^9}, 3.782554424664989*^9, 
   3.7825548497120376`*^9, 3.782554925989896*^9, 3.782696607052631*^9, 
   3.782696788486364*^9, 3.782698849357856*^9, 3.782702253379169*^9, 
   3.7844726033220086`*^9, 3.784845481749939*^9, 3.7848457449029245`*^9, 
   3.7848457810419273`*^9, 3.784845876060665*^9, {3.784845911051614*^9, 
   3.7848459285403934`*^9}, {3.784846572864131*^9, 3.7848465889411616`*^9}, 
   3.7850440643854136`*^9, 3.7859887228198385`*^9, 3.80006430979825*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "00"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`P00,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], "2"]}], "-", 
          RowBox[{"6", " ", "r", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], "2"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], "2"]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H2,
          Editable->False], "[", "r", "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "-", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "-", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"96", " ", "\[Pi]", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "K"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`TK,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              InterpretationBox[
               StyleBox["M",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{"6", " ", "r", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["r", "3"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "-", 
          RowBox[{"6", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "-", 
          RowBox[{"12", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "4"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "-", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7825537461779323`*^9, 3.7825537592964745`*^9}, {
   3.7825538915556555`*^9, 3.78255391190132*^9}, 3.782554424664989*^9, 
   3.7825548497120376`*^9, 3.782554925989896*^9, 3.782696607052631*^9, 
   3.782696788486364*^9, 3.782698849357856*^9, 3.782702253379169*^9, 
   3.7844726033220086`*^9, 3.784845481749939*^9, 3.7848457449029245`*^9, 
   3.7848457810419273`*^9, 3.784845876060665*^9, {3.784845911051614*^9, 
   3.7848459285403934`*^9}, {3.784846572864131*^9, 3.7848465889411616`*^9}, 
   3.7850440643854136`*^9, 3.7859887228198385`*^9, 3.8000643099544635`*^9}]
}, Open  ]],

Cell["The other components are identically satisfied...", "Text",
 CellChangeTimes->{{3.7825539312442245`*^9, 3.7825539489570584`*^9}, {
  3.7825544408513284`*^9, 3.782554452020465*^9}, {3.782554524183134*^9, 
  3.7825545438625326`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"EERW", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
   RowBox[{"EERW", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
   RowBox[{"EERW", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "3"}], "]"}], "]"}], ",", 
   RowBox[{"EERW", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
   RowBox[{"EERW", "[", 
    RowBox[{"[", 
     RowBox[{"3", ",", "4"}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.782553951419273*^9, 3.78255399958727*^9}, {
  3.782554192122451*^9, 3.7825542178577476`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.782553966897146*^9, 3.782554000610862*^9}, {
   3.782554193767533*^9, 3.782554218846547*^9}, 3.782554453785269*^9, 
   3.7825549266482286`*^9, 3.7826967968980513`*^9, 3.782702257626013*^9, 
   3.7844726035677147`*^9, 3.7848459801316304`*^9, 3.7850440693255076`*^9, 
   3.7859887232119503`*^9, 3.800064309970085*^9}]
}, Open  ]],

Cell[TextData[{
 "and also ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["G", "\[Phi]\[Phi]"], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["sin", "2"], "(", "\[Theta]", ")"}], 
     SubscriptBox["G", "\[Theta]\[Theta]"]}]}], TraditionalForm]]],
 ".\n\nFinally, we solve the perturbation equations (4 nonindependent \
equations, 2 unknowns). We start with the ",
 StyleBox["tr",
  FontSlant->"Italic"],
 " component which we solve for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["H", "2"], "(", "r", ")"}], TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{{3.7825545473234863`*^9, 3.7825545811168966`*^9}, {
  3.7825550889674997`*^9, 3.7825550891231623`*^9}, {3.7825551423200083`*^9, 
  3.782555205899059*^9}, {3.7826968243214483`*^9, 3.7826968582382183`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"soltr", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"trsim", ",", 
       RowBox[{"H2", "[", "r", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"tr00", "=", 
  RowBox[{
   RowBox[{"H2", "[", "r", "]"}], "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"H2", "[", "r", "]"}], "/.", "soltr"}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.782555207416709*^9, 3.782555264076477*^9}, {
  3.7825561907101326`*^9, 3.782556221332642*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     SubscriptBox["H", "2"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`H2,
    Editable->False], "[", "r", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", "r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["T", "1"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`T1,
      Editable->False], "[", "r", "]"}]}], 
   InterpretationBox[
    StyleBox["\[Omega]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Omega],
    Editable->False]]}]], "Output",
 CellChangeTimes->{{3.7825552489734817`*^9, 3.782555264470525*^9}, {
   3.782556202577611*^9, 3.782556222048239*^9}, 3.7826969500814276`*^9, 
   3.782699303489422*^9, 3.782702392516015*^9, 3.784472603585552*^9, 
   3.7848459926089973`*^9, 3.7850440719921055`*^9, 3.785988723276679*^9, 
   3.8000643100013666`*^9}]
}, Open  ]],

Cell[TextData[{
 "We then put this back into the ",
 StyleBox["tt",
  FontSlant->"Italic"],
 " component to obtain..."
}], "Text",
 CellChangeTimes->{{3.7825552912342377`*^9, 3.7825553234873314`*^9}, 
   3.7826969609862647`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tttr", "=", 
   RowBox[{
    RowBox[{"ttsim", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H2", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"H2", "[", "r", "]"}], "/.", "soltr"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"H2", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"H2", "[", "r", "]"}], "/.", "soltr"}], ")"}], ",", "r"}],
          "]"}]}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", "tttr"}], "Input",
 CellChangeTimes->{{3.782555326066049*^9, 3.7825553928091993`*^9}, {
  3.7825554377366047`*^9, 3.78255544432992*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False]}]], 
   RowBox[{"8", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "00"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`P00,
     Editable->False], " ", "\[Pi]", " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"6", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["r", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["T", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`T0,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"3", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["T", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`T1,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T1,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{
  3.7825553361552505`*^9, {3.7825553663793354`*^9, 3.7825553933804197`*^9}, 
   3.78255544476217*^9, 3.782696965012697*^9, 3.7826993053343353`*^9, 
   3.7827023954205666`*^9, 3.784472603684099*^9, 3.784845999132408*^9, 
   3.7850440742182727`*^9, 3.7859887234031506`*^9, 3.8000643101106987`*^9}]
}, Open  ]],

Cell[TextData[{
 "This shows that the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "1"], TraditionalForm]]],
 " matter monopole components are not independent. In particular, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "1"], TraditionalForm]]],
 " are related by..."
}], "Text",
 CellChangeTimes->{{3.78255548947548*^9, 3.7825555141396427`*^9}, {
  3.782555577362563*^9, 3.7825555962360497`*^9}, {3.782696984432187*^9, 
  3.7826969942949076`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tttrsol", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"tttr", ",", 
      RowBox[{"T0", "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T0", "[", "r", "]"}], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"T0", "[", "r", "]"}], "/.", "tttrsol"}], "//", "Simplify"}], 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.782555537567977*^9, 3.782555561557327*^9}, {
  3.782555617331487*^9, 3.782555641628851*^9}, {3.782697022770258*^9, 
  3.782697050983863*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     SubscriptBox["T", "0"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`T0,
    Editable->False], "[", "r", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"3", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["T", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`T1,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T1,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{"6", " ", 
    SuperscriptBox["r", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Omega]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Omega],
     Editable->False]}]]}]], "Output",
 CellChangeTimes->{{3.7825555502358503`*^9, 3.7825555622327213`*^9}, 
   3.7825556421278276`*^9, {3.782697037780325*^9, 3.782697051474449*^9}, 
   3.7826993420118427`*^9, 3.782702399590845*^9, 3.784472603729069*^9, 
   3.7848460113860984`*^9, 3.7850440761000924`*^9, 3.785988723432766*^9, 
   3.8000643101575413`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["rr",
  FontSlant->"Italic"],
 " equation can then be solved for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.782697077994108*^9, 3.7826970958079867`*^9}, {
  3.7826971585704665`*^9, 3.7826971586984587`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rrsol", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"rrsim", "/.", "soltr"}], ",", 
       RowBox[{
        RowBox[{"H0", "'"}], "[", "r", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)'(r)\>\"", "\[Equal]", 
   RowBox[{
    RowBox[{"H0", "'"}], "[", "r", "]"}]}], "/.", "rrsol"}]}], "Input",
 CellChangeTimes->{{3.7826971798912096`*^9, 3.782697214933118*^9}, {
  3.7826972566287584`*^9, 3.7826972645144215`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(0\\)]\\)'(r)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "-", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}], " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox["q", "~"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`qt,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False], "]"}]}], "-", 
    RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
     SuperscriptBox["r", "2"], " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T1,
          Editable->False], "[", "r", "]"}]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Omega]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Omega],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["T", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`T2,
          Editable->False], "[", "r", "]"}]}]}], ")"}]}]}], 
   RowBox[{"r", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"6", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda],
        Editable->False]}]}], ")"}], " ", 
    InterpretationBox[
     StyleBox["\[Omega]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Omega],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", "r", "]"}], 
     RowBox[{"3", "/", "2"}]]}]]}]], "Output",
 CellChangeTimes->{{3.782697191241378*^9, 3.7826972152090197`*^9}, {
   3.782697258054928*^9, 3.7826972648287687`*^9}, 3.782699344800812*^9, 
   3.782702402401662*^9, 3.7844726037674527`*^9, 3.7848460453327684`*^9, 
   3.7850440787224755`*^9, 3.785988723485485*^9, 3.800064310220027*^9}]
}, Open  ]],

Cell[TextData[{
 "With ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "2"], TraditionalForm]]],
 " completely determined, the final expression (\[Theta]\[Theta]) becomes..."
}], "Text",
 CellChangeTimes->{{3.7826972927937403`*^9, 3.7826973478063135`*^9}, {
  3.7826976673511286`*^9, 3.782697667808153*^9}, {3.782698005558153*^9, 
  3.7826980058002243`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Theta]\[Theta]mon", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Theta]\[Theta]sim", "/.", "soltr"}], "/.", "rrsol"}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"H2", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"H2", "[", "r", "]"}], "/.", "soltr"}], ",", "r"}], 
         "]"}]}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"H0", "''"}], "[", "r", "]"}], "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"H0", "'"}], "[", "r", "]"}], "/.", "rrsol"}], ",", "r"}], 
        "]"}]}]}], "//", "Simplify"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[Theta]\[Theta]mon", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"tttr", ",", 
       RowBox[{
        RowBox[{"T1", "'"}], "[", "r", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.782697351876036*^9, 3.7826975272112694`*^9}, {
  3.782697683675316*^9, 3.7826976919924097`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "00"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`P00,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"72", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], "2"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], "2"]}], "+", 
          RowBox[{"6", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "6"}], " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["r", "4"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}]}], "-", 
       RowBox[{"r", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "+", 
           RowBox[{"6", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False]}]}], ")"}], "2"], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{"32", " ", "\[Pi]", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], 
         RowBox[{"5", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              InterpretationBox[
               StyleBox["M",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T1,
             Editable->False], "[", "r", "]"}]}], "-", 
          RowBox[{"18", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"12", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"24", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "K"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`TK,
             Editable->False], "[", "r", "]"}]}], "-", 
          RowBox[{"12", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "K"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`TK,
             Editable->False], "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "K"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`TK,
             Editable->False], "[", "r", "]"}]}], "-", 
          RowBox[{"12", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`T2,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`T2,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "4"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["T", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`T2,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}]]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.782697524315195*^9, 3.7826975274988575`*^9}, {
   3.7826976733043375`*^9, 3.7826976923716297`*^9}, 3.782699348501214*^9, 
   3.7827024053745604`*^9, 3.784472604070179*^9, 3.784846083184819*^9, 
   3.7850440819282165`*^9, 3.7859887243256173`*^9, 3.8000643110323343`*^9}]
}, Open  ]],

Cell["This of course is expected from the conservation of SET.", "Text",
 CellChangeTimes->{{3.782697985233835*^9, 3.7826980150917926`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Vacuum solution", "Subsubsection",
 CellChangeTimes->{{3.7827024095654364`*^9, 3.7827024253909235`*^9}}],

Cell["\<\
In vacuum, we can show that the solution of the linearized equations \
correspond to a redefinition of the mass term (as the 00-harmonic is \
spherically symmetric). We take the vacuum limit using...\
\>", "Text",
 CellChangeTimes->{{3.7827024322519107`*^9, 3.782702477803212*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"vacmon", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"T0", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}], ",", 
      RowBox[{"T1", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}], ",", 
      RowBox[{"T2", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}], ",", 
      RowBox[{"TK", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ttvac", "=", 
   RowBox[{"ttsim", "/.", "vacmon"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trvac", "=", 
   RowBox[{"trsim", "/.", "vacmon"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rrvac", "=", 
   RowBox[{"rrsim", "/.", "vacmon"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Theta]\[Theta]vac", "=", 
    RowBox[{"\[Theta]\[Theta]sim", "/.", "vacmon"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ttvac", "\
\[IndentingNewLine]", "trvac", "\[IndentingNewLine]", "rrvac", "\
\[IndentingNewLine]", "\[Theta]\[Theta]vac"}], "Input",
 CellChangeTimes->{{3.782702480849111*^9, 3.7827024894595413`*^9}, {
  3.782702522073633*^9, 3.7827026028589582`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "00"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`P00,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"6", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H2,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{"r", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]}]], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7827026039196277`*^9, 3.784472604125948*^9, 
  3.784846114491293*^9, 3.7850440943411703`*^9, 3.7859887418871803`*^9, 
  3.800064438638981*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "00"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`P00,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Omega]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Omega],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "2"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H2,
      Editable->False], "[", "r", "]"}]}], "r"], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7827026039196277`*^9, 3.784472604125948*^9, 
  3.784846114491293*^9, 3.7850440943411703`*^9, 3.7859887418871803`*^9, 
  3.800064438638981*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "00"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`P00,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}]}], "+", 
       RowBox[{"r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "12"}], " ", 
              InterpretationBox[
               StyleBox["M",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{"6", " ", "r", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False]}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda],
               Editable->False]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7827026039196277`*^9, 3.784472604125948*^9, 
  3.784846114491293*^9, 3.7850440943411703`*^9, 3.7859887418871803`*^9, 
  3.800064438638981*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "-", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["P", "00"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`P00,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], "2"]}], "-", 
         RowBox[{"6", " ", "r", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], "2"]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "-", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "-", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "-", 
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "-", 
         RowBox[{"12", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H0,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H0,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "4"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H0,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
     ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7827026039196277`*^9, 3.784472604125948*^9, 
  3.784846114491293*^9, 3.7850440943411703`*^9, 3.7859887418871803`*^9, 
  3.800064438654604*^9}]
}, Open  ]],

Cell[TextData[{
 "Obviously, the ",
 StyleBox["tr",
  FontSlant->"Italic"],
 " component implies that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "=", "0"}], TraditionalForm]]],
 ". The monopole component does not depend on time.\n\nOn the other hand, the \
",
 StyleBox["tt",
  FontSlant->"Italic"],
 " and ",
 StyleBox["rr",
  FontSlant->"Italic"],
 " components can be solved analytically..."
}], "Text",
 CellChangeTimes->{{3.78270265196128*^9, 3.7827026831824803`*^9}, {
  3.7827028125722275`*^9, 3.7827028392600937`*^9}, {3.784846246427927*^9, 
  3.784846247375834*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"H2sol", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{"ttvac", ",", "H2", ",", "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\"", "\[Equal]", 
     RowBox[{"H2", "[", "r", "]"}]}], "/.", "H2sol"}], "//", 
   "TraditionalForm"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H0sol", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"rrvac", "/.", "H2sol"}], ",", "H0", ",", "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)\>\"", "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"H0", "[", "r", "]"}], "/.", "H0sol"}], "//", "FullSimplify"}], 
    ")"}]}], "//", "TraditionalForm"}]}], "Input",
 CellChangeTimes->{{3.782702859214322*^9, 3.7827029537671924`*^9}, {
  3.784846291698705*^9, 3.784846296739112*^9}, {3.7848463301638107`*^9, 
  3.784846335020587*^9}, {3.78484667695253*^9, 3.7848466957483315`*^9}, {
  3.7859887559481716`*^9, 3.785988767822382*^9}, {3.785993526561632*^9, 
  3.7859936000766087`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,123,1,16658321408445140980,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.782702872125645*^9, 3.782702901405821*^9}, 
   3.7827029546394734`*^9, 3.784472604318463*^9, 3.784846122623188*^9, 
   3.7848462977685738`*^9, 3.7848463354451327`*^9, {3.784846678847108*^9, 
   3.7848466964510865`*^9}, 3.785044099503004*^9, 3.785988769779465*^9, {
   3.7859935437060375`*^9, 3.785993601415388*^9}, 3.800064495026449*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(2\\)]\\)\"\>", 
   "\[LongEqual]", 
   FractionBox[
    SubscriptBox[
     TagBox["c",
      C], "1"], 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"12", " ", "\[Kappa]", " ", "M"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      SuperscriptBox["r", "3"]}], "+", 
     RowBox[{"6", " ", "\[Kappa]", " ", "r"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.7827028721323824`*^9, 3.7827029014263153`*^9}, 
   3.7827029546608443`*^9, 3.784472604321761*^9, 3.7848461226438046`*^9, 
   3.7848462978092065`*^9, 3.784846335557543*^9, {3.7848466788681984`*^9, 
   3.784846696476019*^9}, 3.7850440995297318`*^9, 3.7859887698003764`*^9, {
   3.785993543734672*^9, 3.7859936014413214`*^9}, 3.80006449505769*^9}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,125,2,16658321408445140980,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.782702872125645*^9, 3.782702901405821*^9}, 
   3.7827029546394734`*^9, 3.784472604318463*^9, 3.784846122623188*^9, 
   3.7848462977685738`*^9, 3.7848463354451327`*^9, {3.784846678847108*^9, 
   3.7848466964510865`*^9}, 3.785044099503004*^9, 3.785988769779465*^9, {
   3.7859935437060375`*^9, 3.785993601415388*^9}, 3.8000644963542624`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(0\\)]\\)\"\>", 
   "\[LongEqual]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "1", "r"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", 
           SubscriptBox[
            TagBox["c",
             C], "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Lambda]", " ", 
              SuperscriptBox[
               RowBox[{"K", "[", "1", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", "\[Kappa]"}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "\[Kappa]", " ", 
              RowBox[{"K", "[", "1", "]"}]}], "+", 
             RowBox[{"\[Lambda]", " ", 
              SuperscriptBox[
               RowBox[{"K", "[", "1", "]"}], "3"]}], "-", 
             RowBox[{"12", " ", "\[Kappa]", " ", "M"}]}], ")"}], "2"]]}], "-", 
        FractionBox[
         RowBox[{"qt", "(", "\[Omega]", ")"}], 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"K", "[", "1", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"f", "(", 
            RowBox[{"K", "[", "1", "]"}], ")"}], 
           RowBox[{"3", "/", "2"}]]}]]}], ")"}], 
      RowBox[{"\[DifferentialD]", 
       RowBox[{"K", "[", "1", "]"}]}]}]}], "+", 
    SubscriptBox[
     TagBox["c",
      C], "2"]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.7827028721323824`*^9, 3.7827029014263153`*^9}, 
   3.7827029546608443`*^9, 3.784472604321761*^9, 3.7848461226438046`*^9, 
   3.7848462978092065`*^9, 3.784846335557543*^9, {3.7848466788681984`*^9, 
   3.784846696476019*^9}, 3.7850440995297318`*^9, 3.7859887698003764`*^9, {
   3.785993543734672*^9, 3.7859936014413214`*^9}, 3.800064802509241*^9}]
}, Open  ]],

Cell["For the Schwarzschild case, we obtain...", "Text",
 CellChangeTimes->{{3.784846342165985*^9, 3.7848463471561823`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"H2solSc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ttvac", "/.", 
         RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], ")"}], ",", "H2", ",", 
       "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\"", "\[Equal]", 
     RowBox[{"H2", "[", "r", "]"}]}], "/.", "H2solSc"}], "//", "Simplify"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H0solSc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"rrvac", "/.", "H2solSc"}], "/.", "SdS"}], "/.", 
         RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], ")"}], ",", "H0", ",", 
       "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)\>\"", "\[Equal]", 
    RowBox[{"H0", "[", "r", "]"}]}], "/.", "H0solSc"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.784846352505494*^9, 3.784846435349286*^9}, {
  3.784846468465105*^9, 3.7848464755573254`*^9}, {3.78484662821345*^9, 
  3.7848466293286877`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,127,3,16658321408445140980,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.7848463843872414`*^9, 3.7848464373427553`*^9}, 
   3.7848464759763565`*^9, 3.784846630363532*^9, 3.78504410381114*^9, 
   3.785994042580411*^9, 3.8000650079822435`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(2\\)]\\)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{"C", "[", "1", "]"}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     InterpretationBox[
      StyleBox["M",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`M,
      Editable->False]}], "+", "r"}]]}]], "Output",
 CellChangeTimes->{{3.784846384398271*^9, 3.784846437373665*^9}, 
   3.784846476001289*^9, 3.784846630388633*^9, 3.78504410383527*^9, 
   3.7859940426064653`*^9, 3.800065007997865*^9}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,129,4,16658321408445140980,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.7848463843872414`*^9, 3.7848464373427553`*^9}, 
   3.7848464759763565`*^9, 3.784846630363532*^9, 3.78504410381114*^9, 
   3.785994042580411*^9, 3.8000650081540794`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(0\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"C", "[", "2", "]"}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False]}], "r"]}]], " ", "r"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", "r"}], ")"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Log",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Log,
           Editable->False], "[", 
          RowBox[{
           RowBox[{"-", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "+", "r", "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox[
               RowBox[{"2", " ", 
                InterpretationBox[
                 StyleBox["M",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M,
                 Editable->False]}], "r"]}]], " ", "r"}]}], "]"}]}]}], ")"}], 
      " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox["q", "~"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`qt,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], "]"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False]}], "+", "r"}], ")"}], " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]]}]}]], "Output",
 CellChangeTimes->{{3.784846384398271*^9, 3.784846437373665*^9}, 
   3.784846476001289*^9, 3.784846630388633*^9, 3.78504410383527*^9, 
   3.7859940426064653`*^9, 3.8000650082947035`*^9}]
}, Open  ]],

Cell[TextData[{
 "We note that the integration constant ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "2"], TraditionalForm]]],
 " can be removed by a gauge transformation. Also, the \[Theta]\[Theta] \
component is automatically satisfied by the above solutions..."
}], "Text",
 CellChangeTimes->{{3.78270305626268*^9, 3.782703113483324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Theta]\[Theta]vac", "/.", 
       RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", "H2sol"}], "/.", 
     "H0sol"}], "/.", "SdS"}], "//", "Simplify"}], ")"}]], "Input",
 CellChangeTimes->{{3.782702985904149*^9, 3.7827030057433043`*^9}, {
  3.7827031169892335`*^9, 3.782703119228633*^9}, {3.784846940453453*^9, 
  3.7848469415906887`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7827030031249485`*^9, 3.78270300596027*^9}, 
   3.7827031201148033`*^9, 3.784472604388091*^9, {3.7848469233959866`*^9, 
   3.784846942767028*^9}, 3.7850441126848865`*^9, 3.80006505550476*^9}]
}, Open  ]],

Cell["\<\
To see what this means we look at the full metric (for the Schwarzschild \
case)...\
\>", "Text",
 CellChangeTimes->{{3.782703137143838*^9, 3.7827031582940664`*^9}, {
  3.7848469563737917`*^9, 3.78484697758488*^9}, {3.7848474767993975`*^9, 
  3.7848474803022757`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"H0solsim", "=", 
   RowBox[{"H0solSc", "/.", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False]}], "-", 
       RowBox[{"3", " ", "r"}]}], ")"}], "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "r", " ", 
       RowBox[{"f", "[", "r", "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H2solsim", "=", 
    RowBox[{"H2solSc", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         InterpretationBox[
          StyleBox["M",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M,
          Editable->False]}], "-", 
        RowBox[{"3", " ", "r"}]}], ")"}], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "r", " ", 
        RowBox[{"f", "[", "r", "]"}]}], ")"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"metricpert", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"metricmon", "/.", "removebrackets"}], "/.", 
          RowBox[{
           RowBox[{"h", "[", "r", "]"}], "\[Rule]", 
           RowBox[{"f", "[", "r", "]"}]}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"KK", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{"r", ",", "0"}], "]"}]}], ",", 
           RowBox[{"H1", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{"r", ",", "0"}], "]"}]}]}], "}"}]}], "/.", 
        RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", "H0solsim"}], "/.", 
      "H2solsim"}], "/.", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          RowBox[{"C", "[", "1", "]"}]}], 
         RowBox[{"6", " ", 
          SqrtBox["\[Pi]"]}]], "\[Equal]", 
        RowBox[{"-", "Q"}]}], ",", "P00"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(g\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"metricpert", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7827031598568974`*^9, 3.7827033704567413`*^9}, {
   3.782703485946455*^9, 3.782703628047408*^9}, {3.782704236838869*^9, 
   3.782704252712039*^9}, 3.782704711485031*^9, {3.784847071942897*^9, 
   3.7848470972094755`*^9}, {3.784847129601615*^9, 3.784847143204567*^9}, {
   3.784847488468187*^9, 3.784847510873928*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(g\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}]}], "-", 
        FractionBox[
         RowBox[{"3", " ", "Q", " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{"1", "-", 
                  FractionBox[
                   RowBox[{"2", " ", 
                    InterpretationBox[
                    StyleBox["M",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M,
                    Editable->False]}], "r"]}]], " ", "r"}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   InterpretationBox[
                    StyleBox["M",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M,
                    Editable->False]}], "+", "r"}], ")"}], " ", 
                RowBox[{
                 InterpretationBox[
                  StyleBox["Log",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  Log,
                  Editable->False], "[", 
                 RowBox[{
                  RowBox[{"-", 
                   InterpretationBox[
                    StyleBox["M",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M,
                    Editable->False]}], "+", "r", "+", 
                  RowBox[{
                   SqrtBox[
                    RowBox[{"1", "-", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    StyleBox["M",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M,
                    Editable->False]}], "r"]}]], " ", "r"}]}], "]"}]}]}], 
              ")"}], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                OverscriptBox["q", "~"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`qt,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], "]"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False]}], "+", "r"}], ")"}], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          RowBox[{"C", "[", "1", "]"}]}]]}], "0", "0", "0"},
      {"0", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}]], "-", 
        FractionBox[
         RowBox[{"3", " ", "Q", " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False]}], "+", "r"}], ")"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], "0", "0"},
      {"0", "0", 
       SuperscriptBox["r", "2"], "0"},
      {"0", "0", "0", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], "2"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.7827031624554987`*^9, 3.7827031774154253`*^9}, {
   3.782703229758877*^9, 3.7827032736573696`*^9}, {3.7827033084283266`*^9, 
   3.7827033707884765`*^9}, {3.7827035155946608`*^9, 
   3.7827036287219625`*^9}, {3.7827042458991175`*^9, 3.78270425343614*^9}, 
   3.7827047472665987`*^9, 3.784472604409998*^9, 3.7848469886517334`*^9, 
   3.7848470985917683`*^9, 3.7848472224614973`*^9, 3.7848475131416345`*^9, 
   3.7850441155497413`*^9, 3.8000650662522597`*^9}]
}, Open  ]],

Cell[TextData[{
 "In GR, the monopole term corresponds to a ",
 StyleBox["mass redefinition",
  FontSlant->"Italic"],
 " of the mass term, in vacuum. We see that the ",
 StyleBox["scalar hair spoils this simplicity",
  FontSlant->"Italic"],
 " and modifies instead the full metric with a ",
 StyleBox["logarithmic divergence",
  FontSlant->"Italic"],
 " at infinity. The exact solution cannot, of course, be trusted at full \
value as perturbation theory can only be reliable as far as the size of the \
fluctuation is small.\n\nHere, we extract the monopole correction to the \
metric..."
}], "Text",
 CellChangeTimes->{{3.782704516366634*^9, 3.782704559063969*^9}, {
  3.78270461930956*^9, 3.782704634262385*^9}, {3.782704720142213*^9, 
  3.782704738839741*^9}, {3.7848470523951583`*^9, 3.7848470534278784`*^9}, {
  3.784847813539796*^9, 3.784847815867282*^9}, {3.7848479081554046`*^9, 
  3.7848480563422327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"corr", "=", 
   RowBox[{
    RowBox[{"qt", "[", "\[Omega]", "]"}], 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"metricpert", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"qt", "[", "\[Omega]", "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]g\), \(tt\)]\)\>\"", "\[Equal]", 
  "corr"}]}], "Input",
 CellChangeTimes->{{3.7848481268532543`*^9, 3.784848148902939*^9}, {
  3.7848481845619707`*^9, 3.78484821311197*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]g\\), \\(tt\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"6", " ", "Q", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "r"]}]], " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False]}], "+", "r"}], ")"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{"C", "[", "1", "]"}]}]]}], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", "Q", " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", "r", "]"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["Log",
          ShowAutoStyles->False,
          AutoSpacing->False],
         Log,
         Editable->False], "[", 
        RowBox[{
         RowBox[{"-", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "+", "r", "+", 
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["M",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M,
               Editable->False]}], "r"]}]], " ", "r"}]}], "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "+", "r"}], ")"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"C", "[", "1", "]"}]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", "Q", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", "r", "]"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["Log",
          ShowAutoStyles->False,
          AutoSpacing->False],
         Log,
         Editable->False], "[", 
        RowBox[{
         RowBox[{"-", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "+", "r", "+", 
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["M",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M,
               Editable->False]}], "r"]}]], " ", "r"}]}], "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "+", "r"}], ")"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"C", "[", "1", "]"}]}]]}], ")"}], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox["q", "~"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`qt,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["\[Omega]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Omega],
     Editable->False], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7848481312437544`*^9, 3.78484815016576*^9}, {
   3.784848188472048*^9, 3.784848213915254*^9}, 3.78504414146356*^9, 
   3.800065117941353*^9}]
}, Open  ]],

Cell["The asymptotic limits of the monopole hair are...", "Text",
 CellChangeTimes->{{3.7848482293879433`*^9, 3.7848482439964333`*^9}, {
  3.784848654099668*^9, 3.784848657693035*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"corrSc", "=", 
   RowBox[{
    RowBox[{"corr", "/.", "SdS"}], "/.", 
    RowBox[{"\[Lambda]", "\[Rule]", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]g\), \(tt\)]\)\>\"", "\[Equal]", 
   RowBox[{"Series", "[", 
    RowBox[{"corrSc", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"2", "M"}], ",", "1"}], "}"}]}], "]"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]g\), \(tt\)]\)\>\"", "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{"corrSc", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}], "//", 
      "Simplify"}], ")"}]}], "/.", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"Log", "[", 
       FractionBox["1", 
        RowBox[{"2", "r"}]], "]"}]}], ")"}], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SuperscriptBox["E", "2"], 
      RowBox[{"2", "r"}]], "]"}]}]}], "/.", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Log", "[", "4", "]"}], "-", 
     RowBox[{"2", 
      RowBox[{"Log", "[", 
       FractionBox["1", "r"], "]"}]}]}], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"4", 
       SuperscriptBox["r", "2"]}], "E"], "]"}]}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7848482463394976`*^9, 3.7848484107087555`*^9}, {
  3.7848484461072397`*^9, 3.7848484654175835`*^9}, {3.7848485551546974`*^9, 
  3.7848485975631237`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]g\\), \\(tt\\)]\\)\"\>", 
  "\[Equal]", 
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox[
          FractionBox["1", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False]]], " ", "Q", " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox["q", "~"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`qt,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], "]"}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}]}]]}], 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"C", "[", "1", "]"}]}]]}], "+", 
    FractionBox[
     RowBox[{"3", " ", "Q", " ", 
      InterpretationBox[
       StyleBox["\[Epsilon]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Epsilon],
       Editable->False], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox["Log",
         ShowAutoStyles->False,
         AutoSpacing->False],
        Log,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], "]"}], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox["q", "~"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`qt,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox["M",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M,
          Editable->False]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["M",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`M,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      RowBox[{"C", "[", "1", "]"}]}]], "+", 
    InterpretationBox[
     SuperscriptBox[
      RowBox[{"O", "[", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox["M",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M,
          Editable->False]}]}], "]"}], 
      RowBox[{"3", "/", "2"}]],
     SeriesData[$CellContext`r, 2 $CellContext`M, {}, 1, 3, 2],
     Editable->False]}],
   SeriesData[$CellContext`r, 
    2 $CellContext`M, {(-3) 
     2^Rational[1, 2] ($CellContext`M^(-1))^
      Rational[1, 
        2] $CellContext`Q $CellContext`\[Epsilon] $CellContext`\[Kappa]^(-1) 
     C[1]^(-1) $CellContext`qt[$CellContext`\[Omega]], 
     Rational[3, 
       2] $CellContext`M^(-1) $CellContext`Q $CellContext`\[Epsilon] \
$CellContext`\[Kappa]^(-1) C[1]^(-1) 
     Log[$CellContext`M] $CellContext`qt[$CellContext`\[Omega]]}, 1, 3, 2],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.784848301729811*^9, 3.7848483851374316`*^9}, {
   3.7848484523365097`*^9, 3.784848466066486*^9}, 3.7848486000008097`*^9, 
   3.785044146063534*^9, 3.8000651297354536`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]g\\), \\(tt\\)]\\)\"\>", 
  "\[Equal]", 
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"Q", " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Log",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Log,
           Editable->False], "[", 
          FractionBox[
           SuperscriptBox["\[ExponentialE]", "2"], 
           RowBox[{"2", " ", "r"}]], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox["q", "~"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`qt,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], "]"}]}], ")"}]}], 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"C", "[", "1", "]"}]}]]}], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", "Q", " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Log",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Log,
          Editable->False], "[", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["r", "2"]}], "\[ExponentialE]"], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", "r"}]], "+", 
    InterpretationBox[
     SuperscriptBox[
      RowBox[{"O", "[", 
       FractionBox["1", "r"], "]"}], "2"],
     SeriesData[$CellContext`r, 
      DirectedInfinity[1], {}, 0, 2, 1],
     Editable->False]}],
   SeriesData[$CellContext`r, 
    DirectedInfinity[
    1], {(-3) $CellContext`Q $CellContext`\[Epsilon] \
$CellContext`\[Kappa]^(-1) C[1]^(-1) 
     Log[Rational[1, 2] 
       E^2/$CellContext`r] $CellContext`qt[$CellContext`\[Omega]], (-3) \
$CellContext`M $CellContext`Q $CellContext`\[Epsilon] \
$CellContext`\[Kappa]^(-1) C[1]^(-1) 
     Log[4 E^(-1) $CellContext`r^2] $CellContext`qt[$CellContext`\[Omega]]}, 
    0, 2, 1],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.784848301729811*^9, 3.7848483851374316`*^9}, {
   3.7848484523365097`*^9, 3.784848466066486*^9}, 3.7848486000008097`*^9, 
   3.785044146063534*^9, 3.8000651297979383`*^9}]
}, Open  ]],

Cell[TextData[{
 "Far away from the event horizon, we see that the monopole correction \
threatens to logarithmically diverge and so ",
 StyleBox["must be controlled",
  FontSlant->"Italic"],
 ".\n\nWe end this section by proving that the monopole correction cannot be \
gauged away.\n\n",
 StyleBox["Proof",
  FontSlant->"Italic"],
 ": We show that any perturbation of the form ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Delta]g", "ab"], "=", 
   RowBox[{
    SubscriptBox["\[Delta]g", "tt"], 
    SubscriptBox[
     SuperscriptBox["\[Delta]", "t"], "a"], 
    SubscriptBox[
     SuperscriptBox["\[Delta]", "t"], "b"]}]}]],
  CellChangeTimes->{{3.784848301729811*^9, 3.7848483851374316`*^9}, {
    3.7848484523365097`*^9, 3.784848466066486*^9}, 3.7848486000008097`*^9, 
    3.785044146063534*^9, 3.8000651297979383`*^9}],
 " cannot be gauged away. To this end, we recall the components of the \
monopole gauge vector ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Xi]", "a"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and the gauge transformation ",
 Cell[BoxData[
  SubscriptBox["\[Delta]h", "ab"]],
  CellChangeTimes->{{3.800065512441839*^9, 3.8000655422652073`*^9}, {
   3.800065578188213*^9, 3.8000657302671795`*^9}}],
 " to the metric..."
}], "Text",
 CellChangeTimes->{{3.7848493031302104`*^9, 3.7848493490446596`*^9}, {
  3.800065200490966*^9, 3.800065297314151*^9}, {3.8000653621818695`*^9, 
  3.8000654408205767`*^9}, {3.8000654714240637`*^9, 3.800065502932103*^9}, {
  3.800065623338003*^9, 3.800065623806468*^9}, {3.8000657519522123`*^9, 
  3.8000657526551423`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(\[Xi]\), \(a\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]mon", "[", "a", "]"}], "//", 
        RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", "ComponentArray"}], "//",
       "ToValues"}], "//", "ToValues"}], "//", "MatrixForm"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"\[Delta]hevencompmon", "//", "MatrixForm"}], 
   ")"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.800065512441839*^9, 3.8000655422652073`*^9}, {
  3.800065578188213*^9, 3.800065782844399*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(\[Xi]\\), \\(a\\)]\\)\"\>", 
  "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["M", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]},
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["M", "1"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M1,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]},
       {"0"},
       {"0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.800065584249148*^9, 3.8000656137775745`*^9}, {
  3.8000656826415553`*^9, 3.800065783359744*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(ab\\)]\\)\"\>", 
  "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["h",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M0,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["h",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox["h",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]]}], "0", "0"},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox["h",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]]}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], "2"]}]], "0", "0"},
      {"0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["M", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False]}], 
        SqrtBox["\[Pi]"]], "0"},
      {"0", "0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["M", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}], "2"]}], 
        SqrtBox["\[Pi]"]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.800065584249148*^9, 3.8000656137775745`*^9}, {
  3.8000656826415553`*^9, 3.8000657833909864`*^9}}]
}, Open  ]],

Cell[TextData[{
 "The problem is make the ",
 StyleBox["tt-",
  FontSlant->"Italic"],
 "component of ",
 Cell[BoxData[
  SubscriptBox["\[Delta]h", "ab"]],
  CellChangeTimes->{{3.800065512441839*^9, 3.8000655422652073`*^9}, {
   3.800065578188213*^9, 3.8000657302671795`*^9}}],
 " equal to the desired expression (the monopole hair) while at the same time \
all other components must vanish. Obviously, we have to set ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["M", "1"], "(", "r", ")"}], "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Doing so we are left with one gauge degree of freedom in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["M", "0"], "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.8000658063219967`*^9, 3.800065895435673*^9}, {
  3.800065963575324*^9, 3.800066040684315*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Delta]hevencompmon", "/.", 
     RowBox[{"M1", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"r", ",", "0"}], "]"}]}]}], "//", "MatrixForm"}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.8000660538160505`*^9, 3.8000660737389593`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(ab\\)]\\)\"\>", 
  "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "00"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`P00,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["M", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        SqrtBox["\[Pi]"]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["h",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}], "0", "0"},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "00"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`P00,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["h",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}], "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.8000660613766007`*^9, 3.800066075004097*^9}}]
}, Open  ]],

Cell[TextData[{
 "At this point, it becomes clear that a single-",
 StyleBox["tt",
  FontSlant->"Italic"],
 "-component perturbation cannot be gauged away. The above expression implies \
that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["M", "0"], "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " must be a constant. At the same time, the ",
 StyleBox["tt",
  FontSlant->"Italic"],
 "-component must satisfy..."
}], "Text",
 CellChangeTimes->{{3.8000661829484186`*^9, 3.8000662823000298`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M0soltt", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"evenfullmon", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Delta]hevencompmon", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], " ", "/.", " ", 
         RowBox[{"M1", " ", "->", " ", 
          RowBox[{"Function", "[", 
           RowBox[{"r", ",", " ", "0"}], "]"}]}]}], ")"}]}], ",", 
      RowBox[{"M0", "[", 
       RowBox[{"r", "[", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(M\), \(0\)]\)(r)\>\"", "\[Equal]", 
   RowBox[{"M0", "[", 
    RowBox[{"r", "[", "]"}], "]"}]}], "/.", "M0soltt"}]}], "Input",
 CellChangeTimes->{{3.8000663024606657`*^9, 3.8000663522351723`*^9}, {
  3.800066387735428*^9, 3.800066426672593*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(M\\), \\(0\\)]\\)(r)\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}], 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False]}]]}]}]], "Output",
 CellChangeTimes->{
  3.800066304975561*^9, {3.8000663492940173`*^9, 3.800066352844369*^9}, 
   3.800066429070397*^9}]
}, Open  ]],

Cell[TextData[{
 "Together with the ",
 Cell[BoxData[
  FormBox[
   StyleBox["tr",
    FontSlant->"Italic"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "-component implying that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["M", "0"], "'"}], 
     RowBox[{"(", "r", ")"}]}], "=", "0"}], TraditionalForm]]],
 ", this shows that only the special case of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["H", "0"], "(", "r", ")"}], "=", "constant"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 " can be removed by a gauge transformation. The monopole correction is of \
course not constant. This ends the proof."
}], "Text",
 CellChangeTimes->{{3.800066434077177*^9, 3.800066517106331*^9}, {
  3.800066561090378*^9, 3.8000665752122335`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IV. dipole-odd parity (unmodified)", "Subsection",
 CellChangeTimes->{{3.782698631990068*^9, 3.7826986670163026`*^9}, {
  3.7848430411403537`*^9, 3.784843069235817*^9}}],

Cell[TextData[{
 "For this section, we focus on the odd parity dipole mode (",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "1"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "). In this case, the most general metric perturbation can, as a matter of \
fact (the odd parity tensor vanishes for ",
 StyleBox["l",
  FontSlant->"Italic"],
 " = 1), be written as..."
}], "Text",
 CellChangeTimes->{{3.784469765546257*^9, 3.7844698215015855`*^9}, {
  3.7844698891866455`*^9, 3.784469905563043*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dipodd", "=", "odd"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
   RowBox[{"(", 
    RowBox[{"dipodd", "//", "MatrixForm"}], ")"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SETdipodd", "=", 
   RowBox[{"PFoddRW", "/.", 
    RowBox[{
     RowBox[{"tt2", "[", "r", "]"}], "\[Rule]", "0"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SETdipodd", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784469823079311*^9, 3.78446988481308*^9}, {
  3.784470067825574*^9, 3.784470122753131*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {"0", "0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.7844701240364833`*^9, 3.7844721849985323`*^9, 
  3.784472674616931*^9, 3.7845026299155283`*^9, 3.784507236591916*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt0,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt0,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {"0", "0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt1,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt1,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt0,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt1,
           Editable->False], "[", "r", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt0,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", "\[Phi]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["t", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`tt1,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.7844701240364833`*^9, 3.7844721849985323`*^9, 
  3.784472674616931*^9, 3.7845026299155283`*^9, 3.78450723663875*^9}]
}, Open  ]],

Cell["\<\
The full metric for the odd parity dipole component is then...\
\>", "Text",
 CellChangeTimes->{{3.784470154077283*^9, 3.784470173898718*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"metricdipodd", "=", 
    RowBox[{"background", "+", 
     RowBox[{"\[Epsilon]", " ", "dipodd"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "tell", " ", "xCoba", " ", "to", " ", "compute", " ", "curvature", " ", 
    "components"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricInBasis", "[", 
   RowBox[{"g", ",", 
    RowBox[{"-", "Schw"}], ",", "metricdipodd"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricCompute", "[", 
   RowBox[{"g", ",", "Schw", ",", "All", ",", 
    RowBox[{"CVSimplify", "\[Rule]", "linearize"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7844701776833334`*^9, 3.78447020128813*^9}}],

Cell[TextData[{
 "In what follows, we show that the residual gauge degree of freedom can be \
used to eliminate either ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The vacuum field equations can then be solved analytically."
}], "Text",
 CellChangeTimes->{{3.78447020621157*^9, 3.7844702820412216`*^9}, {
  3.7844703127473097`*^9, 3.7844703268651686`*^9}}],

Cell[CellGroupData[{

Cell["Gauge fixing", "Subsubsection",
 CellChangeTimes->{{3.7844703306763077`*^9, 3.784470333058597*^9}}],

Cell["We define the odd parity gauge vector \[Zeta]...", "Text",
 CellChangeTimes->{{3.784470482641404*^9, 3.784470490802619*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"odd", " ", "parity", " ", "gauge", " ", "vector"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Zeta]", "[", 
       RowBox[{"-", "a"}], "]"}], ",", "Md"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "G", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"ComponentArray", "[", 
       RowBox[{"\[Zeta]", "[", 
        RowBox[{"{", 
         RowBox[{"a", ",", "Schw"}], "}"}], "]"}], "]"}], ",", 
      RowBox[{"\[Epsilon]", " ", 
       SuperscriptBox["E", 
        RowBox[{
         RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
         RowBox[{"t", "[", "]"}]}]], 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"G", "[", 
             RowBox[{"r", "[", "]"}], "]"}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"r", "[", "]"}], "2"], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "]"}], "]"}]}]]}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"G", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"r", "[", "]"}], "2"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]}]], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChangeComponents", "[", 
     RowBox[{
      RowBox[{"\[Zeta]", "[", 
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"a", ",", "Schw"}], "}"}]}], "]"}], ",", 
      RowBox[{"\[Zeta]", "[", 
       RowBox[{"{", 
        RowBox[{"a", ",", "Schw"}], "}"}], "]"}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7844721427174253`*^9, 3.7844721514847755`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Zeta]", 
         StyleBox[GridBox[{
            {" "},
            {
             StyleBox["a",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Zeta][{-$CellContext`a, -$CellContext`Schw}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{-$CellContext`b, -$CellContext`Schw}, {-$CellContext`a, \
-$CellContext`Schw}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[Zeta]", 
          StyleBox[GridBox[{
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Zeta][{$CellContext`b, $CellContext`Schw}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.0221426`5.796773608202929", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`\[Zeta][{-$CellContext`a, -$CellContext`Schw}] -> \
$CellContext`g[{-$CellContext`b, -$CellContext`Schw}, {-$CellContext`a, \
-$CellContext`Schw}] $CellContext`\[Zeta][{$CellContext`b, \
$CellContext`Schw}], " in ", 0.0221426`5.796773608202929, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7844706211082554`*^9, 3.784472264366764*^9, 
  3.7844727706123066`*^9, 3.7845027778924923`*^9, 3.7845084361292973`*^9}]
}, Open  ]],

Cell["The perturbations then transform as...", "Text",
 CellChangeTimes->{{3.7844706236628914`*^9, 3.784470630300926*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]hodd", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "a"}], "]"}], "[", 
      RowBox[{"\[Zeta]", "[", 
       RowBox[{"-", "b"}], "]"}], "]"}], "+", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "b"}], "]"}], "[", 
      RowBox[{"\[Zeta]", "[", 
       RowBox[{"-", "a"}], "]"}], "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(bc\)]\)\>\"", "==", 
   "\[Delta]hodd"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "odd", " ", "parity", " ", "components", " ", "of", " ", "the", " ", 
    "gauge", " ", "transformation"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]hoddcomp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Delta]hodd", "//", 
          RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", 
         RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", "TraceBasisDummy"}], "//",
        "ComponentArray"}], "//", "ToValues"}], "//", "ToValues"}], "//", 
    "linearize"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(bc\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[EmptyDownTriangle]", "a"], GridBox[{
        {"\[Zeta]", 
         StyleBox[GridBox[{
            {" "},
            {"b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Zeta][-$CellContext`b]],
    Editable->False], "+", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[EmptyDownTriangle]", "b"], GridBox[{
        {"\[Zeta]", 
         StyleBox[GridBox[{
            {" "},
            {"a"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Zeta][-$CellContext`a]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.784470702035393*^9, 3.7844722685183334`*^9, 
  3.7844727733090677`*^9, 3.784502780145076*^9, 3.7845084396149807`*^9}]
}, Open  ]],

Cell["\<\
After transformation the components of the new perturbation becomes...\
\>", "Text",
 CellChangeTimes->{{3.7844707198830833`*^9, 3.784470778852647*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hnewodd", "=", 
   RowBox[{"dipodd", "+", "\[Delta]hoddcomp"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]\[Theta]odd", "=", 
   RowBox[{
    RowBox[{"hnewodd", "[", 
     RowBox[{"[", 
      RowBox[{"3", ",", "3"}], "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]\[CurlyPhi]odd", "=", 
   RowBox[{
    RowBox[{"hnewodd", "[", 
     RowBox[{"[", 
      RowBox[{"3", ",", "4"}], "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CurlyPhi]\[CurlyPhi]odd", "=", 
    RowBox[{
     RowBox[{"hnewodd", "[", 
      RowBox[{"[", 
       RowBox[{"4", ",", "4"}], "]"}], "]"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(33\)]\)'\>\"", "==", 
  "\[Theta]\[Theta]odd"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(34\)]\)'\>\"", "==", 
  "\[Theta]\[CurlyPhi]odd"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(44\)]\)'\>\"", "==", 
  "\[CurlyPhi]\[CurlyPhi]odd"}]}], "Input",
 CellChangeTimes->{{3.784470821702403*^9, 3.7844708237888565`*^9}, {
  3.784470901888468*^9, 3.784470902299988*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(33\\)]\\)'\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["m",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`m,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Csc",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Csc,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False], "-", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False]}], ")"}], "!"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False], "+", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False]}], ")"}], "!"}]]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["Cot",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cot,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["\[Theta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Theta][],
         Editable->False], "]"}]}], ")"}]}], 
    SqrtBox["\[Pi]"]]}]}]], "Output",
 CellChangeTimes->{3.784470904673882*^9, 3.7844723471333575`*^9, 
  3.784472779537468*^9, 3.784502783290162*^9, 3.7845084419828386`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(34\\)]\\)'\"\>", "\[Equal]", 
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      SqrtBox["\[Pi]"]}]], 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False], "-", 
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False]}], ")"}], "!"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False], "+", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False]}], ")"}], "!"}]]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Sin",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Sin,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["l",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`l,
            Editable->False], "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Csc",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Csc,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cot",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cot,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}]}]}], ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{3.784470904673882*^9, 3.7844723471333575`*^9, 
  3.784472779537468*^9, 3.784502783290162*^9, 3.784508441998458*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(44\\)]\\)'\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False]}]}], ")"}]}]], " ", 
    InterpretationBox[
     StyleBox["m",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`m,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False], "-", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False]}], ")"}], "!"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["l",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`l,
          Editable->False], "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Cos",
          ShowAutoStyles->False,
          AutoSpacing->False],
         Cos,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["\[Theta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Theta][],
         Editable->False], "]"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["P", "lm"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`PL,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["\[Theta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Theta][],
         Editable->False], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Sin",
          ShowAutoStyles->False,
          AutoSpacing->False],
         Sin,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["\[Theta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Theta][],
         Editable->False], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["P", "lm"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`PL,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["\[Theta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Theta][],
         Editable->False], "]"}]}]}], ")"}]}], 
   SqrtBox["\[Pi]"]]}]], "Output",
 CellChangeTimes->{3.784470904673882*^9, 3.7844723471333575`*^9, 
  3.784472779537468*^9, 3.784502783290162*^9, 3.784508442020587*^9}]
}, Open  ]],

Cell[TextData[{
 "All of the above trivially vanishes for the ",
 StyleBox["l",
  FontSlant->"Italic"],
 " = 1 case. This can be shown by substituting the specific values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["P", 
    RowBox[{"1", "-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["P", "10"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["P", "11"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", e.g.,..."
}], "Text",
 CellChangeTimes->{{3.784471326481159*^9, 3.784471372922179*^9}, {
  3.784471522585972*^9, 3.7844715280438547`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(33, 1 - 1\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Theta]\[Theta]odd", "/.", 
     RowBox[{"PL", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"x", ",", 
        RowBox[{"LegendreP", "[", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], "]"}]}]}], "//", 
    "Simplify"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(33, 10\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Theta]\[Theta]odd", "/.", 
      RowBox[{"PL", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", 
         RowBox[{"LegendreP", "[", 
          RowBox[{"1", ",", "0", ",", 
           RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], "]"}]}]}], "/.", 
     RowBox[{"m", "\[Rule]", "0"}]}], "//", "Simplify"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(33, 11\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Theta]\[Theta]odd", "/.", 
     RowBox[{"PL", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"x", ",", 
        RowBox[{"LegendreP", "[", 
         RowBox[{"1", ",", "1", ",", 
          RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], "]"}]}]}], "//", 
    "Simplify"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7844711479056845`*^9, 3.7844711624266267`*^9}, {
  3.7844712542901115`*^9, 3.784471268386223*^9}, {3.7844715458192425`*^9, 
  3.7844715562835307`*^9}, {3.7844715902189474`*^9, 3.7844716384988937`*^9}}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.784471151179083*^9, 3.784471162845705*^9}, 
   3.7844715570698795`*^9, 3.7844716037634068`*^9, 3.7844716396616583`*^9, 
   3.784472350336384*^9, 3.784472783606268*^9, 3.78450844527141*^9}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.784471151179083*^9, 3.784471162845705*^9}, 
   3.7844715570698795`*^9, 3.7844716037634068`*^9, 3.7844716396616583`*^9, 
   3.784472350336384*^9, 3.784472783606268*^9, 3.78450844527141*^9}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.784471151179083*^9, 3.784471162845705*^9}, 
   3.7844715570698795`*^9, 3.7844716037634068`*^9, 3.7844716396616583`*^9, 
   3.784472350336384*^9, 3.784472783606268*^9, 3.7845084453026514`*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, ",
 StyleBox["G",
  FontSlant->"Italic"],
 " can instead be suitably chosen by looking at the vector components. For \
this case, we shall choose ",
 StyleBox["G",
  FontSlant->"Italic"],
 " to make ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " vanish. We do so as follows..."
}], "Text",
 CellChangeTimes->{{3.7844717686905775`*^9, 3.784471853941451*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r\[Theta]odd", "=", 
   RowBox[{
    RowBox[{"hnewodd", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "3"}], "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r\[CurlyPhi]odd", "=", 
    RowBox[{
     RowBox[{"hnewodd", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "4"}], "]"}], "]"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "ta", " ", "components", " ", "are", " ", "unaffected", " ", "by", " ", 
    "gauge", " ", "transform"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(r\[Theta]\)]\)'\>\"", "\[Equal]", 
  "r\[Theta]odd"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(r\[CurlyPhi]\)]\)'\>\"", "\[Equal]",
   "r\[CurlyPhi]odd"}]}], "Input",
 CellChangeTimes->{{3.7844718577955313`*^9, 3.784471859338709*^9}, {
  3.784471961464443*^9, 3.7844720675171385`*^9}, {3.784473096591122*^9, 
  3.7844730967603874`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(r\[Theta]\\)]\\)'\"\>", 
  "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False]}]], 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False]}]}], ")"}]}]], " ", 
    InterpretationBox[
     StyleBox["m",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`m,
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Csc",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Csc,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Theta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Theta][],
      Editable->False], "]"}], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False], "-", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False]}], ")"}], "!"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["l",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`l,
          Editable->False], "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Theta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Theta][],
      Editable->False], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.7844720714543552`*^9, 3.7844723536932154`*^9, 
  3.784472786241989*^9, 3.784473047382325*^9, 3.784473101508953*^9, 
  3.784502789213173*^9, 3.784508447374593*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(r\[CurlyPhi]\\)]\\)'\"\>", 
  "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi][],
          Editable->False]}]}], ")"}]}]], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox["l",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`l,
           Editable->False], "-", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False]}], ")"}], "!"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["l",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`l,
          Editable->False], "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Sin",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Sin,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Theta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Theta][],
      Editable->False], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       InterpretationBox[
        StyleBox["\[Epsilon]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Epsilon],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["\[Theta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Theta][],
      Editable->False], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.7844720714543552`*^9, 3.7844723536932154`*^9, 
  3.784472786241989*^9, 3.784473047382325*^9, 3.784473101508953*^9, 
  3.784502789213173*^9, 3.784508447390213*^9}]
}, Open  ]],

Cell[TextData[{
 "Based on the above, we can eliminate the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "ra"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " vector perturbation by choosing ",
 StyleBox["G ",
  FontSlant->"Italic"],
 "such that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["h", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h1,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}]}]}], ")"}]}]}], "=", "0"}]],
  CellChangeTimes->{3.7844720714543552`*^9, 3.7844723536932154`*^9, 
   3.784472786241989*^9, 3.784473047382325*^9, 3.784473101535883*^9}],
 ". The gauge vector must then have ",
 StyleBox["G ",
  FontSlant->"Italic"],
 "given by..."
}], "Text",
 CellChangeTimes->{{3.7844731129069786`*^9, 3.784473206334299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Gsol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           InterpretationBox[
            StyleBox["\[Epsilon]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Epsilon],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], "[", 
            InterpretationBox[
             StyleBox["r",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`r[],
             Editable->False], "]"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h1,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["\[Epsilon]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Epsilon],
               Editable->False], " ", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["G",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`G,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}]}]}], ")"}]}]}], "/.", 
         RowBox[{
          RowBox[{"r", "[", "]"}], "\[Rule]", "r"}]}], ")"}], "\[Equal]", 
       "0"}], ",", "G", ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<G(r)\>\"", "==", 
   RowBox[{"G", "[", "r", "]"}]}], "/.", "Gsol"}]}], "Input",
 CellChangeTimes->{{3.784473196399365*^9, 3.7844732970638585`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,94,1,16556367178186283087,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.784473217973111*^9, 3.784473297756949*^9}, 
   3.784502798952843*^9, 3.7845084510331616`*^9}],

Cell[BoxData[
 RowBox[{"\<\"G(r)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    RowBox[{"C", "[", "1", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "1", "r"], 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "1"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1,
          Editable->False], "[", 
         RowBox[{"K", "[", "1", "]"}], "]"}], 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         SuperscriptBox[
          RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
      RowBox[{"\[DifferentialD]", 
       RowBox[{"K", "[", "1", "]"}]}]}]}]}]}]}]], "Output",
 CellChangeTimes->{{3.784473218095913*^9, 3.7844732977809544`*^9}, 
   3.7845027989725976`*^9, 3.7845084510644436`*^9}]
}, Open  ]],

Cell[TextData[{
 "With this choice the vector ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "ta"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " becomes..."
}], "Text",
 CellChangeTimes->{{3.784473335443598*^9, 3.7844733581153884`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hnewgf", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"hnewodd", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"hnewodd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "3"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"hnewodd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "4"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"hnewodd", "[", 
           RowBox[{"[", 
            RowBox[{"4", ",", "3"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"hnewodd", "[", 
           RowBox[{"[", 
            RowBox[{"4", ",", "4"}], "]"}], "]"}], "\[Rule]", "0"}]}], 
        "}"}]}], "/.", "Gsol"}], "//", "Simplify"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<h'\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"hnewgf", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784473359249095*^9, 3.7844733669950275`*^9}, {
  3.784473425062904*^9, 3.784473447491149*^9}, {3.7844735146032157`*^9, 
  3.784473582969097*^9}}],

Cell[BoxData[
 RowBox[{"\<\"h'\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            InterpretationBox[
             StyleBox["\[Epsilon]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Epsilon],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"C", "[", "1", "]"}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Integral]", "1", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False]], 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["h", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`h1,
                    Editable->False], "[", 
                   RowBox[{"K", "[", "1", "]"}], "]"}], 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["\[Epsilon]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Epsilon],
                    Editable->False], " ", 
                   SuperscriptBox[
                    RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
                RowBox[{"\[DifferentialD]", 
                 RowBox[{"K", "[", "1", "]"}]}]}]}]}], ")"}], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "2"]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["h", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`h0,
             Editable->False], "[", 
            InterpretationBox[
             StyleBox["r",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`r[],
             Editable->False], "]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["\[Epsilon]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Epsilon],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"C", "[", "1", "]"}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Integral]", "1", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False]], 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["h", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`h1,
                    Editable->False], "[", 
                   RowBox[{"K", "[", "1", "]"}], "]"}], 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["\[Epsilon]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Epsilon],
                    Editable->False], " ", 
                   SuperscriptBox[
                    RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
                RowBox[{"\[DifferentialD]", 
                 RowBox[{"K", "[", "1", "]"}]}]}]}]}], ")"}], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "2"]}]}], ")"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {"0", "0", "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}]}], "+", 
           RowBox[{
            InterpretationBox[
             StyleBox["\[Epsilon]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Epsilon],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"C", "[", "1", "]"}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Integral]", "1", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False]], 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["h", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`h1,
                    Editable->False], "[", 
                   RowBox[{"K", "[", "1", "]"}], "]"}], 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["\[Epsilon]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Epsilon],
                    Editable->False], " ", 
                   SuperscriptBox[
                    RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
                RowBox[{"\[DifferentialD]", 
                 RowBox[{"K", "[", "1", "]"}]}]}]}]}], ")"}], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "2"]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["h", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`h0,
             Editable->False], "[", 
            InterpretationBox[
             StyleBox["r",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`r[],
             Editable->False], "]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["\[Epsilon]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Epsilon],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"C", "[", "1", "]"}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Integral]", "1", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False]], 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["h", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`h1,
                    Editable->False], "[", 
                   RowBox[{"K", "[", "1", "]"}], "]"}], 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["\[Epsilon]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Epsilon],
                    Editable->False], " ", 
                   SuperscriptBox[
                    RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
                RowBox[{"\[DifferentialD]", 
                 RowBox[{"K", "[", "1", "]"}]}]}]}]}], ")"}], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "2"]}]}], ")"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.784473367414921*^9, {3.7844734358664083`*^9, 3.78447344898424*^9}, 
   3.784473521312398*^9, {3.7844735777408533`*^9, 3.784473583767391*^9}, 
   3.784502803346645*^9, 3.784508453730588*^9}]
}, Open  ]],

Cell["Finally, by making the substitution...", "Text",
 CellChangeTimes->{{3.784473688263588*^9, 3.7844736993775616`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h0to\[Alpha]", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C", "[", "1", "]"}], "+", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "1", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False]], 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["h", "1"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`h1,
                 Editable->False], "[", 
                RowBox[{"K", "[", "1", "]"}], "]"}], 
               RowBox[{
                InterpretationBox[
                 StyleBox["\[Epsilon]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Epsilon],
                 Editable->False], " ", 
                SuperscriptBox[
                 RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
             RowBox[{"\[DifferentialD]", 
              RowBox[{"K", "[", "1", "]"}]}]}]}]}], ")"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"]}]}], "\[Equal]", 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"r", "[", "]"}], "]"}]}], ",", " ", 
      RowBox[{"h0", "[", 
       RowBox[{"r", "[", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", "h0to\[Alpha]"}]], "Input",
 CellChangeTimes->{{3.784473720598578*^9, 3.784473746893607*^9}, {
  3.7844737800646615`*^9, 3.784473813918765*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox["h", "0"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h0,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["r",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`r[],
     Editable->False], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "1", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False]], 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["h", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`h1,
             Editable->False], "[", 
            RowBox[{"K", "[", "1", "]"}], "]"}], 
           RowBox[{
            InterpretationBox[
             StyleBox["\[Epsilon]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Epsilon],
             Editable->False], " ", 
            SuperscriptBox[
             RowBox[{"K", "[", "1", "]"}], "2"]}]]}], 
         RowBox[{"\[DifferentialD]", 
          RowBox[{"K", "[", "1", "]"}]}]}]}]}], ")"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"]}], "+", 
    RowBox[{"\[Alpha]", "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7844738158262386`*^9, 3.7845028093478193`*^9, 
  3.7845084571012983`*^9}]
}, Open  ]],

Cell["...then the odd parity dipole component simply becomes...", "Text",
 CellChangeTimes->{{3.7844738190943403`*^9, 3.784473845839186*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hnewgffinal", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"hnewgf", "/.", "h0to\[Alpha]"}], "//", "Simplify"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<h'\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"hnewgffinal", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784473859323027*^9, 3.7844739136745124`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"h'\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{"\[Alpha]", "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{"\[Alpha]", "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {"0", "0", "0", "0"},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{"\[Alpha]", "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}], " ", 
         RowBox[{"\[Alpha]", "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.7844739140992985`*^9, 3.7845028118143206`*^9, 
  3.7845084591726294`*^9}]
}, Open  ]],

Cell["\<\
This means that the odd parity dipole component is described only by a one \
(instead of two) gauge invariant.\
\>", "Text",
 CellChangeTimes->{{3.784473940316606*^9, 3.7844739987503614`*^9}, {
  3.7845028184887776`*^9, 3.7845028200255575`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Einstein equation", "Subsubsection",
 CellChangeTimes->{{3.7845028230627794`*^9, 3.784502825079537*^9}}],

Cell["\<\
We now setup the Einstein equation (plus cosmological constant)...\
\>", "Text",
 CellChangeTimes->{3.7845028328435593`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"RicciCD", "[", 
       RowBox[{
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"g", "[", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], 
       RowBox[{"RicciScalarCD", "[", "]"}]}]}], ")"}], "+", 
    RowBox[{"\[CapitalLambda]", " ", 
     RowBox[{"g", "[", 
      RowBox[{
       RowBox[{"-", "c"}], ",", 
       RowBox[{"-", "b"}]}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EE", "\[Equal]", 
  "\"\<8 \[Pi] \!\(\*SubscriptBox[\(T\), \(cb\)]\)\>\""}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`c, -$CellContext`b],
     Editable->False]}], "+", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}], 
        StyleBox[GridBox[{
           {" ", " "},
           {"c", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`c, -$CellContext`b],
    Editable->False], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`c, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[\\(T\\), \
\\(cb\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{3.784502855675605*^9, 3.784508478706808*^9}]
}, Open  ]],

Cell["The linearized expression is...", "Text",
 CellChangeTimes->{{3.7845028669814625`*^9, 3.7845028722112255`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EERW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"EE", "//", 
          RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", "ComponentArray"}], "//",
         "ToValues"}], "//", "ToValues"}], ")"}], "/.", "removebrackets"}], "//",
     "linearize"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EERWGF", "=", 
   RowBox[{
    RowBox[{"EERW", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h1", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"EERW", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"EERW", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "4"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"EERW", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "3"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"EERW", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "4"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"l", "\[Rule]", "1"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7845029914577723`*^9, 3.7845029999085712`*^9}, {
  3.7845033564588575`*^9, 3.7845033790721035`*^9}, {3.7845040410569625`*^9, 
  3.784504042981924*^9}}],

Cell[TextData[{
 "The ",
 StyleBox["nontrivial",
  FontSlant->"Italic"],
 " components of gravitational sector of EE are..."
}], "Text",
 CellChangeTimes->{{3.78450302006487*^9, 3.78450303320126*^9}, {
  3.7845031257885942`*^9, 3.784503130426676*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EERWdipodd", "=", 
   RowBox[{
    RowBox[{"EERWGF", "/.", "SdS"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(G\), \(ab\)]\)+\!\(\*SubscriptBox[\(\
\[CapitalLambda]g\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"EERWdipodd", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784503142598851*^9, 3.7845032013873324`*^9}, {
  3.7845034618897624`*^9, 3.7845035042159767`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(G\\), \
\\(ab\\)]\\)+\\!\\(\\*SubscriptBox[\\(\[CapitalLambda]g\\), \\(ab\\)]\\)\"\>",
   "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         SuperscriptBox["r", "3"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         SuperscriptBox["r", "3"]}]]},
      {"0", "0", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}]}]], 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}]}]]},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         SuperscriptBox["r", "3"]}]], 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Csc",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Csc,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         SuperscriptBox["r", "3"]}]], 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", "\[Phi]"}], "+", 
             RowBox[{"t", " ", 
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["h", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`h0,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["h", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`h0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "\[Theta]", "]"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False]}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[CapitalLambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[CapitalLambda],
             Editable->False]}]}], ")"}]}]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.784503195540861*^9, 3.784503201824402*^9}, 
   3.7845033886190557`*^9, {3.784503483063853*^9, 3.784503504804123*^9}, {
   3.7845040482665215`*^9, 3.7845040707330275`*^9}, 3.7845084938554525`*^9}]
}, Open  ]],

Cell["\<\
We extract the nontrivial equations below and then solve them...\
\>", "Text",
 CellChangeTimes->{{3.784503425701148*^9, 3.784503444852091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"t\[Theta]", "=", 
   RowBox[{
    RowBox[{"EERWdipodd", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "3"}], "]"}], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"8", "\[Pi]", " ", 
         RowBox[{"SETdipodd", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "/.", "SdS"}], "/.", 
       RowBox[{"l", "\[Rule]", "1"}]}], "//", "Simplify"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r\[Theta]", "=", 
    RowBox[{
     RowBox[{"EERWdipodd", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "3"}], "]"}], "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"8", "\[Pi]", " ", 
          RowBox[{"SETdipodd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "/.", "SdS"}], "/.", 
        RowBox[{"l", "\[Rule]", "1"}]}], "//", "Simplify"}], ")"}]}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"t\[Theta]sim", "=", 
  RowBox[{"t\[Theta]", "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"r\[Theta]sim", "=", 
  RowBox[{"r\[Theta]", "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.784503534931696*^9, 3.7845035499664154`*^9}, {
  3.7845035949691615`*^9, 3.7845036929228616`*^9}, {3.784504119363343*^9, 
  3.7845041257765727`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "r"], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", "\[Phi]"}], "+", 
        RowBox[{"t", " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False]}]}], ")"}]}]], " ", 
    InterpretationBox[
     StyleBox["m",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`m,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Csc",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Csc,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "-", 
         RowBox[{"3", " ", "r"}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[CapitalLambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CapitalLambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["h", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h0,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "48"}], " ", "\[Pi]", " ", "r", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["t", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`tt0,
            Editable->False], "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False]}], "-", 
            RowBox[{"3", " ", "r"}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[CapitalLambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[CapitalLambda],
              Editable->False]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["h", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`h0,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
     ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7845036938164434`*^9, 3.784504075300725*^9, 
  3.7845041267434387`*^9, 3.784508500030681*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"6", " ", 
      InterpretationBox[
       StyleBox["M",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`M,
       Editable->False]}], "-", 
     RowBox[{"3", " ", "r"}], "+", 
     RowBox[{
      SuperscriptBox["r", "3"], " ", 
      InterpretationBox[
       StyleBox["\[CapitalLambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[CapitalLambda],
       Editable->False]}]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", "\[Phi]"}], "+", 
        RowBox[{"t", " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False]}]}], ")"}]}]], " ", 
    InterpretationBox[
     StyleBox["m",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`m,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Csc",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Csc,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["h", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h0,
         Editable->False], "[", "r", "]"}]}], "-", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "-", 
         RowBox[{"3", " ", "r"}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[CapitalLambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CapitalLambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["t", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`tt1,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"3", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.7845036938164434`*^9, 3.784504075300725*^9, 
  3.7845041267434387`*^9, 3.784508500384753*^9}]
}, Open  ]],

Cell[TextData[{
 "We see that we have two equations for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The task at hand is to find the common solution to both equations."
}], "Text",
 CellChangeTimes->{{3.784503782174288*^9, 3.784503820878462*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Vacuum solution", "Subsubsection",
 CellChangeTimes->{{3.784503825504773*^9, 3.7845038282195425`*^9}}],

Cell["\<\
To obtain the vacuum limit, we simply make the SET components vanish.\
\>", "Text",
 CellChangeTimes->{{3.784503838080697*^9, 3.7845038519285607`*^9}, {
  3.7845038872805357`*^9, 3.7845038934732018`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"vacdipodd", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tt0", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}], ",", 
      RowBox[{"tt1", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t\[Theta]vac", "=", 
   RowBox[{
    RowBox[{"t\[Theta]sim", "/.", "vacdipodd"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r\[Theta]vac", "=", 
    RowBox[{
     RowBox[{"r\[Theta]sim", "/.", "vacdipodd"}], "//", "Simplify"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", "t\[Theta]vac", "\
\[IndentingNewLine]", "r\[Theta]vac"}], "Input",
 CellChangeTimes->{{3.784503923317284*^9, 3.7845040002734165`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "r"], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", "\[Phi]"}], "+", 
        RowBox[{"t", " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False]}]}], ")"}]}]], " ", 
    InterpretationBox[
     StyleBox["m",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`m,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False]}], "-", 
      RowBox[{"3", " ", "r"}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[CapitalLambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[CapitalLambda],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Csc",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Csc,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["h", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h0,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{
  3.7845040012286415`*^9, 3.784504168544419*^9, {3.784508503051137*^9, 
   3.7845085157515287`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", "\[Phi]"}], "+", 
        RowBox[{"t", " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False]}]}], ")"}]}]], " ", 
    InterpretationBox[
     StyleBox["m",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`m,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["\[Omega]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Omega],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Csc",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Csc,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False]}], ")"}], "!"}]]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["h", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h0,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"6", " ", 
     InterpretationBox[
      StyleBox["M",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`M,
      Editable->False]}], "-", 
    RowBox[{"3", " ", "r"}], "+", 
    RowBox[{
     SuperscriptBox["r", "3"], " ", 
     InterpretationBox[
      StyleBox["\[CapitalLambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[CapitalLambda],
      Editable->False]}]}]], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.7845040012286415`*^9, 3.784504168544419*^9, {3.784508503051137*^9, 
   3.78450851576715*^9}}]
}, Open  ]],

Cell["\<\
The general solution to the above equations can easily be obtained...\
\>", "Text",
 CellChangeTimes->{{3.784504183388461*^9, 3.784504205376696*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"h0t\[Theta]", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{"t\[Theta]vac", ",", "h0", ",", "r"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"h0r\[Theta]", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{"r\[Theta]vac", ",", "h0", ",", "r"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7845042061871147`*^9, 3.7845042401137753`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,126,2,16556367178186283087,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7845042428632927`*^9, 3.7845085228278*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     SubscriptBox["h", "0"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h0,
    Editable->False], "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "r", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"C", "[", "1", "]"}]}], "+", 
      FractionBox[
       RowBox[{"C", "[", "2", "]"}], "r"]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.784504242869708*^9, 3.7845085228590417`*^9}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,127,3,16556367178186283087,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7845042428632927`*^9, 3.784508522990564*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     SubscriptBox["h", "0"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h0,
    Editable->False], "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "r", "}"}], ",", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"C", "[", "1", "]"}]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.784504242869708*^9, 3.784508522990564*^9}]
}, Open  ]],

Cell[TextData[{
 "The common solution to both equations is ",
 StyleBox["only",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["h", "0"], "(", "r", ")"}], "=", 
    RowBox[{"C", " ", 
     SuperscriptBox["r", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " where ",
 StyleBox["C",
  FontSlant->"Italic"],
 " is an integration constant. This is, however, a solution which can be \
gauged away with a suitable transformation. \n\nOn the other hand, the widely \
accepted interpretation of the dipole mode is as an angular momentum \
perturbation. To see this, note that the ",
 StyleBox["r",
  FontSlant->"Italic"],
 "\[Theta] equation depends linearly on \[Omega]. For \[Omega] = 0 \
(corresponding to nondynamical dipole perturbation), the ",
 StyleBox["r",
  FontSlant->"Italic"],
 "\[Theta] then is trivially satisfied and the general solution to the \
Einstein equation becomes..."
}], "Text",
 CellChangeTimes->{{3.784504280154293*^9, 3.784504361249409*^9}, {
  3.784506761686286*^9, 3.784506939769472*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h0", "[", "r", "]"}], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"h0", "[", "r", "]"}], "/.", "h0t\[Theta]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.784506941237864*^9, 3.7845069722776194`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     SubscriptBox["h", "0"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h0,
    Editable->False], "[", "r", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    RowBox[{"C", "[", "1", "]"}]}], "+", 
   FractionBox[
    RowBox[{"C", "[", "2", "]"}], "r"]}]}]], "Output",
 CellChangeTimes->{{3.784506951094924*^9, 3.784506973136653*^9}}]
}, Open  ]],

Cell["\<\
The first term of this can be gauged away and so the solution can be written \
as...\
\>", "Text",
 CellChangeTimes->{{3.7845069846495867`*^9, 3.784507031029443*^9}, {
  3.7845070712871323`*^9, 3.784507076613983*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h0sol", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"h0", "[", "r", "]"}], "/.", "h0t\[Theta]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"C", "[", "2", "]"}], "\[Rule]", "J"}]}], "}"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h0", "[", "r", "]"}], "==", "h0sol"}]}], "Input",
 CellChangeTimes->{{3.7845070863303027`*^9, 3.78450710065524*^9}, {
  3.784507145050887*^9, 3.78450718844711*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     SubscriptBox["h", "0"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h0,
    Editable->False], "[", "r", "]"}], "\[Equal]", 
  FractionBox["J", "r"]}]], "Output",
 CellChangeTimes->{{3.7845071678580627`*^9, 3.784507198788263*^9}, 
   3.7845085581017694`*^9}]
}, Open  ]],

Cell["\<\
For the 11, 1-1, and 10 modes, the metric perturbation is finally...\
\>", "Text",
 CellChangeTimes->{{3.7845086725961885`*^9, 3.7845087112223883`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pertdip", "[", 
     RowBox[{"L_", ",", "M_"}], "]"}], ":=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"dipodd", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"l", "\[Rule]", "L"}], ",", 
         RowBox[{"m", "\[Rule]", "M"}], ",", 
         RowBox[{"PL", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{"\[Theta]", ",", 
            RowBox[{"LegendreP", "[", 
             RowBox[{"L", ",", "M", ",", 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "\[Rule]", "h0sol"}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "}"}]}], ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Theta]", "[", "]"}], "\[GreaterEqual]", "0"}], "&&", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "]"}], "]"}], "\[GreaterEqual]", 
         "0"}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"pertdip", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "/.", 
      RowBox[{
      "J", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(J\), \(10\)]\)\>\""}]}], "//",
      "MatrixForm"}], ")"}], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"pertdip", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "/.", 
      RowBox[{
      "J", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(J\), \(11\)]\)\>\""}]}], "//",
      "MatrixForm"}], ")"}], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"pertdip", "[", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "]"}], "/.", 
      RowBox[{
      "J", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(J\), \(1 - 1\)]\)\>\""}]}], "//",
      "MatrixForm"}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.7845085853017316`*^9, 3.7845086260774336`*^9}, {
  3.784508785084441*^9, 3.784508795649847*^9}, {3.7845088262775345`*^9, 
  3.784508919724759*^9}, {3.7845089580335455`*^9, 3.784508976652028*^9}, {
  3.784509012612338*^9, 3.784509029364233*^9}, {3.7845091653568325`*^9, 
  3.784509168122674*^9}, {3.7845092967533493`*^9, 3.7845093817145987`*^9}, {
  3.7845094655492764`*^9, 3.7845094858339386`*^9}, {3.784509708845711*^9, 
  3.784509738356431*^9}, {3.784509822648073*^9, 3.7845098542444844`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(10\\)]\\)\"\>", " ", 
           SqrtBox[
            FractionBox["3", "\[Pi]"]], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}], "2"]}], 
          RowBox[{"2", " ", "r"}]]}]},
       {"0", "0", "0", "0"},
       {"0", "0", "0", "0"},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(10\\)]\\)\"\>", " ", 
           SqrtBox[
            FractionBox["3", "\[Pi]"]], " ", 
           SuperscriptBox[
            RowBox[{
             InterpretationBox[
              StyleBox["Sin",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Sin,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}], "2"]}], 
          RowBox[{"2", " ", "r"}]]}], "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "+", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
          "\[ImaginaryI]", 
           " ", "\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(11\\)]\\)\"\>", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi][],
              Editable->False]}]], " ", 
           SqrtBox[
            FractionBox["3", 
             RowBox[{"2", " ", "\[Pi]"}]]]}], 
          RowBox[{"2", " ", "r"}]]}], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(11\\)]\\)\"\>", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi][],
              Editable->False]}]], " ", 
           SqrtBox[
            FractionBox["3", 
             RowBox[{"2", " ", "\[Pi]"}]]], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["Sin",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Sin,
             Editable->False], "[", 
            RowBox[{"2", " ", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False]}], "]"}]}], 
          RowBox[{"4", " ", "r"}]]}]},
       {"0", "0", "0", "0"},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
          "\[ImaginaryI]", 
           " ", "\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(11\\)]\\)\"\>", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi][],
              Editable->False]}]], " ", 
           SqrtBox[
            FractionBox["3", 
             RowBox[{"2", " ", "\[Pi]"}]]]}], 
          RowBox[{"2", " ", "r"}]]}], "0", "0", "0"},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(11\\)]\\)\"\>", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi][],
              Editable->False]}]], " ", 
           SqrtBox[
            FractionBox["3", 
             RowBox[{"2", " ", "\[Pi]"}]]], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["Sin",
              ShowAutoStyles->False,
              AutoSpacing->False],
             Sin,
             Editable->False], "[", 
            RowBox[{"2", " ", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False]}], "]"}]}], 
          RowBox[{"4", " ", "r"}]]}], "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "+", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
          "\[ImaginaryI]", 
           " ", "\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(1 - 1\\)]\\)\"\>", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi][],
              Editable->False]}]], " ", 
           SqrtBox[
            FractionBox["3", 
             RowBox[{"2", " ", "\[Pi]"}]]]}], 
          RowBox[{"2", " ", "r"}]]}], 
        FractionBox[
         RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(1 - 1\\)]\\)\"\>", 
          " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", 
            RowBox[{"2", " ", "\[Pi]"}]]], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox["\[Theta]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Theta][],
             Editable->False]}], "]"}]}], 
         RowBox[{"4", " ", "r"}]]},
       {"0", "0", "0", "0"},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
          "\[ImaginaryI]", 
           " ", "\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(1 - 1\\)]\\)\"\>", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi][],
              Editable->False]}]], " ", 
           SqrtBox[
            FractionBox["3", 
             RowBox[{"2", " ", "\[Pi]"}]]]}], 
          RowBox[{"2", " ", "r"}]]}], "0", "0", "0"},
       {
        FractionBox[
         RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(J\\), \\(1 - 1\\)]\\)\"\>", 
          " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", 
            RowBox[{"2", " ", "\[Pi]"}]]], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox["\[Theta]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Theta][],
             Editable->False]}], "]"}]}], 
         RowBox[{"4", " ", "r"}]], "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}]}]], "Output",
 CellChangeTimes->{{3.784509478847555*^9, 3.7845094861561775`*^9}, {
  3.784509715622537*^9, 3.784509740025898*^9}, {3.7845098326867075`*^9, 
  3.784509854991943*^9}}]
}, Open  ]],

Cell["\<\
Obviously, this is an angular momentum perturbation, i.e., the full metric \
goes into the slow rotation limit of the Kerr solution.\
\>", "Text",
 CellChangeTimes->{{3.784509506497797*^9, 3.784509547386553*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["V. dipole-even parity", "Subsection",
 CellChangeTimes->{{3.7826986530890303`*^9, 3.782698668862176*^9}, {
  3.784843058105073*^9, 3.784843077977034*^9}}],

Cell[TextData[{
 "Finally, we discuss the even parity dipole moment (",
 StyleBox["l",
  FontSlant->"Italic"],
 " = 1) of gravitational perturbations of a nonrotating black hole.\n\nThe \
most general metric for the perturbations of even parity can be written as..."
}], "Text",
 CellChangeTimes->{{3.784510117203773*^9, 3.7845101240278444`*^9}, {
   3.784605288849032*^9, 3.7846053158108406`*^9}, 3.7846055487169924`*^9, {
   3.7846056116649933`*^9, 3.7846056592887087`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"GG", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<G\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evenfull", "=", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{
       RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
       RowBox[{"t", "[", "]"}]}]], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"H0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
         RowBox[{
          RowBox[{"H1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"H1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "YLM"}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"H2", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           RowBox[{"f", "[", 
            RowBox[{"r", "[", "]"}], "]"}]], "YLM"}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"r", "[", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"KK", "[", 
              RowBox[{"r", "[", "]"}], "]"}], "YLM"}], "+", 
            RowBox[{
             RowBox[{"GG", "[", 
              RowBox[{"r", "[", "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Theta]", "[", "]"}], ",", "2"}], "}"}]}], 
              "]"}]}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"r", "[", "]"}], "2"], " ", 
          RowBox[{"GG", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"YLM", ",", 
                RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
              RowBox[{"\[Theta]", "[", "]"}]}], "]"}], "-", 
            RowBox[{
             FractionBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "]"}], "]"}], 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"r", "[", "]"}], "2"], 
          RowBox[{"GG", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"YLM", ",", 
                RowBox[{"\[Phi]", "[", "]"}]}], "]"}], ",", 
              RowBox[{"\[Theta]", "[", "]"}]}], "]"}], "-", 
            RowBox[{
             FractionBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "]"}], "]"}], 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "]"}], "]"}]], 
             RowBox[{"D", "[", 
              RowBox[{"YLM", ",", 
               RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"r", "[", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"KK", "[", 
              RowBox[{"r", "[", "]"}], "]"}], 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"], " ", "YLM"}], "+", 
            RowBox[{
             RowBox[{"GG", "[", 
              RowBox[{"r", "[", "]"}], "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"YLM", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Phi]", "[", "]"}], ",", "2"}], "}"}]}], "]"}], 
               "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Theta]", "[", "]"}], "]"}], 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "]"}], "]"}], 
                RowBox[{"D", "[", 
                 RowBox[{"YLM", ",", 
                  RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], "}"}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"evenfull", "//", "Simplify"}], "//", "MatrixForm"}], 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.784605817549425*^9, 3.7846058524154887`*^9}, {
  3.7846059407626305`*^9, 3.784605942319535*^9}, {3.784605999921918*^9, 
  3.784606020550393*^9}, {3.7846067054124823`*^9, 3.7846067069539356`*^9}, {
  3.7846067760592976`*^9, 3.784606778600689*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False]}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi][],
                Editable->False]}]}], ")"}]}]], " ", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False], "-", 
                InterpretationBox[
                 StyleBox["m",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`m,
                 Editable->False]}], ")"}], "!"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "+", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]]], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["h", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}]},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "2"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H2,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False]}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi][],
                Editable->False]}]}], ")"}]}]], " ", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False], "-", 
                InterpretationBox[
                 StyleBox["m",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`m,
                 Editable->False]}], ")"}], "!"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "+", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]]], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["h", "1"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h1,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}]},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["h", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False]}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi][],
                Editable->False]}]}], ")"}]}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False], "-", 
                InterpretationBox[
                 StyleBox["m",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`m,
                 Editable->False]}], ")"}], "!"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "+", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]]], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               InterpretationBox[
                StyleBox["K",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`KK,
                Editable->False], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}]}], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["P", "lm"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`PL,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["\[Theta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Theta][],
               Editable->False], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`GG,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  InterpretationBox[
                   StyleBox["l",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`l,
                   Editable->False], "+", 
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox["l",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`l,
                    Editable->False], "2"], "-", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["m",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`m,
                    Editable->False], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    InterpretationBox[
                    StyleBox["Csc",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    Csc,
                    Editable->False], "[", 
                    InterpretationBox[
                    StyleBox["\[Theta]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Theta][],
                    Editable->False], "]"}], "2"]}]}], ")"}], " ", 
                RowBox[{
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["P", "lm"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`PL,
                  Editable->False], "[", 
                 InterpretationBox[
                  StyleBox["\[Theta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Theta][],
                  Editable->False], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 InterpretationBox[
                  StyleBox["Cot",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  Cot,
                  Editable->False], "[", 
                 InterpretationBox[
                  StyleBox["\[Theta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Theta][],
                  Editable->False], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["P", "lm"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`PL,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["\[Theta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Theta][],
                  Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`GG,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["Cot",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Cot,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["\[Theta]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Theta][],
             Editable->False], "]"}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False]}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi][],
                Editable->False]}]}], ")"}]}]], " ", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False], "-", 
                InterpretationBox[
                 StyleBox["m",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`m,
                 Editable->False]}], ")"}], "!"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "+", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]]], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["h", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False]}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi][],
                Editable->False]}]}], ")"}]}]], " ", 
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 StyleBox["l",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`l,
                 Editable->False], "-", 
                InterpretationBox[
                 StyleBox["m",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`m,
                 Editable->False]}], ")"}], "!"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "+", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]]], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["h", "1"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h1,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["\[Theta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Theta][],
            Editable->False], "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox["\[Pi]"]}]]}], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`GG,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["Cot",
               ShowAutoStyles->False,
               AutoSpacing->False],
              Cot,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["\[Theta]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Theta][],
             Editable->False], "]"}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["t",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`t[],
               Editable->False]}], "+", 
             RowBox[{
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False], " ", 
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi][],
               Editable->False]}]}], ")"}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["K",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`KK,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["P", "lm"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`PL,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["\[Theta]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Theta][],
              Editable->False], "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              InterpretationBox[
               StyleBox["Sin",
                ShowAutoStyles->False,
                AutoSpacing->False],
               Sin,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["\[Theta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Theta][],
               Editable->False], "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`GG,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["m",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`m,
                  Editable->False], "2"]}], " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["P", "lm"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`PL,
                 Editable->False], "[", 
                InterpretationBox[
                 StyleBox["\[Theta]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Theta][],
                 Editable->False], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                InterpretationBox[
                 StyleBox["Cos",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 Cos,
                 Editable->False], "[", 
                InterpretationBox[
                 StyleBox["\[Theta]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Theta][],
                 Editable->False], "]"}], " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["Sin",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 Sin,
                 Editable->False], "[", 
                InterpretationBox[
                 StyleBox["\[Theta]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Theta][],
                 Editable->False], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["P", "lm"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`PL,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", 
                InterpretationBox[
                 StyleBox["\[Theta]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Theta][],
                 Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.7846059458089128`*^9, {3.7846060131354537`*^9, 3.784606021727944*^9}, 
   3.7846067796490393`*^9, 3.784849455502348*^9, 3.7859941070782056`*^9, 
   3.785994610560849*^9, 3.8000666167482133`*^9, 3.8000774057509136`*^9}]
}, Open  ]],

Cell[TextData[{
 "For the dipole mode, the coefficients appearing in front of ",
 StyleBox["G",
  FontSlant->"Italic"],
 " automatically vanish. Gauge fixing can then be used to reduce the number \
of independent components (from six; instead of seven for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "\[GreaterEqual]", "2"}], TraditionalForm]]],
 ") down to ",
 StyleBox["three",
  FontVariations->{"Underline"->True}],
 ". The gauge-fixed even parity dipole perturbation can therefore be written \
as..."
}], "Text",
 CellChangeTimes->{{3.7846060327299757`*^9, 3.7846061930486226`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dipevenGF", "=", 
    RowBox[{"evenfull", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"GG", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"r", ",", "0"}], "]"}]}], ",", 
       RowBox[{"KK", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"r", ",", "0"}], "]"}]}], ",", 
       RowBox[{"h1", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"r", ",", "0"}], "]"}]}], ",", 
       RowBox[{"h0", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"r", ",", "0"}], "]"}]}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(h\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"dipevenGF", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784606199857444*^9, 3.7846062839991956`*^9}, {
  3.78460631627275*^9, 3.7846063308924146`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(h\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["h",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "0", "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "1"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H1,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["m",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`m,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi][],
             Editable->False]}]}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               InterpretationBox[
                StyleBox["l",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`l,
                Editable->False], "-", 
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False]}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox["l",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`l,
               Editable->False], "+", 
              InterpretationBox[
               StyleBox["m",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`m,
               Editable->False]}], ")"}], "!"}]]], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["H", "2"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`H2,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["P", "lm"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`PL,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["\[Theta]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Theta][],
           Editable->False], "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "]"}]}]], "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.784606331377982*^9, 3.784606785682635*^9, 
  3.784849484084917*^9, 3.7859941071271477`*^9, 3.7859946106830645`*^9, 
  3.8000666223093767`*^9, 3.800077405866604*^9}]
}, Open  ]],

Cell["We now input the full metric...", "Text",
 CellChangeTimes->{{3.784606354068454*^9, 3.784606376107785*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"metricdipeven", "=", 
    RowBox[{"background", "+", 
     RowBox[{"\[Epsilon]", " ", "dipevenGF"}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "tell", " ", "xCoba", " ", "to", " ", "compute", " ", "curvature", " ", 
    "components"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricInBasis", "[", 
   RowBox[{"g", ",", 
    RowBox[{"-", "Schw"}], ",", "metricdipeven"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricCompute", "[", 
   RowBox[{"g", ",", "Schw", ",", "All", ",", 
    RowBox[{"CVSimplify", "\[Rule]", "linearize"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.784606379532512*^9, 3.784606410265475*^9}}],

Cell["\<\
We now solve the Einstein equation for the even parity dipole perturbation.\
\>", "Text",
 CellChangeTimes->{{3.7846064259996443`*^9, 3.784606452608353*^9}}],

Cell["Gauge fixing (left as exercise)", "Subsubsection",
 CellChangeTimes->{{3.7846064670483394`*^9, 3.7846064859291787`*^9}}],

Cell[CellGroupData[{

Cell["Einstein equation", "Subsubsection",
 CellChangeTimes->{{3.7845028230627794`*^9, 3.784502825079537*^9}}],

Cell["\<\
We now setup the Einstein equation (plus cosmological constant)...\
\>", "Text",
 CellChangeTimes->{3.7845028328435593`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"RicciCD", "[", 
       RowBox[{
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"g", "[", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], 
       RowBox[{"RicciScalarCD", "[", "]"}]}]}], ")"}], "+", 
    RowBox[{"\[CapitalLambda]", " ", 
     RowBox[{"g", "[", 
      RowBox[{
       RowBox[{"-", "c"}], ",", 
       RowBox[{"-", "b"}]}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EE", "\[Equal]", 
  "\"\<8 \[Pi] \!\(\*SubscriptBox[\(T\), \(cb\)]\)\>\""}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`c, -$CellContext`b],
     Editable->False]}], "+", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}], 
        StyleBox[GridBox[{
           {" ", " "},
           {"c", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`c, -$CellContext`b],
    Editable->False], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`c, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[\\(T\\), \
\\(cb\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{3.784502855675605*^9, 3.784508478706808*^9, 
  3.7846064981764507`*^9, 3.7846068786419888`*^9, 3.7848495485287867`*^9, 
  3.785994156242274*^9, 3.78599469245099*^9, 3.8000667034010024`*^9, 
  3.8000774432406545`*^9}]
}, Open  ]],

Cell["The linearized expression is...", "Text",
 CellChangeTimes->{{3.7845028669814625`*^9, 3.7845028722112255`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EERW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"EE", "//", 
          RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", "ComponentArray"}], "//",
         "ToValues"}], "//", "ToValues"}], ")"}], "/.", "removebrackets"}], "//",
     "linearize"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7845029914577723`*^9, 3.7845029999085712`*^9}, {
  3.7845033564588575`*^9, 3.7845033790721035`*^9}, {3.7845040410569625`*^9, 
  3.784504042981924*^9}, {3.7846065258954997`*^9, 3.784606527021598*^9}}],

Cell[TextData[{
 "In this part, we manually code the ",
 StyleBox["hairy",
  FontSlant->"Italic"],
 " correction to the ",
 StyleBox["rr",
  FontSlant->"Italic"],
 "-component:"
}], "Text",
 CellChangeTimes->{{3.784849591461512*^9, 3.784849602271484*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Lambda]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DefScalarFunction", "[", 
    RowBox[{"qt", ",", 
     RowBox[{
     "PrintAs", "\[Rule]", "\"\<\!\(\*OverscriptBox[\(q\), \(~\)]\)\>\""}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "hair"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]", "=", 
   RowBox[{"-", 
    FractionBox["\[Lambda]", 
     RowBox[{"2", "\[Kappa]"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hair", "=", 
   RowBox[{"\[Epsilon]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"qt", "[", "\[Omega]", "]"}], 
         RowBox[{"\[Kappa]", " ", 
          SuperscriptBox["r", "2"], 
          SuperscriptBox[
           RowBox[{"f", "[", "r", "]"}], 
           RowBox[{"3", "/", "2"}]]}]]}], 
       RowBox[{"(", 
        RowBox[{"YLM", "/.", "removebrackets"}], ")"}], " ", 
       SuperscriptBox["E", 
        RowBox[{
         RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}]]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PL", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"LegendreP", "[", 
            RowBox[{"1", ",", "0", ",", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.784849618619543*^9, 3.7848496368136063`*^9}, {
  3.784849785545291*^9, 3.784849791627846*^9}, {3.785994250419716*^9, 
  3.7859942530984335`*^9}}],

Cell[TextData[{
 "To focus on the analysis, we restrict our attention to the 10 mode. This \
can be done without loss of generality because of spherical symmetry as the \
11 and 1-1 modes can be achieved by rotating the axes.\n\nThe ",
 StyleBox["nontrivial",
  FontSlant->"Italic"],
 " components of unmodified gravitational sector of EE are..."
}], "Text",
 CellChangeTimes->{{3.78450302006487*^9, 3.78450303320126*^9}, {
  3.7845031257885942`*^9, 3.784503130426676*^9}, {3.784607425267172*^9, 
  3.7846075353145313`*^9}, {3.784849660204072*^9, 3.7848496619704833`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EERWdipeven", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"EERW", "/.", "SdS"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PL", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"\[Theta]", ",", 
          RowBox[{"LegendreP", "[", 
           RowBox[{"1", ",", "0", ",", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"l", "\[Rule]", "1"}], ",", 
       RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(G\), \(ab\)]\)+\!\(\*SubscriptBox[\(\
\[CapitalLambda]g\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"EERWdipeven", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784503142598851*^9, 3.7845032013873324`*^9}, {
  3.7845034618897624`*^9, 3.7845035042159767`*^9}, {3.7846065684250736`*^9, 
  3.78460657659654*^9}, {3.7846075473817897`*^9, 3.784607558327054*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(G\\), \
\\(ab\\)]\\)+\\!\\(\\*SubscriptBox[\\(\[CapitalLambda]g\\), \\(ab\\)]\\)\"\>",
   "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "+", 
           RowBox[{"6", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False]}]}], ")"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               InterpretationBox[
                StyleBox["\[Lambda]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Lambda],
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "12"}], " ", 
               InterpretationBox[
                StyleBox["M",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{"6", " ", "r", " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               InterpretationBox[
                StyleBox["\[Lambda]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Lambda],
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"24", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], "2"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H1,
             Editable->False], "[", "r", "]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "2"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                InterpretationBox[
                 StyleBox["M",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M,
                 Editable->False], " ", 
                InterpretationBox[
                 StyleBox["\[Kappa]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Kappa],
                 Editable->False]}], "+", 
               RowBox[{
                SuperscriptBox["r", "3"], " ", 
                InterpretationBox[
                 StyleBox["\[Lambda]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Lambda],
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", "\[ImaginaryI]", " ", "r", " ", 
                InterpretationBox[
                 StyleBox["\[Kappa]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Kappa],
                 Editable->False], " ", 
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], " ", 
                RowBox[{
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["H", "2"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`H2,
                  Editable->False], "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "12"}], " ", 
                   InterpretationBox[
                    StyleBox["M",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M,
                    Editable->False], " ", 
                   InterpretationBox[
                    StyleBox["\[Kappa]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Kappa],
                    Editable->False]}], "+", 
                  RowBox[{"6", " ", "r", " ", 
                   InterpretationBox[
                    StyleBox["\[Kappa]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Kappa],
                    Editable->False]}], "+", 
                  RowBox[{
                   SuperscriptBox["r", "3"], " ", 
                   InterpretationBox[
                    StyleBox["\[Lambda]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Lambda],
                    Editable->False]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["H", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`H1,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
           ")"}]}], 
         RowBox[{"8", " ", 
          SqrtBox[
           RowBox[{"3", " ", "\[Pi]"}]], " ", 
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}]]}], "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H1,
             Editable->False], "[", "r", "]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "2"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Cos",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Cos,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "6"}], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "-", 
            RowBox[{"12", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False]}]}], ")"}]}]]}], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                InterpretationBox[
                 StyleBox["M",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M,
                 Editable->False]}], "-", "r"}], ")"}], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", "\[ImaginaryI]", " ", 
             SuperscriptBox["r", "2"], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "[", "r", "]"}]}], "-", 
            RowBox[{"6", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "-", 
            RowBox[{"12", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["r", "2"], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "4"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"4", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False]}]}], ")"}]}]]}], "0"},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                InterpretationBox[
                 StyleBox["M",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M,
                 Editable->False], " ", 
                InterpretationBox[
                 StyleBox["\[Kappa]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Kappa],
                 Editable->False]}], "+", 
               RowBox[{
                SuperscriptBox["r", "3"], " ", 
                InterpretationBox[
                 StyleBox["\[Lambda]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Lambda],
                 Editable->False]}]}], ")"}], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", "\[ImaginaryI]", " ", "r", " ", 
                InterpretationBox[
                 StyleBox["\[Kappa]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Kappa],
                 Editable->False], " ", 
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], " ", 
                RowBox[{
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["H", "2"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`H2,
                  Editable->False], "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "12"}], " ", 
                   InterpretationBox[
                    StyleBox["M",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M,
                    Editable->False], " ", 
                   InterpretationBox[
                    StyleBox["\[Kappa]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Kappa],
                    Editable->False]}], "+", 
                  RowBox[{"6", " ", "r", " ", 
                   InterpretationBox[
                    StyleBox["\[Kappa]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Kappa],
                    Editable->False]}], "+", 
                  RowBox[{
                   SuperscriptBox["r", "3"], " ", 
                   InterpretationBox[
                    StyleBox["\[Lambda]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Lambda],
                    Editable->False]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["H", "1"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`H1,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
           ")"}]}], 
         RowBox[{"8", " ", 
          SqrtBox[
           RowBox[{"3", " ", "\[Pi]"}]], " ", 
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}]]}], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                InterpretationBox[
                 StyleBox["M",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M,
                 Editable->False]}], "-", "r"}], ")"}], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", "\[ImaginaryI]", " ", 
             SuperscriptBox["r", "2"], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "[", "r", "]"}]}], "-", 
            RowBox[{"6", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", "r", "]"}]}], "-", 
            RowBox[{"12", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["r", "2"], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "4"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"4", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{"6", " ", "r", " ", 
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False]}]}], ")"}]}]]}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               InterpretationBox[
                StyleBox["M",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "-", 
              RowBox[{"6", " ", "r", " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "-", 
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               InterpretationBox[
                StyleBox["\[Lambda]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Lambda],
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"24", " ", "\[ImaginaryI]", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               InterpretationBox[
                StyleBox["M",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{"3", " ", "r", " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               InterpretationBox[
                StyleBox["\[Lambda]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Lambda],
                Editable->False]}]}], ")"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H1,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"72", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"72", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "2"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"42", " ", 
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"72", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"36", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"42", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"30", " ", 
            SuperscriptBox["r", "4"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"144", " ", "\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"72", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"12", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["r", "5"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"72", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"108", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"30", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"18", " ", 
            SuperscriptBox["r", "4"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"144", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], "2"], " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"144", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"24", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "4"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"12", " ", 
            SuperscriptBox["r", "5"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "-", 
           RowBox[{"6", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "-", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False]}]}], ")"}]}]], "0"},
      {"0", "0", "0", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               InterpretationBox[
                StyleBox["M",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "-", 
              RowBox[{"6", " ", "r", " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "-", 
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               InterpretationBox[
                StyleBox["\[Lambda]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Lambda],
                Editable->False]}]}], ")"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"24", " ", "\[ImaginaryI]", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               InterpretationBox[
                StyleBox["M",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M,
                Editable->False], " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{"3", " ", "r", " ", 
               InterpretationBox[
                StyleBox["\[Kappa]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Kappa],
                Editable->False]}], "+", 
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               InterpretationBox[
                StyleBox["\[Lambda]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Lambda],
                Editable->False]}]}], ")"}], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H1,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"72", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"72", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "2"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"42", " ", 
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "2"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H2,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"72", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"36", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"42", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"30", " ", 
            SuperscriptBox["r", "4"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"144", " ", "\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"72", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"12", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["r", "5"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"72", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"108", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"30", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"18", " ", 
            SuperscriptBox["r", "4"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"144", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], "2"], " ", "r", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"144", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"36", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Kappa]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Kappa],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "-", 
           RowBox[{"24", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            SuperscriptBox["r", "4"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"12", " ", 
            SuperscriptBox["r", "5"], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"3", " ", "\[Pi]"}]], " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            InterpretationBox[
             StyleBox["M",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "-", 
           RowBox[{"6", " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False]}], "-", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda],
             Editable->False]}]}], ")"}]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.784503195540861*^9, 3.784503201824402*^9}, 
   3.7845033886190557`*^9, {3.784503483063853*^9, 3.784503504804123*^9}, {
   3.7845040482665215`*^9, 3.7845040707330275`*^9}, 3.7845084938554525`*^9, 
   3.7846065780147595`*^9, 3.784606889824664*^9, 3.7846075637516212`*^9, 
   3.7848496666859446`*^9, 3.784849795085719*^9, 3.7859941592538157`*^9, 
   3.78599469617422*^9, 3.8000667051349707`*^9, 3.800077444970029*^9}]
}, Open  ]],

Cell["We solve the system using the following equations...", "Text",
 CellChangeTimes->{{3.784503425701148*^9, 3.784503444852091*^9}, {
  3.784607652263149*^9, 3.784607675423049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SETdipeven", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SETeven", "/.", "removebrackets"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"TG", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"r", ",", "0"}], "]"}]}], ",", 
        RowBox[{"PL", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"LegendreP", "[", 
            RowBox[{"1", ",", "0", ",", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}], "//", "Simplify"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tt", "=", 
   RowBox[{
    RowBox[{"EERWdipeven", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"8", "\[Pi]", " ", 
        RowBox[{"SETdipeven", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rr", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"EERWdipeven", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", "hair"}], ")"}], 
    "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"8", "\[Pi]", " ", 
        RowBox[{"SETdipeven", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
      "Simplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tr", "=", 
    RowBox[{
     RowBox[{"EERWdipeven", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"8", "\[Pi]", " ", 
         RowBox[{"SETdipeven", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/.", "SdS"}], "//", 
       "Simplify"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"tt", "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"rr", "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"tr", "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.784503534931696*^9, 3.7845035499664154`*^9}, {
  3.7845035949691615`*^9, 3.7845036929228616`*^9}, {3.784504119363343*^9, 
  3.7845041257765727`*^9}, {3.7846076787655573`*^9, 3.784607781289464*^9}, {
  3.7846078287444677`*^9, 3.784607923538503*^9}, {3.784608000080443*^9, 
  3.7846080014307594`*^9}, {3.7848497040356693`*^9, 3.784849706918624*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"6", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Cos",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Cos,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}], "-", 
      RowBox[{"48", " ", "\[Pi]", " ", 
       SuperscriptBox["r", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["T", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`T0,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H2,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.7845036938164434`*^9, 3.784504075300725*^9, 
  3.7845041267434387`*^9, 3.784508500030681*^9, 3.784607924811268*^9, 
  3.784608006002442*^9, 3.784849713738003*^9, 3.7848497976761413`*^9, 
  3.7859941600518384`*^9, 3.78599469697659*^9, 3.800066705509882*^9, 
  3.8000774454218445`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Cos",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Cos,
       Editable->False], "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}]}], "+", 
       RowBox[{"r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "6"}], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H1,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"48", " ", "\[Pi]", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["T", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`T2,
             Editable->False], "[", "r", "]"}]}], "-", 
          RowBox[{"12", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7845036938164434`*^9, 3.784504075300725*^9, 
  3.7845041267434387`*^9, 3.784508500030681*^9, 3.784607924811268*^9, 
  3.784608006002442*^9, 3.784849713738003*^9, 3.7848497976761413`*^9, 
  3.7859941600518384`*^9, 3.78599469697659*^9, 3.800066705509882*^9, 
  3.8000774458916254`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Cos",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Cos,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "1"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H1,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["H", "2"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`H2,
            Editable->False], "[", "r", "]"}]}], "+", 
         RowBox[{"8", " ", "\[Pi]", " ", "r", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["T", "1"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`T1,
            Editable->False], "[", "r", "]"}]}]}], ")"}]}]}], ")"}]}], "r"], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7845036938164434`*^9, 3.784504075300725*^9, 
  3.7845041267434387`*^9, 3.784508500030681*^9, 3.784607924811268*^9, 
  3.784608006002442*^9, 3.784849713738003*^9, 3.7848497976761413`*^9, 
  3.7859941600518384`*^9, 3.78599469697659*^9, 3.800066705509882*^9, 
  3.8000774459583855`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Vacuum solution", "Subsubsection",
 CellChangeTimes->{{3.784609322552618*^9, 3.784609325901823*^9}}],

Cell[TextData[{
 "Finally, we solve the ",
 StyleBox["tt",
  FontSlant->"Italic"],
 ", ",
 StyleBox["tr",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["rr",
  FontSlant->"Italic"],
 " perturbation equations in vacuum:"
}], "Text",
 CellChangeTimes->{{3.78460933393468*^9, 3.7846093380799685`*^9}, {
  3.78460937603265*^9, 3.78460940859435*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"vac", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"T0", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}], ",", 
      RowBox[{"T1", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}], ",", 
      RowBox[{"T2", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"r", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ttvac", "=", 
   RowBox[{
    RowBox[{"tt", "/.", "vac"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trvac", "=", 
   RowBox[{
    RowBox[{"tr", "/.", "vac"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rrvac", "=", 
    RowBox[{
     RowBox[{"rr", "/.", "vac"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ttvac", "\
\[IndentingNewLine]", "trvac", "\[IndentingNewLine]", "rrvac"}], "Input",
 CellChangeTimes->{{3.7846094107691813`*^9, 3.784609491035925*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"6", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Cos",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Cos,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{"6", " ", "r", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "2"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H2,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.7846094918841124`*^9, 3.78484984442315*^9, 
  3.7859941616390553`*^9, 3.78599469875838*^9, 3.800066712894421*^9, 
  3.8000774463164268`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False]}]], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Cos",
       ShowAutoStyles->False,
       AutoSpacing->False],
      Cos,
      Editable->False], "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["H", "1"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`H1,
        Editable->False], "[", "r", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "r", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["H", "2"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`H2,
         Editable->False], "[", "r", "]"}]}]}], ")"}]}], "r"], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7846094918841124`*^9, 3.78484984442315*^9, 
  3.7859941616390553`*^9, 3.78599469875838*^9, 3.800066712894421*^9, 
  3.8000774463234096`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox["\[Epsilon]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Epsilon],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Cos",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Cos,
       Editable->False], "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox["q", "~"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`qt,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "]"}]}], "+", 
       RowBox[{"r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "6"}], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H1,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["H", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`H2,
             Editable->False], "[", "r", "]"}]}], "-", 
          RowBox[{"12", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"6", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda],
            Editable->False], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"r", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{"6", " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda],
         Editable->False]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7846094918841124`*^9, 3.78484984442315*^9, 
  3.7859941616390553`*^9, 3.78599469875838*^9, 3.800066712894421*^9, 
  3.8000774463344035`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["tt",
  FontSlant->"Italic"],
 " equation can already be solved for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "2"], TraditionalForm]]],
 " while the ",
 StyleBox["tr",
  FontSlant->"Italic"],
 " equation shows that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["H", "1"], "=", 
    RowBox[{"i", " ", "r", " ", "\[Omega]", " ", 
     SubscriptBox["H", "2"]}]}], TraditionalForm]]],
 ". The ",
 StyleBox["rr",
  FontSlant->"Italic"],
 " equation can be solved for the last piece ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " of the perturbation.\n\nThe ODEs involved are all only of first-order. \
Thus, the expressions can be solved analytically. For simplicity, we focus on \
the Schwarzschild case, \[CapitalLambda] = 0..."
}], "Text",
 CellChangeTimes->{{3.7846095144003*^9, 3.784609665703734*^9}, {
  3.7846097422793465`*^9, 3.784609767763809*^9}, {3.7846114803515053`*^9, 
  3.784611480429159*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"H2solSc", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ttvac", "/.", "SdS"}], "/.", 
       RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], ",", "H2", ",", "r"}], "]"}], 
    "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H1solSc", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"trvac", "/.", "SdS"}], "/.", 
        RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "/.", "H2solSc"}], ",", "H1",
       ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H0solSc", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"rrvac", "/.", "SdS"}], "/.", 
          RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "/.", "H2solSc"}], "/.", 
        "H1solSc"}], ",", "H0", ",", "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)\>\"", "\[Equal]", 
   RowBox[{"H0", "[", "r", "]"}]}], "/.", "H0solSc"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(1\)]\)\>\"", "\[Equal]", 
   RowBox[{"H1", "[", "r", "]"}]}], "/.", "H1solSc"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\"", "\[Equal]", 
   RowBox[{"H2", "[", "r", "]"}]}], "/.", "H2solSc"}]}], "Input",
 CellChangeTimes->{{3.784609771962494*^9, 3.7846099531954618`*^9}, {
  3.7848498812324944`*^9, 3.784849919275115*^9}, {3.785994563704874*^9, 
  3.7859945647732544`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,82,1,16658407811262272033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.78460979877909*^9, 3.784609806015126*^9}, 
   3.7846098524715223`*^9, {3.784609895032732*^9, 3.784609902655369*^9}, 
   3.78460995699784*^9, 3.78484991998973*^9, 3.785994161825945*^9, 
   3.7859946989601746`*^9, 3.800066799836958*^9, 3.8000774465737395`*^9}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,84,2,16658407811262272033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.78460979877909*^9, 3.784609806015126*^9}, 
   3.7846098524715223`*^9, {3.784609895032732*^9, 3.784609902655369*^9}, 
   3.78460995699784*^9, 3.78484991998973*^9, 3.785994161825945*^9, 
   3.7859946989601746`*^9, 3.800066799836958*^9, 3.800077446833143*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(0\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False]}], "+", "r"}], ")"}], " ", 
    RowBox[{"C", "[", "2", "]"}]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["M",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`M,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], "2"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], "2"]}], "+", 
        RowBox[{"12", " ", 
         InterpretationBox[
          StyleBox["M",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M,
          Editable->False], " ", "r", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], "2"]}]}], ")"}], " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False]}], "r"]}]], " ", 
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         InterpretationBox[
          StyleBox["M",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M,
          Editable->False]}], "+", "r"}], ")"}], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox["q", "~"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`qt,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], "]"}]}]}], 
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox["M",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`M,
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         InterpretationBox[
          StyleBox["M",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`M,
          Editable->False]}], "+", "r"}], ")"}], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]]}]}]], "Output",
 CellChangeTimes->{{3.7846097987813625`*^9, 3.7846098060352645`*^9}, 
   3.784609852480627*^9, {3.784609895076505*^9, 3.7846099027280855`*^9}, 
   3.7846099570632057`*^9, 3.7848499202992706`*^9, 3.7859941622577944`*^9, 
   3.7859946993974075`*^9, 3.8000668000868845`*^9, 3.800077446856017*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(1\\)]\\)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "r", " ", 
    InterpretationBox[
     StyleBox["\[Omega]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Omega],
     Editable->False], " ", 
    RowBox[{"C", "[", "1", "]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False]}], "-", "r"}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.7846097987813625`*^9, 3.7846098060352645`*^9}, 
   3.784609852480627*^9, {3.784609895076505*^9, 3.7846099027280855`*^9}, 
   3.7846099570632057`*^9, 3.7848499202992706`*^9, 3.7859941622577944`*^9, 
   3.7859946993974075`*^9, 3.8000668000868845`*^9, 3.800077446862998*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(2\\)]\\)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{"C", "[", "1", "]"}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       InterpretationBox[
        StyleBox["M",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M,
        Editable->False]}], "+", "r"}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.7846097987813625`*^9, 3.7846098060352645`*^9}, 
   3.784609852480627*^9, {3.784609895076505*^9, 3.7846099027280855`*^9}, 
   3.7846099570632057`*^9, 3.7848499202992706`*^9, 3.7859941622577944`*^9, 
   3.7859946993974075`*^9, 3.8000668000868845`*^9, 3.800077446867013*^9}]
}, Open  ]],

Cell[TextData[{
 "These ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["q", "~"], "=", "0"}], TraditionalForm]]],
 " limit (no \[OpenCurlyDoubleQuote]hair\[CloseCurlyDoubleQuote]) are the \
same solutions ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "i"], TraditionalForm]]],
 " presented in Section C of Appendix G (page 2153) of the paper by Zerilli \
[Zerilli, F. J. (1970). ",
 StyleBox["Gravitational field of a particle falling in a Schwarzschild \
geometry analyzed in tensor harmonics",
  FontSlant->"Italic"],
 ". PRD, 2(10), 2141.]. In the same paper, it is shown that these solutions \
are equivalent to a gauge transformation.\n\nThe vacuum Einstein equation can \
indeed be satisfied by the solution. Substituting the results..."
}], "Text",
 CellChangeTimes->{{3.7846104885228295`*^9, 3.7846105468056192`*^9}, {
   3.7846107338153715`*^9, 3.7846109016561728`*^9}, {3.784611404660884*^9, 
   3.7846114342286634`*^9}, {3.78484993755053*^9, 3.7848499660072966`*^9}, 
   3.784850008362321*^9, 3.7848500608423147`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<\!\(\*SubscriptBox[\(G\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"EERWdipeven", "/.", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"EERWdipeven", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Rule]", 
              RowBox[{
               RowBox[{"EERWdipeven", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", "hair"}]}], 
             ")"}]}], "/.", "SdS"}], "/.", 
          RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "/.", "H0solSc"}], "/.", 
        "H1solSc"}], "/.", "H2solSc"}], "//", "Simplify"}], ")"}], "//", 
    "MatrixForm"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.784610934191499*^9, 3.7846110070820875`*^9}, {
  3.7846112725776987`*^9, 3.784611273744994*^9}, {3.78484998383169*^9, 
  3.7848500020952997`*^9}, {3.784850115697873*^9, 3.784850141039315*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(G\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", "0", "0"},
      {"0", "0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], "2"], " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            RowBox[{"3", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             RowBox[{"C", "[", "2", "]"}]}]}], ")"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}]}], 
         RowBox[{"4", " ", "r"}]]}], "0"},
      {"0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], "2"], " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            RowBox[{"3", " ", 
             InterpretationBox[
              StyleBox["M",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M,
              Editable->False], " ", 
             RowBox[{"C", "[", "2", "]"}]}]}], ")"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}]}], 
         RowBox[{"4", " ", "r"}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], "2"], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"3", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           RowBox[{"C", "[", "2", "]"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}]}], "0"},
      {"0", "0", "0", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], "2"], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"3", " ", 
           InterpretationBox[
            StyleBox["M",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`M,
            Editable->False], " ", 
           RowBox[{"C", "[", "2", "]"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], "2"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.7846110084452453`*^9, 3.784850100917719*^9, 
  3.7848501416539803`*^9, 3.7859941628692384`*^9, 3.78599470000927*^9, 
  3.800066923238085*^9, 3.800077447166156*^9}]
}, Open  ]],

Cell["\<\
To satisfy all components the integration constants must be fixed as follows:\
\>", "Text",
 CellChangeTimes->{{3.7846111000566483`*^9, 3.784611132256801*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Csol", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], "2"], " ", 
          RowBox[{"C", "[", "1", "]"}]}], "+", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox["M",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M,
           Editable->False], " ", 
          RowBox[{"C", "[", "2", "]"}]}]}], "\[Equal]", "0"}], ",", 
       RowBox[{"C", "[", "2", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(C\), \(2\)]\)\>\"", "\[Equal]", 
    RowBox[{"C", "[", "2", "]"}]}], "/.", "Csol"}], "/.", 
  RowBox[{
   RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
   "\"\<\!\(\*SubscriptBox[\(C\), \(1\)]\)\>\""}]}]}], "Input",
 CellChangeTimes->{{3.7846111432774525`*^9, 3.784611208481453*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(C\\), \\(2\\)]\\)\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(C\\), \\(1\\)]\\)\"\>", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Omega]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Omega],
       Editable->False], "2"]}], 
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox["M",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`M,
      Editable->False]}]]}]}]], "Output",
 CellChangeTimes->{{3.7846111601148996`*^9, 3.784611166081026*^9}, {
   3.784611199688478*^9, 3.784611212031375*^9}, 3.7848501572581897`*^9, 
   3.78599416292279*^9, 3.785994700040109*^9, 3.800066933918895*^9, 
   3.8000774472167187`*^9}]
}, Open  ]],

Cell["Finally, all components vanish...", "Text",
 CellChangeTimes->{{3.784611214493651*^9, 3.7846112458852005`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<\!\(\*SubscriptBox[\(G\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"EERWdipeven", "/.", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"EERWdipeven", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"EERWdipeven", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", "hair"}]}], 
              ")"}]}], "/.", "SdS"}], "/.", 
           RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "/.", "H0solSc"}], "/.", 
         "H1solSc"}], "/.", "H2solSc"}], "/.", "Csol"}], "//", "Simplify"}], 
     ")"}], "//", "MatrixForm"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.7846112333245597`*^9, 3.7846112345829744`*^9}, {
  3.7846112657235193`*^9, 3.7846112672217016`*^9}, {3.7848501661029353`*^9, 
  3.7848501855151873`*^9}, {3.7848502158545666`*^9, 3.784850216105293*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(G\\), \\(ab\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.784611235203594*^9, 3.784611307969927*^9, {3.7848501637115917`*^9, 
   3.7848501865210304`*^9}, 3.784850217861723*^9, 3.7859941631552734`*^9, 
   3.7859947003289604`*^9, 3.800066953695498*^9, 3.800077447594011*^9}]
}, Open  ]],

Cell[TextData[{
 "...and so the vacuum equation is solved.\n\nWe end this section by \
interpreting the ",
 StyleBox["dipole hair",
  FontSlant->"Italic"],
 ". This is only attached to the ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["q", "~"], TraditionalForm]]],
 " and so we pull this as..."
}], "Text",
 CellChangeTimes->{{3.784611248708123*^9, 3.784611256268491*^9}, {
  3.7846113807721224`*^9, 3.7846113959111304`*^9}, {3.784850224237996*^9, 
  3.7848502429919033`*^9}, {3.784850332993072*^9, 3.7848503470681467`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"H0dip", "=", 
    RowBox[{
     RowBox[{"H0", "[", "r", "]"}], "/.", "H0solSc"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]H\), \(0\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"qt", "[", "\[Omega]", "]"}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"H0dip", ",", 
        RowBox[{"qt", "[", "\[Omega]", "]"}]}], "]"}]}], ")"}], "//", 
    "FullSimplify"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7848503612442017`*^9, 3.784850421740172*^9}, {
  3.7848504737461824`*^9, 3.784850518610797*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]H\\), \\(0\\)]\\)\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{"r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox["q", "~"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`qt,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], "]"}]}], 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["M",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`M,
     Editable->False], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False]}], "r"]}]], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]}]]}]], "Output",
 CellChangeTimes->{{3.784850365261894*^9, 3.7848503857006435`*^9}, {
   3.7848504853455415`*^9, 3.784850519196042*^9}, 3.785994163344797*^9, 
   3.7859947005135736`*^9, 3.800066967567227*^9, 3.800077447992977*^9}]
}, Open  ]],

Cell[TextData[{
 "this ",
 StyleBox["does not",
  FontSlant->"Italic"],
 " correspond to a ",
 StyleBox["gauge transformation",
  FontSlant->"Italic"],
 ", i.e., there is no gauge vector that yields exactly this perturbation to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["g", "tt"], TraditionalForm]]],
 ".\n\n",
 StyleBox["Proof",
  FontVariations->{"Underline"->True}],
 ": We show that only very specific classes of ",
 StyleBox["tt",
  FontSlant->"Italic"],
 "-only-perturbation can be gauged away or be a gauge transformation. We \
proceed as follows. Define the even parity gauge vector \[Xi]..."
}], "Text",
 CellChangeTimes->{{3.7848505590490103`*^9, 3.7848505777771344`*^9}, {
  3.784850638819192*^9, 3.784850639984064*^9}, {3.7848581990650325`*^9, 
  3.784858215554585*^9}, {3.7848582830282774`*^9, 3.7848583118640795`*^9}, {
  3.784858412652355*^9, 3.784858425977912*^9}, {3.784861194364352*^9, 
  3.78486122036843*^9}, {3.78486157257419*^9, 3.784861590406747*^9}, {
  3.800067200395873*^9, 3.800067305583867*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"even", " ", "parity", " ", "gauge", " ", "vector"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Xi]", "[", 
       RowBox[{"-", "a"}], "]"}], ",", "Md", ",", 
      RowBox[{"PrintAs", "\[Rule]", "\"\<\[Xi]\>\""}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"M0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(M\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"M1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(M\), \(1\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"M2", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(M\), \(2\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YLMdip", "=", 
     RowBox[{"YLM", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PL", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"LegendreP", "[", 
            RowBox[{"1", ",", "0", ",", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"components", " ", "of", " ", 
     RowBox[{"\[Xi]", "[", 
      SubscriptBox["M", "i"], "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"ComponentArray", "[", 
       RowBox[{"\[Xi]", "[", 
        RowBox[{"{", 
         RowBox[{"a", ",", "Schw"}], "}"}], "]"}], "]"}], ",", 
      RowBox[{"\[Epsilon]", " ", 
       SuperscriptBox["E", 
        RowBox[{
         RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
         RowBox[{"t", "[", "]"}]}]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"M0", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "YLMdip"}], ",", 
         RowBox[{
          RowBox[{"M1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], "YLMdip"}], ",", 
         RowBox[{
          RowBox[{"M2", "[", 
           RowBox[{"r", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLMdip", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}]}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"M2", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]], 
          RowBox[{"D", "[", 
           RowBox[{"YLMdip", ",", 
            RowBox[{"\[Phi]", "[", "]"}]}], "]"}]}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChangeComponents", "[", 
     RowBox[{
      RowBox[{"\[Xi]", "[", 
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"a", ",", "Schw"}], "}"}]}], "]"}], ",", 
      RowBox[{"\[Xi]", "[", 
       RowBox[{"{", 
        RowBox[{"a", ",", "Schw"}], "}"}], "]"}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.78485848605373*^9, 3.7848586501572886`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {" "},
            {
             StyleBox["a",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Xi][{-$CellContext`a, -$CellContext`Schw}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{-$CellContext`b, -$CellContext`Schw}, {-$CellContext`a, \
-$CellContext`Schw}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[Xi]", 
          StyleBox[GridBox[{
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Xi][{$CellContext`b, $CellContext`Schw}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.0309688`5.942469370842583", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`\[Xi][{-$CellContext`a, -$CellContext`Schw}] -> \
$CellContext`g[{-$CellContext`b, -$CellContext`Schw}, {-$CellContext`a, \
-$CellContext`Schw}] $CellContext`\[Xi][{$CellContext`b, $CellContext`Schw}], 
   " in ", 0.0309688`5.942469370842583, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.784858669422937*^9, 3.7859941635890675`*^9, 
  3.7859947007685537`*^9, 3.8000673100121555`*^9, 3.8000774481216373`*^9}]
}, Open  ]],

Cell[TextData[{
 "After a gauge transformation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "a"], "\[Rule]", 
    RowBox[{
     SuperscriptBox["x", "a"], "+", 
     SuperscriptBox["\[Xi]", "a"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " the perturbation becomes..."
}], "Text",
 CellChangeTimes->{{3.784858693738439*^9, 3.784858727873743*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]h", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "a"}], "]"}], "[", 
      RowBox[{"\[Xi]", "[", 
       RowBox[{"-", "b"}], "]"}], "]"}], "+", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "b"}], "]"}], "[", 
      RowBox[{"\[Xi]", "[", 
       RowBox[{"-", "a"}], "]"}], "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(bc\)]\)\>\"", "==", "\[Delta]h"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "components", " ", "of", " ", "the", " ", "gauge", " ", "transformation"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]hcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"\[Delta]h", "//", 
               RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", 
              RowBox[{"ToBasis", "[", "Schw", "]"}]}], "//", 
             "TraceBasisDummy"}], "//", "TraceBasisDummy"}], "//", 
           "ComponentArray"}], "//", "ToValues"}], "//", "ToValues"}], "//", 
        "linearize"}], ")"}], "/.", "removebrackets"}], "/.", 
     RowBox[{"h", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"r", ",", 
        RowBox[{"f", "[", "r", "]"}]}], "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(bc\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"\[Delta]hcomp", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7848587332139564`*^9, 3.7848587538042154`*^9}, {
  3.7848588452138515`*^9, 3.784858873246648*^9}, {3.7848592735666256`*^9, 
  3.7848593263571014`*^9}, {3.7848593635169125`*^9, 3.784859364029133*^9}, {
  3.784859410922357*^9, 3.784859413577186*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(bc\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[EmptyDownTriangle]", "a"], GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {" "},
            {"b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][-$CellContext`b]],
    Editable->False], "+", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[EmptyDownTriangle]", "b"], GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {" "},
            {"a"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][-$CellContext`a]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{
  3.7848588739441347`*^9, {3.7848593185086904`*^9, 3.7848593268742056`*^9}, 
   3.784859364667804*^9, 3.784859423355091*^9, 3.7859941637518997`*^9, 
   3.7859947008163476`*^9, 3.8000673248367496`*^9, 3.800077448218454*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(bc\\)]\\)\"\>", 
  "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M1,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Cos",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Cos,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M2,
             Editable->False], "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}]}], "0"},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Cos",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Cos,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", "r", "]"}]}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}], "2"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", "r", "]"}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "2"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M2,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], "0"},
      {
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["r", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M2,
             Editable->False], "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}]}], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", "r", "]"}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "2"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M2,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]]}], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M1,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M2,
             Editable->False], "[", "r", "]"}]}]}], ")"}]}], "0"},
      {"0", "0", "0", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]]}], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", "r", " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M1,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "2"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M2,
             Editable->False], "[", "r", "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], "2"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.7848588739441347`*^9, {3.7848593185086904`*^9, 3.7848593268742056`*^9}, 
   3.784859364667804*^9, 3.784859423355091*^9, 3.7859941637518997`*^9, 
   3.7859947008163476`*^9, 3.8000673248367496`*^9, 3.800077448946394*^9}]
}, Open  ]],

Cell[TextData[{
 "We want this ",
 Cell[BoxData[
  SubscriptBox["\[Delta]h", "bc"]],
  CellChangeTimes->{
   3.7848588739441347`*^9, {3.7848593185086904`*^9, 3.7848593268742056`*^9}, 
    3.784859364667804*^9, 3.784859423355091*^9, 3.7859941637518997`*^9, 
    3.7859947008163476`*^9, 3.8000673248367496`*^9}],
 " to be equal to just the ",
 StyleBox["tt",
  FontSlant->"Italic"],
 "-only-perturbation..."
}], "Text",
 CellChangeTimes->{{3.784858950957412*^9, 3.784858956741542*^9}, {
  3.8000673403844776`*^9, 3.8000673706415014`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]htt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{"evenfull", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PL", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"LegendreP", "[", 
            RowBox[{"1", ",", "0", ",", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}], "/.", 
     RowBox[{"h", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"r", ",", 
        RowBox[{"f", "[", "r", "]"}]}], "]"}]}]}], "/.", "removebrackets"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]h\), \(tt\)]\)\>\"", "\[Equal]", 
  "\[Delta]htt"}]}], "Input",
 CellChangeTimes->{{3.78485895865248*^9, 3.784858963381443*^9}, {
  3.784859063679388*^9, 3.7848591258291235`*^9}, {3.7848594280153236`*^9, 
  3.7848594577363234`*^9}, {3.784860174894422*^9, 3.7848601821424513`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]h\\), \\(tt\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False]}]], " ", 
   SqrtBox[
    FractionBox["3", "\[Pi]"]], " ", 
   InterpretationBox[
    StyleBox["\[Epsilon]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Epsilon],
    Editable->False], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox["Cos",
      ShowAutoStyles->False,
      AutoSpacing->False],
     Cos,
     Editable->False], "[", "\[Theta]", "]"}], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox["f",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`f,
     Editable->False], "[", "r", "]"}], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox["H", "0"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`H0,
     Editable->False], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.784859067162487*^9, 3.7848590952739363`*^9}, 
   3.7848591265811625`*^9, 3.7848594581991806`*^9, 3.7848601833555965`*^9, 
   3.7859941649672413`*^9, 3.785994702200145*^9, 3.800067495615842*^9, 
   3.8000774490511475`*^9}]
}, Open  ]],

Cell["\<\
..., with all other components vanishing. From the angular parts we see \
that...\
\>", "Text",
 CellChangeTimes->{{3.784859134308798*^9, 3.784859139485888*^9}, {
  3.7848593721624537`*^9, 3.78485939695971*^9}, {3.8000673812089634`*^9, 
  3.8000673873872075`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M2sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]hcomp", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "4"}], "]"}], "]"}], "\[Equal]", "0"}], ",", "M2", 
      ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(M\), \(2\)]\)\>\"", "\[Equal]", 
    RowBox[{"M2", "[", "r", "]"}]}], "/.", "M2sol"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]hcomp2", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Delta]hcomp", "/.", "M2sol"}], "//", "Simplify"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Delta]h\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"\[Delta]hcomp2", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.784859466221072*^9, 3.784859500435381*^9}, {
   3.7848595580497756`*^9, 3.7848595896391153`*^9}, {3.7848596336575203`*^9, 
   3.784859666598704*^9}, 3.784859701096841*^9, {3.7848599301314287`*^9, 
   3.78485995789713*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(M\\), \\(2\\)]\\)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox["M", "1"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`M1,
     Editable->False], "[", "r", "]"}], "r"]}]], "Output",
 CellChangeTimes->{
  3.784859498156679*^9, {3.7848595827318263`*^9, 3.7848595899407063`*^9}, {
   3.7848596449448624`*^9, 3.7848596671544647`*^9}, 3.784859701915752*^9, {
   3.784859951000679*^9, 3.784859958161919*^9}, 3.7848601852405195`*^9, 
   3.785994165016432*^9, 3.785994702227309*^9, 3.800067521263665*^9, 
   3.8000774490730968`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Delta]h\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M1,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Cos",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Cos,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M1,
             Editable->False], "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}]}], "0"},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Cos",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Cos,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], " ", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", "r", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["M", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`M0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}]}]]}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "[", "r", "]"}]}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}], "2"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", "r", "]"}]}], ")"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"r", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}]}]], "0"},
      {
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "[", "r", "]"}], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M0,
             Editable->False], "[", "r", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "r", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              SubscriptBox["M", "1"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`M1,
             Editable->False], "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}]}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "[", "r", "]"}]}], ")"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "1"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M1,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{"r", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "1"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M1,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}]}]], "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.784859498156679*^9, {3.7848595827318263`*^9, 3.7848595899407063`*^9}, {
   3.7848596449448624`*^9, 3.7848596671544647`*^9}, 3.784859701915752*^9, {
   3.784859951000679*^9, 3.784859958161919*^9}, 3.7848601852405195`*^9, 
   3.785994165016432*^9, 3.785994702227309*^9, 3.800067521263665*^9, 
   3.800077449247588*^9}]
}, Open  ]],

Cell[TextData[{
 "This leaves us with two gauge d.o.f.s ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["M", "0"], ",", 
     SubscriptBox["M", "1"]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". We now set the ",
 StyleBox["tt",
  FontSlant->"Italic"],
 " component of the above equation to the desired hairy correction term by \
spending the gauge d.o.f. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["M", "1"], "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":"
}], "Text",
 CellChangeTimes->{{3.78485985471245*^9, 3.7848598770118985`*^9}, {
  3.8000675249661036`*^9, 3.800067559887467*^9}, {3.8000676125329924`*^9, 
  3.800067613564021*^9}, {3.8000679198495665`*^9, 3.800067937461626*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ttGT", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Delta]hcomp2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "\[Delta]htt"}], 
      ")"}], "//", "Simplify"}]}], ";", "ttGT"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M1sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{"ttGT", ",", "M1", ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(M\), \(1\)]\)\>\"", "\[Equal]", 
    RowBox[{"M1", "[", "r", "]"}]}], "/.", "M1sol"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]hcomp3", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Delta]hcomp2", "/.", "M1sol"}], "//", "Simplify"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Delta]h\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"\[Delta]hcomp3", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7848598798859863`*^9, 3.7848599127370267`*^9}, {
   3.784859971496521*^9, 3.784860039192665*^9}, {3.784860078833303*^9, 
   3.784860097518838*^9}, {3.7848602048146954`*^9, 3.784860250516262*^9}, {
   3.784860335555109*^9, 3.7848603381949787`*^9}, 3.784860384732846*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox["\[Epsilon]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Epsilon],
    Editable->False], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox["Cos",
      ShowAutoStyles->False,
      AutoSpacing->False],
     Cos,
     Editable->False], "[", "\[Theta]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H0,
          Editable->False], "[", "r", "]"}], "-", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["M", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`M0,
           Editable->False], "[", "r", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["M", "1"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`M1,
        Editable->False], "[", "r", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.784859905107093*^9, 3.784859913335856*^9}, {
   3.784859969470456*^9, 3.7848600058476686`*^9}, 3.7848600982461987`*^9, 
   3.7848601988719387`*^9, 3.784860251648883*^9, 3.7848603387263055`*^9, 
   3.784860385265365*^9, 3.7859941653904934`*^9, 3.7859947028104897`*^9, 
   3.800067859350193*^9, 3.8000774493313656`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(M\\), \\(1\\)]\\)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "[", "r", "]"}]}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H0,
       Editable->False], "[", "r", "]"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", "r", "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["M", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`M0,
       Editable->False], "[", "r", "]"}]}]}], 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]]}]], "Output",
 CellChangeTimes->{{3.784859905107093*^9, 3.784859913335856*^9}, {
   3.784859969470456*^9, 3.7848600058476686`*^9}, 3.7848600982461987`*^9, 
   3.7848601988719387`*^9, 3.784860251648883*^9, 3.7848603387263055`*^9, 
   3.784860385265365*^9, 3.7859941653904934`*^9, 3.7859947028104897`*^9, 
   3.800067859350193*^9, 3.8000774493383455`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Delta]h\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H0,
          Editable->False], "[", "r", "]"}]}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M0,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]], "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["\[Omega]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Omega],
              Editable->False], "2"], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M0,
              Editable->False], "[", "r", "]"}]}], "-", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["M", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`M0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "[", "r", "]"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox[
                    SubscriptBox["H", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`H0,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  InterpretationBox[
                   StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Omega],
                   Editable->False], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox[
                    SubscriptBox["M", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M0,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["M", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M0,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}]}], ")"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`f,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
              RowBox[{"r", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox[
                    SubscriptBox["H", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`H0,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  InterpretationBox[
                   StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Omega],
                   Editable->False], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox[
                    SubscriptBox["M", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M0,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["M", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M0,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}]}], ")"}]}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{"r", " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
                 RowBox[{"r", " ", 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]], "0"},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "r", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["M", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`M0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}]}], ")"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`f,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
              RowBox[{"r", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox[
                    SubscriptBox["H", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`H0,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  InterpretationBox[
                   StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Omega],
                   Editable->False], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox[
                    SubscriptBox["M", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`M0,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{"2", " ", 
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["M", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`M0,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}]}], ")"}]}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{"r", " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
                 RowBox[{"r", " ", 
                  RowBox[{
                   InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "[", "r", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]], "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.784859905107093*^9, 3.784859913335856*^9}, {
   3.784859969470456*^9, 3.7848600058476686`*^9}, 3.7848600982461987`*^9, 
   3.7848601988719387`*^9, 3.784860251648883*^9, 3.7848603387263055`*^9, 
   3.784860385265365*^9, 3.7859941653904934`*^9, 3.7859947028104897`*^9, 
   3.800067859350193*^9, 3.8000774497463403`*^9}]
}, Open  ]],

Cell[TextData[{
 "At this point, we got the desired ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "tt"], TraditionalForm]]],
 " correction already; however, we still have to make all of the other \
components vanish with only one remaining DoF, i.e., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "0"], TraditionalForm]]],
 ". Solving the ",
 StyleBox["t",
  FontSlant->"Italic"],
 "\[Theta] part of this (thus, using the last DoF) and substituting back into \
the gauge transformed metric perturbation leaves us with..."
}], "Text",
 CellChangeTimes->{{3.784860390395563*^9, 3.7848604831924343`*^9}, {
  3.7848612507150173`*^9, 3.7848612591074*^9}, {3.800067875679781*^9, 
  3.800067886730958*^9}, {3.800068451864147*^9, 3.800068480584301*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M0sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]hcomp3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "\[Equal]", "0"}], ",", "M0", 
      ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(M\), \(0\)]\)\>\"", "\[Equal]", 
    RowBox[{"M0", "[", "r", "]"}]}], "/.", "M0sol"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]hcomp4", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Delta]hcomp3", "/.", "M0sol"}], "//", "Simplify"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Delta]h\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"\[Delta]hcomp4", "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.800068491752447*^9, 3.800068511665305*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(M\\), \\(0\\)]\\)\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "r", " ", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H0,
       Editable->False], "[", "r", "]"}]}], 
    RowBox[{
     RowBox[{"2", " ", "r", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Omega]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Omega],
        Editable->False], "2"]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["f",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`f,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]]}]}]], "Output",
 CellChangeTimes->{3.8000685171435556`*^9, 3.800077449778199*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Delta]h\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False]}]], " ", 
        SqrtBox[
         FractionBox["3", "\[Pi]"]], " ", 
        InterpretationBox[
         StyleBox["\[Epsilon]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Epsilon],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Cos",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Cos,
          Editable->False], "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["H", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`H0,
          Editable->False], "[", "r", "]"}]}], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "-", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  InterpretationBox[
                   StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`f,
                   Editable->False], "[", "r", "]"}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "r", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], ")"}], "2"]}]], 
       "0", "0"},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "-", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  InterpretationBox[
                   StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`f,
                   Editable->False], "[", "r", "]"}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "r", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], ")"}], "2"]}]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False]}]], " ", 
         SqrtBox[
          FractionBox["3", "\[Pi]"]], " ", 
         InterpretationBox[
          StyleBox["\[Epsilon]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Epsilon],
          Editable->False], " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Cos",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Cos,
           Editable->False], "[", "\[Theta]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["H", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`H0,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["\[Omega]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Omega],
                 Editable->False], "2"]}], "-", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["f",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`f,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "r", " ", 
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Omega],
                    Editable->False], "2"]}], "-", 
                 RowBox[{
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox[
                   SubscriptBox["H", "0"],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`H0,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["H", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`H0,
                 Editable->False], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Omega],
                    Editable->False], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "r", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Omega]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Omega],
               Editable->False], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], ")"}], "2"]}]], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "r", " ", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["\[Omega]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Omega],
                  Editable->False], "2"]}], "-", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "r", " ", 
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Omega],
                    Editable->False], "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"r", " ", 
                   RowBox[{
                    SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{
                RowBox[{
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", "r", " ", 
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Omega],
                    Editable->False], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "+", 
                  RowBox[{"r", " ", 
                   RowBox[{
                    SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "r", " ", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], ")"}], "2"]}]]}], 
       "0"},
      {"0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", 
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False]}]], " ", 
          SqrtBox[
           FractionBox["3", "\[Pi]"]], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{
              InterpretationBox[
               StyleBox["f",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`f,
               Editable->False], "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "r", " ", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["\[Omega]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Omega],
                  Editable->False], "2"]}], "-", 
               RowBox[{
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["H", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`H0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H0,
               Editable->False], "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "r", " ", 
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Omega],
                    Editable->False], "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"r", " ", 
                   RowBox[{
                    SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{
                RowBox[{
                 InterpretationBox[
                  StyleBox["f",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`f,
                  Editable->False], "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", "r", " ", 
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["\[Omega]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Omega],
                    Editable->False], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "+", 
                  RowBox[{"r", " ", 
                   RowBox[{
                    SuperscriptBox[
                    InterpretationBox[
                    StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`f,
                    Editable->False], "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "r", " ", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], ")"}], "2"]}]]}], 
       "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.8000685171435556`*^9, 3.800077450139677*^9}]
}, Open  ]],

Cell[TextData[{
 "The remaining nonzero components should all be satisfied by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["H", "0"], "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " should it be a ",
 StyleBox["tt",
  FontSlant->"Italic"],
 "-only-gauge transformation. We write down these differential equations \
below..."
}], "Text",
 CellChangeTimes->{{3.800068540169568*^9, 3.800068636594166*^9}, {
  3.800068735804143*^9, 3.8000687362573256`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"trTTonly", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"H0", "'"}], "[", "r", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"H0", "'"}], "[", "r", "]"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]hcomp4", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"H0", "'"}], "[", "r", "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rrTTonly", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"H0", "'"}], "[", "r", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"H0", "'"}], "[", "r", "]"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]hcomp4", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"H0", "'"}], "[", "r", "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r\[Theta]TTonly", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"H0", "'"}], "[", "r", "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"H0", "'"}], "[", "r", "]"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Delta]hcomp4", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "3"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"H0", "'"}], "[", "r", "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}], ")"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", "trTTonly", "\
\[IndentingNewLine]", "rrTTonly", "\[IndentingNewLine]", "r\[Theta]TTonly"}], \
"Input",
 CellChangeTimes->{{3.80006865202*^9, 3.8000688122184105`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      SubscriptBox["H", "0"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`H0,
     Editable->False], "\[Prime]",
    MultilineFunction->None], "[", "r", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H0,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["f",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`f,
           Editable->False], "[", "r", "]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], "2"]}], "-", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "[", "r", "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "r", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Omega]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Omega],
         Editable->False], "2"]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.8000687004845653`*^9, 3.800068717708213*^9}, {
   3.8000687829157476`*^9, 3.800068812812006*^9}, 3.800077450293823*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      SubscriptBox["H", "0"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`H0,
     Editable->False], "\[Prime]",
    MultilineFunction->None], "[", "r", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H0,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "r", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["f",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`f,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "r", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Omega]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Omega],
         Editable->False], "2"]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.8000687004845653`*^9, 3.800068717708213*^9}, {
   3.8000687829157476`*^9, 3.800068812812006*^9}, 3.800077450301773*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      SubscriptBox["H", "0"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`H0,
     Editable->False], "\[Prime]",
    MultilineFunction->None], "[", "r", "]"}], "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H0,
       Editable->False], "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "r", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Omega]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Omega],
             Editable->False], "2"]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"r", " ", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["f",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`f,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["f",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`f,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "r", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]]}]}]], "Output",
 CellChangeTimes->{{3.8000687004845653`*^9, 3.800068717708213*^9}, {
   3.8000687829157476`*^9, 3.800068812812006*^9}, 3.8000774503087516`*^9}]
}, Open  ]],

Cell[TextData[{
 "To end the discussion, we show that the above differential equations can \
only be simultaneously satisfied by a special metric function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Solving trTTonly for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["H", "0"], "'"}], 
    RowBox[{"(", "r", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and substituting into rrTTonly and r\[Theta]TTonly leads to..."
}], "Text",
 CellChangeTimes->{{3.8000689898226905`*^9, 3.8000690404822216`*^9}, {
  3.800069100827394*^9, 3.8000691768074923`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nec1", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"rrTTonly", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{"trTTonly", ",", 
         RowBox[{
          RowBox[{"H0", "'"}], "[", "r", "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nec2", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r\[Theta]TTonly", "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{"trTTonly", ",", 
          RowBox[{
           RowBox[{"H0", "'"}], "[", "r", "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}], ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "nec1", \
"\[IndentingNewLine]", "nec2"}], "Input",
 CellChangeTimes->{{3.800069187662749*^9, 3.8000692193691864`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H0,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "-", 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{"r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", "r", "]"}]}]], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.800069221071781*^9, 3.800077450379653*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H0,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "-", 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{"r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", "r", "]"}]}]], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.800069221071781*^9, 3.8000774503856134`*^9}]
}, Open  ]],

Cell[TextData[{
 "Seeing that the same expression emerges, this expression is the necessary \
condition so that a solution to the ",
 StyleBox["tr",
  FontSlant->"Italic"],
 " equation would also be a solution to the ",
 StyleBox["rr",
  FontSlant->"Italic"],
 " and ",
 StyleBox["r",
  FontSlant->"Italic"],
 "\[Theta] equations. It can be shown further that this is the same \
expression needed so that the solution of the ",
 StyleBox["rr",
  FontSlant->"Italic"],
 " equation would be a solution of the ",
 StyleBox["r",
  FontSlant->"Italic"],
 "\[Theta] equation. To conclude the proof, this necessary condition can be \
satisfied only by the very restrictive metric function..."
}], "Text",
 CellChangeTimes->{{3.800069249410574*^9, 3.800069331754019*^9}, {
  3.8000693752491074`*^9, 3.8000694114280663`*^9}, {3.8000694507522907`*^9, 
  3.8000694932266264`*^9}, {3.800069567605415*^9, 3.800069567761462*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fnec", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{"nec1", ",", "f", ",", "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"f\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
   RowBox[{"f", "[", "r", "]"}]}], "/.", "fnec"}]}], "Input",
 CellChangeTimes->{{3.800069505804437*^9, 3.800069508788109*^9}, {
  3.8000696245464787`*^9, 3.800069641011344*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,130,3,16658407811262272033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.800069642682656*^9, 3.8000774504513693`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"f\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    RowBox[{"C", "[", "1", "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.8000696426982775`*^9, 3.800077450472313*^9}]
}, Open  ]],

Cell[TextData[{
 "While this is a subset of the Schwarzschild-(A)dS class of maximally \
symmetric solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", the missing \[OpenCurlyDoubleQuote]mass\[CloseCurlyDoubleQuote] term, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "2"}], 
    RowBox[{"M", "/", "r"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", shows that in general the remaining differential equations cannot be \
simultaneously satisfied. Hence, the ",
 StyleBox["tt",
  FontSlant->"Italic"],
 "-only-perturbation cannot be gauged away.\n\n[",
 StyleBox["Schwarzschild case",
  FontSlant->"Italic"],
 "]\n\nFor the sake of being more explicit, we pursue this further for the \
Schwarzschild limit, i.e., we solve the remaining conditions ",
 StyleBox["trTTonly",
  FontSlant->"Italic"],
 ", ",
 StyleBox["rrTTonly",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["r\[Theta]TTonly",
  FontSlant->"Italic"],
 ", for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["H", "0"], "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.800069663874148*^9, 3.8000697085852203`*^9}, {
  3.800069847912589*^9, 3.800069850786913*^9}, {3.80006989998228*^9, 
  3.8000700685216675`*^9}, {3.800070109733531*^9, 3.8000701657477*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"trTTonlySc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"trTTonly", "/.", "SdS"}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rrTTonlySc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"rrTTonly", "/.", "SdS"}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r\[Theta]TTonlySc", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"r\[Theta]TTonly", "/.", "SdS"}], "/.", 
      RowBox[{"\[Lambda]", "\[Rule]", "0"}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trTTonlyScsol", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{"trTTonlySc", ",", "H0", ",", "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rrTTonlyScsol", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{"rrTTonlySc", ",", "H0", ",", "r"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r\[Theta]TTonlyScsol", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"DSolve", "[", 
       RowBox[{"r\[Theta]TTonlySc", ",", "H0", ",", "r"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"H\",
FontSlant->\"Italic\"], \"0\"]\)(\!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
    RowBox[{"H0", "[", "r", "]"}]}], "/.", "trTTonlyScsol"}], "//", 
  "TraditionalForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"H\",
FontSlant->\"Italic\"], \"0\"]\)(\!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
    RowBox[{"H0", "[", "r", "]"}]}], "/.", "rrTTonlyScsol"}], "//", 
  "TraditionalForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"H\",
FontSlant->\"Italic\"], \"0\"]\)(\!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
    RowBox[{"H0", "[", "r", "]"}]}], "/.", "r\[Theta]TTonlyScsol"}], "//", 
  "TraditionalForm"}]}], "Input",
 CellChangeTimes->{{3.8000701673098335`*^9, 3.8000703153401594`*^9}, {
  3.800070347832613*^9, 3.8000703794629536`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,135,4,16658407811262272033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8000702514541388`*^9, 3.8000703799472055`*^9, 
  3.800077450659902*^9}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,136,5,16658407811262272033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8000702514541388`*^9, 3.8000703799472055`*^9, 
  3.8000774507097425`*^9}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,137,6,16658407811262272033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8000702514541388`*^9, 3.8000703799472055`*^9, 
  3.800077450792551*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"0\\\"]\\)(\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSlant->\\\"Italic\\\"]\\))\
\"\>", "\[LongEqual]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      TagBox["c",
       C], "1"], " ", 
     RowBox[{"(", 
      RowBox[{"r", "-", 
       RowBox[{"2", " ", "M"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"M", "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], 
    SuperscriptBox["r", "3"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.800070176713876*^9, 3.8000701821322737`*^9}, 
   3.800070251469749*^9, 3.800070380040966*^9, 3.8000774508144293`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"0\\\"]\\)(\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSlant->\\\"Italic\\\"]\\))\
\"\>", "\[LongEqual]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      TagBox["c",
       C], "1"], " ", 
     RowBox[{"(", 
      RowBox[{"M", "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"3", "/", "2"}]], " ", 
     SqrtBox[
      RowBox[{"r", "-", 
       RowBox[{"2", " ", "M"}]}]]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.800070176713876*^9, 3.8000701821322737`*^9}, 
   3.800070251469749*^9, 3.800070380040966*^9, 3.8000774508193846`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"0\\\"]\\)(\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSlant->\\\"Italic\\\"]\\))\
\"\>", "\[LongEqual]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      TagBox["c",
       C], "1"], " ", 
     RowBox[{"(", 
      RowBox[{"M", "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", "-", 
       RowBox[{"2", " ", "M"}]}], ")"}], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.800070176713876*^9, 3.8000701821322737`*^9}, 
   3.800070251469749*^9, 3.800070380040966*^9, 3.8000774508253694`*^9}]
}, Open  ]],

Cell[TextData[{
 "These solutions can be the same only if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], "=", "0"}], TraditionalForm]]],
 ", but this is the trivial case.\n\nFor reference here is the desired ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " term:"
}], "Text",
 CellChangeTimes->{{3.78486138662368*^9, 3.7848613983048687`*^9}, {
  3.7848614873110356`*^9, 3.784861517322773*^9}, {3.784874225085821*^9, 
  3.7848742260839834`*^9}, {3.8000704551372786`*^9, 3.8000704740545673`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]H\), \(0\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"qt", "[", "\[Omega]", "]"}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"H0dip", ",", 
        RowBox[{"qt", "[", "\[Omega]", "]"}]}], "]"}]}], ")"}], "//", 
    "FullSimplify"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.784861399438233*^9, 3.784861433345521*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]H\\), \\(0\\)]\\)\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{"r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox["q", "~"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`qt,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Omega]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Omega],
      Editable->False], "]"}]}], 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["M",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`M,
     Editable->False], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["M",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`M,
         Editable->False]}], "r"]}]], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]}]]}]], "Output",
 CellChangeTimes->{3.784861434509611*^9, 3.7859941681382647`*^9, 
  3.7859947059734883`*^9, 3.800070422567829*^9, 3.800077450892223*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1025, 1110},
WindowMargins->{{Automatic, 643}, {Automatic, 52}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 211, 4, 70, "Section"],
Cell[794, 28, 120, 2, 30, "Input"],
Cell[917, 32, 457, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[1399, 46, 96, 1, 49, "Subsection"],
Cell[CellGroupData[{
Cell[1520, 51, 5202, 146, 1511, "Input"],
Cell[CellGroupData[{
Cell[6747, 201, 811, 11, 48, "Print"],
Cell[7561, 214, 1082, 18, 48, "Print"],
Cell[8646, 234, 834, 11, 48, "Print"],
Cell[9483, 247, 790, 10, 48, "Print"],
Cell[10276, 259, 774, 10, 48, "Print"],
Cell[11053, 271, 811, 11, 48, "Print"],
Cell[11867, 284, 1087, 19, 48, "Print"],
Cell[12957, 305, 832, 11, 48, "Print"],
Cell[13792, 318, 813, 11, 48, "Print"],
Cell[14608, 331, 1082, 18, 48, "Print"],
Cell[15693, 351, 850, 11, 88, "Print"],
Cell[16546, 364, 811, 11, 48, "Print"],
Cell[17360, 377, 966, 13, 127, "Print"],
Cell[18329, 392, 811, 11, 48, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[19201, 410, 103, 1, 41, "Subsection"],
Cell[19307, 413, 190, 4, 486, "Text"],
Cell[CellGroupData[{
Cell[19522, 421, 2148, 64, 3148, "Input"],
Cell[21673, 487, 2929, 86, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24651, 579, 176, 2, 41, "Subsection"],
Cell[24830, 583, 200, 5, 147, "Text"],
Cell[CellGroupData[{
Cell[25055, 592, 2411, 71, 395, "Input"],
Cell[27469, 665, 22309, 699, 70, "Output"]
}, Open  ]],
Cell[49793, 1367, 121, 1, 686, "Text"],
Cell[CellGroupData[{
Cell[49939, 1372, 3561, 104, 7886, "Input"],
Cell[53503, 1478, 31446, 989, 70, "Output"]
}, Open  ]],
Cell[84964, 2470, 160, 3, 36905, "Text"],
Cell[85127, 2475, 2383, 68, 348713, "Input"],
Cell[87513, 2545, 127, 1, 36905, "Text"],
Cell[CellGroupData[{
Cell[87665, 2550, 6889, 198, 609100, "Input"],
Cell[94557, 2750, 55042, 1673, 70, "Output"]
}, Open  ]],
Cell[149614, 4426, 122, 1, 65, "Text"],
Cell[CellGroupData[{
Cell[149761, 4431, 7210, 206, 941, "Input"],
Cell[156974, 4639, 45048, 1385, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[202071, 6030, 212, 3, 41, "Subsection"],
Cell[202286, 6035, 559, 18, 49, "Text"],
Cell[CellGroupData[{
Cell[202870, 6057, 799, 20, 69, "Input"],
Cell[203672, 6079, 1077, 28, 30, "Output"],
Cell[204752, 6109, 1007, 26, 52, "Output"]
}, Open  ]],
Cell[205774, 6138, 872, 22, 106, "Text"],
Cell[CellGroupData[{
Cell[206671, 6164, 1072, 29, 69, "Input"],
Cell[207746, 6195, 1297, 28, 80, "Output"],
Cell[209046, 6225, 1297, 28, 80, "Output"]
}, Open  ]],
Cell[210358, 6256, 249, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[210632, 6265, 1106, 26, 107, "Input"],
Cell[211741, 6293, 10320, 320, 148, "Output"],
Cell[222064, 6615, 8519, 256, 127, "Output"]
}, Open  ]],
Cell[230598, 6874, 162, 2, 29, "Text"],
Cell[230763, 6878, 684, 19, 128, "Input"],
Cell[CellGroupData[{
Cell[231472, 6901, 105, 1, 39, "Subsubsection"],
Cell[231580, 6904, 399, 9, 190, "Text"],
Cell[CellGroupData[{
Cell[232004, 6917, 6731, 193, 878, "Input"],
Cell[238738, 7112, 11179, 351, 309, "Output"]
}, Open  ]],
Cell[249932, 7466, 180, 2, 65, "Text"],
Cell[CellGroupData[{
Cell[250137, 7472, 3811, 105, 614, "Input"],
Cell[253951, 7579, 4248, 108, 54, "Print"]
}, Open  ]],
Cell[258214, 7690, 138, 1, 65, "Text"],
Cell[CellGroupData[{
Cell[258377, 7695, 1307, 39, 354, "Input"],
Cell[259687, 7736, 2549, 68, 101, "Output"]
}, Open  ]],
Cell[262251, 7807, 278, 8, 65, "Text"],
Cell[CellGroupData[{
Cell[262554, 7819, 645, 13, 139, "Input"],
Cell[263202, 7834, 22947, 687, 311, "Output"]
}, Open  ]],
Cell[286164, 8524, 753, 27, 189, "Text"],
Cell[CellGroupData[{
Cell[286942, 8555, 1425, 40, 225, "Input"],
Cell[288370, 8597, 866, 27, 66, "Output"],
Cell[289239, 8626, 2494, 88, 125, "Output"]
}, Open  ]],
Cell[291748, 8717, 190, 2, 65, "Text"],
Cell[CellGroupData[{
Cell[291963, 8723, 7974, 219, 526, "Input"],
Cell[299940, 8944, 3864, 115, 255, "Output"],
Cell[303807, 9061, 5931, 205, 203, "Output"]
}, Open  ]],
Cell[309753, 9269, 170, 3, 65, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[309960, 9277, 110, 1, 31, "Subsubsection"],
Cell[310073, 9280, 308, 5, 65, "Text"],
Cell[CellGroupData[{
Cell[310406, 9289, 761, 24, 176, "Input"],
Cell[311170, 9315, 3978, 110, 118, "Output"]
}, Open  ]],
Cell[315163, 9428, 170, 2, 65, "Text"],
Cell[315336, 9432, 921, 27, 182, "Input"],
Cell[316260, 9461, 262, 9, 66, "Text"],
Cell[316525, 9472, 2012, 51, 448, "Input"],
Cell[318540, 9525, 213, 6, 490, "Text"],
Cell[CellGroupData[{
Cell[318778, 9535, 3014, 89, 2815, "Input"],
Cell[321795, 9626, 5045, 159, 66, "Output"],
Cell[326843, 9787, 2078, 60, 66, "Output"],
Cell[328924, 9849, 7727, 233, 66, "Output"],
Cell[336654, 10084, 11961, 351, 66, "Output"]
}, Open  ]],
Cell[348630, 10438, 237, 3, 299, "Text"],
Cell[CellGroupData[{
Cell[348892, 10445, 633, 19, 638, "Input"],
Cell[349528, 10466, 441, 7, 66, "Output"]
}, Open  ]],
Cell[349984, 10476, 804, 23, 1100, "Text"],
Cell[CellGroupData[{
Cell[350813, 10503, 580, 17, 638, "Input"],
Cell[351396, 10522, 996, 30, 66, "Output"]
}, Open  ]],
Cell[352407, 10555, 228, 7, 303, "Text"],
Cell[CellGroupData[{
Cell[352660, 10566, 784, 23, 1034, "Input"],
Cell[353447, 10591, 5637, 182, 66, "Output"]
}, Open  ]],
Cell[359099, 10776, 624, 21, 486, "Text"],
Cell[CellGroupData[{
Cell[359748, 10801, 598, 17, 638, "Input"],
Cell[360349, 10820, 3598, 114, 126, "Output"]
}, Open  ]],
Cell[363962, 10937, 348, 12, 66, "Text"],
Cell[CellGroupData[{
Cell[364335, 10953, 622, 17, 139, "Input"],
Cell[364960, 10972, 5419, 177, 181, "Output"]
}, Open  ]],
Cell[370394, 11152, 443, 13, 65, "Text"],
Cell[CellGroupData[{
Cell[370862, 11169, 1210, 36, 225, "Input"],
Cell[372075, 11207, 15525, 470, 299, "Output"]
}, Open  ]],
Cell[387615, 11680, 140, 1, 65, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[387792, 11686, 110, 1, 31, "Subsubsection"],
Cell[387905, 11689, 291, 5, 86, "Text"],
Cell[CellGroupData[{
Cell[388221, 11698, 1355, 36, 245, "Input"],
Cell[389579, 11736, 4100, 136, 87, "Output"],
Cell[393682, 11874, 1269, 42, 43, "Output"],
Cell[394954, 11918, 6748, 212, 100, "Output"],
Cell[401705, 12132, 10662, 329, 159, "Output"]
}, Open  ]],
Cell[412382, 12464, 584, 19, 106, "Text"],
Cell[CellGroupData[{
Cell[412991, 12487, 1338, 35, 268, "Input"],
Cell[414332, 12524, 588, 10, 49, "Message"],
Cell[414923, 12536, 788, 19, 122, "Output"],
Cell[415714, 12557, 590, 10, 49, "Message"],
Cell[416307, 12569, 1840, 48, 152, "Output"]
}, Open  ]],
Cell[418162, 12620, 124, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[418311, 12625, 1372, 40, 167, "Input"],
Cell[419686, 12667, 419, 8, 22, "Message"],
Cell[420108, 12677, 555, 15, 41, "Output"],
Cell[420666, 12694, 419, 8, 22, "Message"],
Cell[421088, 12704, 3014, 98, 134, "Output"]
}, Open  ]],
Cell[424117, 12805, 346, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[424488, 12817, 431, 11, 30, "Input"],
Cell[424922, 12830, 245, 3, 30, "Output"]
}, Open  ]],
Cell[425182, 12836, 278, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[425485, 12846, 3005, 90, 232, "Input"],
Cell[428493, 12938, 6726, 191, 293, "Output"]
}, Open  ]],
Cell[435234, 13132, 916, 19, 276, "Text"],
Cell[CellGroupData[{
Cell[436175, 13155, 567, 15, 70, "Input"],
Cell[436745, 13172, 5715, 190, 168, "Output"]
}, Open  ]],
Cell[442475, 13365, 184, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[442684, 13371, 1608, 48, 155, "Input"],
Cell[444295, 13421, 4407, 141, 93, "Output"],
Cell[448705, 13564, 3810, 118, 103, "Output"]
}, Open  ]],
Cell[452530, 13685, 1600, 39, 240, "Text"],
Cell[CellGroupData[{
Cell[454155, 13728, 721, 17, 109, "Input"],
Cell[454879, 13747, 3840, 117, 102, "Output"],
Cell[458722, 13866, 18852, 570, 128, "Output"]
}, Open  ]],
Cell[477589, 14439, 917, 26, 106, "Text"],
Cell[CellGroupData[{
Cell[478531, 14469, 382, 9, 70, "Input"],
Cell[478916, 14480, 6839, 210, 130, "Output"]
}, Open  ]],
Cell[485770, 14693, 530, 16, 87, "Text"],
Cell[CellGroupData[{
Cell[486325, 14713, 1003, 26, 109, "Input"],
Cell[487331, 14741, 850, 28, 41, "Output"]
}, Open  ]],
Cell[488196, 14772, 828, 27, 106, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489073, 14805, 175, 2, 47, "Subsection"],
Cell[489251, 14809, 504, 13, 188038, "Text"],
Cell[CellGroupData[{
Cell[489780, 14826, 730, 18, 335493, "Input"],
Cell[490513, 14846, 31968, 982, 551496, "Output"],
Cell[522484, 15830, 26159, 790, 551496, "Output"]
}, Open  ]],
Cell[548658, 16623, 152, 3, 81248, "Text"],
Cell[548813, 16628, 756, 20, 335493, "Input"],
Cell[549572, 16650, 539, 15, 186177, "Text"],
Cell[CellGroupData[{
Cell[550136, 16669, 105, 1, 107483, "Subsubsection"],
Cell[550244, 16672, 130, 1, 81248, "Text"],
Cell[CellGroupData[{
Cell[550399, 16677, 2195, 65, 593788, "Input"],
Cell[552597, 16744, 4204, 107, 66961, "Print"]
}, Open  ]],
Cell[556816, 16854, 122, 1, 81248, "Text"],
Cell[CellGroupData[{
Cell[556963, 16859, 1196, 36, 443264, "Input"],
Cell[558162, 16897, 2478, 67, 126312, "Output"]
}, Open  ]],
Cell[560655, 16967, 162, 3, 81248, "Text"],
Cell[CellGroupData[{
Cell[560842, 16974, 1273, 34, 497424, "Input"],
Cell[562118, 17010, 4894, 164, 300744, "Output"],
Cell[567015, 17176, 5995, 198, 254121, "Output"],
Cell[573013, 17376, 4786, 164, 300744, "Output"]
}, Open  ]],
Cell[577814, 17543, 682, 23, 134948, "Text"],
Cell[CellGroupData[{
Cell[578521, 17570, 1599, 39, 501540, "Input"],
Cell[580123, 17611, 243, 3, 118762, "Output"],
Cell[580369, 17616, 243, 3, 118762, "Output"],
Cell[580615, 17621, 246, 3, 118762, "Output"]
}, Open  ]],
Cell[580876, 17627, 446, 15, 189111, "Text"],
Cell[CellGroupData[{
Cell[581347, 17646, 1042, 27, 390840, "Input"],
Cell[582392, 17675, 5545, 190, 290613, "Output"],
Cell[587940, 17867, 5450, 186, 247909, "Output"]
}, Open  ]],
Cell[593405, 18056, 2466, 86, 190040, "Text"],
Cell[CellGroupData[{
Cell[595896, 18146, 2800, 83, 227979, "Input"],
Cell[598699, 18231, 343, 7, 60860, "Message"],
Cell[599045, 18240, 1096, 34, 162828, "Output"]
}, Open  ]],
Cell[600156, 18277, 250, 8, 81248, "Text"],
Cell[CellGroupData[{
Cell[600431, 18289, 1152, 32, 335493, "Input"],
Cell[601586, 18323, 25286, 738, 476387, "Output"]
}, Open  ]],
Cell[626887, 19064, 122, 1, 81248, "Text"],
Cell[CellGroupData[{
Cell[627034, 19069, 2794, 82, 370985, "Input"],
Cell[629831, 19153, 2367, 80, 162828, "Output"]
}, Open  ]],
Cell[632213, 19236, 141, 1, 81248, "Text"],
Cell[CellGroupData[{
Cell[632379, 19241, 383, 10, 173817, "Input"],
Cell[632765, 19253, 15883, 482, 476387, "Output"]
}, Open  ]],
Cell[648663, 19738, 255, 5, 133870, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[648955, 19748, 110, 1, 84620, "Subsubsection"],
Cell[649068, 19751, 134, 3, 81248, "Text"],
Cell[CellGroupData[{
Cell[649227, 19758, 719, 23, 274012, "Input"],
Cell[649949, 19783, 3742, 106, 147303, "Output"]
}, Open  ]],
Cell[653706, 19892, 117, 1, 81248, "Text"],
Cell[653826, 19895, 1447, 42, 443264, "Input"],
Cell[655276, 19939, 251, 7, 82524, "Text"],
Cell[CellGroupData[{
Cell[655552, 19950, 486, 11, 175302, "Input"],
Cell[656041, 19963, 31260, 935, 582960, "Output"]
}, Open  ]],
Cell[687316, 20901, 154, 3, 81248, "Text"],
Cell[CellGroupData[{
Cell[687495, 20908, 1419, 40, 443264, "Input"],
Cell[688917, 20950, 4410, 146, 255193, "Output"],
Cell[693330, 21098, 4442, 152, 255193, "Output"]
}, Open  ]],
Cell[697787, 21253, 314, 8, 133870, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[698138, 21266, 108, 1, 84620, "Subsubsection"],
Cell[698249, 21269, 214, 4, 81248, "Text"],
Cell[CellGroupData[{
Cell[698488, 21277, 881, 25, 443264, "Input"],
Cell[699372, 21304, 3289, 116, 276861, "Output"],
Cell[702664, 21422, 3320, 118, 226703, "Output"]
}, Open  ]],
Cell[705999, 21543, 159, 3, 81248, "Text"],
Cell[CellGroupData[{
Cell[706183, 21550, 457, 11, 173817, "Input"],
Cell[706643, 21563, 292, 6, 60860, "Message"],
Cell[706938, 21571, 563, 19, 147303, "Output"],
Cell[707504, 21592, 294, 6, 60860, "Message"],
Cell[707801, 21600, 474, 16, 126312, "Output"]
}, Open  ]],
Cell[708290, 21619, 1081, 30, 503586, "Text"],
Cell[CellGroupData[{
Cell[709396, 21653, 242, 6, 118762, "Input"],
Cell[709641, 21661, 464, 16, 147303, "Output"]
}, Open  ]],
Cell[710120, 21680, 227, 5, 133870, "Text"],
Cell[CellGroupData[{
Cell[710372, 21689, 584, 17, 173817, "Input"],
Cell[710959, 21708, 360, 12, 147303, "Output"]
}, Open  ]],
Cell[711334, 21723, 162, 3, 81248, "Text"],
Cell[CellGroupData[{
Cell[711521, 21730, 2631, 68, 605193, "Input"],
Cell[714155, 21800, 10265, 290, 1333802, "Output"]
}, Open  ]],
Cell[724435, 22093, 222, 4, 133870, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[724706, 22103, 160, 2, 37, "Subsection"],
Cell[724869, 22107, 476, 9, 191, "Text"],
Cell[CellGroupData[{
Cell[725370, 22120, 6819, 191, 878, "Input"],
Cell[732192, 22313, 69273, 2068, 441, "Output"]
}, Open  ]],
Cell[801480, 24384, 588, 15, 191, "Text"],
Cell[CellGroupData[{
Cell[802093, 24403, 929, 24, 268, "Input"],
Cell[803025, 24429, 15105, 461, 321, "Output"]
}, Open  ]],
Cell[818145, 24893, 113, 1, 65, "Text"],
Cell[818261, 24896, 760, 20, 268, "Input"],
Cell[819024, 24918, 167, 3, 65, "Text"],
Cell[819194, 24923, 126, 1, 86, "Subsubsection"],
Cell[CellGroupData[{
Cell[819345, 24928, 110, 1, 68, "Subsubsection"],
Cell[819458, 24931, 134, 3, 65, "Text"],
Cell[CellGroupData[{
Cell[819617, 24938, 719, 23, 176, "Input"],
Cell[820339, 24963, 3914, 109, 118, "Output"]
}, Open  ]],
Cell[824268, 25075, 117, 1, 65, "Text"],
Cell[824388, 25078, 595, 15, 139, "Input"],
Cell[824986, 25095, 255, 9, 66, "Text"],
Cell[825244, 25106, 1868, 52, 585, "Input"],
Cell[827115, 25160, 572, 10, 233, "Text"],
Cell[CellGroupData[{
Cell[827712, 25174, 988, 23, 226, "Input"],
Cell[828703, 25199, 98913, 2775, 70, "Output"]
}, Open  ]],
Cell[927631, 27977, 183, 2, 65, "Text"],
Cell[CellGroupData[{
Cell[927839, 27983, 2685, 75, 569, "Input"],
Cell[930527, 28060, 4772, 156, 171, "Output"],
Cell[935302, 28218, 9390, 288, 248, "Output"],
Cell[944695, 28508, 2209, 69, 124, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[946953, 28583, 106, 1, 68, "Subsubsection"],
Cell[947062, 28586, 344, 13, 66, "Text"],
Cell[CellGroupData[{
Cell[947431, 28603, 1094, 33, 440, "Input"],
Cell[948528, 28638, 4132, 138, 171, "Output"],
Cell[952663, 28778, 1613, 54, 124, "Output"],
Cell[954279, 28834, 8686, 270, 248, "Output"]
}, Open  ]],
Cell[962980, 29107, 990, 31, 234, "Text"],
Cell[CellGroupData[{
Cell[963995, 29142, 1742, 47, 354, "Input"],
Cell[965740, 29191, 508, 9, 49, "Message"],
Cell[966251, 29202, 506, 9, 49, "Message"],
Cell[966760, 29213, 4103, 134, 199, "Output"],
Cell[970866, 29349, 918, 24, 128, "Output"],
Cell[971787, 29375, 732, 18, 128, "Output"]
}, Open  ]],
Cell[972534, 29396, 1044, 23, 317, "Text"],
Cell[CellGroupData[{
Cell[973603, 29423, 1075, 27, 182, "Input"],
Cell[974681, 29452, 7313, 217, 339, "Output"]
}, Open  ]],
Cell[982009, 29672, 169, 3, 65, "Text"],
Cell[CellGroupData[{
Cell[982203, 29679, 1220, 36, 188, "Input"],
Cell[983426, 29717, 819, 22, 125, "Output"]
}, Open  ]],
Cell[984260, 29742, 117, 1, 65, "Text"],
Cell[CellGroupData[{
Cell[984402, 29747, 1134, 28, 225, "Input"],
Cell[985539, 29777, 996, 24, 200, "Output"]
}, Open  ]],
Cell[986550, 29804, 525, 13, 191, "Text"],
Cell[CellGroupData[{
Cell[987100, 29821, 668, 18, 182, "Input"],
Cell[987771, 29841, 1326, 44, 149, "Output"]
}, Open  ]],
Cell[989112, 29888, 1027, 25, 275, "Text"],
Cell[CellGroupData[{
Cell[990164, 29917, 3394, 96, 700, "Input"],
Cell[993561, 30015, 4194, 107, 54, "Print"]
}, Open  ]],
Cell[997770, 30125, 381, 12, 65, "Text"],
Cell[CellGroupData[{
Cell[998176, 30141, 1974, 54, 483, "Input"],
Cell[1000153, 30197, 2574, 69, 101, "Output"],
Cell[1002730, 30268, 21976, 657, 406, "Output"]
}, Open  ]],
Cell[1024721, 30928, 536, 14, 67, "Text"],
Cell[CellGroupData[{
Cell[1025282, 30946, 1165, 29, 225, "Input"],
Cell[1026450, 30977, 1438, 47, 149, "Output"]
}, Open  ]],
Cell[1027903, 31027, 274, 6, 65, "Text"],
Cell[CellGroupData[{
Cell[1028202, 31037, 1113, 29, 268, "Input"],
Cell[1029318, 31068, 664, 16, 118, "Output"],
Cell[1029985, 31086, 19292, 574, 382, "Output"]
}, Open  ]],
Cell[1049292, 31663, 778, 23, 108, "Text"],
Cell[CellGroupData[{
Cell[1050095, 31690, 1353, 35, 354, "Input"],
Cell[1051451, 31727, 2567, 83, 95, "Output"],
Cell[1054021, 31812, 1787, 56, 125, "Output"],
Cell[1055811, 31870, 37833, 1055, 384, "Output"]
}, Open  ]],
Cell[1093659, 32928, 753, 18, 191, "Text"],
Cell[CellGroupData[{
Cell[1094437, 32950, 936, 26, 268, "Input"],
Cell[1095376, 32978, 1150, 37, 128, "Output"],
Cell[1096529, 33017, 31380, 874, 401, "Output"]
}, Open  ]],
Cell[1127924, 33894, 491, 14, 108, "Text"],
Cell[CellGroupData[{
Cell[1128440, 33912, 2209, 67, 483, "Input"],
Cell[1130652, 33981, 2998, 100, 144, "Output"],
Cell[1133653, 34083, 3325, 110, 144, "Output"],
Cell[1136981, 34195, 3978, 126, 144, "Output"]
}, Open  ]],
Cell[1140974, 34324, 669, 18, 149, "Text"],
Cell[CellGroupData[{
Cell[1141668, 34346, 906, 27, 268, "Input"],
Cell[1142577, 34375, 1148, 40, 125, "Output"],
Cell[1143728, 34417, 1150, 40, 125, "Output"]
}, Open  ]],
Cell[1144893, 34460, 915, 23, 235, "Text"],
Cell[CellGroupData[{
Cell[1145833, 34487, 577, 17, 182, "Input"],
Cell[1146413, 34506, 294, 6, 49, "Message"],
Cell[1146710, 34514, 366, 8, 95, "Output"]
}, Open  ]],
Cell[1147091, 34525, 1389, 41, 401, "Text"],
Cell[CellGroupData[{
Cell[1148505, 34570, 2514, 76, 526, "Input"],
Cell[1151022, 34648, 321, 7, 49, "Message"],
Cell[1151346, 34657, 323, 7, 49, "Message"],
Cell[1151672, 34666, 321, 7, 49, "Message"],
Cell[1151996, 34675, 759, 21, 137, "Output"],
Cell[1152758, 34698, 791, 23, 146, "Output"],
Cell[1153552, 34723, 749, 21, 142, "Output"]
}, Open  ]],
Cell[1154316, 34747, 546, 14, 149, "Text"],
Cell[CellGroupData[{
Cell[1154887, 34765, 437, 11, 95, "Input"],
Cell[1155327, 34778, 1249, 43, 149, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

