(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    673651,      17997]
NotebookOptionsPosition[    660179,      17614]
NotebookOutlinePosition[    660531,      17629]
CellTagsIndexPosition[    660488,      17626]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Tailoring cosmologies in cubic Horndeski theory", "Section",
 CellChangeTimes->{{3.788425311540043*^9, 3.788425327187666*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7884255694324555`*^9, 3.7884255700749645`*^9}}],

Cell["\<\
In this notebook, we use xCoba to setup the cosmology-generating method \
outlined in JCAP10(2019)058.\
\>", "Text",
 CellChangeTimes->{{3.7884253413213205`*^9, 3.788425379003604*^9}, {
  3.788425424660529*^9, 3.7884254460830975`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0.1 Setup",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777684103615888*^9, 3.777684108386374*^9}, 
   3.7776846492181263`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xCoba"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"<<", "xAct`xCoba`"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "    ", "\[IndentingNewLine]", 
   RowBox[{"DefManifold", "[", 
    RowBox[{"M", ",", "dim", ",", 
     RowBox[{"{", 
      RowBox[{
      "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", "j", ",", 
       "k", ",", "l", ",", "p", ",", "q", ",", "r", ",", "s"}], "}"}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"DefMetric", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"g", "[", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "]"}], ",", "CD", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
     RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Detg", "]"}], "^=", "\"\<g\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "define", " ", "scalar", " ", "field", " ", "and", " ", "potentials"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], ",", "M"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "G", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[CapitalLambda]", "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.7776842285875587`*^9, {3.777684343005937*^9, 3.77768437303294*^9}, {
   3.777684449042101*^9, 3.777684630351591*^9}, {3.777685859005588*^9, 
   3.777685859671356*^9}, {3.777686291180215*^9, 3.777686292009376*^9}, {
   3.7884255923274097`*^9, 3.7884255926150665`*^9}, {3.788425668944124*^9, 
   3.788425669450387*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028412234483`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028412265186`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841250309*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841257988*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841520035*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.78910284154265*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028415632915`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028415764136`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841783761*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028417894335`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841795228*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028417992697`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028418076525`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841810891*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028418165493`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841821172*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841827815*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028418335285`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841837495*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841842987*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841846839*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841851184*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.78910284185618*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102841860402*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028418643665`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028423605123`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028423753057`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.78910284238588*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028423917413`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842396683*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424014935`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424066553`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424116373`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424160776`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842420553*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842426139*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424301233`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842434924*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842456241*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424617033`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028424901066`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028425944605`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028426202264`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028426263046`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842761883*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028427853203`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028427974195`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028428031654`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "G", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`G, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.789102842809169*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028428131623`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[CapitalLambda]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[CapitalLambda], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, {
   3.788425583657099*^9, 3.788425607515831*^9}, 3.788427343828969*^9, 
   3.7888483533058558`*^9, 3.7889050042433577`*^9, 3.7889086536541615`*^9, 
   3.7889174713228827`*^9, 3.788938349250766*^9, 3.7891028428181467`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0.2 CP code",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.77768465587844*^9, 3.777684673012726*^9}}],

Cell["\<\
Here is the code by CP that we use for deriving the covariant field equations.\
\>", "Text",
 CellChangeTimes->{{3.777684697448556*^9, 3.777684715449011*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "UpIndexQ"}], ",", 
       RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "DownIndexQ"}], ",", 
       RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
      RowBox[{"(*", 
       RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}], 
      ",", " ", 
      RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dgloc", "=", 
      RowBox[{"SymbolJoin", "[", 
       RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"hp", "=", 
      RowBox[{"Head", "@", 
       RowBox[{"Perturbation", "[", 
        RowBox[{"g", "[", 
         RowBox[{
          RowBox[{"DownIndex", "@", "a"}], ",", 
          RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"hp", "===", "Perturbation"}], ",", 
       RowBox[{"DefMetricPerturbation", "[", 
        RowBox[{"g", ",", "dgloc", ",", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
       RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
         "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
         " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", " ", 
         "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pertexpr", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
              RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
           RowBox[{"ToCanonical", "@", 
            RowBox[{"ContractMetric", "@", 
             RowBox[{"ExpandPerturbation", "@", 
              RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
          RowBox[{
           RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
           "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"We", " ", "then", " ", "use", " ", 
          RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", " ", 
          "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ", 
          "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
          "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dgloc", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], "]"}],
                  ",", 
                 RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
               "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
          " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
          "tensor"}], ",", " ", 
         RowBox[{
         "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", "the", 
          " ", "formal", " ", "first", " ", "order", " ", "perturbation", " ",
           "the", " ", "tensor"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
         "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"inds", "=", 
         RowBox[{"DummyIn", "/@", 
          RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "@@", "inds"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
          "and", " ", "replace", " ", 
          RowBox[{"Perturbation", "[", 
           RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", "this", 
          " ", "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", " ", 
          RowBox[{"VarD", " ", "works", " ", 
           RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need", 
           " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
           "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
               "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "@", 
     RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
    "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "VarD", " ", "and", " ", "removal", " ", "of", " ", 
          "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], "]"}],
                "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"g_", "?", "MetricQ"}], "[", 
     RowBox[{"as__", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
          RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
     "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sqrtg", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
        RowBox[{
         RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ToCanonical", "[", 
      RowBox[{
       RowBox[{"PerturbAction", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"sqrtg", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
         RowBox[{"Not", "[", 
          RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", "tensor", ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}]}], "]"}], ":=", 
    RowBox[{"VarAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
          RowBox[{"Not", "[", 
           RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}],
      "[", "inds___", "]"}], ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VarAction", "[", 
    RowBox[{"expr_", ",", 
     RowBox[{
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
   RowBox[{"VarAction", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"tensor", "[", "inds", "]"}], ",", 
     RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["I. Kinetic gravity braiding",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777684771051243*^9, 3.777684777686041*^9}}],

Cell["\<\
Kinetic gravity braiding is defined by the following Lagrangian.\
\>", "Text",
 CellChangeTimes->{{3.777685051160142*^9, 3.777685071298682*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "b", "]"}], "[", 
     RowBox[{"\[Phi]", "[", "]"}], "]"}], 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "b"}], "]"}], "[", 
     RowBox[{"\[Phi]", "[", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LG", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"G", "[", "X", "]"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "i", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "i"}], "]"}], "[", 
      RowBox[{"\[Phi]", "[", "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LEH", "=", 
    RowBox[{"\[Kappa]", " ", 
     RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"X", "-", 
      RowBox[{"2", "\[CapitalLambda]"}]}], ")"}], "+", "LG", "+", "LEH"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", "L"}]}], "Input",
 CellChangeTimes->{{3.7776850890641727`*^9, 3.777685188201232*^9}, {
  3.777685232922462*^9, 3.777685328684702*^9}, {3.777685885612694*^9, 
  3.777685891586584*^9}, {3.788425632406698*^9, 3.7884256367711782`*^9}, {
  3.7884256856874247`*^9, 3.7884256987481117`*^9}, {3.7884257959127707`*^9, 
  3.7884258056129403`*^9}, {3.788427326413154*^9, 3.788427328073298*^9}}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False]}], "-", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False]}], "]"}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "i"], 
       SubscriptBox["\[Del]", "i"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`i][
      $CellContext`CD[-$CellContext`i][
       $CellContext`\[Phi][]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{3.7776858921055403`*^9, 3.777686312077167*^9, 
  3.777686750087504*^9, 3.777686833416018*^9, 3.7776876921697273`*^9, 
  3.7776879990617847`*^9, 3.777688061840715*^9, 3.777774900298315*^9, 
  3.7777788451422434`*^9, 3.788425727973752*^9, 3.788425806595318*^9, 
  3.788427367108157*^9, 3.7888483713616004`*^9, 3.7889050170372286`*^9, 
  3.7889086750061474`*^9, 3.7889174860481277`*^9, 3.7889383682309427`*^9, 
  3.789102854976996*^9}]
}, Open  ]],

Cell["\<\
For the rest of this section, we derive the covariant field equations from \
this Lagrangian. Finally, we bring it down to component form by using the \
spatially flat FRW metric.\
\>", "Text",
 CellChangeTimes->{{3.777685375452651*^9, 3.777685460201378*^9}}],

Cell[CellGroupData[{

Cell["Background field equations", "Subsubsection",
 CellChangeTimes->{{3.777685478944446*^9, 3.777685481993011*^9}}],

Cell[TextData[{
 "For clarity, we separate the analysis into the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence (defined by ",
 StyleBox["K",
  FontSlant->"Italic"],
 "), braiding (defined by ",
 StyleBox["G",
  FontSlant->"Italic"],
 ") and Einstein-Hilbert sectors (tracked by \[Kappa]). \n\nThe Einstein \
equation is given by..."
}], "Text",
 CellChangeTimes->{{3.777685562579516*^9, 3.777685695300316*^9}, {
  3.777686048518564*^9, 3.777686054051899*^9}, {3.7884258231154594`*^9, 
  3.78842582930622*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"L", ",", 
         RowBox[{"g", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "RicciToEinstein"}], "//", "ToCanonical"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFE", "\[Equal]", 
  "\"\<8 \[Pi] \!\(\*SubscriptBox[SuperscriptBox[\(T\), \((M)\)], \(bc\)]\)\>\
\""}]}], "Input",
 CellChangeTimes->{{3.7776857000160217`*^9, 3.777685820606783*^9}, {
  3.77768590902424*^9, 3.7776859472749968`*^9}, {3.7776859825127287`*^9, 
  3.777685995319107*^9}, {3.7884257531318145`*^9, 3.788425778194111*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7884273671754065`*^9, 3.788848371431657*^9, 
  3.7889050171153345`*^9, 3.788908675075179*^9, 3.7889174861789784`*^9, 
  3.788938368308809*^9, 3.7891028551485863`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7884273671754065`*^9, 3.788848371431657*^9, 
  3.7889050171153345`*^9, 3.788908675075179*^9, 3.7889174861789784`*^9, 
  3.788938368308809*^9, 3.789102855167073*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "e"], 
       SubscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \
\\((M)\\)], \\(bc\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{
  3.7776858223690443`*^9, 3.77768590307835*^9, 3.777685950506002*^9, {
   3.77768598845282*^9, 3.7776859964171047`*^9}, 3.7776863155900593`*^9, 
   3.777686750738288*^9, 3.777686834121142*^9, 3.777687692803525*^9, 
   3.7776879997021103`*^9, 3.7776880624830637`*^9, 3.7777749011159267`*^9, 
   3.7777788459597993`*^9, {3.7884257817286596`*^9, 3.7884258108032885`*^9}, 
   3.7884273678026237`*^9, 3.7888483721321325`*^9, 3.788905017755808*^9, 
   3.7889086756610527`*^9, 3.788917486794532*^9, 3.7889383689336615`*^9, 
   3.7891028558945284`*^9}]
}, Open  ]],

Cell["On the other hand, the scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.7776860372102003`*^9, 3.7776860454678583`*^9}, {
  3.7884258330229435`*^9, 3.7884258437526236`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"L", ",", 
         RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "ToCanonical"}], "//", "NoScalar"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"BSE", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7776860788488817`*^9, 3.777686143256228*^9}, {
  3.7884258496611977`*^9, 3.7884258620579276`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]]],
    Editable->False], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`c][
       $CellContext`CD[$CellContext`c][
        $CellContext`\[Phi][]]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.777686144760418*^9, 3.777686320706005*^9, 
  3.777686751287487*^9, 3.777686834684125*^9, 3.777687693385708*^9, 
  3.777688000265327*^9, 3.777688063051939*^9, 3.777774901848841*^9, 
  3.7777788466927967`*^9, 3.7884258660731497`*^9, 3.7884273683005543`*^9, 
  3.788848372650221*^9, 3.788905018224448*^9, 3.7889086761401286`*^9, 
  3.7889174873122644`*^9, 3.7889383694179273`*^9, 3.789102856817135*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["II. Friedmann equations",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777686179101707*^9, 3.777686184072307*^9}}],

Cell["\<\
In this section, we use xCoba to reduce the covariant expressions derived \
previously into their component forms in FRW spacetime. \
\>", "Text",
 CellChangeTimes->{{3.7776861974948483`*^9, 3.7776862533410788`*^9}, 
   3.7884260320626926`*^9}],

Cell[CellGroupData[{

Cell["FRW spacetime", "Subsubsection",
 CellChangeTimes->{{3.788426037817053*^9, 3.788426060986907*^9}}],

Cell["\<\
We start, of course, by defining the chart and the FRW metric.\
\>", "Text",
 CellChangeTimes->{3.7884260354624195`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "define", " ", "chart", " ", "B", " ", "in", " ", "manifold", " ", "M"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefChart", "[", 
     RowBox[{"B", ",", "M", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"t", "[", "]"}], ",", 
        RowBox[{"x", "[", "]"}], ",", 
        RowBox[{"y", "[", "]"}], ",", 
        RowBox[{"z", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "scale", " ", "factor", " ", "a", 
     StyleBox[
      RowBox[{"(", "t", ")"}],
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], "and", " ", "FRW", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "a", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FRW", "=", 
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"]}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "tell", " ", "xCoba", " ", "FRW", " ", "is", " ", "the", " ", "metric", 
     " ", "and", " ", "compute", " ", "curvature", " ", "quantities"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricInBasis", "[", 
     RowBox[{"g", ",", 
      RowBox[{"-", "B"}], ",", "FRW"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricCompute", "[", 
     RowBox[{"g", ",", "B", ",", "All", ",", 
      RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.777686278318387*^9, 3.777686283132815*^9}, {
  3.777686345022435*^9, 3.777686431063656*^9}, {3.7776866634874153`*^9, 
  3.7776867062141743`*^9}, {3.777686803669854*^9, 3.777686804238579*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefChart", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"chart \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefChart, ": Defining ", "chart ", $CellContext`B, ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864372201*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"t", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`t[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864375106*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"x", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`x[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028643873467`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"y", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`y[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028643913894`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"z", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`z[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.78910286439651*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", "mapping ", $CellContext`B, 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644006433`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse mapping \"\>", "\[InvisibleSpace]", "iB",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", 
   "inverse mapping ", $CellContext`iB, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864404708*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"diB", "[", 
    RowBox[{
     RowBox[{"-", "\[FormalA]"}], ",", "iBb"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`diB[-\[FormalA], $CellContext`iBb], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644102635`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"dB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", "B\[FormalA]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`dB[-$CellContext`b, $CellContext`B\[FormalA]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864416275*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefBasis", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"basis \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Coordinated basis.\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefBasis, ": Defining ", "basis ", $CellContext`B, ". ", 
   "Coordinated basis."],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644204025`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parallel derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"PDB", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "parallel derivative ", 
   $CellContext`PDB[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644248857`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionPDB[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864429613*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelPDB[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864434003*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Riemann tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RiemannPDB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", "e"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Riemann tensor ", 
   $CellContext`RiemannPDB[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644378653`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciPDB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Ricci tensor ", 
   $CellContext`RicciPDB[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644416237`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric +1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaUpB", "[", 
    RowBox[{"b", ",", "c", ",", "d", ",", "e"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric +1 density ", 
   $CellContext`etaUpB[$CellContext`b, $CellContext`c, $CellContext`d, \
$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644467297`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric -1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaDownB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric -1 density ", 
   $CellContext`etaDownB[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644506826`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "a", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`a, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864454194*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", "1"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> -1, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644601097`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864474578*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644809737`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028644932566`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028645036263`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864514073*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864534588*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864540908*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028645530443`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.789102864561602*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028645778847`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028645846643`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028645973144`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028646067543`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028646170726`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028646295385`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetgB", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetgB[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028646332064`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelCDPDB[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.788425916986667*^9, 3.7884273765774403`*^9, 3.7888483795858107`*^9, 
  3.7889050279565463`*^9, 3.7889086835548725`*^9, 3.788917492945162*^9, 
  3.7889383808839874`*^9, 3.7891028646943965`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We now define the matter SET and also assume that the scalar field respects \
the isotropy and homogeneity of the spacetime, i.e, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "(", "t", ")"}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.777687075777155*^9, 3.7776871480056753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PF", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"\[Rho]", "[", 
        RowBox[{"t", "[", "]"}], "]"}]}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComponentValue", "[", 
    RowBox[{
     RowBox[{"ComponentArray", "[", 
      RowBox[{"T", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"b", ",", "B"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"c", ",", "B"}], "}"}]}], "]"}], "]"}], ",", "PF"}], "]"}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"compute", " ", "down"}], "-", 
    RowBox[{
    "down", " ", "components", " ", "of", " ", "matter", " ", "SET"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ChangeComponents", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", "B"}], "}"}]}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"matter", " ", "SET"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(T\), \(a\)], \(b\)]\)\>\"", 
   "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{
           RowBox[{"-", "b"}], ",", 
           RowBox[{"-", "c"}]}], "]"}], "//", 
         RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
        "ToValues"}], "//", "ToValues"}], "//", "MatrixForm"}], ")"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "in", " ", "FRW"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"\[Phi]0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(0\)]\)\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComponentValue", "[", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "]"}], ",", " ", 
    RowBox[{"\[Phi]0", "[", 
     RowBox[{"t", "[", "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.777687168943804*^9, 3.77768729132369*^9}, 
   3.777687329868163*^9, {3.777687380512602*^9, 3.777687380956182*^9}, {
   3.777687591270731*^9, 3.7776876239071608`*^9}, {3.7776876647361097`*^9, 
   3.777687665072289*^9}, {3.777687809350095*^9, 3.777687809842127*^9}, {
   3.7776879675610027`*^9, 3.777687974209988*^9}, {3.7776880433914824`*^9, 
   3.777688044880334*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`T[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028652517986`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{0, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865270494*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"\[Rho]", "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     0, -$CellContext`B}] -> -$CellContext`\[Rho][
      $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865276359*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028652896137`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028652955904`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028653088293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028653194866`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028653275213`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865340103*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865348465*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.78910286536043*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865367317*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028653812957`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028653882985`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028653987503`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028654079*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`T[{2, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865420863*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028654274216`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865438612*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028654502373`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865459714*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028654707127`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028654797554`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`T[{2, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028654911127`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865500189*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`T[{3, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865510764*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{3, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865519703*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028655728664`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028656150527`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865653885*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028656924777`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.78910286570537*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865750398*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028658010645`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865849921*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865916852*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865953636*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102865999671*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028660186005`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], 
   " by ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866064707*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866112979*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028661511707`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866168661*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028662152147`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866233533*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], 
   " by ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866281881*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866300016*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], 
   " by ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866348441*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866398738*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["b",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["c",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{-$CellContext`b, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["d",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["c",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{-$CellContext`d, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"T", 
          StyleBox[GridBox[{
             {" ", 
              StyleBox["d",
               FontColor->RGBColor[1., 0., 0.]]},
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`T[{-$CellContext`b, -$CellContext`B}, {$CellContext`d, \
$CellContext`B}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.878037`7.395057810720138", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`T[{-$CellContext`b, -$CellContext`B}, \
{-$CellContext`c, -$CellContext`B}] -> $CellContext`g[{-$CellContext`d, \
-$CellContext`B}, {-$CellContext`c, -$CellContext`B}] \
$CellContext`T[{-$CellContext`b, -$CellContext`B}, {$CellContext`d, \
$CellContext`B}], " in ", 0.878037`7.395057810720138, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028664375815`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \\(a\\)], \
\\(b\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"\[Rho]", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "0", "0", "0"},
      {"0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "0", "0"},
      {"0", "0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "0"},
      {"0", "0", "0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.777687354562492*^9, 3.77768771134719*^9, 
  3.777688017053129*^9, 3.77768807695894*^9, 3.777774913194344*^9, 
  3.7777788540892677`*^9, 3.7884259401056166`*^9, 3.78842737835588*^9, 
  3.7888483815130653`*^9, 3.788905029815487*^9, 3.788908685775977*^9, 
  3.7889174951024914`*^9, 3.7889383827273054`*^9, 3.789102866492603*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Phi]0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Phi]0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.789102866503025*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Phi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Phi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[Phi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Phi][] -> $CellContext`\[Phi]0[
     $CellContext`t[]], " for tensor ", $CellContext`\[Phi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.7884259390750933`*^9, 3.788427377127858*^9, 
  3.788848380432253*^9, 3.788905028737618*^9, 3.7889086842032146`*^9, 
  3.788917493611349*^9, 3.788938381633812*^9, 3.7891028665060897`*^9}]
}, Open  ]]
}, Open  ]],

Cell["The scalar field\[CloseCurlyQuote]s kinetic density becomes...", "Text",
 CellChangeTimes->{{3.777688706101716*^9, 3.7776887133805523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Xcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"X", "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<X\>\"", "\[Equal]", "Xcomp"}]}], "Input"],

Cell[BoxData[
 RowBox[{"\<\"X\"\>", "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.777688756737903*^9, 3.7777749132633443`*^9, 
  3.7777788541582656`*^9, 3.7884259523891177`*^9, 3.788427378441141*^9, 
  3.7888483815768204`*^9, 3.7889050298779726`*^9, 3.788908685854083*^9, 
  3.788917495178097*^9, 3.788938382789792*^9, 3.7891028665600014`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gravity sector", "Subsubsection",
 CellChangeTimes->{{3.7884260053180456`*^9, 3.7884260100607986`*^9}, {
  3.7884260912622805`*^9, 3.7884260970763426`*^9}, {3.788426611224958*^9, 
  3.788426614020832*^9}}],

Cell["We simplify the notation using the rule...", "Text",
 CellChangeTimes->{{3.7884261016923037`*^9, 3.788426131751294*^9}, {
  3.7884274322782907`*^9, 3.788427438234999*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplifyG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "'"}], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "b"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`b][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`b][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "'"}], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "''"}], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "b"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`b][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`b][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "''"}], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "'''"}], "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[Del]", "b"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`b][
              $CellContext`\[Phi][]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[$CellContext`b][
              $CellContext`\[Phi][]],
             Editable->False]}], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]]],
         Editable->False]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "'''"}], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788426147688992*^9, 3.7884261638237853`*^9}, {
  3.78842738882835*^9, 3.7884273899012084`*^9}, {3.7884274526635723`*^9, 
  3.7884275191196156`*^9}}],

Cell["\<\
The equations of motion on the FRW background are then obtained as follows. \
First, the Einstein equation leads to...\
\>", "Text",
 CellChangeTimes->{{3.7884261688990498`*^9, 3.7884261907433653`*^9}, {
  3.788426443631839*^9, 3.788426451499674*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MFE", "/.", "simplifyG"}], "//", 
            RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
           "TraceBasisDummy"}], "//", "ToValues"}], "//", "ToValues"}], "//", 
       RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//", 
     "ToValues"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcomp", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7884262059367523`*^9, 3.7884264173133183`*^9}, {
   3.788426455638585*^9, 3.78842648079881*^9}, 3.7884275273347855`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox["\[CapitalLambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[CapitalLambda],
         Editable->False]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "2"]}], 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], "3"]}], 
        RowBox[{"2", " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}]}]]}], "0", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["\[CapitalLambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[CapitalLambda],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["\[CapitalLambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[CapitalLambda],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["\[CapitalLambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[CapitalLambda],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.788426359803237*^9, 3.7884264590609703`*^9, 
  3.788427531084626*^9, 3.7888483827788496`*^9, 3.788905031049574*^9, 
  3.7889086870102224`*^9, 3.788917496449738*^9, 3.788938383961422*^9, 
  3.789102867786683*^9}]
}, Open  ]],

Cell["On the other hand, the scalar field equation becomes...", "Text",
 CellChangeTimes->{{3.7884264644967723`*^9, 3.788426490364216*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSEcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"BSE", "/.", "simplifyG"}], "//", 
             RowBox[{"SeparateMetric", "[", "g", "]"}]}], "//", 
            RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
           "ToValues"}], "//", "ToValues"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"BSEcomp", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.788426476784648*^9, 3.7884265383310413`*^9}, 
   3.7884275408139687`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}]}], 
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]]}], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.788426675981201*^9, 3.7884276697360373`*^9, 
  3.788848556133631*^9, 3.7889051910403647`*^9, 3.7889088068641443`*^9, 
  3.788917627001251*^9, 3.788938621579846*^9, 3.7891029920701675`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Matter sector", "Subsubsection",
 CellChangeTimes->{{3.7776918567665777`*^9, 3.7776918584310303`*^9}}],

Cell["\<\
The matter sector is defined by the perfect fluid in the usual way, i.e.,...\
\>", "Text",
 CellChangeTimes->{{3.777691860535028*^9, 3.777691879356771*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Tcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          RowBox[{"-", "b"}], ",", 
          RowBox[{"-", "c"}]}], "]"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
      "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Tcomp", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.777691882286499*^9, 3.777691908500108*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Rho]", "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "0", "0", "0"},
     {"0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776918927994843`*^9, 3.7776919090199127`*^9}, 
   3.7777750545163126`*^9, 3.777778980573655*^9, 3.7884268274638195`*^9, 
   3.788427716167909*^9, 3.788848556199932*^9, 3.7889051911093616`*^9, 
   3.7889088069236417`*^9, 3.788917627065139*^9, 3.788938621648364*^9, 
   3.789102992130675*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Friedmann equations", "Subsubsection",
 CellChangeTimes->{{3.777691578623334*^9, 3.777691581852126*^9}}],

Cell["\<\
By equating the gravity and matter sectors, we obtain the Friedmann equations.\
\>", "Text",
 CellChangeTimes->{{3.777691583933619*^9, 3.777691615951915*^9}, {
  3.7776916581539373`*^9, 3.777691737928487*^9}, {3.7884266393285503`*^9, 
  3.7884266610208783`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FE1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"MFEcomp", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "\[Kappa]"}], "]"}], 
      "\[Equal]", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"Tcomp", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ")"}], "/.", 
    RowBox[{
     RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{"MFEcomp", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", "\[Kappa]"}], "]"}], 
       "\[Equal]", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"Tcomp", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1", \
"\[IndentingNewLine]", "FE2"}], "Input",
 CellChangeTimes->{{3.7776916276755943`*^9, 3.7776916525962667`*^9}, {
  3.777691742666757*^9, 3.7776917856871977`*^9}, {3.777691925270817*^9, 
  3.77769195636649*^9}, {3.7776921465647984`*^9, 3.777692164420169*^9}, {
  3.777692242891243*^9, 3.777692257048708*^9}, {3.7777788092476945`*^9, 
  3.777778817884759*^9}, {3.7884268485204544`*^9, 3.7884268494349813`*^9}, {
  3.7884269343005066`*^9, 3.7884269377272415`*^9}, {3.78842699602457*^9, 
  3.7884270037644496`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], 
    RowBox[{"2", " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}]}]]}], "\[Equal]", 
  FractionBox[
   RowBox[{"\[Rho]", "[", "t", "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.7776917728469143`*^9, 3.7776919572971992`*^9, {3.777692153934587*^9, 
   3.777692172752434*^9}, 3.777692257530259*^9, 3.7777750545565844`*^9, 
   3.7777789805957794`*^9, 3.7884270057115955`*^9, 3.7884277363088484`*^9, 
   3.788848556242528*^9, 3.788905191140606*^9, 3.7889088069548855`*^9, 
   3.788917627085064*^9, 3.788938621671407*^9, 3.789102992177971*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}], "2"], " ", 
   RowBox[{"P", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7776917728469143`*^9, 3.7776919572971992`*^9, {3.777692153934587*^9, 
   3.777692172752434*^9}, 3.777692257530259*^9, 3.7777750545565844`*^9, 
   3.7777789805957794`*^9, 3.7884270057115955`*^9, 3.7884277363088484`*^9, 
   3.788848556242528*^9, 3.788905191140606*^9, 3.7889088069548855`*^9, 
   3.788917627085064*^9, 3.788938621671407*^9, 3.7891029921807775`*^9}]
}, Open  ]],

Cell["The scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.77769204849536*^9, 3.7776920855198097`*^9}, {
  3.7884272364589543`*^9, 3.788427254486044*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFE", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"BSEcomp", "\[Equal]", "0"}], ")"}], "/.", 
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "SFE"}], "Input",
 CellChangeTimes->{{3.7776920886511297`*^9, 3.777692119722003*^9}, {
   3.7776921676273823`*^9, 3.7776921698194113`*^9}, 3.788427262866313*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], 
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}]]}], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7776921202754517`*^9, 3.777692170398808*^9, 
  3.777775054698418*^9, 3.777778980689516*^9, 3.788427270308778*^9, 
  3.788427743549409*^9, 3.7888485562745795`*^9, 3.7889051911939845`*^9, 
  3.7889088070082717`*^9, 3.78891762712495*^9, 3.7889386217047157`*^9, 
  3.7891029922113056`*^9}]
}, Open  ]],

Cell[TextData[{
 "We can also express these in terms of the Hubble parameter, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "=", 
    RowBox[{
     RowBox[{"a", "'"}], "/", "a"}]}], TraditionalForm]]],
 ". The following rule does exactly this."
}], "Text",
 CellChangeTimes->{{3.777775493657487*^9, 3.7777755429139214`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleatoH", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "t", "]"}], 
          RowBox[{"a", "[", "t", "]"}]], "\[Equal]", 
         RowBox[{"H", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "t", "]"}], 
            RowBox[{"a", "[", "t", "]"}]], ",", "t"}], "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"a", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "ruleatoH"}], "Input",
 CellChangeTimes->{{3.7777755456033773`*^9, 3.7777756362451468`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], "+", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7777756367768545`*^9, 3.7777789807585144`*^9, 
  3.788427818790016*^9, 3.788848556358303*^9, 3.7889051912942233`*^9, 
  3.788908807055131*^9, 3.788917627164483*^9, 3.7889386218283215`*^9, 
  3.789102992295391*^9}]
}, Open  ]],

Cell["\<\
The Friedmann equations and the scalar field equation then become...\
\>", "Text",
 CellChangeTimes->{{3.7777756500826187`*^9, 3.7777756611479483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FE1H", "=", 
   RowBox[{
    RowBox[{"FE1", "/.", "ruleatoH"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE2H", "=", 
   RowBox[{
    RowBox[{"FE2", "/.", "ruleatoH"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFEH", "=", 
    RowBox[{
     RowBox[{"SFE", "/.", "ruleatoH"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1H", \
"\[IndentingNewLine]", "FE2H", "\[IndentingNewLine]", "SFEH"}], "Input",
 CellChangeTimes->{{3.777775662568621*^9, 3.7777757131341105`*^9}, {
  3.7777759224295654`*^9, 3.7777759337843575`*^9}, {3.777779779801956*^9, 
  3.7777797926685333`*^9}, {3.788427826568879*^9, 3.7884278321085043`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
   RowBox[{"6", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "3"]}]}], "\[Equal]", 
  RowBox[{"12", " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9, 3.788427833056518*^9, 
   3.7888485564295406`*^9, 3.7889051914100876`*^9, 3.788908807124131*^9, 
   3.7889176272326565`*^9, 3.7889386219555163`*^9, 3.7891029923939495`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      InterpretationBox[
       StyleBox["\[CapitalLambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[CapitalLambda],
       Editable->False]}], "+", 
     RowBox[{"12", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"P", "[", "t", "]"}]}], "+", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9, 3.788427833056518*^9, 
   3.7888485564295406`*^9, 3.7889051914100876`*^9, 3.788908807124131*^9, 
   3.7889176272326565`*^9, 3.7889386219555163`*^9, 3.7891029924075537`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9, 3.788427833056518*^9, 
   3.7888485564295406`*^9, 3.7889051914100876`*^9, 3.788908807124131*^9, 
   3.7889176272326565`*^9, 3.7889386219555163`*^9, 3.7891029924184303`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["III. Tailoring cosmologies",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.788428162925914*^9, 3.7884281677533183`*^9}}],

Cell["\<\
An important idea in \[OpenCurlyDoubleQuote]tailoring\[CloseCurlyDoubleQuote] \
cosmologies to cubic Horndeski theory is to realize that the scalar field \
equation is equivalent to a total divergence. Specifically, the scalar field \
equation...\
\>", "Text",
 CellChangeTimes->{{3.7884281800471416`*^9, 3.7884282480568185`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"J", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"3", 
       RowBox[{
        RowBox[{"G", "'"}], "[", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"]}], "]"}], 
       RowBox[{"H", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFEdiv", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "3"]], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "3"], 
            RowBox[{"J", "[", "t", "]"}]}], ",", "t"}], "]"}]}], "/.", 
        "ruleatoH"}], "//", "Simplify"}], ")"}], "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "SFEdiv"}], "Input",
 CellChangeTimes->{{3.7884282504904895`*^9, 3.7884283470441027`*^9}, {
  3.78842852585474*^9, 3.7884285582576227`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.788428562730221*^9, 3.788848603356041*^9, 
  3.7889052633069744`*^9, 3.788908807224372*^9, 3.7889176273224907`*^9, 
  3.788938622056029*^9, 3.789102992496089*^9}]
}, Open  ]],

Cell["\<\
It is easy to verify that the above expression for the total divergence is \
equivalent to the scalar field equation...\
\>", "Text",
 CellChangeTimes->{{3.7884284707306185`*^9, 3.788428495813598*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SFEH", "-", "SFEdiv"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7884284985397453`*^9, 3.788428506318221*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7884285023999405`*^9, 3.788428506771204*^9}, {
   3.7884285504227915`*^9, 3.7884285661723537`*^9}, 3.788848607880085*^9, 
   3.788905263369483*^9, 3.788908807255616*^9, 3.788917627343607*^9, 
   3.788938622081856*^9, 3.7891029925280027`*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, instead of solving the scalar field equation directly we treat the \
much simpler expression ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["J", "t"], "(", "t", ")"}], "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The more interesting branch here is of course given by..."
}], "Text",
 CellChangeTimes->{{3.788428691519598*^9, 3.788428764634631*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFEsurr", "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"3", 
       RowBox[{
        RowBox[{"G", "'"}], "[", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"]}], "]"}], 
       RowBox[{"H", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}]}]}], "\[Equal]", "0"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", "SFEsurr"}], "Input",
 CellChangeTimes->{{3.788428785709397*^9, 3.788428806386551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7884288067455626`*^9, 3.788848628666684*^9, 
  3.7889052633850727`*^9, 3.7889088072712383`*^9, 3.7889176273682857`*^9, 
  3.7889386221218143`*^9, 3.7891029925614057`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation of necessary conditions", "Subsubsection",
 CellChangeTimes->{{3.788428977933298*^9, 3.7884289816953373`*^9}, {
  3.788848885665118*^9, 3.7888488940415583`*^9}}],

Cell[TextData[{
 "So, we setup the model-independent necessary conditions for the tailoring \
procedure. Using SFEsurr to eliminate ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"G", "'"}], 
    RowBox[{"(", "X", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " from FE1H and FE2H leads to..."
}], "Text",
 CellChangeTimes->{{3.788428983930997*^9, 3.78842907514122*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Gsol", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"SFEsurr", ",", 
      RowBox[{
       RowBox[{"G", "'"}], "[", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox[
         RowBox[{
          RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"]}], "]"}]}], "]"}], 
    "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE1mi", "=", 
   RowBox[{
    RowBox[{"FE1H", "/.", "Gsol"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2mi", "=", 
    RowBox[{
     RowBox[{"FE2H", "/.", "Gsol"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1mi", "\
\[IndentingNewLine]", "FE2mi"}], "Input",
 CellChangeTimes->{{3.7884290807974396`*^9, 3.7884291693143787`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"12", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "\[Equal]", 
  RowBox[{
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"\[Rho]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.788429169832409*^9, 3.788848681473744*^9, 
  3.7889052634631777`*^9, 3.788908807355858*^9, 3.7889176274350967`*^9, 
  3.7889386222060523`*^9, 3.789102992653364*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      InterpretationBox[
       StyleBox["\[CapitalLambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[CapitalLambda],
       Editable->False]}], "+", 
     RowBox[{"12", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"P", "[", "t", "]"}]}], "+", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}]}]]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.788429169832409*^9, 3.788848681473744*^9, 
  3.7889052634631777`*^9, 3.788908807355858*^9, 3.7889176274350967`*^9, 
  3.7889386222060523`*^9, 3.789102992666484*^9}]
}, Open  ]],

Cell["\<\
From FE1mi, we obtain the following expression for the kinetic density...\
\>", "Text",
 CellChangeTimes->{{3.788429244575398*^9, 3.7884292627534037`*^9}, {
  3.7884293066477537`*^9, 3.7884293149155893`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"X0sol", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"FE1mi", "/.", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"], "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"X0", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{"X0", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<X\>\"", "\[Equal]", 
   RowBox[{"X0", "[", "t", "]"}]}], "/.", "X0sol"}]}], "Input",
 CellChangeTimes->{{3.788429317144647*^9, 3.7884294366554565`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"X\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.788429397371297*^9, 3.78842943940521*^9, 
  3.7888487836112895`*^9, 3.7889052634788*^9, 3.7889088073936105`*^9, 
  3.7889176274683757`*^9, 3.788938622239916*^9, 3.789102992684003*^9}]
}, Open  ]],

Cell[TextData[{
 "Now, we use FE1mi to eliminate the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in FE2mi. This can be done as follows... "
}], "Text",
 CellChangeTimes->{{3.7884294878589954`*^9, 3.7884295236873136`*^9}, {
  3.788429618651402*^9, 3.7884296227214804`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Phi]pp", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"FE1mi", ",", "t"}], "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]p", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"FE2mi", "/.", "\[Phi]pp"}], "/.", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"], "\[Rule]", 
          RowBox[{"2", 
           RowBox[{"X0", "[", "t", "]"}]}]}]}], "/.", "X0sol"}], "//", 
       "Simplify"}], ",", 
      RowBox[{
       RowBox[{"\[Rho]", "'"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CoE", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "'"}], "[", "t", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "'"}], "[", "t", "]"}], "/.", "\[Rho]p"}], ")"}]}]}],
   ";"}], "\[IndentingNewLine]", "CoE"}], "Input",
 CellChangeTimes->{{3.788429646357835*^9, 3.788429704135356*^9}, {
  3.7884297401345067`*^9, 3.7884298844779763`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Rho]", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"P", "[", "t", "]"}], "+", 
     RowBox[{"\[Rho]", "[", "t", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.788429659526778*^9, 3.788429704685803*^9}, {
   3.7884297629522734`*^9, 3.788429781152995*^9}, {3.7884298138898816`*^9, 
   3.788429885366251*^9}, 3.788848790335287*^9, 3.7889052635256653`*^9, 
   3.788908807409238*^9, 3.7889176275058947`*^9, 3.7889386222942605`*^9, 
   3.7891029927388315`*^9}]
}, Open  ]],

Cell["\<\
The conservation of energy appears as a necessary condition. An explanation \
to this is nicely offered in JCAP10(2019)058.

Lastly, instead of SFEsurr as it is, we express the scalar field in terms of \
its background kinetic density...\
\>", "Text",
 CellChangeTimes->{{3.7884298921493535`*^9, 3.788429946985384*^9}, {
  3.788848865610444*^9, 3.7888488668640203`*^9}, {3.7888489936363573`*^9, 
  3.788849046793713*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFEsurrX", "=", 
    RowBox[{
     RowBox[{"SFEsurr", "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"G", "'"}], "[", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"]}], "]"}], 
       "\[Rule]", 
       RowBox[{
        RowBox[{"G", "'"}], "[", "\[Chi]", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "\[Chi]"}]]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "SFEsurrX"}], "Input",
 CellChangeTimes->{{3.788849050265586*^9, 3.788849141584199*^9}, {
  3.788850972510953*^9, 3.7888509803671474`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"3", " ", 
    SqrtBox["2"], " ", 
    SqrtBox["\[Chi]"], " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "\[Chi]", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7888491420275345`*^9, 3.788850982311535*^9, 
  3.788905263556908*^9, 3.788908807440481*^9, 3.788917627527458*^9, 
  3.78893862232225*^9, 3.789102992767891*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary of necessary conditions", "Subsubsection",
 CellChangeTimes->{{3.7888488718965654`*^9, 3.7888488999876604`*^9}}],

Cell["The necessary conditions for the tailoring process are...", "Text",
 CellChangeTimes->{{3.7888489079167786`*^9, 3.788848917528367*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nc1", "=", 
   RowBox[{
    RowBox[{"CoE", "/.", 
     RowBox[{
      RowBox[{"P", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"w", " ", 
       RowBox[{"\[Rho]", "[", "t", "]"}]}]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nc2", "=", 
   RowBox[{"\[Chi]", "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"X0", "[", "t", "]"}], "/.", "X0sol"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nc3", "=", "SFEsurrX"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "nc1", \
"\[IndentingNewLine]", "nc2", "\[IndentingNewLine]", "nc3"}], "Input",
 CellChangeTimes->{{3.7888489192341766`*^9, 3.788848941413492*^9}, {
  3.7888491490452976`*^9, 3.788849171766621*^9}, {3.788849234262475*^9, 
  3.788849249372796*^9}, {3.788849901817151*^9, 3.788849916121752*^9}, {
  3.7888505422852726`*^9, 3.7888505596154785`*^9}, {3.788850611210183*^9, 
  3.788850619054702*^9}, {3.7888509888070655`*^9, 3.7888509900690703`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Rho]", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "w"}], ")"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7888491665026283`*^9, 3.788849249980394*^9, {3.7888499099788857`*^9, 
   3.7888499166695614`*^9}, 3.7888505609501715`*^9, {3.788850612804449*^9, 
   3.7888506195338726`*^9}, 3.788850992555314*^9, 3.788905263572528*^9, 
   3.7889088074717245`*^9, 3.788917627551921*^9, 3.7889386223630943`*^9, 
   3.7891029927938223`*^9}],

Cell[BoxData[
 RowBox[{"\[Chi]", "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7888491665026283`*^9, 3.788849249980394*^9, {3.7888499099788857`*^9, 
   3.7888499166695614`*^9}, 3.7888505609501715`*^9, {3.788850612804449*^9, 
   3.7888506195338726`*^9}, 3.788850992555314*^9, 3.788905263572528*^9, 
   3.7889088074717245`*^9, 3.788917627551921*^9, 3.7889386223630943`*^9, 
   3.7891029927976446`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"3", " ", 
    SqrtBox["2"], " ", 
    SqrtBox["\[Chi]"], " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "\[Chi]", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.7888491665026283`*^9, 3.788849249980394*^9, {3.7888499099788857`*^9, 
   3.7888499166695614`*^9}, 3.7888505609501715`*^9, {3.788850612804449*^9, 
   3.7888506195338726`*^9}, 3.788850992555314*^9, 3.788905263572528*^9, 
   3.7889088074717245`*^9, 3.788917627551921*^9, 3.7889386223630943`*^9, 
   3.789102992800646*^9}]
}, Open  ]],

Cell[TextData[{
 "The tailoring process moves on in the following way:\n(1) nc1 is solved for \
\[Rho] provided the expansion history ",
 StyleBox["H",
  FontSlant->"Italic"],
 ";",
 StyleBox["\n",
  FontSlant->"Italic"],
 "(2) \[Rho] is substituted into nc2 to solve for the background kinetic \
density \[Chi];\n(3) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Chi]", "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is inverted for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", 
    RowBox[{"T", "(", "\[Chi]", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and substituted into ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{"H", "(", 
      RowBox[{"T", "(", "\[Chi]", ")"}], ")"}], "=", 
     RowBox[{"H", "(", "\[Chi]", ")"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " of nc3 to determine ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"G", "'"}], 
    RowBox[{"(", "\[Chi]", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.7888492621629844`*^9, 3.7888493599571853`*^9}, {
  3.7888495101251326`*^9, 3.7888495347899027`*^9}, {3.7888495841609726`*^9, 
  3.7888496354851513`*^9}, {3.788851002646011*^9, 3.788851030189417*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 1: de Sitter cosmology", "Subsubsection",
 CellChangeTimes->{{3.78884971937906*^9, 3.78884972818084*^9}}],

Cell["\<\
As an example, we construct the cubic Horndeski theory supporting an \
inflationary/de Sitter expansion. For this, the Hubble parameter is a \
constant, thus, we set...\
\>", "Text",
 CellChangeTimes->{{3.7888497305142717`*^9, 3.7888497467495995`*^9}, {
  3.7888498341868024`*^9, 3.7888498779933987`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex1", "=", 
   RowBox[{"H", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", "h"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7888499350466156`*^9, 3.7888499802299414`*^9}}],

Cell["First, solving nc1 for \[Rho]...", "Text",
 CellChangeTimes->{{3.788849984876136*^9, 3.788849997188491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex1step1", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"nc1", "/.", "ex1"}], ",", "\[Rho]", ",", "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\[Rho]\>\"", "\[Equal]", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}], "/.", "ex1step1"}]}], "Input",
 CellChangeTimes->{{3.788849998161337*^9, 3.7888500428262963`*^9}, {
  3.7888500908298225`*^9, 3.7888501177071095`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,96,1,16586475524527909951,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.7888500109656224`*^9, 3.788850044442299*^9}, 
   3.788850118356639*^9, 3.7888506271769905`*^9, 3.7888510376938076`*^9, 
   3.7889052637952995`*^9, 3.7889088075940943`*^9, 3.7889176276415014`*^9, 
   3.7889386225213537`*^9, 3.7891029929826207`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Rho]\"\>", "\[Equal]", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"h", "+", 
       RowBox[{"h", " ", "w"}]}], ")"}]}]], " ", 
   RowBox[{"C", "[", "1", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7888500109719057`*^9, 3.788850044464205*^9}, 
   3.788850118376217*^9, 3.7888506271987295`*^9, 3.7888510377155485`*^9, 
   3.7889052637952995`*^9, 3.7889088075940943`*^9, 3.788917627644919*^9, 
   3.7889386225275908`*^9, 3.789102992988223*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " then becomes..."
}], "Text",
 CellChangeTimes->{{3.7888502169656143`*^9, 3.7888502387609406`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex1step2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"nc2", "/.", "ex1"}], "/.", "ex1step1"}], "//", "Simplify"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\[Chi]\>\"", "\[Equal]", "\[Chi]"}], "/.", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"ex1step2", ",", "\[Chi]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.788850241602615*^9, 3.788850311062935*^9}, {
  3.7888510771937456`*^9, 3.7888510935443354`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Chi]\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", 
    SuperscriptBox["h", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "h", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}]}]], " ", 
    RowBox[{"C", "[", "1", "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7888502470257044`*^9, 3.788850274304349*^9}, 
   3.7888503117871513`*^9, 3.788850629910434*^9, 3.788851047815218*^9, 
   3.7888510958092875`*^9, 3.7889052638735447`*^9, 3.788908807672205*^9, 
   3.7889176277195654`*^9, 3.7889386226218114`*^9, 3.7891029930614357`*^9}]
}, Open  ]],

Cell[TextData[{
 "Lastly, inverting the last expression for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "(", "X", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.7888503194331098`*^9, 3.7888503728870015`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ex1step3", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"ex1step2", ",", "t"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", "ex1step3"}]], "Input",
 CellChangeTimes->{{3.7888503817115564`*^9, 3.7888503864694443`*^9}, {
   3.788850636816462*^9, 3.7888507366304836`*^9}, {3.788850776057653*^9, 
   3.7888507829643764`*^9}, 3.7888511197534857`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
        RowBox[{"C", "[", "2", "]"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox["Log",
          ShowAutoStyles->False,
          AutoSpacing->False],
         Log,
         Editable->False], "[", 
        FractionBox[
         RowBox[{"C", "[", "1", "]"}], 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox["h", "2"], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False]}], "-", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[CapitalLambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[CapitalLambda],
            Editable->False]}], "+", "\[Chi]"}]], "]"}]}], 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}]}]], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7888503873378544`*^9, {3.788850652200759*^9, 3.7888506598943443`*^9}, {
   3.7888507027317605`*^9, 3.7888507129170866`*^9}, {3.788850777249072*^9, 
   3.788850785198718*^9}, 3.7888511220873814`*^9, 3.7889052639202566`*^9, 
   3.7889088076943417`*^9, 3.788917627745331*^9, 3.7889386226550283`*^9, 
   3.789102993101366*^9}]
}, Open  ]],

Cell[TextData[{
 "In this case, however, the Hubble parameter ",
 StyleBox["H",
  FontSlant->"Italic"],
 " is already constant. So, using nc3, we determine that the model function ",
 StyleBox["G",
  FontSlant->"Italic"],
 " must be..."
}], "Text",
 CellChangeTimes->{{3.7888507883230977`*^9, 3.788850791623579*^9}, {
  3.788850857547958*^9, 3.7888508968385077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex1G", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"nc3", "/.", "ex1"}], ",", 
       RowBox[{
        RowBox[{"G", "'"}], "[", "\[Chi]", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"G\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\[Chi]\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\"", "\[Equal]", 
   RowBox[{
    RowBox[{"G", "'"}], "[", "\[Chi]", "]"}]}], "/.", "ex1G"}]}], "Input",
 CellChangeTimes->{{3.7888508982343636`*^9, 3.788850900490249*^9}, {
  3.788850931466441*^9, 3.7888509408199873`*^9}, {3.788851143001395*^9, 
  3.788851204941145*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"G\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\[Chi]\\!\\(\\*\
\\nStyleBox[\\\")\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox["1", 
    RowBox[{"3", " ", 
     SqrtBox["2"], " ", "h", " ", 
     SqrtBox["\[Chi]"]}]]}]}]], "Output",
 CellChangeTimes->{
  3.7888509009996595`*^9, 3.7888511507548585`*^9, {3.78885119497816*^9, 
   3.7888512075815225`*^9}, 3.788905263951497*^9, 3.788908807725591*^9, 
   3.7889176277681303`*^9, 3.788938622692436*^9, 3.7891029931277647`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7888498797782183`*^9, 3.7888498819049206`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example II: radiation-domination ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "(", "t", ")"}], "~", 
    SuperscriptBox["t", 
     RowBox[{"1", "/", "2"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.7888512187396326`*^9, 3.7888512218508453`*^9}, {
  3.7888513456278296`*^9, 3.7888513918871164`*^9}, {3.7888514549427853`*^9, 
  3.78885145642165*^9}}],

Cell[TextData[{
 "For this case, we start with the scale factor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.788851417495996*^9, 3.7888514406325655`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wrad", "=", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{"1", "/", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], "=", 
   RowBox[{"ai", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["t", "ti"], ")"}], "n"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7888514421128635`*^9, 3.788851483162587*^9}, {
  3.7888519577676563`*^9, 3.788851963474532*^9}}],

Cell["The Hubble parameter is then given by...", "Text",
 CellChangeTimes->{{3.788851490912898*^9, 3.788851509488881*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex2", "=", 
    RowBox[{"H", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"a", "[", "t", "]"}], ",", "t"}], "]"}], 
          RowBox[{"a", "[", "t", "]"}]], "//", "Simplify"}], ")"}]}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)\>\"", "\[Equal]", 
   RowBox[{"H", "[", "t", "]"}]}], "/.", "ex2"}]}], "Input",
 CellChangeTimes->{{3.7888515106260395`*^9, 3.788851589527378*^9}, {
  3.7888516201187015`*^9, 3.7888516335481853`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>", "\[Equal]", 
  FractionBox["1", 
   RowBox[{"2", " ", "t"}]]}]], "Output",
 CellChangeTimes->{3.7888516340106244`*^9, 3.7888519723552036`*^9, 
  3.7889052639983616`*^9, 3.7889088078102293`*^9, 3.7889176278292127`*^9, 
  3.7889386227339144`*^9, 3.789102993172922*^9}]
}, Open  ]],

Cell["Substituting this Hubble parameter into nc1, we obtain...", "Text",
 CellChangeTimes->{{3.788851741501442*^9, 3.788851772765274*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex2step1", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"nc1", "/.", "ex2"}], "/.", "wrad"}], ",", "\[Rho]", ",", 
       "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\[Rho]\>\"", "\[Equal]", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}], "/.", "ex2step1"}]}], "Input",
 CellChangeTimes->{{3.788851687799507*^9, 3.7888517248388906`*^9}, {
  3.788851980497302*^9, 3.788851985993537*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,109,2,16586475524527909951,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.7888517105572753`*^9, 3.7888517253500834`*^9}, 
   3.7888519865197706`*^9, 3.7889052640296054`*^9, 3.788908807857098*^9, 
   3.7889176278567624`*^9, 3.7889386227697573`*^9, 3.7891029932131553`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Rho]\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{"C", "[", "1", "]"}], 
   SuperscriptBox["t", "2"]]}]], "Output",
 CellChangeTimes->{{3.788851688554294*^9, 3.788851725371558*^9}, 
   3.788851986539028*^9, 3.7889052640296054`*^9, 3.788908807857098*^9, 
   3.7889176278707356`*^9, 3.7889386227730293`*^9, 3.789102993216942*^9}]
}, Open  ]],

Cell["This then determines the kinetic density...", "Text",
 CellChangeTimes->{{3.7888517783850164`*^9, 3.78885178776694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ex2step2", "=", 
   RowBox[{
    RowBox[{"nc2", "/.", "ex2"}], "/.", "ex2step1"}]}], ";", 
  "ex2step2"}]], "Input",
 CellChangeTimes->{{3.7888517901698856`*^9, 3.7888517997214975`*^9}, {
  3.788851887857992*^9, 3.7888518940319624`*^9}}],

Cell[BoxData[
 RowBox[{"\[Chi]", "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["t", "2"]}]]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[CapitalLambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[CapitalLambda],
     Editable->False]}], "+", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox["t", "2"]]}]}]], "Output",
 CellChangeTimes->{3.7888518000338287`*^9, 3.7888518944697604`*^9, 
  3.788851997456015*^9, 3.7889052640549936`*^9, 3.7889088078883505`*^9, 
  3.7889176278924975`*^9, 3.7889386227894464`*^9, 3.7891029932297645`*^9}]
}, Open  ]],

Cell[TextData[{
 "Finally, we solve the last expression for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "(", "\[Chi]", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.788851900549164*^9, 3.7888519024186335`*^9}, {
  3.7888520196426926`*^9, 3.788852033379862*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "we", " ", "take", " ", "only", " ", "the", " ", "root", " ", "with", " ", 
    "positive", " ", "time"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ex2step3", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"ex2step2", ",", "t"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";", "ex2step3"}]}]], "Input",
 CellChangeTimes->{{3.788852035967865*^9, 3.788852041939155*^9}, {
  3.78885207540162*^9, 3.7888521669250855`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   FractionBox[
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"C", "[", "1", "]"}]}]}]], 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[CapitalLambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[CapitalLambda],
        Editable->False]}], "+", 
      RowBox[{"2", " ", "\[Chi]"}]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.7888521673764625`*^9, 3.7889052640706196`*^9, 
  3.788908807910494*^9, 3.788917627915552*^9, 3.788938622806402*^9, 
  3.789102993261741*^9}]
}, Open  ]],

Cell["The model function is then given by...", "Text",
 CellChangeTimes->{{3.788852207384311*^9, 3.7888522430026674`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ex2G", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nc3", "/.", "ex2"}], "/.", "ex2step3"}], ",", 
     RowBox[{
      RowBox[{"G", "'"}], "[", "\[Chi]", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.788852286833577*^9, 3.788852324093006*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "\[Prime]",
     MultilineFunction->None], "[", "\[Chi]", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"C", "[", "1", "]"}]}]}]], 
     RowBox[{"3", " ", 
      SqrtBox["\[Chi]"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         InterpretationBox[
          StyleBox["\[CapitalLambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[CapitalLambda],
          Editable->False]}], "+", "\[Chi]"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7888522876583886`*^9, 3.788852325291281*^9}, 
   3.788905264086237*^9, 3.7889088079417443`*^9, 3.7889176279407196`*^9, 
   3.7889386228234406`*^9, 3.789102993294896*^9}]
}, Open  ]],

Cell["", "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{857, 943},
WindowMargins->{{19, Automatic}, {Automatic, 96}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 132, 1, 70, "Section"],
Cell[715, 25, 122, 2, 30, "Input"],
Cell[840, 29, 245, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[1110, 38, 178, 3, 49, "Subsection"],
Cell[CellGroupData[{
Cell[1313, 45, 3047, 84, 1106, "Input"],
Cell[CellGroupData[{
Cell[4385, 133, 596, 8, 51, "Print"],
Cell[4984, 143, 865, 15, 51, "Print"],
Cell[5852, 160, 615, 8, 94, "Print"],
Cell[6470, 170, 574, 7, 51, "Print"],
Cell[7047, 179, 555, 7, 51, "Print"],
Cell[7605, 188, 593, 8, 51, "Print"],
Cell[8201, 198, 872, 16, 51, "Print"],
Cell[9076, 216, 617, 8, 94, "Print"],
Cell[9696, 226, 594, 8, 51, "Print"],
Cell[10293, 236, 865, 15, 51, "Print"],
Cell[11161, 253, 663, 9, 94, "Print"],
Cell[11827, 264, 596, 8, 51, "Print"],
Cell[12426, 274, 751, 10, 178, "Print"],
Cell[13180, 286, 594, 8, 51, "Print"],
Cell[13777, 296, 838, 15, 51, "Print"],
Cell[14618, 313, 920, 16, 51, "Print"],
Cell[15541, 331, 1021, 16, 94, "Print"],
Cell[16565, 349, 981, 16, 51, "Print"],
Cell[17549, 367, 997, 16, 51, "Print"],
Cell[18549, 385, 594, 8, 51, "Print"],
Cell[19146, 395, 863, 15, 51, "Print"],
Cell[20012, 412, 633, 8, 94, "Print"],
Cell[20648, 422, 593, 8, 51, "Print"],
Cell[21244, 432, 749, 10, 178, "Print"],
Cell[21996, 444, 596, 8, 51, "Print"],
Cell[22595, 454, 928, 16, 51, "Print"],
Cell[23526, 472, 938, 16, 51, "Print"],
Cell[24467, 490, 1085, 21, 51, "Print"],
Cell[25555, 513, 1190, 23, 51, "Print"],
Cell[26748, 538, 1163, 22, 51, "Print"],
Cell[27914, 562, 1183, 22, 51, "Print"],
Cell[29100, 586, 1012, 18, 51, "Print"],
Cell[30115, 606, 1136, 22, 51, "Print"],
Cell[31254, 630, 1154, 23, 94, "Print"],
Cell[32411, 655, 1178, 23, 51, "Print"],
Cell[33592, 680, 1096, 21, 51, "Print"],
Cell[34691, 703, 605, 8, 51, "Print"],
Cell[35299, 713, 977, 16, 51, "Print"],
Cell[36279, 731, 607, 8, 51, "Print"],
Cell[36889, 741, 1110, 21, 51, "Print"],
Cell[38002, 764, 1165, 22, 51, "Print"],
Cell[39170, 788, 1106, 21, 51, "Print"],
Cell[40279, 811, 994, 17, 51, "Print"],
Cell[41276, 830, 740, 12, 51, "Print"],
Cell[42019, 844, 730, 12, 51, "Print"],
Cell[42752, 858, 744, 12, 51, "Print"],
Cell[43499, 872, 998, 17, 51, "Print"],
Cell[44500, 891, 953, 16, 51, "Print"],
Cell[45456, 909, 952, 16, 51, "Print"],
Cell[46411, 927, 972, 17, 51, "Print"],
Cell[47386, 946, 988, 17, 51, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[48435, 970, 151, 2, 41, "Subsection"],
Cell[48589, 974, 168, 3, 4305, "Text"],
Cell[48760, 979, 16940, 426, 263154, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[65737, 1410, 168, 2, 41, "Subsection"],
Cell[65908, 1414, 154, 3, 68, "Text"],
Cell[CellGroupData[{
Cell[66087, 1421, 1504, 44, 325, "Input"],
Cell[67594, 1467, 2782, 90, 123, "Output"]
}, Open  ]],
Cell[70391, 1560, 269, 5, 154, "Text"],
Cell[CellGroupData[{
Cell[70685, 1569, 117, 1, 88, "Subsubsection"],
Cell[70805, 1572, 516, 15, 199, "Text"],
Cell[CellGroupData[{
Cell[71346, 1591, 728, 18, 235, "Input"],
Cell[CellGroupData[{
Cell[72099, 1613, 644, 13, 51, "Print"],
Cell[72746, 1628, 834, 17, 51, "Print"]
}, Open  ]],
Cell[73595, 1648, 15456, 479, 411, "Output"]
}, Open  ]],
Cell[89066, 2130, 198, 2, 68, "Text"],
Cell[CellGroupData[{
Cell[89289, 2136, 514, 14, 190, "Input"],
Cell[89806, 2152, 14325, 457, 339, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[104192, 2616, 164, 2, 41, "Subsection"],
Cell[104359, 2620, 254, 5, 111, "Text"],
Cell[CellGroupData[{
Cell[104638, 2629, 104, 1, 88, "Subsubsection"],
Cell[104745, 2632, 130, 3, 68, "Text"],
Cell[CellGroupData[{
Cell[104900, 2639, 2263, 62, 512, "Input"],
Cell[CellGroupData[{
Cell[107188, 2705, 819, 15, 51, "Print"],
Cell[108010, 2722, 873, 16, 51, "Print"],
Cell[108886, 2740, 875, 16, 51, "Print"],
Cell[109764, 2758, 875, 16, 51, "Print"],
Cell[110642, 2776, 872, 16, 51, "Print"],
Cell[111517, 2794, 831, 15, 51, "Print"],
Cell[112351, 2811, 847, 15, 51, "Print"],
Cell[113201, 2828, 998, 20, 56, "Print"],
Cell[114202, 2850, 1005, 20, 56, "Print"],
Cell[115210, 2872, 861, 16, 51, "Print"],
Cell[116074, 2890, 919, 17, 51, "Print"],
Cell[116996, 2909, 1043, 21, 51, "Print"],
Cell[118042, 2932, 1061, 22, 94, "Print"],
Cell[119106, 2956, 1091, 22, 94, "Print"],
Cell[120200, 2980, 1007, 20, 51, "Print"],
Cell[121210, 3002, 1017, 19, 51, "Print"],
Cell[122230, 3023, 1109, 23, 94, "Print"],
Cell[123342, 3048, 859, 15, 51, "Print"],
Cell[124204, 3065, 1984, 47, 57, "Print"],
Cell[126191, 3114, 1961, 46, 57, "Print"],
Cell[128155, 3162, 1963, 46, 57, "Print"],
Cell[130121, 3210, 1963, 46, 57, "Print"],
Cell[132087, 3258, 3188, 79, 57, "Print"],
Cell[135278, 3339, 2360, 61, 57, "Print"],
Cell[137641, 3402, 1961, 46, 57, "Print"],
Cell[139605, 3450, 1961, 46, 57, "Print"],
Cell[141569, 3498, 3188, 79, 57, "Print"],
Cell[144760, 3579, 3186, 79, 57, "Print"],
Cell[147949, 3660, 2362, 61, 57, "Print"],
Cell[150314, 3723, 1963, 46, 57, "Print"],
Cell[152280, 3771, 3188, 79, 57, "Print"],
Cell[155471, 3852, 3188, 79, 57, "Print"],
Cell[158662, 3933, 3188, 79, 57, "Print"],
Cell[161853, 4014, 2362, 61, 57, "Print"],
Cell[164218, 4077, 907, 16, 51, "Print"],
Cell[165128, 4095, 1012, 19, 51, "Print"]
}, Open  ]]
}, Open  ]],
Cell[166167, 4118, 374, 10, 111, "Text"],
Cell[CellGroupData[{
Cell[166566, 4132, 3525, 108, 730, "Input"],
Cell[CellGroupData[{
Cell[170116, 4244, 895, 17, 51, "Print"],
Cell[171014, 4263, 3123, 78, 57, "Print"],
Cell[174140, 4343, 2152, 54, 57, "Print"],
Cell[176295, 4399, 1902, 45, 57, "Print"],
Cell[178200, 4446, 1902, 45, 57, "Print"],
Cell[180105, 4493, 1902, 45, 57, "Print"],
Cell[182010, 4540, 3125, 78, 57, "Print"],
Cell[185138, 4620, 1902, 45, 57, "Print"],
Cell[187043, 4667, 3123, 78, 57, "Print"],
Cell[190169, 4747, 2113, 53, 57, "Print"],
Cell[192285, 4802, 1899, 45, 57, "Print"],
Cell[194187, 4849, 1900, 45, 57, "Print"],
Cell[196090, 4896, 3125, 78, 57, "Print"],
Cell[199218, 4976, 1902, 45, 57, "Print"],
Cell[201123, 5023, 3125, 78, 57, "Print"],
Cell[204251, 5103, 1898, 45, 57, "Print"],
Cell[206152, 5150, 3123, 78, 57, "Print"],
Cell[209278, 5230, 2115, 53, 57, "Print"],
Cell[211396, 5285, 1900, 45, 57, "Print"],
Cell[213299, 5332, 3125, 78, 57, "Print"],
Cell[216427, 5412, 1900, 45, 57, "Print"],
Cell[218330, 5459, 3125, 78, 57, "Print"],
Cell[221458, 5539, 1902, 45, 57, "Print"],
Cell[223363, 5586, 3125, 78, 57, "Print"],
Cell[226491, 5666, 1900, 45, 57, "Print"],
Cell[228394, 5713, 3123, 78, 57, "Print"],
Cell[231520, 5793, 2113, 53, 57, "Print"],
Cell[233636, 5848, 12425, 314, 100, "Print"],
Cell[246064, 6164, 12425, 314, 100, "Print"],
Cell[258492, 6480, 12423, 314, 100, "Print"],
Cell[270918, 6796, 12425, 314, 100, "Print"],
Cell[283346, 7112, 3126, 78, 57, "Print"],
Cell[286475, 7192, 24296, 619, 107, "Print"],
Cell[310774, 7813, 12425, 314, 100, "Print"],
Cell[323202, 8129, 12423, 314, 100, "Print"],
Cell[335628, 8445, 12423, 314, 100, "Print"],
Cell[348054, 8761, 3127, 78, 57, "Print"],
Cell[351184, 8841, 24296, 619, 107, "Print"],
Cell[375483, 9462, 3129, 78, 57, "Print"],
Cell[378615, 9542, 24296, 619, 107, "Print"],
Cell[402914, 10163, 12423, 314, 100, "Print"],
Cell[415340, 10479, 12425, 314, 100, "Print"],
Cell[427768, 10795, 3127, 78, 57, "Print"],
Cell[430898, 10875, 24298, 619, 107, "Print"],
Cell[455199, 11496, 3127, 78, 57, "Print"],
Cell[458329, 11576, 24296, 619, 107, "Print"],
Cell[482628, 12197, 3127, 78, 57, "Print"],
Cell[485758, 12277, 24296, 619, 107, "Print"],
Cell[510057, 12898, 12423, 314, 100, "Print"],
Cell[522483, 13214, 4663, 117, 57, "Print"]
}, Open  ]],
Cell[527161, 13334, 3273, 99, 221, "Output"],
Cell[CellGroupData[{
Cell[530459, 13437, 816, 15, 51, "Print"],
Cell[531278, 13454, 1256, 33, 51, "Print"]
}, Open  ]]
}, Open  ]],
Cell[532561, 13491, 146, 1, 68, "Text"],
Cell[CellGroupData[{
Cell[532732, 13496, 367, 11, 190, "Input"],
Cell[533102, 13509, 848, 24, 123, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[533999, 13539, 211, 3, 1067, "Subsubsection"],
Cell[534213, 13544, 177, 2, 1892, "Text"],
Cell[534393, 13548, 7130, 221, 8461, "Input"],
Cell[541526, 13771, 261, 5, 3098, "Text"],
Cell[CellGroupData[{
Cell[541812, 13780, 763, 19, 9087, "Input"],
Cell[542578, 13801, 23146, 734, 70, "Output"]
}, Open  ]],
Cell[565739, 14538, 139, 1, 1892, "Text"],
Cell[CellGroupData[{
Cell[565903, 14543, 799, 22, 9087, "Input"],
Cell[566705, 14567, 11476, 401, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[578230, 14974, 108, 1, 834, "Subsubsection"],
Cell[578341, 14977, 166, 3, 1892, "Text"],
Cell[CellGroupData[{
Cell[578532, 14984, 543, 16, 6568, "Input"],
Cell[579078, 15002, 3043, 97, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[582170, 15105, 110, 1, 834, "Subsubsection"],
Cell[582283, 15108, 272, 5, 586, "Text"],
Cell[CellGroupData[{
Cell[582580, 15117, 1662, 47, 1897, "Input"],
Cell[584245, 15166, 3324, 108, 70, "Output"],
Cell[587572, 15276, 4358, 145, 70, "Output"]
}, Open  ]],
Cell[591945, 15424, 174, 2, 358, "Text"],
Cell[CellGroupData[{
Cell[592144, 15430, 436, 11, 1002, "Input"],
Cell[592583, 15443, 8151, 271, 70, "Output"]
}, Open  ]],
Cell[600749, 15717, 329, 9, 586, "Text"],
Cell[CellGroupData[{
Cell[601103, 15730, 1023, 31, 1511, "Input"],
Cell[602129, 15763, 1532, 51, 70, "Output"]
}, Open  ]],
Cell[603676, 15817, 162, 3, 358, "Text"],
Cell[CellGroupData[{
Cell[603863, 15824, 778, 20, 1954, "Input"],
Cell[604644, 15846, 2244, 71, 70, "Output"],
Cell[606891, 15919, 3218, 101, 70, "Output"],
Cell[610112, 16022, 5764, 182, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[615937, 16211, 169, 2, 41, "Subsection"],
Cell[616109, 16215, 340, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[616474, 16225, 1296, 41, 133, "Input"],
Cell[617773, 16268, 5631, 180, 80, "Output"]
}, Open  ]],
Cell[623419, 16451, 211, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[623655, 16459, 156, 3, 30, "Input"],
Cell[623814, 16464, 295, 4, 30, "Output"]
}, Open  ]],
Cell[624124, 16471, 424, 11, 53, "Text"],
Cell[CellGroupData[{
Cell[624573, 16486, 611, 18, 89, "Input"],
Cell[625187, 16506, 1271, 40, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[626495, 16551, 178, 2, 39, "Subsubsection"],
Cell[626676, 16555, 393, 11, 1347, "Text"],
Cell[CellGroupData[{
Cell[627094, 16570, 852, 27, 4427, "Input"],
Cell[627949, 16599, 1093, 35, 70, "Output"],
Cell[629045, 16636, 2462, 79, 70, "Output"]
}, Open  ]],
Cell[631522, 16718, 218, 4, 823, "Text"],
Cell[CellGroupData[{
Cell[631765, 16726, 686, 20, 2380, "Input"],
Cell[632454, 16748, 772, 22, 70, "Output"]
}, Open  ]],
Cell[633241, 16773, 351, 9, 1347, "Text"],
Cell[CellGroupData[{
Cell[633617, 16786, 1342, 41, 3574, "Input"],
Cell[634962, 16829, 666, 16, 70, "Output"]
}, Open  ]],
Cell[635643, 16848, 431, 9, 2918, "Text"],
Cell[CellGroupData[{
Cell[636099, 16861, 776, 24, 2780, "Input"],
Cell[636878, 16887, 631, 19, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[637558, 16912, 126, 1, 33, "Subsubsection"],
Cell[637687, 16915, 141, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[637853, 16920, 1036, 26, 145, "Input"],
Cell[638892, 16948, 670, 16, 30, "Output"],
Cell[639565, 16966, 909, 25, 30, "Output"],
Cell[640477, 16993, 793, 22, 33, "Output"]
}, Open  ]],
Cell[641285, 17018, 1311, 41, 89, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[642633, 17064, 119, 1, 39, "Subsubsection"],
Cell[642755, 17067, 315, 6, 1872, "Text"],
Cell[643073, 17075, 232, 6, 1200, "Input"],
Cell[643308, 17083, 114, 1, 823, "Text"],
Cell[CellGroupData[{
Cell[643447, 17088, 539, 14, 2304, "Input"],
Cell[643989, 17104, 497, 9, 70, "Message"],
Cell[644489, 17115, 564, 13, 70, "Output"]
}, Open  ]],
Cell[645068, 17131, 229, 7, 823, "Text"],
Cell[CellGroupData[{
Cell[645322, 17142, 556, 15, 2304, "Input"],
Cell[645881, 17159, 1034, 29, 70, "Output"]
}, Open  ]],
Cell[646930, 17191, 263, 8, 823, "Text"],
Cell[CellGroupData[{
Cell[647218, 17203, 410, 9, 1200, "Input"],
Cell[647631, 17214, 1622, 45, 70, "Output"]
}, Open  ]],
Cell[649268, 17262, 367, 10, 1368, "Text"],
Cell[CellGroupData[{
Cell[649660, 17276, 785, 24, 2304, "Input"],
Cell[650448, 17302, 623, 12, 70, "Output"]
}, Open  ]],
Cell[651086, 17317, 96, 1, 850, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[651219, 17323, 435, 12, 33, "Subsubsection"],
Cell[651657, 17337, 265, 8, 823, "Text"],
Cell[651925, 17347, 533, 16, 2780, "Input"],
Cell[652461, 17365, 122, 1, 823, "Text"],
Cell[CellGroupData[{
Cell[652608, 17370, 733, 21, 2865, "Input"],
Cell[653344, 17393, 366, 7, 70, "Output"]
}, Open  ]],
Cell[653725, 17403, 139, 1, 823, "Text"],
Cell[CellGroupData[{
Cell[653889, 17408, 576, 16, 2304, "Input"],
Cell[654468, 17426, 448, 8, 70, "Message"],
Cell[654919, 17436, 357, 7, 70, "Output"]
}, Open  ]],
Cell[655291, 17446, 126, 1, 823, "Text"],
Cell[CellGroupData[{
Cell[655442, 17451, 272, 7, 1200, "Input"],
Cell[655717, 17460, 867, 26, 70, "Output"]
}, Open  ]],
Cell[656599, 17489, 317, 9, 823, "Text"],
Cell[CellGroupData[{
Cell[656941, 17502, 512, 13, 2304, "Input"],
Cell[657456, 17517, 891, 29, 70, "Output"]
}, Open  ]],
Cell[658362, 17549, 122, 1, 823, "Text"],
Cell[CellGroupData[{
Cell[658509, 17554, 352, 10, 1200, "Input"],
Cell[658864, 17566, 1244, 40, 70, "Output"]
}, Open  ]],
Cell[660123, 17609, 16, 0, 823, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

